Class: Authentik::Api::AccountLockdownStageRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/account_lockdown_stage_request.rb

Overview

AccountLockdownStage Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountLockdownStageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AccountLockdownStageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AccountLockdownStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'deactivate_user')
    self.deactivate_user = attributes[:'deactivate_user']
  end

  if attributes.key?(:'set_unusable_password')
    self.set_unusable_password = attributes[:'set_unusable_password']
  end

  if attributes.key?(:'delete_sessions')
    self.delete_sessions = attributes[:'delete_sessions']
  end

  if attributes.key?(:'revoke_tokens')
    self.revoke_tokens = attributes[:'revoke_tokens']
  end

  if attributes.key?(:'self_service_completion_flow')
    self.self_service_completion_flow = attributes[:'self_service_completion_flow']
  end
end

Instance Attribute Details

#deactivate_userObject

Deactivate the user account (set is_active to False)



16
17
18
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 16

def deactivate_user
  @deactivate_user
end

#delete_sessionsObject

Delete all active sessions for the user



22
23
24
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 22

def delete_sessions
  @delete_sessions
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 13

def name
  @name
end

#revoke_tokensObject

Revoke all tokens for the user (API, app password, recovery, verification, OAuth)



25
26
27
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 25

def revoke_tokens
  @revoke_tokens
end

#self_service_completion_flowObject

Flow to redirect users to after self-service lockdown. This flow should not require authentication since the user’s session is deleted.



28
29
30
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 28

def self_service_completion_flow
  @self_service_completion_flow
end

#set_unusable_passwordObject

Set an unusable password for the user



19
20
21
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 19

def set_unusable_password
  @set_unusable_password
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 31

def self.attribute_map
  {
    :'name' => :'name',
    :'deactivate_user' => :'deactivate_user',
    :'set_unusable_password' => :'set_unusable_password',
    :'delete_sessions' => :'delete_sessions',
    :'revoke_tokens' => :'revoke_tokens',
    :'self_service_completion_flow' => :'self_service_completion_flow'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 65

def self.openapi_nullable
  Set.new([
    :'self_service_completion_flow'
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 53

def self.openapi_types
  {
    :'name' => :'String',
    :'deactivate_user' => :'Boolean',
    :'set_unusable_password' => :'Boolean',
    :'delete_sessions' => :'Boolean',
    :'revoke_tokens' => :'Boolean',
    :'self_service_completion_flow' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
162
163
164
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      deactivate_user == o.deactivate_user &&
      set_unusable_password == o.set_unusable_password &&
      delete_sessions == o.delete_sessions &&
      revoke_tokens == o.revoke_tokens &&
      self_service_completion_flow == o.self_service_completion_flow
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 174

def hash
  [name, deactivate_user, set_unusable_password, delete_sessions, revoke_tokens, self_service_completion_flow].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
137
# File 'lib/authentik/api/models/account_lockdown_stage_request.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  true
end