Class: Authentik::Api::AdminApi
- Inherits:
-
Object
- Object
- Authentik::Api::AdminApi
- Defined in:
- lib/authentik/api/api/admin_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#admin_apps_list(opts = {}) ⇒ Array<App>
Read-only view list all installed apps.
-
#admin_apps_list_with_http_info(opts = {}) ⇒ Array<(Array<App>, Integer, Hash)>
Read-only view list all installed apps.
-
#admin_file_create(file, opts = {}) ⇒ nil
Upload file to storage backend.
-
#admin_file_create_with_http_info(file, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Upload file to storage backend.
-
#admin_file_destroy(opts = {}) ⇒ nil
Delete file from storage backend.
-
#admin_file_destroy_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete file from storage backend.
-
#admin_file_list(opts = {}) ⇒ Array<FileList>
List files from storage backend.
-
#admin_file_list_with_http_info(opts = {}) ⇒ Array<(Array<FileList>, Integer, Hash)>
List files from storage backend.
- #admin_file_used_by_list(opts = {}) ⇒ Array<UsedBy>
-
#admin_file_used_by_list_with_http_info(opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>
Array
data, response status code and response headers. -
#admin_models_list(opts = {}) ⇒ Array<App>
Read-only view list all installed models.
-
#admin_models_list_with_http_info(opts = {}) ⇒ Array<(Array<App>, Integer, Hash)>
Read-only view list all installed models.
-
#admin_settings_partial_update(opts = {}) ⇒ Settings
Settings view.
-
#admin_settings_partial_update_with_http_info(opts = {}) ⇒ Array<(Settings, Integer, Hash)>
Settings view.
-
#admin_settings_retrieve(opts = {}) ⇒ Settings
Settings view.
-
#admin_settings_retrieve_with_http_info(opts = {}) ⇒ Array<(Settings, Integer, Hash)>
Settings view.
-
#admin_settings_update(settings_request, opts = {}) ⇒ Settings
Settings view.
-
#admin_settings_update_with_http_info(settings_request, opts = {}) ⇒ Array<(Settings, Integer, Hash)>
Settings view.
-
#admin_system_create(opts = {}) ⇒ SystemInfo
Get system information.
-
#admin_system_create_with_http_info(opts = {}) ⇒ Array<(SystemInfo, Integer, Hash)>
Get system information.
-
#admin_system_retrieve(opts = {}) ⇒ SystemInfo
Get system information.
-
#admin_system_retrieve_with_http_info(opts = {}) ⇒ Array<(SystemInfo, Integer, Hash)>
Get system information.
-
#admin_version_history_list(opts = {}) ⇒ Array<VersionHistory>
VersionHistory Viewset.
-
#admin_version_history_list_with_http_info(opts = {}) ⇒ Array<(Array<VersionHistory>, Integer, Hash)>
VersionHistory Viewset.
-
#admin_version_history_retrieve(id, opts = {}) ⇒ VersionHistory
VersionHistory Viewset.
-
#admin_version_history_retrieve_with_http_info(id, opts = {}) ⇒ Array<(VersionHistory, Integer, Hash)>
VersionHistory Viewset.
-
#admin_version_retrieve(opts = {}) ⇒ Version
Get running and latest version.
-
#admin_version_retrieve_with_http_info(opts = {}) ⇒ Array<(Version, Integer, Hash)>
Get running and latest version.
-
#initialize(api_client = ApiClient.default) ⇒ AdminApi
constructor
A new instance of AdminApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
11 12 13 |
# File 'lib/authentik/api/api/admin_api.rb', line 11 def api_client @api_client end |
Instance Method Details
#admin_apps_list(opts = {}) ⇒ Array<App>
Read-only view list all installed apps
19 20 21 22 |
# File 'lib/authentik/api/api/admin_api.rb', line 19 def admin_apps_list(opts = {}) data, _status_code, _headers = admin_apps_list_with_http_info(opts) data end |
#admin_apps_list_with_http_info(opts = {}) ⇒ Array<(Array<App>, Integer, Hash)>
Read-only view list all installed apps
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/authentik/api/api/admin_api.rb', line 27 def admin_apps_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_apps_list ...' end # resource path local_var_path = '/admin/apps/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<App>' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_apps_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_apps_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_file_create(file, opts = {}) ⇒ nil
Upload file to storage backend.
77 78 79 80 |
# File 'lib/authentik/api/api/admin_api.rb', line 77 def admin_file_create(file, opts = {}) admin_file_create_with_http_info(file, opts) nil end |
#admin_file_create_with_http_info(file, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Upload file to storage backend.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/authentik/api/api/admin_api.rb', line 88 def admin_file_create_with_http_info(file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_file_create ...' end # verify the required parameter 'file' is set if @api_client.config.client_side_validation && file.nil? fail ArgumentError, "Missing the required parameter 'file' when calling AdminApi.admin_file_create" end if @api_client.config.client_side_validation && !opts[:'usage'].nil? && opts[:'usage'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"usage"]" when calling AdminApi.admin_file_create, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/admin/file/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['file'] = file form_params['name'] = opts[:'name'] if !opts[:'name'].nil? form_params['usage'] = opts[:'usage'] if !opts[:'usage'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_file_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_file_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_file_destroy(opts = {}) ⇒ nil
Delete file from storage backend.
153 154 155 156 |
# File 'lib/authentik/api/api/admin_api.rb', line 153 def admin_file_destroy(opts = {}) admin_file_destroy_with_http_info(opts) nil end |
#admin_file_destroy_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete file from storage backend.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/authentik/api/api/admin_api.rb', line 163 def admin_file_destroy_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_file_destroy ...' end if @api_client.config.client_side_validation && !opts[:'usage'].nil? && opts[:'usage'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"usage"]" when calling AdminApi.admin_file_destroy, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/admin/file/' # query parameters query_params = opts[:query_params] || {} query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'usage'] = opts[:'usage'] if !opts[:'usage'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_file_destroy", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_file_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_file_list(opts = {}) ⇒ Array<FileList>
List files from storage backend.
219 220 221 222 |
# File 'lib/authentik/api/api/admin_api.rb', line 219 def admin_file_list(opts = {}) data, _status_code, _headers = admin_file_list_with_http_info(opts) data end |
#admin_file_list_with_http_info(opts = {}) ⇒ Array<(Array<FileList>, Integer, Hash)>
List files from storage backend.
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/authentik/api/api/admin_api.rb', line 230 def admin_file_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_file_list ...' end if @api_client.config.client_side_validation && !opts[:'usage'].nil? && opts[:'usage'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"usage"]" when calling AdminApi.admin_file_list, the character length must be greater than or equal to 1.' end # resource path local_var_path = '/admin/file/' # query parameters query_params = opts[:query_params] || {} query_params[:'manageable_only'] = opts[:'manageable_only'] if !opts[:'manageable_only'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'usage'] = opts[:'usage'] if !opts[:'usage'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<FileList>' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_file_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_file_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_file_used_by_list(opts = {}) ⇒ Array<UsedBy>
284 285 286 287 |
# File 'lib/authentik/api/api/admin_api.rb', line 284 def admin_file_used_by_list(opts = {}) data, _status_code, _headers = admin_file_used_by_list_with_http_info(opts) data end |
#admin_file_used_by_list_with_http_info(opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>
Returns Array
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/authentik/api/api/admin_api.rb', line 292 def admin_file_used_by_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_file_used_by_list ...' end # resource path local_var_path = '/admin/file/used_by/' # query parameters query_params = opts[:query_params] || {} query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<UsedBy>' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_file_used_by_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_file_used_by_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_models_list(opts = {}) ⇒ Array<App>
Read-only view list all installed models
341 342 343 344 |
# File 'lib/authentik/api/api/admin_api.rb', line 341 def admin_models_list(opts = {}) data, _status_code, _headers = admin_models_list_with_http_info(opts) data end |
#admin_models_list_with_http_info(opts = {}) ⇒ Array<(Array<App>, Integer, Hash)>
Read-only view list all installed models
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/authentik/api/api/admin_api.rb', line 350 def admin_models_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_models_list ...' end # resource path local_var_path = '/admin/models/' # query parameters query_params = opts[:query_params] || {} query_params[:'filter_has_attributes'] = opts[:'filter_has_attributes'] if !opts[:'filter_has_attributes'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<App>' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_models_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_models_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_settings_partial_update(opts = {}) ⇒ Settings
Settings view
399 400 401 402 |
# File 'lib/authentik/api/api/admin_api.rb', line 399 def admin_settings_partial_update(opts = {}) data, _status_code, _headers = admin_settings_partial_update_with_http_info(opts) data end |
#admin_settings_partial_update_with_http_info(opts = {}) ⇒ Array<(Settings, Integer, Hash)>
Settings view
408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/authentik/api/api/admin_api.rb', line 408 def admin_settings_partial_update_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_settings_partial_update ...' end # resource path local_var_path = '/admin/settings/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_settings_request']) # return_type return_type = opts[:debug_return_type] || 'Settings' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_settings_partial_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_settings_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_settings_retrieve(opts = {}) ⇒ Settings
Settings view
460 461 462 463 |
# File 'lib/authentik/api/api/admin_api.rb', line 460 def admin_settings_retrieve(opts = {}) data, _status_code, _headers = admin_settings_retrieve_with_http_info(opts) data end |
#admin_settings_retrieve_with_http_info(opts = {}) ⇒ Array<(Settings, Integer, Hash)>
Settings view
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 |
# File 'lib/authentik/api/api/admin_api.rb', line 468 def admin_settings_retrieve_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_settings_retrieve ...' end # resource path local_var_path = '/admin/settings/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Settings' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_settings_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_settings_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_settings_update(settings_request, opts = {}) ⇒ Settings
Settings view
516 517 518 519 |
# File 'lib/authentik/api/api/admin_api.rb', line 516 def admin_settings_update(settings_request, opts = {}) data, _status_code, _headers = admin_settings_update_with_http_info(settings_request, opts) data end |
#admin_settings_update_with_http_info(settings_request, opts = {}) ⇒ Array<(Settings, Integer, Hash)>
Settings view
525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/authentik/api/api/admin_api.rb', line 525 def admin_settings_update_with_http_info(settings_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_settings_update ...' end # verify the required parameter 'settings_request' is set if @api_client.config.client_side_validation && settings_request.nil? fail ArgumentError, "Missing the required parameter 'settings_request' when calling AdminApi.admin_settings_update" end # resource path local_var_path = '/admin/settings/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(settings_request) # return_type return_type = opts[:debug_return_type] || 'Settings' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_settings_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_settings_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_system_create(opts = {}) ⇒ SystemInfo
Get system information.
581 582 583 584 |
# File 'lib/authentik/api/api/admin_api.rb', line 581 def admin_system_create(opts = {}) data, _status_code, _headers = admin_system_create_with_http_info(opts) data end |
#admin_system_create_with_http_info(opts = {}) ⇒ Array<(SystemInfo, Integer, Hash)>
Get system information.
589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/authentik/api/api/admin_api.rb', line 589 def admin_system_create_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_system_create ...' end # resource path local_var_path = '/admin/system/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SystemInfo' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_system_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_system_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_system_retrieve(opts = {}) ⇒ SystemInfo
Get system information.
636 637 638 639 |
# File 'lib/authentik/api/api/admin_api.rb', line 636 def admin_system_retrieve(opts = {}) data, _status_code, _headers = admin_system_retrieve_with_http_info(opts) data end |
#admin_system_retrieve_with_http_info(opts = {}) ⇒ Array<(SystemInfo, Integer, Hash)>
Get system information.
644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/authentik/api/api/admin_api.rb', line 644 def admin_system_retrieve_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_system_retrieve ...' end # resource path local_var_path = '/admin/system/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SystemInfo' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_system_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_system_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_version_history_list(opts = {}) ⇒ Array<VersionHistory>
VersionHistory Viewset
695 696 697 698 |
# File 'lib/authentik/api/api/admin_api.rb', line 695 def admin_version_history_list(opts = {}) data, _status_code, _headers = admin_version_history_list_with_http_info(opts) data end |
#admin_version_history_list_with_http_info(opts = {}) ⇒ Array<(Array<VersionHistory>, Integer, Hash)>
VersionHistory Viewset
707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 |
# File 'lib/authentik/api/api/admin_api.rb', line 707 def admin_version_history_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_version_history_list ...' end # resource path local_var_path = '/admin/version/history/' # query parameters query_params = opts[:query_params] || {} query_params[:'build'] = opts[:'build'] if !opts[:'build'].nil? query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<VersionHistory>' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_version_history_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_version_history_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_version_history_retrieve(id, opts = {}) ⇒ VersionHistory
VersionHistory Viewset
759 760 761 762 |
# File 'lib/authentik/api/api/admin_api.rb', line 759 def admin_version_history_retrieve(id, opts = {}) data, _status_code, _headers = admin_version_history_retrieve_with_http_info(id, opts) data end |
#admin_version_history_retrieve_with_http_info(id, opts = {}) ⇒ Array<(VersionHistory, Integer, Hash)>
VersionHistory Viewset
768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 |
# File 'lib/authentik/api/api/admin_api.rb', line 768 def admin_version_history_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_version_history_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AdminApi.admin_version_history_retrieve" end # resource path local_var_path = '/admin/version/history/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VersionHistory' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_version_history_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_version_history_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#admin_version_retrieve(opts = {}) ⇒ Version
Get running and latest version.
819 820 821 822 |
# File 'lib/authentik/api/api/admin_api.rb', line 819 def admin_version_retrieve(opts = {}) data, _status_code, _headers = admin_version_retrieve_with_http_info(opts) data end |
#admin_version_retrieve_with_http_info(opts = {}) ⇒ Array<(Version, Integer, Hash)>
Get running and latest version.
827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 |
# File 'lib/authentik/api/api/admin_api.rb', line 827 def admin_version_retrieve_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AdminApi.admin_version_retrieve ...' end # resource path local_var_path = '/admin/version/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Version' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AdminApi.admin_version_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AdminApi#admin_version_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |