Class: Authentik::Api::Agent

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/agent.rb

Overview

Mixin to validate that a valid enterprise license exists before allowing to save the object

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Agent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/authentik/api/models/agent.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Agent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Agent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  else
    self.username = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'last_login')
    self. = attributes[:'last_login']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end

  if attributes.key?(:'uid')
    self.uid = attributes[:'uid']
  else
    self.uid = nil
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  else
    self.uuid = nil
  end

  if attributes.key?(:'expiring')
    self.expiring = attributes[:'expiring']
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  end

  if attributes.key?(:'parent')
    self.parent = attributes[:'parent']
  else
    self.parent = nil
  end

  if attributes.key?(:'policy_behavior')
    self.policy_behavior = attributes[:'policy_behavior']
  else
    self.policy_behavior = nil
  end

  if attributes.key?(:'token_identifier')
    self.token_identifier = attributes[:'token_identifier']
  else
    self.token_identifier = nil
  end
end

Instance Attribute Details

#attributesObject

Returns the value of attribute attributes.



28
29
30
# File 'lib/authentik/api/models/agent.rb', line 28

def attributes
  @attributes
end

#emailObject

Returns the value of attribute email.



26
27
28
# File 'lib/authentik/api/models/agent.rb', line 26

def email
  @email
end

#expiresObject

Returns the value of attribute expires.



36
37
38
# File 'lib/authentik/api/models/agent.rb', line 36

def expires
  @expires
end

#expiringObject

Returns the value of attribute expiring.



34
35
36
# File 'lib/authentik/api/models/agent.rb', line 34

def expiring
  @expiring
end

#is_activeObject

Designates whether this user should be treated as active. Unselect this instead of deleting accounts.



22
23
24
# File 'lib/authentik/api/models/agent.rb', line 22

def is_active
  @is_active
end

#last_loginObject

Returns the value of attribute last_login.



24
25
26
# File 'lib/authentik/api/models/agent.rb', line 24

def 
  @last_login
end

#nameObject

User's display name.



19
20
21
# File 'lib/authentik/api/models/agent.rb', line 19

def name
  @name
end

#parentObject

Returns the value of attribute parent.



38
39
40
# File 'lib/authentik/api/models/agent.rb', line 38

def parent
  @parent
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/agent.rb', line 13

def pk
  @pk
end

#policy_behaviorObject

Returns the value of attribute policy_behavior.



40
41
42
# File 'lib/authentik/api/models/agent.rb', line 40

def policy_behavior
  @policy_behavior
end

#token_identifierObject

Identifier of the agent's API token, so its key can be retrieved/copied later.



43
44
45
# File 'lib/authentik/api/models/agent.rb', line 43

def token_identifier
  @token_identifier
end

#uidObject

Returns the value of attribute uid.



30
31
32
# File 'lib/authentik/api/models/agent.rb', line 30

def uid
  @uid
end

#usernameObject

Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.



16
17
18
# File 'lib/authentik/api/models/agent.rb', line 16

def username
  @username
end

#uuidObject

Returns the value of attribute uuid.



32
33
34
# File 'lib/authentik/api/models/agent.rb', line 32

def uuid
  @uuid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



88
89
90
# File 'lib/authentik/api/models/agent.rb', line 88

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/authentik/api/models/agent.rb', line 93

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/authentik/api/models/agent.rb', line 68

def self.attribute_map
  {
    :'pk' => :'pk',
    :'username' => :'username',
    :'name' => :'name',
    :'is_active' => :'is_active',
    :'last_login' => :'last_login',
    :'email' => :'email',
    :'attributes' => :'attributes',
    :'uid' => :'uid',
    :'uuid' => :'uuid',
    :'expiring' => :'expiring',
    :'expires' => :'expires',
    :'parent' => :'parent',
    :'policy_behavior' => :'policy_behavior',
    :'token_identifier' => :'token_identifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/authentik/api/models/agent.rb', line 412

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
122
123
124
# File 'lib/authentik/api/models/agent.rb', line 118

def self.openapi_nullable
  Set.new([
    :'last_login',
    :'expires',
    :'token_identifier'
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/authentik/api/models/agent.rb', line 98

def self.openapi_types
  {
    :'pk' => :'Integer',
    :'username' => :'String',
    :'name' => :'String',
    :'is_active' => :'Boolean',
    :'last_login' => :'Time',
    :'email' => :'String',
    :'attributes' => :'Hash<String, Object>',
    :'uid' => :'String',
    :'uuid' => :'String',
    :'expiring' => :'Boolean',
    :'expires' => :'Time',
    :'parent' => :'PartialUser',
    :'policy_behavior' => :'PolicyBehaviorEnum',
    :'token_identifier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/authentik/api/models/agent.rb', line 378

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      username == o.username &&
      name == o.name &&
      is_active == o.is_active &&
       == o. &&
      email == o.email &&
      attributes == o.attributes &&
      uid == o.uid &&
      uuid == o.uuid &&
      expiring == o.expiring &&
      expires == o.expires &&
      parent == o.parent &&
      policy_behavior == o.policy_behavior &&
      token_identifier == o.token_identifier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


399
400
401
# File 'lib/authentik/api/models/agent.rb', line 399

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



405
406
407
# File 'lib/authentik/api/models/agent.rb', line 405

def hash
  [pk, username, name, is_active, , email, attributes, uid, uuid, expiring, expires, parent, policy_behavior, token_identifier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/authentik/api/models/agent.rb', line 219

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  if @username.to_s.length > 150
    invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 150.')
  end

  pattern = Regexp.new(/^[\w.@+-]+$/)
  if @username !~ pattern
    invalid_properties.push("invalid value for \"username\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if !@email.nil? && @email.to_s.length > 254
    invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 254.')
  end

  if @uid.nil?
    invalid_properties.push('invalid value for "uid", uid cannot be nil.')
  end

  if @uuid.nil?
    invalid_properties.push('invalid value for "uuid", uuid cannot be nil.')
  end

  if @parent.nil?
    invalid_properties.push('invalid value for "parent", parent cannot be nil.')
  end

  if @policy_behavior.nil?
    invalid_properties.push('invalid value for "policy_behavior", policy_behavior cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/authentik/api/models/agent.rb', line 434

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/authentik/api/models/agent.rb', line 268

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @username.nil?
  return false if @username.to_s.length > 150
  return false if @username !~ Regexp.new(/^[\w.@+-]+$/)
  return false if @name.nil?
  return false if !@email.nil? && @email.to_s.length > 254
  return false if @uid.nil?
  return false if @uuid.nil?
  return false if @parent.nil?
  return false if @policy_behavior.nil?
  true
end