Class: Authentik::Api::AgentConnector

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/agent_connector.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AgentConnector

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/authentik/api/models/agent_connector.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AgentConnector` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AgentConnector`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'connector_uuid')
    self.connector_uuid = attributes[:'connector_uuid']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'snapshot_expiry')
    self.snapshot_expiry = attributes[:'snapshot_expiry']
  end

  if attributes.key?(:'auth_session_duration')
    self.auth_session_duration = attributes[:'auth_session_duration']
  end

  if attributes.key?(:'auth_terminate_session_on_expiry')
    self.auth_terminate_session_on_expiry = attributes[:'auth_terminate_session_on_expiry']
  end

  if attributes.key?(:'refresh_interval')
    self.refresh_interval = attributes[:'refresh_interval']
  end

  if attributes.key?(:'authorization_flow')
    self.authorization_flow = attributes[:'authorization_flow']
  end

  if attributes.key?(:'nss_uid_offset')
    self.nss_uid_offset = attributes[:'nss_uid_offset']
  end

  if attributes.key?(:'nss_gid_offset')
    self.nss_gid_offset = attributes[:'nss_gid_offset']
  end

  if attributes.key?(:'challenge_key')
    self.challenge_key = attributes[:'challenge_key']
  end

  if attributes.key?(:'challenge_idle_timeout')
    self.challenge_idle_timeout = attributes[:'challenge_idle_timeout']
  end

  if attributes.key?(:'challenge_trigger_check_in')
    self.challenge_trigger_check_in = attributes[:'challenge_trigger_check_in']
  end

  if attributes.key?(:'jwt_federation_providers')
    if (value = attributes[:'jwt_federation_providers']).is_a?(Array)
      self.jwt_federation_providers = value
    end
  end
end

Instance Attribute Details

#auth_session_durationObject

Returns the value of attribute auth_session_duration.



32
33
34
# File 'lib/authentik/api/models/agent_connector.rb', line 32

def auth_session_duration
  @auth_session_duration
end

#auth_terminate_session_on_expiryObject

Returns the value of attribute auth_terminate_session_on_expiry.



34
35
36
# File 'lib/authentik/api/models/agent_connector.rb', line 34

def auth_terminate_session_on_expiry
  @auth_terminate_session_on_expiry
end

#authorization_flowObject

Returns the value of attribute authorization_flow.



38
39
40
# File 'lib/authentik/api/models/agent_connector.rb', line 38

def authorization_flow
  @authorization_flow
end

#challenge_idle_timeoutObject

Returns the value of attribute challenge_idle_timeout.



46
47
48
# File 'lib/authentik/api/models/agent_connector.rb', line 46

def challenge_idle_timeout
  @challenge_idle_timeout
end

#challenge_keyObject

Returns the value of attribute challenge_key.



44
45
46
# File 'lib/authentik/api/models/agent_connector.rb', line 44

def challenge_key
  @challenge_key
end

#challenge_trigger_check_inObject

Returns the value of attribute challenge_trigger_check_in.



48
49
50
# File 'lib/authentik/api/models/agent_connector.rb', line 48

def challenge_trigger_check_in
  @challenge_trigger_check_in
end

#componentObject

Get object component so that we know how to edit the object



19
20
21
# File 'lib/authentik/api/models/agent_connector.rb', line 19

def component
  @component
end

#connector_uuidObject

Returns the value of attribute connector_uuid.



12
13
14
# File 'lib/authentik/api/models/agent_connector.rb', line 12

def connector_uuid
  @connector_uuid
end

#enabledObject

Returns the value of attribute enabled.



16
17
18
# File 'lib/authentik/api/models/agent_connector.rb', line 16

def enabled
  @enabled
end

#jwt_federation_providersObject

Returns the value of attribute jwt_federation_providers.



50
51
52
# File 'lib/authentik/api/models/agent_connector.rb', line 50

def jwt_federation_providers
  @jwt_federation_providers
end

#meta_model_nameObject

Return internal model name



28
29
30
# File 'lib/authentik/api/models/agent_connector.rb', line 28

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



14
15
16
# File 'lib/authentik/api/models/agent_connector.rb', line 14

def name
  @name
end

#nss_gid_offsetObject

Returns the value of attribute nss_gid_offset.



42
43
44
# File 'lib/authentik/api/models/agent_connector.rb', line 42

def nss_gid_offset
  @nss_gid_offset
end

#nss_uid_offsetObject

Returns the value of attribute nss_uid_offset.



40
41
42
# File 'lib/authentik/api/models/agent_connector.rb', line 40

def nss_uid_offset
  @nss_uid_offset
end

#refresh_intervalObject

Returns the value of attribute refresh_interval.



36
37
38
# File 'lib/authentik/api/models/agent_connector.rb', line 36

def refresh_interval
  @refresh_interval
end

#snapshot_expiryObject

Returns the value of attribute snapshot_expiry.



30
31
32
# File 'lib/authentik/api/models/agent_connector.rb', line 30

def snapshot_expiry
  @snapshot_expiry
end

#verbose_nameObject

Return object’s verbose_name



22
23
24
# File 'lib/authentik/api/models/agent_connector.rb', line 22

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



25
26
27
# File 'lib/authentik/api/models/agent_connector.rb', line 25

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/authentik/api/models/agent_connector.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/authentik/api/models/agent_connector.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/authentik/api/models/agent_connector.rb', line 53

def self.attribute_map
  {
    :'connector_uuid' => :'connector_uuid',
    :'name' => :'name',
    :'enabled' => :'enabled',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'snapshot_expiry' => :'snapshot_expiry',
    :'auth_session_duration' => :'auth_session_duration',
    :'auth_terminate_session_on_expiry' => :'auth_terminate_session_on_expiry',
    :'refresh_interval' => :'refresh_interval',
    :'authorization_flow' => :'authorization_flow',
    :'nss_uid_offset' => :'nss_uid_offset',
    :'nss_gid_offset' => :'nss_gid_offset',
    :'challenge_key' => :'challenge_key',
    :'challenge_idle_timeout' => :'challenge_idle_timeout',
    :'challenge_trigger_check_in' => :'challenge_trigger_check_in',
    :'jwt_federation_providers' => :'jwt_federation_providers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/authentik/api/models/agent_connector.rb', line 405

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
116
# File 'lib/authentik/api/models/agent_connector.rb', line 111

def self.openapi_nullable
  Set.new([
    :'authorization_flow',
    :'challenge_key',
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/authentik/api/models/agent_connector.rb', line 87

def self.openapi_types
  {
    :'connector_uuid' => :'String',
    :'name' => :'String',
    :'enabled' => :'Boolean',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'snapshot_expiry' => :'String',
    :'auth_session_duration' => :'String',
    :'auth_terminate_session_on_expiry' => :'Boolean',
    :'refresh_interval' => :'String',
    :'authorization_flow' => :'String',
    :'nss_uid_offset' => :'Integer',
    :'nss_gid_offset' => :'Integer',
    :'challenge_key' => :'String',
    :'challenge_idle_timeout' => :'String',
    :'challenge_trigger_check_in' => :'Boolean',
    :'jwt_federation_providers' => :'Array<Integer>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/authentik/api/models/agent_connector.rb', line 367

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      connector_uuid == o.connector_uuid &&
      name == o.name &&
      enabled == o.enabled &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      snapshot_expiry == o.snapshot_expiry &&
      auth_session_duration == o.auth_session_duration &&
      auth_terminate_session_on_expiry == o.auth_terminate_session_on_expiry &&
      refresh_interval == o.refresh_interval &&
      authorization_flow == o.authorization_flow &&
      nss_uid_offset == o.nss_uid_offset &&
      nss_gid_offset == o.nss_gid_offset &&
      challenge_key == o.challenge_key &&
      challenge_idle_timeout == o.challenge_idle_timeout &&
      challenge_trigger_check_in == o.challenge_trigger_check_in &&
      jwt_federation_providers == o.jwt_federation_providers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


392
393
394
# File 'lib/authentik/api/models/agent_connector.rb', line 392

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



398
399
400
# File 'lib/authentik/api/models/agent_connector.rb', line 398

def hash
  [connector_uuid, name, enabled, component, verbose_name, verbose_name_plural, meta_model_name, snapshot_expiry, auth_session_duration, auth_terminate_session_on_expiry, refresh_interval, authorization_flow, nss_uid_offset, nss_gid_offset, challenge_key, challenge_idle_timeout, challenge_trigger_check_in, jwt_federation_providers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/authentik/api/models/agent_connector.rb', line 221

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if !@nss_uid_offset.nil? && @nss_uid_offset > 2147483647
    invalid_properties.push('invalid value for "nss_uid_offset", must be smaller than or equal to 2147483647.')
  end

  if !@nss_uid_offset.nil? && @nss_uid_offset < 0
    invalid_properties.push('invalid value for "nss_uid_offset", must be greater than or equal to 0.')
  end

  if !@nss_gid_offset.nil? && @nss_gid_offset > 2147483647
    invalid_properties.push('invalid value for "nss_gid_offset", must be smaller than or equal to 2147483647.')
  end

  if !@nss_gid_offset.nil? && @nss_gid_offset < 0
    invalid_properties.push('invalid value for "nss_gid_offset", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/authentik/api/models/agent_connector.rb', line 427

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/authentik/api/models/agent_connector.rb', line 265

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if !@nss_uid_offset.nil? && @nss_uid_offset > 2147483647
  return false if !@nss_uid_offset.nil? && @nss_uid_offset < 0
  return false if !@nss_gid_offset.nil? && @nss_gid_offset > 2147483647
  return false if !@nss_gid_offset.nil? && @nss_gid_offset < 0
  true
end