Class: Authentik::Api::AgentConnectorRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/agent_connector_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AgentConnectorRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/authentik/api/models/agent_connector_request.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AgentConnectorRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AgentConnectorRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'connector_uuid')
    self.connector_uuid = attributes[:'connector_uuid']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'snapshot_expiry')
    self.snapshot_expiry = attributes[:'snapshot_expiry']
  end

  if attributes.key?(:'auth_session_duration')
    self.auth_session_duration = attributes[:'auth_session_duration']
  end

  if attributes.key?(:'auth_terminate_session_on_expiry')
    self.auth_terminate_session_on_expiry = attributes[:'auth_terminate_session_on_expiry']
  end

  if attributes.key?(:'refresh_interval')
    self.refresh_interval = attributes[:'refresh_interval']
  end

  if attributes.key?(:'authorization_flow')
    self.authorization_flow = attributes[:'authorization_flow']
  end

  if attributes.key?(:'nss_uid_offset')
    self.nss_uid_offset = attributes[:'nss_uid_offset']
  end

  if attributes.key?(:'nss_gid_offset')
    self.nss_gid_offset = attributes[:'nss_gid_offset']
  end

  if attributes.key?(:'challenge_key')
    self.challenge_key = attributes[:'challenge_key']
  end

  if attributes.key?(:'challenge_idle_timeout')
    self.challenge_idle_timeout = attributes[:'challenge_idle_timeout']
  end

  if attributes.key?(:'challenge_trigger_check_in')
    self.challenge_trigger_check_in = attributes[:'challenge_trigger_check_in']
  end

  if attributes.key?(:'jwt_federation_providers')
    if (value = attributes[:'jwt_federation_providers']).is_a?(Array)
      self.jwt_federation_providers = value
    end
  end
end

Instance Attribute Details

#auth_session_durationObject

Returns the value of attribute auth_session_duration.



20
21
22
# File 'lib/authentik/api/models/agent_connector_request.rb', line 20

def auth_session_duration
  @auth_session_duration
end

#auth_terminate_session_on_expiryObject

Returns the value of attribute auth_terminate_session_on_expiry.



22
23
24
# File 'lib/authentik/api/models/agent_connector_request.rb', line 22

def auth_terminate_session_on_expiry
  @auth_terminate_session_on_expiry
end

#authorization_flowObject

Returns the value of attribute authorization_flow.



26
27
28
# File 'lib/authentik/api/models/agent_connector_request.rb', line 26

def authorization_flow
  @authorization_flow
end

#challenge_idle_timeoutObject

Returns the value of attribute challenge_idle_timeout.



34
35
36
# File 'lib/authentik/api/models/agent_connector_request.rb', line 34

def challenge_idle_timeout
  @challenge_idle_timeout
end

#challenge_keyObject

Returns the value of attribute challenge_key.



32
33
34
# File 'lib/authentik/api/models/agent_connector_request.rb', line 32

def challenge_key
  @challenge_key
end

#challenge_trigger_check_inObject

Returns the value of attribute challenge_trigger_check_in.



36
37
38
# File 'lib/authentik/api/models/agent_connector_request.rb', line 36

def challenge_trigger_check_in
  @challenge_trigger_check_in
end

#connector_uuidObject

Returns the value of attribute connector_uuid.



12
13
14
# File 'lib/authentik/api/models/agent_connector_request.rb', line 12

def connector_uuid
  @connector_uuid
end

#enabledObject

Returns the value of attribute enabled.



16
17
18
# File 'lib/authentik/api/models/agent_connector_request.rb', line 16

def enabled
  @enabled
end

#jwt_federation_providersObject

Returns the value of attribute jwt_federation_providers.



38
39
40
# File 'lib/authentik/api/models/agent_connector_request.rb', line 38

def jwt_federation_providers
  @jwt_federation_providers
end

#nameObject

Returns the value of attribute name.



14
15
16
# File 'lib/authentik/api/models/agent_connector_request.rb', line 14

def name
  @name
end

#nss_gid_offsetObject

Returns the value of attribute nss_gid_offset.



30
31
32
# File 'lib/authentik/api/models/agent_connector_request.rb', line 30

def nss_gid_offset
  @nss_gid_offset
end

#nss_uid_offsetObject

Returns the value of attribute nss_uid_offset.



28
29
30
# File 'lib/authentik/api/models/agent_connector_request.rb', line 28

def nss_uid_offset
  @nss_uid_offset
end

#refresh_intervalObject

Returns the value of attribute refresh_interval.



24
25
26
# File 'lib/authentik/api/models/agent_connector_request.rb', line 24

def refresh_interval
  @refresh_interval
end

#snapshot_expiryObject

Returns the value of attribute snapshot_expiry.



18
19
20
# File 'lib/authentik/api/models/agent_connector_request.rb', line 18

def snapshot_expiry
  @snapshot_expiry
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/authentik/api/models/agent_connector_request.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/authentik/api/models/agent_connector_request.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/authentik/api/models/agent_connector_request.rb', line 41

def self.attribute_map
  {
    :'connector_uuid' => :'connector_uuid',
    :'name' => :'name',
    :'enabled' => :'enabled',
    :'snapshot_expiry' => :'snapshot_expiry',
    :'auth_session_duration' => :'auth_session_duration',
    :'auth_terminate_session_on_expiry' => :'auth_terminate_session_on_expiry',
    :'refresh_interval' => :'refresh_interval',
    :'authorization_flow' => :'authorization_flow',
    :'nss_uid_offset' => :'nss_uid_offset',
    :'nss_gid_offset' => :'nss_gid_offset',
    :'challenge_key' => :'challenge_key',
    :'challenge_idle_timeout' => :'challenge_idle_timeout',
    :'challenge_trigger_check_in' => :'challenge_trigger_check_in',
    :'jwt_federation_providers' => :'jwt_federation_providers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/authentik/api/models/agent_connector_request.rb', line 382

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
96
# File 'lib/authentik/api/models/agent_connector_request.rb', line 91

def self.openapi_nullable
  Set.new([
    :'authorization_flow',
    :'challenge_key',
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/authentik/api/models/agent_connector_request.rb', line 71

def self.openapi_types
  {
    :'connector_uuid' => :'String',
    :'name' => :'String',
    :'enabled' => :'Boolean',
    :'snapshot_expiry' => :'String',
    :'auth_session_duration' => :'String',
    :'auth_terminate_session_on_expiry' => :'Boolean',
    :'refresh_interval' => :'String',
    :'authorization_flow' => :'String',
    :'nss_uid_offset' => :'Integer',
    :'nss_gid_offset' => :'Integer',
    :'challenge_key' => :'String',
    :'challenge_idle_timeout' => :'String',
    :'challenge_trigger_check_in' => :'Boolean',
    :'jwt_federation_providers' => :'Array<Integer>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/authentik/api/models/agent_connector_request.rb', line 348

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      connector_uuid == o.connector_uuid &&
      name == o.name &&
      enabled == o.enabled &&
      snapshot_expiry == o.snapshot_expiry &&
      auth_session_duration == o.auth_session_duration &&
      auth_terminate_session_on_expiry == o.auth_terminate_session_on_expiry &&
      refresh_interval == o.refresh_interval &&
      authorization_flow == o.authorization_flow &&
      nss_uid_offset == o.nss_uid_offset &&
      nss_gid_offset == o.nss_gid_offset &&
      challenge_key == o.challenge_key &&
      challenge_idle_timeout == o.challenge_idle_timeout &&
      challenge_trigger_check_in == o.challenge_trigger_check_in &&
      jwt_federation_providers == o.jwt_federation_providers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


369
370
371
# File 'lib/authentik/api/models/agent_connector_request.rb', line 369

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



375
376
377
# File 'lib/authentik/api/models/agent_connector_request.rb', line 375

def hash
  [connector_uuid, name, enabled, snapshot_expiry, auth_session_duration, auth_terminate_session_on_expiry, refresh_interval, authorization_flow, nss_uid_offset, nss_gid_offset, challenge_key, challenge_idle_timeout, challenge_trigger_check_in, jwt_federation_providers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/authentik/api/models/agent_connector_request.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@snapshot_expiry.nil? && @snapshot_expiry.to_s.length < 1
    invalid_properties.push('invalid value for "snapshot_expiry", the character length must be greater than or equal to 1.')
  end

  if !@auth_session_duration.nil? && @auth_session_duration.to_s.length < 1
    invalid_properties.push('invalid value for "auth_session_duration", the character length must be greater than or equal to 1.')
  end

  if !@refresh_interval.nil? && @refresh_interval.to_s.length < 1
    invalid_properties.push('invalid value for "refresh_interval", the character length must be greater than or equal to 1.')
  end

  if !@nss_uid_offset.nil? && @nss_uid_offset > 2147483647
    invalid_properties.push('invalid value for "nss_uid_offset", must be smaller than or equal to 2147483647.')
  end

  if !@nss_uid_offset.nil? && @nss_uid_offset < 0
    invalid_properties.push('invalid value for "nss_uid_offset", must be greater than or equal to 0.')
  end

  if !@nss_gid_offset.nil? && @nss_gid_offset > 2147483647
    invalid_properties.push('invalid value for "nss_gid_offset", must be smaller than or equal to 2147483647.')
  end

  if !@nss_gid_offset.nil? && @nss_gid_offset < 0
    invalid_properties.push('invalid value for "nss_gid_offset", must be greater than or equal to 0.')
  end

  if !@challenge_idle_timeout.nil? && @challenge_idle_timeout.to_s.length < 1
    invalid_properties.push('invalid value for "challenge_idle_timeout", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/authentik/api/models/agent_connector_request.rb', line 404

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/authentik/api/models/agent_connector_request.rb', line 225

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if !@snapshot_expiry.nil? && @snapshot_expiry.to_s.length < 1
  return false if !@auth_session_duration.nil? && @auth_session_duration.to_s.length < 1
  return false if !@refresh_interval.nil? && @refresh_interval.to_s.length < 1
  return false if !@nss_uid_offset.nil? && @nss_uid_offset > 2147483647
  return false if !@nss_uid_offset.nil? && @nss_uid_offset < 0
  return false if !@nss_gid_offset.nil? && @nss_gid_offset > 2147483647
  return false if !@nss_gid_offset.nil? && @nss_gid_offset < 0
  return false if !@challenge_idle_timeout.nil? && @challenge_idle_timeout.to_s.length < 1
  true
end