Class: Authentik::Api::AgentPSSODeviceRegistrationResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/agent_psso_device_registration_response.rb

Overview

authentik settings for Platform SSO tokens

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AgentPSSODeviceRegistrationResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AgentPSSODeviceRegistrationResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AgentPSSODeviceRegistrationResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  else
    self.client_id = nil
  end

  if attributes.key?(:'issuer')
    self.issuer = attributes[:'issuer']
  else
    self.issuer = nil
  end

  if attributes.key?(:'token_endpoint')
    self.token_endpoint = attributes[:'token_endpoint']
  else
    self.token_endpoint = nil
  end

  if attributes.key?(:'jwks_endpoint')
    self.jwks_endpoint = attributes[:'jwks_endpoint']
  else
    self.jwks_endpoint = nil
  end

  if attributes.key?(:'audience')
    self.audience = attributes[:'audience']
  else
    self.audience = nil
  end

  if attributes.key?(:'nonce_endpoint')
    self.nonce_endpoint = attributes[:'nonce_endpoint']
  else
    self.nonce_endpoint = nil
  end
end

Instance Attribute Details

#audienceObject

Returns the value of attribute audience.



21
22
23
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 21

def audience
  @audience
end

#client_idObject

Returns the value of attribute client_id.



13
14
15
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 13

def client_id
  @client_id
end

#issuerObject

Returns the value of attribute issuer.



15
16
17
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 15

def issuer
  @issuer
end

#jwks_endpointObject

Returns the value of attribute jwks_endpoint.



19
20
21
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 19

def jwks_endpoint
  @jwks_endpoint
end

#nonce_endpointObject

Returns the value of attribute nonce_endpoint.



23
24
25
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 23

def nonce_endpoint
  @nonce_endpoint
end

#token_endpointObject

Returns the value of attribute token_endpoint.



17
18
19
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 17

def token_endpoint
  @token_endpoint
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
35
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 26

def self.attribute_map
  {
    :'client_id' => :'client_id',
    :'issuer' => :'issuer',
    :'token_endpoint' => :'token_endpoint',
    :'jwks_endpoint' => :'jwks_endpoint',
    :'audience' => :'audience',
    :'nonce_endpoint' => :'nonce_endpoint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 251

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 48

def self.openapi_types
  {
    :'client_id' => :'String',
    :'issuer' => :'String',
    :'token_endpoint' => :'String',
    :'jwks_endpoint' => :'String',
    :'audience' => :'String',
    :'nonce_endpoint' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



225
226
227
228
229
230
231
232
233
234
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 225

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_id == o.client_id &&
      issuer == o.issuer &&
      token_endpoint == o.token_endpoint &&
      jwks_endpoint == o.jwks_endpoint &&
      audience == o.audience &&
      nonce_endpoint == o.nonce_endpoint
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


238
239
240
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 238

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



244
245
246
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 244

def hash
  [client_id, issuer, token_endpoint, jwks_endpoint, audience, nonce_endpoint].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @client_id.nil?
    invalid_properties.push('invalid value for "client_id", client_id cannot be nil.')
  end

  if @issuer.nil?
    invalid_properties.push('invalid value for "issuer", issuer cannot be nil.')
  end

  if @token_endpoint.nil?
    invalid_properties.push('invalid value for "token_endpoint", token_endpoint cannot be nil.')
  end

  if @jwks_endpoint.nil?
    invalid_properties.push('invalid value for "jwks_endpoint", jwks_endpoint cannot be nil.')
  end

  if @audience.nil?
    invalid_properties.push('invalid value for "audience", audience cannot be nil.')
  end

  if @nonce_endpoint.nil?
    invalid_properties.push('invalid value for "nonce_endpoint", nonce_endpoint cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 273

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
159
160
161
# File 'lib/authentik/api/models/agent_psso_device_registration_response.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @client_id.nil?
  return false if @issuer.nil?
  return false if @token_endpoint.nil?
  return false if @jwks_endpoint.nil?
  return false if @audience.nil?
  return false if @nonce_endpoint.nil?
  true
end