Class: Authentik::Api::AgentPSSOUserRegistrationRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/agent_psso_user_registration_request.rb

Overview

Register Apple device user via Platform SSO

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AgentPSSOUserRegistrationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 55

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AgentPSSOUserRegistrationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AgentPSSOUserRegistrationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'user_auth')
    self.user_auth = attributes[:'user_auth']
  else
    self.user_auth = nil
  end

  if attributes.key?(:'user_secure_enclave_key')
    self.user_secure_enclave_key = attributes[:'user_secure_enclave_key']
  else
    self.user_secure_enclave_key = nil
  end

  if attributes.key?(:'enclave_key_id')
    self.enclave_key_id = attributes[:'enclave_key_id']
  else
    self.enclave_key_id = nil
  end
end

Instance Attribute Details

#enclave_key_idObject

Returns the value of attribute enclave_key_id.



17
18
19
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 17

def enclave_key_id
  @enclave_key_id
end

#user_authObject

Returns the value of attribute user_auth.



13
14
15
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 13

def user_auth
  @user_auth
end

#user_secure_enclave_keyObject

Returns the value of attribute user_secure_enclave_key.



15
16
17
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 15

def user_secure_enclave_key
  @user_secure_enclave_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



29
30
31
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 29

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



34
35
36
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 34

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



20
21
22
23
24
25
26
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 20

def self.attribute_map
  {
    :'user_auth' => :'user_auth',
    :'user_secure_enclave_key' => :'user_secure_enclave_key',
    :'enclave_key_id' => :'enclave_key_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



48
49
50
51
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 48

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 39

def self.openapi_types
  {
    :'user_auth' => :'String',
    :'user_secure_enclave_key' => :'String',
    :'enclave_key_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



177
178
179
180
181
182
183
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 177

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      user_auth == o.user_auth &&
      user_secure_enclave_key == o.user_secure_enclave_key &&
      enclave_key_id == o.enclave_key_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 193

def hash
  [user_auth, user_secure_enclave_key, enclave_key_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 90

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @user_auth.nil?
    invalid_properties.push('invalid value for "user_auth", user_auth cannot be nil.')
  end

  if @user_auth.to_s.length < 1
    invalid_properties.push('invalid value for "user_auth", the character length must be greater than or equal to 1.')
  end

  if @user_secure_enclave_key.nil?
    invalid_properties.push('invalid value for "user_secure_enclave_key", user_secure_enclave_key cannot be nil.')
  end

  if @user_secure_enclave_key.to_s.length < 1
    invalid_properties.push('invalid value for "user_secure_enclave_key", the character length must be greater than or equal to 1.')
  end

  if @enclave_key_id.nil?
    invalid_properties.push('invalid value for "enclave_key_id", enclave_key_id cannot be nil.')
  end

  if @enclave_key_id.to_s.length < 1
    invalid_properties.push('invalid value for "enclave_key_id", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



122
123
124
125
126
127
128
129
130
131
# File 'lib/authentik/api/models/agent_psso_user_registration_request.rb', line 122

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @user_auth.nil?
  return false if @user_auth.to_s.length < 1
  return false if @user_secure_enclave_key.nil?
  return false if @user_secure_enclave_key.to_s.length < 1
  return false if @enclave_key_id.nil?
  return false if @enclave_key_id.to_s.length < 1
  true
end