Class: Authentik::Api::AgentRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::AgentRequest
- Defined in:
- lib/authentik/api/models/agent_request.rb
Overview
Mixin to validate that a valid enterprise license exists before allowing to save the object
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#email ⇒ Object
Returns the value of attribute email.
-
#expires ⇒ Object
Returns the value of attribute expires.
-
#expiring ⇒ Object
Returns the value of attribute expiring.
-
#is_active ⇒ Object
Designates whether this user should be treated as active.
-
#last_login ⇒ Object
Returns the value of attribute last_login.
-
#name ⇒ Object
User's display name.
-
#username ⇒ Object
Required.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AgentRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AgentRequest
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/authentik/api/models/agent_request.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AgentRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AgentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'last_login') self.last_login = attributes[:'last_login'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end if attributes.key?(:'expiring') self.expiring = attributes[:'expiring'] end if attributes.key?(:'expires') self.expires = attributes[:'expires'] end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
26 27 28 |
# File 'lib/authentik/api/models/agent_request.rb', line 26 def attributes @attributes end |
#email ⇒ Object
Returns the value of attribute email.
24 25 26 |
# File 'lib/authentik/api/models/agent_request.rb', line 24 def email @email end |
#expires ⇒ Object
Returns the value of attribute expires.
30 31 32 |
# File 'lib/authentik/api/models/agent_request.rb', line 30 def expires @expires end |
#expiring ⇒ Object
Returns the value of attribute expiring.
28 29 30 |
# File 'lib/authentik/api/models/agent_request.rb', line 28 def expiring @expiring end |
#is_active ⇒ Object
Designates whether this user should be treated as active. Unselect this instead of deleting accounts.
20 21 22 |
# File 'lib/authentik/api/models/agent_request.rb', line 20 def is_active @is_active end |
#last_login ⇒ Object
Returns the value of attribute last_login.
22 23 24 |
# File 'lib/authentik/api/models/agent_request.rb', line 22 def last_login @last_login end |
#name ⇒ Object
User's display name.
17 18 19 |
# File 'lib/authentik/api/models/agent_request.rb', line 17 def name @name end |
#username ⇒ Object
Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.
14 15 16 |
# File 'lib/authentik/api/models/agent_request.rb', line 14 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/authentik/api/models/agent_request.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/authentik/api/models/agent_request.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/authentik/api/models/agent_request.rb', line 33 def self.attribute_map { :'username' => :'username', :'name' => :'name', :'is_active' => :'is_active', :'last_login' => :'last_login', :'email' => :'email', :'attributes' => :'attributes', :'expiring' => :'expiring', :'expires' => :'expires' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/authentik/api/models/agent_request.rb', line 265 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 75 76 |
# File 'lib/authentik/api/models/agent_request.rb', line 71 def self.openapi_nullable Set.new([ :'last_login', :'expires' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/authentik/api/models/agent_request.rb', line 57 def self.openapi_types { :'username' => :'String', :'name' => :'String', :'is_active' => :'Boolean', :'last_login' => :'Time', :'email' => :'String', :'attributes' => :'Hash<String, Object>', :'expiring' => :'Boolean', :'expires' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/authentik/api/models/agent_request.rb', line 237 def ==(o) return true if self.equal?(o) self.class == o.class && username == o.username && name == o.name && is_active == o.is_active && last_login == o.last_login && email == o.email && attributes == o.attributes && expiring == o.expiring && expires == o.expires end |
#eql?(o) ⇒ Boolean
252 253 254 |
# File 'lib/authentik/api/models/agent_request.rb', line 252 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/authentik/api/models/agent_request.rb', line 258 def hash [username, name, is_active, last_login, email, attributes, expiring, expires].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/authentik/api/models/agent_request.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end if @username.to_s.length > 150 invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 150.') end if @username.to_s.length < 1 invalid_properties.push('invalid value for "username", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[\w.@+-]+$/) if @username !~ pattern invalid_properties.push("invalid value for \"username\", must conform to the pattern #{pattern}.") end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@email.nil? && @email.to_s.length > 254 invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 254.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/authentik/api/models/agent_request.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/authentik/api/models/agent_request.rb', line 172 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @username.nil? return false if @username.to_s.length > 150 return false if @username.to_s.length < 1 return false if @username !~ Regexp.new(/^[\w.@+-]+$/) return false if @name.nil? return false if @name.to_s.length < 1 return false if !@email.nil? && @email.to_s.length > 254 true end |