Class: Authentik::Api::ApplicationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ApplicationRequest
- Defined in:
- lib/authentik/api/models/application_request.rb
Overview
Application Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#backchannel_providers ⇒ Object
Returns the value of attribute backchannel_providers.
-
#group ⇒ Object
Returns the value of attribute group.
-
#meta_description ⇒ Object
Returns the value of attribute meta_description.
-
#meta_icon ⇒ Object
Returns the value of attribute meta_icon.
-
#meta_launch_url ⇒ Object
Returns the value of attribute meta_launch_url.
-
#meta_publisher ⇒ Object
Returns the value of attribute meta_publisher.
-
#name ⇒ Object
Application’s display Name.
-
#open_in_new_tab ⇒ Object
Open launch URL in a new browser tab or window.
-
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#slug ⇒ Object
Internal application name, used in URLs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationRequest
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/authentik/api/models/application_request.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ApplicationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ApplicationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'backchannel_providers') if (value = attributes[:'backchannel_providers']).is_a?(Array) self.backchannel_providers = value end end if attributes.key?(:'open_in_new_tab') self.open_in_new_tab = attributes[:'open_in_new_tab'] end if attributes.key?(:'meta_launch_url') self. = attributes[:'meta_launch_url'] end if attributes.key?(:'meta_icon') self. = attributes[:'meta_icon'] end if attributes.key?(:'meta_description') self. = attributes[:'meta_description'] end if attributes.key?(:'meta_publisher') self. = attributes[:'meta_publisher'] end if attributes.key?(:'policy_engine_mode') self.policy_engine_mode = attributes[:'policy_engine_mode'] end if attributes.key?(:'group') self.group = attributes[:'group'] end end |
Instance Attribute Details
#backchannel_providers ⇒ Object
Returns the value of attribute backchannel_providers.
21 22 23 |
# File 'lib/authentik/api/models/application_request.rb', line 21 def backchannel_providers @backchannel_providers end |
#group ⇒ Object
Returns the value of attribute group.
36 37 38 |
# File 'lib/authentik/api/models/application_request.rb', line 36 def group @group end |
#meta_description ⇒ Object
Returns the value of attribute meta_description.
30 31 32 |
# File 'lib/authentik/api/models/application_request.rb', line 30 def @meta_description end |
#meta_icon ⇒ Object
Returns the value of attribute meta_icon.
28 29 30 |
# File 'lib/authentik/api/models/application_request.rb', line 28 def @meta_icon end |
#meta_launch_url ⇒ Object
Returns the value of attribute meta_launch_url.
26 27 28 |
# File 'lib/authentik/api/models/application_request.rb', line 26 def @meta_launch_url end |
#meta_publisher ⇒ Object
Returns the value of attribute meta_publisher.
32 33 34 |
# File 'lib/authentik/api/models/application_request.rb', line 32 def @meta_publisher end |
#name ⇒ Object
Application’s display Name.
14 15 16 |
# File 'lib/authentik/api/models/application_request.rb', line 14 def name @name end |
#open_in_new_tab ⇒ Object
Open launch URL in a new browser tab or window.
24 25 26 |
# File 'lib/authentik/api/models/application_request.rb', line 24 def open_in_new_tab @open_in_new_tab end |
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
34 35 36 |
# File 'lib/authentik/api/models/application_request.rb', line 34 def policy_engine_mode @policy_engine_mode end |
#provider ⇒ Object
Returns the value of attribute provider.
19 20 21 |
# File 'lib/authentik/api/models/application_request.rb', line 19 def provider @provider end |
#slug ⇒ Object
Internal application name, used in URLs.
17 18 19 |
# File 'lib/authentik/api/models/application_request.rb', line 17 def slug @slug end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/authentik/api/models/application_request.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/authentik/api/models/application_request.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/authentik/api/models/application_request.rb', line 61 def self.attribute_map { :'name' => :'name', :'slug' => :'slug', :'provider' => :'provider', :'backchannel_providers' => :'backchannel_providers', :'open_in_new_tab' => :'open_in_new_tab', :'meta_launch_url' => :'meta_launch_url', :'meta_icon' => :'meta_icon', :'meta_description' => :'meta_description', :'meta_publisher' => :'meta_publisher', :'policy_engine_mode' => :'policy_engine_mode', :'group' => :'group' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/authentik/api/models/application_request.rb', line 285 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 |
# File 'lib/authentik/api/models/application_request.rb', line 105 def self.openapi_nullable Set.new([ :'provider', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/authentik/api/models/application_request.rb', line 88 def self.openapi_types { :'name' => :'String', :'slug' => :'String', :'provider' => :'Integer', :'backchannel_providers' => :'Array<Integer>', :'open_in_new_tab' => :'Boolean', :'meta_launch_url' => :'String', :'meta_icon' => :'String', :'meta_description' => :'String', :'meta_publisher' => :'String', :'policy_engine_mode' => :'PolicyEngineMode', :'group' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/authentik/api/models/application_request.rb', line 254 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && slug == o.slug && provider == o.provider && backchannel_providers == o.backchannel_providers && open_in_new_tab == o.open_in_new_tab && == o. && == o. && == o. && == o. && policy_engine_mode == o.policy_engine_mode && group == o.group end |
#eql?(o) ⇒ Boolean
272 273 274 |
# File 'lib/authentik/api/models/application_request.rb', line 272 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
278 279 280 |
# File 'lib/authentik/api/models/application_request.rb', line 278 def hash [name, slug, provider, backchannel_providers, open_in_new_tab, , , , , policy_engine_mode, group].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/authentik/api/models/application_request.rb', line 180 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end if @slug.to_s.length < 1 invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/) if @slug !~ pattern invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/authentik/api/models/application_request.rb', line 307 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 213 214 215 216 217 |
# File 'lib/authentik/api/models/application_request.rb', line 209 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @slug.nil? return false if @slug.to_s.length < 1 return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/) true end |