Class: Authentik::Api::AuthenticatedSession
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::AuthenticatedSession
- Defined in:
- lib/authentik/api/models/authenticated_session.rb
Overview
AuthenticatedSession Serializer
Instance Attribute Summary collapse
-
#asn ⇒ Object
Returns the value of attribute asn.
-
#current ⇒ Object
Check if session is currently active session.
-
#expires ⇒ Object
Returns the value of attribute expires.
-
#geo_ip ⇒ Object
Returns the value of attribute geo_ip.
-
#last_ip ⇒ Object
Returns the value of attribute last_ip.
-
#last_used ⇒ Object
Returns the value of attribute last_used.
-
#last_user_agent ⇒ Object
Returns the value of attribute last_user_agent.
-
#user ⇒ Object
Returns the value of attribute user.
-
#user_agent ⇒ Object
Returns the value of attribute user_agent.
-
#uuid ⇒ Object
Returns the value of attribute uuid.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthenticatedSession
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuthenticatedSession
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatedSession` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatedSession`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'current') self.current = attributes[:'current'] else self.current = nil end if attributes.key?(:'user_agent') self.user_agent = attributes[:'user_agent'] else self.user_agent = nil end if attributes.key?(:'geo_ip') self.geo_ip = attributes[:'geo_ip'] else self.geo_ip = nil end if attributes.key?(:'asn') self.asn = attributes[:'asn'] else self.asn = nil end if attributes.key?(:'user') self.user = attributes[:'user'] else self.user = nil end if attributes.key?(:'last_ip') self.last_ip = attributes[:'last_ip'] else self.last_ip = nil end if attributes.key?(:'last_user_agent') self.last_user_agent = attributes[:'last_user_agent'] else self.last_user_agent = nil end if attributes.key?(:'last_used') self.last_used = attributes[:'last_used'] else self.last_used = nil end if attributes.key?(:'expires') self.expires = attributes[:'expires'] else self.expires = nil end end |
Instance Attribute Details
#asn ⇒ Object
Returns the value of attribute asn.
22 23 24 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 22 def asn @asn end |
#current ⇒ Object
Check if session is currently active session
16 17 18 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 16 def current @current end |
#expires ⇒ Object
Returns the value of attribute expires.
32 33 34 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 32 def expires @expires end |
#geo_ip ⇒ Object
Returns the value of attribute geo_ip.
20 21 22 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 20 def geo_ip @geo_ip end |
#last_ip ⇒ Object
Returns the value of attribute last_ip.
26 27 28 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 26 def last_ip @last_ip end |
#last_used ⇒ Object
Returns the value of attribute last_used.
30 31 32 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 30 def last_used @last_used end |
#last_user_agent ⇒ Object
Returns the value of attribute last_user_agent.
28 29 30 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 28 def last_user_agent @last_user_agent end |
#user ⇒ Object
Returns the value of attribute user.
24 25 26 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 24 def user @user end |
#user_agent ⇒ Object
Returns the value of attribute user_agent.
18 19 20 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 18 def user_agent @user_agent end |
#uuid ⇒ Object
Returns the value of attribute uuid.
13 14 15 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 13 def uuid @uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 35 def self.attribute_map { :'uuid' => :'uuid', :'current' => :'current', :'user_agent' => :'user_agent', :'geo_ip' => :'geo_ip', :'asn' => :'asn', :'user' => :'user', :'last_ip' => :'last_ip', :'last_user_agent' => :'last_user_agent', :'last_used' => :'last_used', :'expires' => :'expires' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 311 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 81 82 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 77 def self.openapi_nullable Set.new([ :'geo_ip', :'asn', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 61 def self.openapi_types { :'uuid' => :'String', :'current' => :'Boolean', :'user_agent' => :'AuthenticatedSessionUserAgent', :'geo_ip' => :'AuthenticatedSessionGeoIp', :'asn' => :'AuthenticatedSessionAsn', :'user' => :'Integer', :'last_ip' => :'String', :'last_user_agent' => :'String', :'last_used' => :'Time', :'expires' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && uuid == o.uuid && current == o.current && user_agent == o.user_agent && geo_ip == o.geo_ip && asn == o.asn && user == o.user && last_ip == o.last_ip && last_user_agent == o.last_user_agent && last_used == o.last_used && expires == o.expires end |
#eql?(o) ⇒ Boolean
298 299 300 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 298 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 304 def hash [uuid, current, user_agent, geo_ip, asn, user, last_ip, last_user_agent, last_used, expires].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @current.nil? invalid_properties.push('invalid value for "current", current cannot be nil.') end if @user_agent.nil? invalid_properties.push('invalid value for "user_agent", user_agent cannot be nil.') end if @user.nil? invalid_properties.push('invalid value for "user", user cannot be nil.') end if @last_ip.nil? invalid_properties.push('invalid value for "last_ip", last_ip cannot be nil.') end if @last_user_agent.nil? invalid_properties.push('invalid value for "last_user_agent", last_user_agent cannot be nil.') end if @last_used.nil? invalid_properties.push('invalid value for "last_used", last_used cannot be nil.') end if @expires.nil? invalid_properties.push('invalid value for "expires", expires cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/authentik/api/models/authenticated_session.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @current.nil? return false if @user_agent.nil? return false if @user.nil? return false if @last_ip.nil? return false if @last_user_agent.nil? return false if @last_used.nil? return false if @expires.nil? true end |