Class: Authentik::Api::AuthenticatorEmailStage

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/authenticator_email_stage.rb

Overview

AuthenticatorEmailStage Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthenticatorEmailStage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorEmailStage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorEmailStage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'flow_set')
    if (value = attributes[:'flow_set']).is_a?(Array)
      self.flow_set = value
    end
  else
    self.flow_set = nil
  end

  if attributes.key?(:'configure_flow')
    self.configure_flow = attributes[:'configure_flow']
  end

  if attributes.key?(:'friendly_name')
    self.friendly_name = attributes[:'friendly_name']
  end

  if attributes.key?(:'use_global_settings')
    self.use_global_settings = attributes[:'use_global_settings']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'port')
    self.port = attributes[:'port']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'use_tls')
    self.use_tls = attributes[:'use_tls']
  end

  if attributes.key?(:'use_ssl')
    self.use_ssl = attributes[:'use_ssl']
  end

  if attributes.key?(:'timeout')
    self.timeout = attributes[:'timeout']
  end

  if attributes.key?(:'from_address')
    self.from_address = attributes[:'from_address']
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'token_expiry')
    self.token_expiry = attributes[:'token_expiry']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end
end

Instance Attribute Details

#componentObject

Get object type so that we know how to edit the object



18
19
20
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 18

def component
  @component
end

#configure_flowObject

Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.



32
33
34
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 32

def configure_flow
  @configure_flow
end

#flow_setObject

Returns the value of attribute flow_set.



29
30
31
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 29

def flow_set
  @flow_set
end

#friendly_nameObject

Returns the value of attribute friendly_name.



34
35
36
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 34

def friendly_name
  @friendly_name
end

#from_addressObject

Returns the value of attribute from_address.



53
54
55
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 53

def from_address
  @from_address
end

#hostObject

Returns the value of attribute host.



39
40
41
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 39

def host
  @host
end

#meta_model_nameObject

Return internal model name



27
28
29
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 27

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 15

def name
  @name
end

#passwordObject

Returns the value of attribute password.



45
46
47
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 45

def password
  @password
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 13

def pk
  @pk
end

#portObject

Returns the value of attribute port.



41
42
43
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 41

def port
  @port
end

#subjectObject

Returns the value of attribute subject.



55
56
57
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 55

def subject
  @subject
end

#templateObject

Returns the value of attribute template.



60
61
62
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 60

def template
  @template
end

#timeoutObject

Returns the value of attribute timeout.



51
52
53
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 51

def timeout
  @timeout
end

#token_expiryObject

Time the token sent is valid (Format: hours=3,minutes=17,seconds=300).



58
59
60
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 58

def token_expiry
  @token_expiry
end

#use_global_settingsObject

When enabled, global Email connection settings will be used and connection settings below will be ignored.



37
38
39
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 37

def use_global_settings
  @use_global_settings
end

#use_sslObject

Returns the value of attribute use_ssl.



49
50
51
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 49

def use_ssl
  @use_ssl
end

#use_tlsObject

Returns the value of attribute use_tls.



47
48
49
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 47

def use_tls
  @use_tls
end

#usernameObject

Returns the value of attribute username.



43
44
45
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 43

def username
  @username
end

#verbose_nameObject

Return object’s verbose_name



21
22
23
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 21

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



24
25
26
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 24

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



90
91
92
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 90

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



95
96
97
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 95

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 63

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'flow_set' => :'flow_set',
    :'configure_flow' => :'configure_flow',
    :'friendly_name' => :'friendly_name',
    :'use_global_settings' => :'use_global_settings',
    :'host' => :'host',
    :'port' => :'port',
    :'username' => :'username',
    :'password' => :'password',
    :'use_tls' => :'use_tls',
    :'use_ssl' => :'use_ssl',
    :'timeout' => :'timeout',
    :'from_address' => :'from_address',
    :'subject' => :'subject',
    :'token_expiry' => :'token_expiry',
    :'template' => :'template'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 488

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
131
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 127

def self.openapi_nullable
  Set.new([
    :'configure_flow',
  ])
end

.openapi_typesObject

Attribute type mapping.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 100

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'flow_set' => :'Array<FlowSet>',
    :'configure_flow' => :'String',
    :'friendly_name' => :'String',
    :'use_global_settings' => :'Boolean',
    :'host' => :'String',
    :'port' => :'Integer',
    :'username' => :'String',
    :'password' => :'String',
    :'use_tls' => :'Boolean',
    :'use_ssl' => :'Boolean',
    :'timeout' => :'Integer',
    :'from_address' => :'String',
    :'subject' => :'String',
    :'token_expiry' => :'String',
    :'template' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 447

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      flow_set == o.flow_set &&
      configure_flow == o.configure_flow &&
      friendly_name == o.friendly_name &&
      use_global_settings == o.use_global_settings &&
      host == o.host &&
      port == o.port &&
      username == o.username &&
      password == o.password &&
      use_tls == o.use_tls &&
      use_ssl == o.use_ssl &&
      timeout == o.timeout &&
      from_address == o.from_address &&
      subject == o.subject &&
      token_expiry == o.token_expiry &&
      template == o.template
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


475
476
477
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 475

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



481
482
483
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 481

def hash
  [pk, name, component, verbose_name, verbose_name_plural, meta_model_name, flow_set, configure_flow, friendly_name, use_global_settings, host, port, username, password, use_tls, use_ssl, timeout, from_address, subject, token_expiry, template].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 252

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @flow_set.nil?
    invalid_properties.push('invalid value for "flow_set", flow_set cannot be nil.')
  end

  if !@port.nil? && @port > 2147483647
    invalid_properties.push('invalid value for "port", must be smaller than or equal to 2147483647.')
  end

  if !@port.nil? && @port < -2147483648
    invalid_properties.push('invalid value for "port", must be greater than or equal to -2147483648.')
  end

  if !@timeout.nil? && @timeout > 2147483647
    invalid_properties.push('invalid value for "timeout", must be smaller than or equal to 2147483647.')
  end

  if !@timeout.nil? && @timeout < -2147483648
    invalid_properties.push('invalid value for "timeout", must be greater than or equal to -2147483648.')
  end

  if !@from_address.nil? && @from_address.to_s.length > 254
    invalid_properties.push('invalid value for "from_address", the character length must be smaller than or equal to 254.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 510

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/authentik/api/models/authenticator_email_stage.rb', line 308

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @flow_set.nil?
  return false if !@port.nil? && @port > 2147483647
  return false if !@port.nil? && @port < -2147483648
  return false if !@timeout.nil? && @timeout > 2147483647
  return false if !@timeout.nil? && @timeout < -2147483648
  return false if !@from_address.nil? && @from_address.to_s.length > 254
  true
end