Class: Authentik::Api::AuthenticatorSMSStageRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/authenticator_sms_stage_request.rb

Overview

AuthenticatorSMSStage Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthenticatorSMSStageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorSMSStageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorSMSStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'configure_flow')
    self.configure_flow = attributes[:'configure_flow']
  end

  if attributes.key?(:'friendly_name')
    self.friendly_name = attributes[:'friendly_name']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'from_number')
    self.from_number = attributes[:'from_number']
  else
    self.from_number = nil
  end

  if attributes.key?(:'account_sid')
    self. = attributes[:'account_sid']
  else
    self. = nil
  end

  if attributes.key?(:'auth')
    self.auth = attributes[:'auth']
  else
    self.auth = nil
  end

  if attributes.key?(:'auth_password')
    self.auth_password = attributes[:'auth_password']
  end

  if attributes.key?(:'auth_type')
    self.auth_type = attributes[:'auth_type']
  end

  if attributes.key?(:'verify_only')
    self.verify_only = attributes[:'verify_only']
  end

  if attributes.key?(:'mapping')
    self.mapping = attributes[:'mapping']
  end
end

Instance Attribute Details

#account_sidObject

Returns the value of attribute account_sid.



24
25
26
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 24

def 
  @account_sid
end

#authObject

Returns the value of attribute auth.



26
27
28
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 26

def auth
  @auth
end

#auth_passwordObject

Returns the value of attribute auth_password.



28
29
30
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 28

def auth_password
  @auth_password
end

#auth_typeObject

Returns the value of attribute auth_type.



30
31
32
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 30

def auth_type
  @auth_type
end

#configure_flowObject

Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.



16
17
18
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 16

def configure_flow
  @configure_flow
end

#friendly_nameObject

Returns the value of attribute friendly_name.



18
19
20
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 18

def friendly_name
  @friendly_name
end

#from_numberObject

Returns the value of attribute from_number.



22
23
24
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 22

def from_number
  @from_number
end

#mappingObject

Optionally modify the payload being sent to custom providers.



36
37
38
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 36

def mapping
  @mapping
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 13

def name
  @name
end

#providerObject

Returns the value of attribute provider.



20
21
22
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 20

def provider
  @provider
end

#verify_onlyObject

When enabled, the Phone number is only used during enrollment to verify the users authenticity. Only a hash of the phone number is saved to ensure it is not reused in the future.



33
34
35
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 33

def verify_only
  @verify_only
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 61

def self.attribute_map
  {
    :'name' => :'name',
    :'configure_flow' => :'configure_flow',
    :'friendly_name' => :'friendly_name',
    :'provider' => :'provider',
    :'from_number' => :'from_number',
    :'account_sid' => :'account_sid',
    :'auth' => :'auth',
    :'auth_password' => :'auth_password',
    :'auth_type' => :'auth_type',
    :'verify_only' => :'verify_only',
    :'mapping' => :'mapping'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 342

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
109
110
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 105

def self.openapi_nullable
  Set.new([
    :'configure_flow',
    :'mapping'
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 88

def self.openapi_types
  {
    :'name' => :'String',
    :'configure_flow' => :'String',
    :'friendly_name' => :'String',
    :'provider' => :'ProviderEnum',
    :'from_number' => :'String',
    :'account_sid' => :'String',
    :'auth' => :'String',
    :'auth_password' => :'String',
    :'auth_type' => :'AuthTypeEnum',
    :'verify_only' => :'Boolean',
    :'mapping' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 311

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      configure_flow == o.configure_flow &&
      friendly_name == o.friendly_name &&
      provider == o.provider &&
      from_number == o.from_number &&
       == o. &&
      auth == o.auth &&
      auth_password == o.auth_password &&
      auth_type == o.auth_type &&
      verify_only == o.verify_only &&
      mapping == o.mapping
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


329
330
331
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 329

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



335
336
337
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 335

def hash
  [name, configure_flow, friendly_name, provider, from_number, , auth, auth_password, auth_type, verify_only, mapping].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 185

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @from_number.nil?
    invalid_properties.push('invalid value for "from_number", from_number cannot be nil.')
  end

  if @from_number.to_s.length < 1
    invalid_properties.push('invalid value for "from_number", the character length must be greater than or equal to 1.')
  end

  if @account_sid.nil?
    invalid_properties.push('invalid value for "account_sid", account_sid cannot be nil.')
  end

  if @account_sid.to_s.length < 1
    invalid_properties.push('invalid value for "account_sid", the character length must be greater than or equal to 1.')
  end

  if @auth.nil?
    invalid_properties.push('invalid value for "auth", auth cannot be nil.')
  end

  if @auth.to_s.length < 1
    invalid_properties.push('invalid value for "auth", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 364

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/authentik/api/models/authenticator_sms_stage_request.rb', line 229

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @provider.nil?
  return false if @from_number.nil?
  return false if @from_number.to_s.length < 1
  return false if @account_sid.nil?
  return false if @account_sid.to_s.length < 1
  return false if @auth.nil?
  return false if @auth.to_s.length < 1
  true
end