Class: Authentik::Api::AuthenticatorStaticStage

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/authenticator_static_stage.rb

Overview

AuthenticatorStaticStage Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthenticatorStaticStage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorStaticStage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorStaticStage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'flow_set')
    if (value = attributes[:'flow_set']).is_a?(Array)
      self.flow_set = value
    end
  else
    self.flow_set = nil
  end

  if attributes.key?(:'configure_flow')
    self.configure_flow = attributes[:'configure_flow']
  end

  if attributes.key?(:'friendly_name')
    self.friendly_name = attributes[:'friendly_name']
  end

  if attributes.key?(:'token_count')
    self.token_count = attributes[:'token_count']
  end

  if attributes.key?(:'token_length')
    self.token_length = attributes[:'token_length']
  end
end

Instance Attribute Details

#componentObject

Get object type so that we know how to edit the object



18
19
20
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 18

def component
  @component
end

#configure_flowObject

Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.



32
33
34
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 32

def configure_flow
  @configure_flow
end

#flow_setObject

Returns the value of attribute flow_set.



29
30
31
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 29

def flow_set
  @flow_set
end

#friendly_nameObject

Returns the value of attribute friendly_name.



34
35
36
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 34

def friendly_name
  @friendly_name
end

#meta_model_nameObject

Return internal model name



27
28
29
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 27

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 15

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 13

def pk
  @pk
end

#token_countObject

Returns the value of attribute token_count.



36
37
38
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 36

def token_count
  @token_count
end

#token_lengthObject

Returns the value of attribute token_length.



38
39
40
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 38

def token_length
  @token_length
end

#verbose_nameObject

Return object’s verbose_name



21
22
23
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 21

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



24
25
26
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 24

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 41

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'flow_set' => :'flow_set',
    :'configure_flow' => :'configure_flow',
    :'friendly_name' => :'friendly_name',
    :'token_count' => :'token_count',
    :'token_length' => :'token_length'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 377

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
89
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 85

def self.openapi_nullable
  Set.new([
    :'configure_flow',
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 68

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'flow_set' => :'Array<FlowSet>',
    :'configure_flow' => :'String',
    :'friendly_name' => :'String',
    :'token_count' => :'Integer',
    :'token_length' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 346

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      flow_set == o.flow_set &&
      configure_flow == o.configure_flow &&
      friendly_name == o.friendly_name &&
      token_count == o.token_count &&
      token_length == o.token_length
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


364
365
366
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 364

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



370
371
372
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 370

def hash
  [pk, name, component, verbose_name, verbose_name_plural, meta_model_name, flow_set, configure_flow, friendly_name, token_count, token_length].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 170

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @flow_set.nil?
    invalid_properties.push('invalid value for "flow_set", flow_set cannot be nil.')
  end

  if !@token_count.nil? && @token_count > 2147483647
    invalid_properties.push('invalid value for "token_count", must be smaller than or equal to 2147483647.')
  end

  if !@token_count.nil? && @token_count < 0
    invalid_properties.push('invalid value for "token_count", must be greater than or equal to 0.')
  end

  if !@token_length.nil? && @token_length > 100
    invalid_properties.push('invalid value for "token_length", must be smaller than or equal to 100.')
  end

  if !@token_length.nil? && @token_length < 0
    invalid_properties.push('invalid value for "token_length", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 399

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/authentik/api/models/authenticator_static_stage.rb', line 222

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @flow_set.nil?
  return false if !@token_count.nil? && @token_count > 2147483647
  return false if !@token_count.nil? && @token_count < 0
  return false if !@token_length.nil? && @token_length > 100
  return false if !@token_length.nil? && @token_length < 0
  true
end