Class: Authentik::Api::AuthenticatorTOTPChallenge
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::AuthenticatorTOTPChallenge
- Defined in:
- lib/authentik/api/models/authenticator_totp_challenge.rb
Overview
TOTP Setup challenge
Instance Attribute Summary collapse
-
#component ⇒ Object
Returns the value of attribute component.
-
#config_url ⇒ Object
Returns the value of attribute config_url.
-
#flow_info ⇒ Object
Returns the value of attribute flow_info.
-
#pending_user ⇒ Object
Returns the value of attribute pending_user.
-
#pending_user_avatar ⇒ Object
Returns the value of attribute pending_user_avatar.
-
#response_errors ⇒ Object
Returns the value of attribute response_errors.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthenticatorTOTPChallenge
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuthenticatorTOTPChallenge
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorTOTPChallenge` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorTOTPChallenge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'flow_info') self.flow_info = attributes[:'flow_info'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = 'ak-stage-authenticator-totp' end if attributes.key?(:'response_errors') if (value = attributes[:'response_errors']).is_a?(Hash) self.response_errors = value end end if attributes.key?(:'pending_user') self.pending_user = attributes[:'pending_user'] else self.pending_user = nil end if attributes.key?(:'pending_user_avatar') self.pending_user_avatar = attributes[:'pending_user_avatar'] else self.pending_user_avatar = nil end if attributes.key?(:'config_url') self.config_url = attributes[:'config_url'] else self.config_url = nil end end |
Instance Attribute Details
#component ⇒ Object
Returns the value of attribute component.
15 16 17 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 15 def component @component end |
#config_url ⇒ Object
Returns the value of attribute config_url.
23 24 25 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 23 def config_url @config_url end |
#flow_info ⇒ Object
Returns the value of attribute flow_info.
13 14 15 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 13 def flow_info @flow_info end |
#pending_user ⇒ Object
Returns the value of attribute pending_user.
19 20 21 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 19 def pending_user @pending_user end |
#pending_user_avatar ⇒ Object
Returns the value of attribute pending_user_avatar.
21 22 23 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 21 def pending_user_avatar @pending_user_avatar end |
#response_errors ⇒ Object
Returns the value of attribute response_errors.
17 18 19 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 17 def response_errors @response_errors end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 26 def self.attribute_map { :'flow_info' => :'flow_info', :'component' => :'component', :'response_errors' => :'response_errors', :'pending_user' => :'pending_user', :'pending_user_avatar' => :'pending_user_avatar', :'config_url' => :'config_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 204 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 48 def self.openapi_types { :'flow_info' => :'ContextualFlowInfo', :'component' => :'String', :'response_errors' => :'Hash<String, Array<ErrorDetail>>', :'pending_user' => :'String', :'pending_user_avatar' => :'String', :'config_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && flow_info == o.flow_info && component == o.component && response_errors == o.response_errors && pending_user == o.pending_user && pending_user_avatar == o.pending_user_avatar && config_url == o.config_url end |
#eql?(o) ⇒ Boolean
191 192 193 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 191 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 197 def hash [flow_info, component, response_errors, pending_user, pending_user_avatar, config_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pending_user.nil? invalid_properties.push('invalid value for "pending_user", pending_user cannot be nil.') end if @pending_user_avatar.nil? invalid_properties.push('invalid value for "pending_user_avatar", pending_user_avatar cannot be nil.') end if @config_url.nil? invalid_properties.push('invalid value for "config_url", config_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 226 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 143 144 |
# File 'lib/authentik/api/models/authenticator_totp_challenge.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pending_user.nil? return false if @pending_user_avatar.nil? return false if @config_url.nil? true end |