Class: Authentik::Api::AuthenticatorValidateStage

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/authenticator_validate_stage.rb

Overview

AuthenticatorValidateStage Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthenticatorValidateStage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorValidateStage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorValidateStage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'flow_set')
    if (value = attributes[:'flow_set']).is_a?(Array)
      self.flow_set = value
    end
  else
    self.flow_set = nil
  end

  if attributes.key?(:'not_configured_action')
    self.not_configured_action = attributes[:'not_configured_action']
  end

  if attributes.key?(:'device_classes')
    if (value = attributes[:'device_classes']).is_a?(Array)
      self.device_classes = value
    end
  end

  if attributes.key?(:'configuration_stages')
    if (value = attributes[:'configuration_stages']).is_a?(Array)
      self.configuration_stages = value
    end
  end

  if attributes.key?(:'last_auth_threshold')
    self.last_auth_threshold = attributes[:'last_auth_threshold']
  end

  if attributes.key?(:'webauthn_user_verification')
    self.webauthn_user_verification = attributes[:'webauthn_user_verification']
  end

  if attributes.key?(:'webauthn_hints')
    if (value = attributes[:'webauthn_hints']).is_a?(Array)
      self.webauthn_hints = value
    end
  end

  if attributes.key?(:'webauthn_allowed_device_types')
    if (value = attributes[:'webauthn_allowed_device_types']).is_a?(Array)
      self.webauthn_allowed_device_types = value
    end
  end

  if attributes.key?(:'webauthn_allowed_device_types_obj')
    if (value = attributes[:'webauthn_allowed_device_types_obj']).is_a?(Array)
      self.webauthn_allowed_device_types_obj = value
    end
  else
    self.webauthn_allowed_device_types_obj = nil
  end

  if attributes.key?(:'email_otp_throttling_factor')
    self.email_otp_throttling_factor = attributes[:'email_otp_throttling_factor']
  end

  if attributes.key?(:'sms_otp_throttling_factor')
    self.sms_otp_throttling_factor = attributes[:'sms_otp_throttling_factor']
  end

  if attributes.key?(:'totp_otp_throttling_factor')
    self.totp_otp_throttling_factor = attributes[:'totp_otp_throttling_factor']
  end

  if attributes.key?(:'static_otp_throttling_factor')
    self.static_otp_throttling_factor = attributes[:'static_otp_throttling_factor']
  end
end

Instance Attribute Details

#componentObject

Get object type so that we know how to edit the object



18
19
20
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 18

def component
  @component
end

#configuration_stagesObject

Stages used to configure Authenticator when user doesn’t have any compatible devices. After this configuration Stage passes, the user is not prompted again.



37
38
39
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 37

def configuration_stages
  @configuration_stages
end

#device_classesObject

Device classes which can be used to authenticate



34
35
36
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 34

def device_classes
  @device_classes
end

#email_otp_throttling_factorObject

Returns the value of attribute email_otp_throttling_factor.



51
52
53
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 51

def email_otp_throttling_factor
  @email_otp_throttling_factor
end

#flow_setObject

Returns the value of attribute flow_set.



29
30
31
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 29

def flow_set
  @flow_set
end

#last_auth_thresholdObject

If any of the user’s device has been used within this threshold, this stage will be skipped



40
41
42
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 40

def last_auth_threshold
  @last_auth_threshold
end

#meta_model_nameObject

Return internal model name



27
28
29
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 27

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 15

def name
  @name
end

#not_configured_actionObject

Returns the value of attribute not_configured_action.



31
32
33
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 31

def not_configured_action
  @not_configured_action
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 13

def pk
  @pk
end

#sms_otp_throttling_factorObject

Returns the value of attribute sms_otp_throttling_factor.



53
54
55
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 53

def sms_otp_throttling_factor
  @sms_otp_throttling_factor
end

#static_otp_throttling_factorObject

Returns the value of attribute static_otp_throttling_factor.



57
58
59
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 57

def static_otp_throttling_factor
  @static_otp_throttling_factor
end

#totp_otp_throttling_factorObject

Returns the value of attribute totp_otp_throttling_factor.



55
56
57
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 55

def totp_otp_throttling_factor
  @totp_otp_throttling_factor
end

#verbose_nameObject

Return object’s verbose_name



21
22
23
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 21

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



24
25
26
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 24

def verbose_name_plural
  @verbose_name_plural
end

#webauthn_allowed_device_typesObject

Returns the value of attribute webauthn_allowed_device_types.



47
48
49
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 47

def webauthn_allowed_device_types
  @webauthn_allowed_device_types
end

#webauthn_allowed_device_types_objObject

Returns the value of attribute webauthn_allowed_device_types_obj.



49
50
51
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 49

def webauthn_allowed_device_types_obj
  @webauthn_allowed_device_types_obj
end

#webauthn_hintsObject

Returns the value of attribute webauthn_hints.



45
46
47
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 45

def webauthn_hints
  @webauthn_hints
end

#webauthn_user_verificationObject

Enforce user verification for WebAuthn devices.



43
44
45
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 43

def webauthn_user_verification
  @webauthn_user_verification
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



107
108
109
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 107

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



112
113
114
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 112

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 82

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'flow_set' => :'flow_set',
    :'not_configured_action' => :'not_configured_action',
    :'device_classes' => :'device_classes',
    :'configuration_stages' => :'configuration_stages',
    :'last_auth_threshold' => :'last_auth_threshold',
    :'webauthn_user_verification' => :'webauthn_user_verification',
    :'webauthn_hints' => :'webauthn_hints',
    :'webauthn_allowed_device_types' => :'webauthn_allowed_device_types',
    :'webauthn_allowed_device_types_obj' => :'webauthn_allowed_device_types_obj',
    :'email_otp_throttling_factor' => :'email_otp_throttling_factor',
    :'sms_otp_throttling_factor' => :'sms_otp_throttling_factor',
    :'totp_otp_throttling_factor' => :'totp_otp_throttling_factor',
    :'static_otp_throttling_factor' => :'static_otp_throttling_factor'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 444

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



142
143
144
145
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 142

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 117

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'flow_set' => :'Array<FlowSet>',
    :'not_configured_action' => :'NotConfiguredActionEnum',
    :'device_classes' => :'Array<DeviceClassesEnum>',
    :'configuration_stages' => :'Array<String>',
    :'last_auth_threshold' => :'String',
    :'webauthn_user_verification' => :'UserVerificationEnum',
    :'webauthn_hints' => :'Array<WebAuthnHintEnum>',
    :'webauthn_allowed_device_types' => :'Array<String>',
    :'webauthn_allowed_device_types_obj' => :'Array<WebAuthnDeviceType>',
    :'email_otp_throttling_factor' => :'Float',
    :'sms_otp_throttling_factor' => :'Float',
    :'totp_otp_throttling_factor' => :'Float',
    :'static_otp_throttling_factor' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 405

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      flow_set == o.flow_set &&
      not_configured_action == o.not_configured_action &&
      device_classes == o.device_classes &&
      configuration_stages == o.configuration_stages &&
      last_auth_threshold == o.last_auth_threshold &&
      webauthn_user_verification == o.webauthn_user_verification &&
      webauthn_hints == o.webauthn_hints &&
      webauthn_allowed_device_types == o.webauthn_allowed_device_types &&
      webauthn_allowed_device_types_obj == o.webauthn_allowed_device_types_obj &&
      email_otp_throttling_factor == o.email_otp_throttling_factor &&
      sms_otp_throttling_factor == o.sms_otp_throttling_factor &&
      totp_otp_throttling_factor == o.totp_otp_throttling_factor &&
      static_otp_throttling_factor == o.static_otp_throttling_factor
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


431
432
433
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 431

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



437
438
439
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 437

def hash
  [pk, name, component, verbose_name, verbose_name_plural, meta_model_name, flow_set, not_configured_action, device_classes, configuration_stages, last_auth_threshold, webauthn_user_verification, webauthn_hints, webauthn_allowed_device_types, webauthn_allowed_device_types_obj, email_otp_throttling_factor, sms_otp_throttling_factor, totp_otp_throttling_factor, static_otp_throttling_factor].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 270

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @flow_set.nil?
    invalid_properties.push('invalid value for "flow_set", flow_set cannot be nil.')
  end

  if @webauthn_allowed_device_types_obj.nil?
    invalid_properties.push('invalid value for "webauthn_allowed_device_types_obj", webauthn_allowed_device_types_obj cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 466

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/authentik/api/models/authenticator_validate_stage.rb', line 310

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @flow_set.nil?
  return false if @webauthn_allowed_device_types_obj.nil?
  true
end