Class: Authentik::Api::AuthenticatorValidateStageRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/authenticator_validate_stage_request.rb

Overview

AuthenticatorValidateStage Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthenticatorValidateStageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorValidateStageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorValidateStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'not_configured_action')
    self.not_configured_action = attributes[:'not_configured_action']
  end

  if attributes.key?(:'device_classes')
    if (value = attributes[:'device_classes']).is_a?(Array)
      self.device_classes = value
    end
  end

  if attributes.key?(:'configuration_stages')
    if (value = attributes[:'configuration_stages']).is_a?(Array)
      self.configuration_stages = value
    end
  end

  if attributes.key?(:'last_auth_threshold')
    self.last_auth_threshold = attributes[:'last_auth_threshold']
  end

  if attributes.key?(:'webauthn_user_verification')
    self.webauthn_user_verification = attributes[:'webauthn_user_verification']
  end

  if attributes.key?(:'webauthn_hints')
    if (value = attributes[:'webauthn_hints']).is_a?(Array)
      self.webauthn_hints = value
    end
  end

  if attributes.key?(:'webauthn_allowed_device_types')
    if (value = attributes[:'webauthn_allowed_device_types']).is_a?(Array)
      self.webauthn_allowed_device_types = value
    end
  end

  if attributes.key?(:'email_otp_throttling_factor')
    self.email_otp_throttling_factor = attributes[:'email_otp_throttling_factor']
  end

  if attributes.key?(:'sms_otp_throttling_factor')
    self.sms_otp_throttling_factor = attributes[:'sms_otp_throttling_factor']
  end

  if attributes.key?(:'totp_otp_throttling_factor')
    self.totp_otp_throttling_factor = attributes[:'totp_otp_throttling_factor']
  end

  if attributes.key?(:'static_otp_throttling_factor')
    self.static_otp_throttling_factor = attributes[:'static_otp_throttling_factor']
  end
end

Instance Attribute Details

#configuration_stagesObject

Stages used to configure Authenticator when user doesn’t have any compatible devices. After this configuration Stage passes, the user is not prompted again.



21
22
23
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 21

def configuration_stages
  @configuration_stages
end

#device_classesObject

Device classes which can be used to authenticate



18
19
20
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 18

def device_classes
  @device_classes
end

#email_otp_throttling_factorObject

Returns the value of attribute email_otp_throttling_factor.



33
34
35
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 33

def email_otp_throttling_factor
  @email_otp_throttling_factor
end

#last_auth_thresholdObject

If any of the user’s device has been used within this threshold, this stage will be skipped



24
25
26
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 24

def last_auth_threshold
  @last_auth_threshold
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 13

def name
  @name
end

#not_configured_actionObject

Returns the value of attribute not_configured_action.



15
16
17
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 15

def not_configured_action
  @not_configured_action
end

#sms_otp_throttling_factorObject

Returns the value of attribute sms_otp_throttling_factor.



35
36
37
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 35

def sms_otp_throttling_factor
  @sms_otp_throttling_factor
end

#static_otp_throttling_factorObject

Returns the value of attribute static_otp_throttling_factor.



39
40
41
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 39

def static_otp_throttling_factor
  @static_otp_throttling_factor
end

#totp_otp_throttling_factorObject

Returns the value of attribute totp_otp_throttling_factor.



37
38
39
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 37

def totp_otp_throttling_factor
  @totp_otp_throttling_factor
end

#webauthn_allowed_device_typesObject

Returns the value of attribute webauthn_allowed_device_types.



31
32
33
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 31

def webauthn_allowed_device_types
  @webauthn_allowed_device_types
end

#webauthn_hintsObject

Returns the value of attribute webauthn_hints.



29
30
31
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 29

def webauthn_hints
  @webauthn_hints
end

#webauthn_user_verificationObject

Enforce user verification for WebAuthn devices.



27
28
29
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 27

def webauthn_user_verification
  @webauthn_user_verification
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 64

def self.attribute_map
  {
    :'name' => :'name',
    :'not_configured_action' => :'not_configured_action',
    :'device_classes' => :'device_classes',
    :'configuration_stages' => :'configuration_stages',
    :'last_auth_threshold' => :'last_auth_threshold',
    :'webauthn_user_verification' => :'webauthn_user_verification',
    :'webauthn_hints' => :'webauthn_hints',
    :'webauthn_allowed_device_types' => :'webauthn_allowed_device_types',
    :'email_otp_throttling_factor' => :'email_otp_throttling_factor',
    :'sms_otp_throttling_factor' => :'sms_otp_throttling_factor',
    :'totp_otp_throttling_factor' => :'totp_otp_throttling_factor',
    :'static_otp_throttling_factor' => :'static_otp_throttling_factor'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 282

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 110

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 92

def self.openapi_types
  {
    :'name' => :'String',
    :'not_configured_action' => :'NotConfiguredActionEnum',
    :'device_classes' => :'Array<DeviceClassesEnum>',
    :'configuration_stages' => :'Array<String>',
    :'last_auth_threshold' => :'String',
    :'webauthn_user_verification' => :'UserVerificationEnum',
    :'webauthn_hints' => :'Array<WebAuthnHintEnum>',
    :'webauthn_allowed_device_types' => :'Array<String>',
    :'email_otp_throttling_factor' => :'Float',
    :'sms_otp_throttling_factor' => :'Float',
    :'totp_otp_throttling_factor' => :'Float',
    :'static_otp_throttling_factor' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      not_configured_action == o.not_configured_action &&
      device_classes == o.device_classes &&
      configuration_stages == o.configuration_stages &&
      last_auth_threshold == o.last_auth_threshold &&
      webauthn_user_verification == o.webauthn_user_verification &&
      webauthn_hints == o.webauthn_hints &&
      webauthn_allowed_device_types == o.webauthn_allowed_device_types &&
      email_otp_throttling_factor == o.email_otp_throttling_factor &&
      sms_otp_throttling_factor == o.sms_otp_throttling_factor &&
      totp_otp_throttling_factor == o.totp_otp_throttling_factor &&
      static_otp_throttling_factor == o.static_otp_throttling_factor
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 275

def hash
  [name, not_configured_action, device_classes, configuration_stages, last_auth_threshold, webauthn_user_verification, webauthn_hints, webauthn_allowed_device_types, email_otp_throttling_factor, sms_otp_throttling_factor, totp_otp_throttling_factor, static_otp_throttling_factor].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@last_auth_threshold.nil? && @last_auth_threshold.to_s.length < 1
    invalid_properties.push('invalid value for "last_auth_threshold", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
# File 'lib/authentik/api/models/authenticator_validate_stage_request.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if !@last_auth_threshold.nil? && @last_auth_threshold.to_s.length < 1
  true
end