Class: Authentik::Api::AuthenticatorValidationChallenge

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/authenticator_validation_challenge.rb

Overview

Authenticator challenge

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthenticatorValidationChallenge

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorValidationChallenge` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorValidationChallenge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flow_info')
    self.flow_info = attributes[:'flow_info']
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = 'ak-stage-authenticator-validate'
  end

  if attributes.key?(:'response_errors')
    if (value = attributes[:'response_errors']).is_a?(Hash)
      self.response_errors = value
    end
  end

  if attributes.key?(:'pending_user')
    self.pending_user = attributes[:'pending_user']
  else
    self.pending_user = nil
  end

  if attributes.key?(:'pending_user_avatar')
    self.pending_user_avatar = attributes[:'pending_user_avatar']
  else
    self.pending_user_avatar = nil
  end

  if attributes.key?(:'device_challenges')
    if (value = attributes[:'device_challenges']).is_a?(Array)
      self.device_challenges = value
    end
  else
    self.device_challenges = nil
  end

  if attributes.key?(:'configuration_stages')
    if (value = attributes[:'configuration_stages']).is_a?(Array)
      self.configuration_stages = value
    end
  else
    self.configuration_stages = nil
  end
end

Instance Attribute Details

#componentObject

Returns the value of attribute component.



15
16
17
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 15

def component
  @component
end

#configuration_stagesObject

Returns the value of attribute configuration_stages.



25
26
27
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 25

def configuration_stages
  @configuration_stages
end

#device_challengesObject

Returns the value of attribute device_challenges.



23
24
25
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 23

def device_challenges
  @device_challenges
end

#flow_infoObject

Returns the value of attribute flow_info.



13
14
15
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 13

def flow_info
  @flow_info
end

#pending_userObject

Returns the value of attribute pending_user.



19
20
21
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 19

def pending_user
  @pending_user
end

#pending_user_avatarObject

Returns the value of attribute pending_user_avatar.



21
22
23
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 21

def pending_user_avatar
  @pending_user_avatar
end

#response_errorsObject

Returns the value of attribute response_errors.



17
18
19
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 17

def response_errors
  @response_errors
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
37
38
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 28

def self.attribute_map
  {
    :'flow_info' => :'flow_info',
    :'component' => :'component',
    :'response_errors' => :'response_errors',
    :'pending_user' => :'pending_user',
    :'pending_user_avatar' => :'pending_user_avatar',
    :'device_challenges' => :'device_challenges',
    :'configuration_stages' => :'configuration_stages'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



64
65
66
67
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 64

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 51

def self.openapi_types
  {
    :'flow_info' => :'ContextualFlowInfo',
    :'component' => :'String',
    :'response_errors' => :'Hash<String, Array<ErrorDetail>>',
    :'pending_user' => :'String',
    :'pending_user_avatar' => :'String',
    :'device_challenges' => :'Array<DeviceChallenge>',
    :'configuration_stages' => :'Array<SelectableStage>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
215
216
217
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flow_info == o.flow_info &&
      component == o.component &&
      response_errors == o.response_errors &&
      pending_user == o.pending_user &&
      pending_user_avatar == o.pending_user_avatar &&
      device_challenges == o.device_challenges &&
      configuration_stages == o.configuration_stages
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 227

def hash
  [flow_info, component, response_errors, pending_user, pending_user_avatar, device_challenges, configuration_stages].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pending_user.nil?
    invalid_properties.push('invalid value for "pending_user", pending_user cannot be nil.')
  end

  if @pending_user_avatar.nil?
    invalid_properties.push('invalid value for "pending_user_avatar", pending_user_avatar cannot be nil.')
  end

  if @device_challenges.nil?
    invalid_properties.push('invalid value for "device_challenges", device_challenges cannot be nil.')
  end

  if @configuration_stages.nil?
    invalid_properties.push('invalid value for "configuration_stages", configuration_stages cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
162
163
# File 'lib/authentik/api/models/authenticator_validation_challenge.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pending_user.nil?
  return false if @pending_user_avatar.nil?
  return false if @device_challenges.nil?
  return false if @configuration_stages.nil?
  true
end