Class: Authentik::Api::AuthenticatorValidationChallengeResponseRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::AuthenticatorValidationChallengeResponseRequest
- Defined in:
- lib/authentik/api/models/authenticator_validation_challenge_response_request.rb
Overview
Challenge used for Code-based and WebAuthn authenticators
Instance Attribute Summary collapse
-
#code ⇒ Object
Returns the value of attribute code.
-
#component ⇒ Object
Returns the value of attribute component.
-
#duo ⇒ Object
Returns the value of attribute duo.
-
#selected_challenge ⇒ Object
Returns the value of attribute selected_challenge.
-
#selected_stage ⇒ Object
Returns the value of attribute selected_stage.
-
#webauthn ⇒ Object
Returns the value of attribute webauthn.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthenticatorValidationChallengeResponseRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuthenticatorValidationChallengeResponseRequest
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorValidationChallengeResponseRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorValidationChallengeResponseRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = 'ak-stage-authenticator-validate' end if attributes.key?(:'selected_challenge') self.selected_challenge = attributes[:'selected_challenge'] end if attributes.key?(:'selected_stage') self.selected_stage = attributes[:'selected_stage'] end if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'webauthn') if (value = attributes[:'webauthn']).is_a?(Hash) self.webauthn = value end end if attributes.key?(:'duo') self.duo = attributes[:'duo'] end end |
Instance Attribute Details
#code ⇒ Object
Returns the value of attribute code.
19 20 21 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 19 def code @code end |
#component ⇒ Object
Returns the value of attribute component.
13 14 15 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 13 def component @component end |
#duo ⇒ Object
Returns the value of attribute duo.
23 24 25 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 23 def duo @duo end |
#selected_challenge ⇒ Object
Returns the value of attribute selected_challenge.
15 16 17 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 15 def selected_challenge @selected_challenge end |
#selected_stage ⇒ Object
Returns the value of attribute selected_stage.
17 18 19 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 17 def selected_stage @selected_stage end |
#webauthn ⇒ Object
Returns the value of attribute webauthn.
21 22 23 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 21 def webauthn @webauthn end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 26 def self.attribute_map { :'component' => :'component', :'selected_challenge' => :'selected_challenge', :'selected_stage' => :'selected_stage', :'code' => :'code', :'webauthn' => :'webauthn', :'duo' => :'duo' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 48 def self.openapi_types { :'component' => :'String', :'selected_challenge' => :'DeviceChallengeRequest', :'selected_stage' => :'String', :'code' => :'String', :'webauthn' => :'Hash<String, Object>', :'duo' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
184 185 186 187 188 189 190 191 192 193 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 184 def ==(o) return true if self.equal?(o) self.class == o.class && component == o.component && selected_challenge == o.selected_challenge && selected_stage == o.selected_stage && code == o.code && webauthn == o.webauthn && duo == o.duo end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 203 def hash [component, selected_challenge, selected_stage, code, webauthn, duo].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@component.nil? && @component.to_s.length < 1 invalid_properties.push('invalid value for "component", the character length must be greater than or equal to 1.') end if !@selected_stage.nil? && @selected_stage.to_s.length < 1 invalid_properties.push('invalid value for "selected_stage", the character length must be greater than or equal to 1.') end if !@code.nil? && @code.to_s.length < 1 invalid_properties.push('invalid value for "code", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 137 138 |
# File 'lib/authentik/api/models/authenticator_validation_challenge_response_request.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@component.nil? && @component.to_s.length < 1 return false if !@selected_stage.nil? && @selected_stage.to_s.length < 1 return false if !@code.nil? && @code.to_s.length < 1 true end |