Class: Authentik::Api::AuthenticatorWebAuthnChallengeResponseRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::AuthenticatorWebAuthnChallengeResponseRequest
- Defined in:
- lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb
Overview
WebAuthn Challenge response
Instance Attribute Summary collapse
-
#component ⇒ Object
Returns the value of attribute component.
-
#response ⇒ Object
Returns the value of attribute response.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthenticatorWebAuthnChallengeResponseRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuthenticatorWebAuthnChallengeResponseRequest
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 51 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorWebAuthnChallengeResponseRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorWebAuthnChallengeResponseRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = 'ak-stage-authenticator-webauthn' end if attributes.key?(:'response') if (value = attributes[:'response']).is_a?(Hash) self.response = value end else self.response = nil end end |
Instance Attribute Details
#component ⇒ Object
Returns the value of attribute component.
13 14 15 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 13 def component @component end |
#response ⇒ Object
Returns the value of attribute response.
15 16 17 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 15 def response @response end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
26 27 28 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 26 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
31 32 33 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 31 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 18 def self.attribute_map { :'component' => :'component', :'response' => :'response' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 153 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
44 45 46 47 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 44 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 36 def self.openapi_types { :'component' => :'String', :'response' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
131 132 133 134 135 136 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 131 def ==(o) return true if self.equal?(o) self.class == o.class && component == o.component && response == o.response end |
#eql?(o) ⇒ Boolean
140 141 142 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 140 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 146 def hash [component, response].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 82 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@component.nil? && @component.to_s.length < 1 invalid_properties.push('invalid value for "component", the character length must be greater than or equal to 1.') end if @response.nil? invalid_properties.push('invalid value for "response", response cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
98 99 100 101 102 103 |
# File 'lib/authentik/api/models/authenticator_web_authn_challenge_response_request.rb', line 98 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@component.nil? && @component.to_s.length < 1 return false if @response.nil? true end |