Class: Authentik::Api::AuthenticatorWebAuthnStage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::AuthenticatorWebAuthnStage
- Defined in:
- lib/authentik/api/models/authenticator_web_authn_stage.rb
Overview
AuthenticatorWebAuthnStage Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#authenticator_attachment ⇒ Object
Returns the value of attribute authenticator_attachment.
-
#component ⇒ Object
Get object type so that we know how to edit the object.
-
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage.
-
#device_type_restrictions ⇒ Object
Returns the value of attribute device_type_restrictions.
-
#device_type_restrictions_obj ⇒ Object
Returns the value of attribute device_type_restrictions_obj.
-
#flow_set ⇒ Object
Returns the value of attribute flow_set.
-
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
-
#hints ⇒ Object
Returns the value of attribute hints.
-
#max_attempts ⇒ Object
Returns the value of attribute max_attempts.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#resident_key_requirement ⇒ Object
Returns the value of attribute resident_key_requirement.
-
#user_verification ⇒ Object
Returns the value of attribute user_verification.
-
#verbose_name ⇒ Object
Return object's verbose_name.
-
#verbose_name_plural ⇒ Object
Return object's plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthenticatorWebAuthnStage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuthenticatorWebAuthnStage
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorWebAuthnStage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorWebAuthnStage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'flow_set') if (value = attributes[:'flow_set']).is_a?(Array) self.flow_set = value end else self.flow_set = nil end if attributes.key?(:'configure_flow') self.configure_flow = attributes[:'configure_flow'] end if attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] end if attributes.key?(:'user_verification') self.user_verification = attributes[:'user_verification'] end if attributes.key?(:'authenticator_attachment') self. = attributes[:'authenticator_attachment'] end if attributes.key?(:'resident_key_requirement') self.resident_key_requirement = attributes[:'resident_key_requirement'] end if attributes.key?(:'hints') if (value = attributes[:'hints']).is_a?(Array) self.hints = value end end if attributes.key?(:'device_type_restrictions') if (value = attributes[:'device_type_restrictions']).is_a?(Array) self.device_type_restrictions = value end end if attributes.key?(:'device_type_restrictions_obj') if (value = attributes[:'device_type_restrictions_obj']).is_a?(Array) self.device_type_restrictions_obj = value end else self.device_type_restrictions_obj = nil end if attributes.key?(:'max_attempts') self.max_attempts = attributes[:'max_attempts'] end end |
Instance Attribute Details
#authenticator_attachment ⇒ Object
Returns the value of attribute authenticator_attachment.
38 39 40 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 38 def @authenticator_attachment end |
#component ⇒ Object
Get object type so that we know how to edit the object
18 19 20 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 18 def component @component end |
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.
32 33 34 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 32 def configure_flow @configure_flow end |
#device_type_restrictions ⇒ Object
Returns the value of attribute device_type_restrictions.
44 45 46 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 44 def device_type_restrictions @device_type_restrictions end |
#device_type_restrictions_obj ⇒ Object
Returns the value of attribute device_type_restrictions_obj.
46 47 48 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 46 def device_type_restrictions_obj @device_type_restrictions_obj end |
#flow_set ⇒ Object
Returns the value of attribute flow_set.
29 30 31 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 29 def flow_set @flow_set end |
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
34 35 36 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 34 def friendly_name @friendly_name end |
#hints ⇒ Object
Returns the value of attribute hints.
42 43 44 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 42 def hints @hints end |
#max_attempts ⇒ Object
Returns the value of attribute max_attempts.
48 49 50 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 48 def max_attempts @max_attempts end |
#meta_model_name ⇒ Object
Return internal model name
27 28 29 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 27 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 13 def pk @pk end |
#resident_key_requirement ⇒ Object
Returns the value of attribute resident_key_requirement.
40 41 42 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 40 def resident_key_requirement @resident_key_requirement end |
#user_verification ⇒ Object
Returns the value of attribute user_verification.
36 37 38 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 36 def user_verification @user_verification end |
#verbose_name ⇒ Object
Return object's verbose_name
21 22 23 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 21 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object's plural verbose_name
24 25 26 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 24 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
95 96 97 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 95 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
100 101 102 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 100 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 73 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'flow_set' => :'flow_set', :'configure_flow' => :'configure_flow', :'friendly_name' => :'friendly_name', :'user_verification' => :'user_verification', :'authenticator_attachment' => :'authenticator_attachment', :'resident_key_requirement' => :'resident_key_requirement', :'hints' => :'hints', :'device_type_restrictions' => :'device_type_restrictions', :'device_type_restrictions_obj' => :'device_type_restrictions_obj', :'max_attempts' => :'max_attempts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 440 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
127 128 129 130 131 132 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 127 def self.openapi_nullable Set.new([ :'configure_flow', :'authenticator_attachment', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 105 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'flow_set' => :'Array<FlowSet>', :'configure_flow' => :'String', :'friendly_name' => :'String', :'user_verification' => :'UserVerificationEnum', :'authenticator_attachment' => :'AuthenticatorAttachmentEnum', :'resident_key_requirement' => :'UserVerificationEnum', :'hints' => :'Array<WebAuthnHintEnum>', :'device_type_restrictions' => :'Array<String>', :'device_type_restrictions_obj' => :'Array<WebAuthnDeviceType>', :'max_attempts' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 404 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && flow_set == o.flow_set && configure_flow == o.configure_flow && friendly_name == o.friendly_name && user_verification == o.user_verification && == o. && resident_key_requirement == o.resident_key_requirement && hints == o.hints && device_type_restrictions == o.device_type_restrictions && device_type_restrictions_obj == o.device_type_restrictions_obj && max_attempts == o.max_attempts end |
#eql?(o) ⇒ Boolean
427 428 429 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 427 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
433 434 435 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 433 def hash [pk, name, component, verbose_name, verbose_name_plural, , flow_set, configure_flow, friendly_name, user_verification, , resident_key_requirement, hints, device_type_restrictions, device_type_restrictions_obj, max_attempts].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 241 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @flow_set.nil? invalid_properties.push('invalid value for "flow_set", flow_set cannot be nil.') end if @device_type_restrictions_obj.nil? invalid_properties.push('invalid value for "device_type_restrictions_obj", device_type_restrictions_obj cannot be nil.') end if !@max_attempts.nil? && @max_attempts > 2147483647 invalid_properties.push('invalid value for "max_attempts", must be smaller than or equal to 2147483647.') end if !@max_attempts.nil? && @max_attempts < 0 invalid_properties.push('invalid value for "max_attempts", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 462 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 289 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @flow_set.nil? return false if @device_type_restrictions_obj.nil? return false if !@max_attempts.nil? && @max_attempts > 2147483647 return false if !@max_attempts.nil? && @max_attempts < 0 true end |