Class: Authentik::Api::BlueprintInstance

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/blueprint_instance.rb

Overview

Info about a single blueprint instance file

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BlueprintInstance

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/authentik/api/models/blueprint_instance.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::BlueprintInstance` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::BlueprintInstance`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  else
    self.path = ''
  end

  if attributes.key?(:'context')
    if (value = attributes[:'context']).is_a?(Hash)
      self.context = value
    end
  end

  if attributes.key?(:'last_applied')
    self.last_applied = attributes[:'last_applied']
  else
    self.last_applied = nil
  end

  if attributes.key?(:'last_applied_hash')
    self.last_applied_hash = attributes[:'last_applied_hash']
  else
    self.last_applied_hash = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'managed_models')
    if (value = attributes[:'managed_models']).is_a?(Array)
      self.managed_models = value
    end
  else
    self.managed_models = nil
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  else
    self. = nil
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end
end

Instance Attribute Details

#contentObject

Returns the value of attribute content.



33
34
35
# File 'lib/authentik/api/models/blueprint_instance.rb', line 33

def content
  @content
end

#contextObject

Returns the value of attribute context.



19
20
21
# File 'lib/authentik/api/models/blueprint_instance.rb', line 19

def context
  @context
end

#enabledObject

Returns the value of attribute enabled.



27
28
29
# File 'lib/authentik/api/models/blueprint_instance.rb', line 27

def enabled
  @enabled
end

#last_appliedObject

Returns the value of attribute last_applied.



21
22
23
# File 'lib/authentik/api/models/blueprint_instance.rb', line 21

def last_applied
  @last_applied
end

#last_applied_hashObject

Returns the value of attribute last_applied_hash.



23
24
25
# File 'lib/authentik/api/models/blueprint_instance.rb', line 23

def last_applied_hash
  @last_applied_hash
end

#managed_modelsObject

Returns the value of attribute managed_models.



29
30
31
# File 'lib/authentik/api/models/blueprint_instance.rb', line 29

def managed_models
  @managed_models
end

#metadataObject

Returns the value of attribute metadata.



31
32
33
# File 'lib/authentik/api/models/blueprint_instance.rb', line 31

def 
  @metadata
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/blueprint_instance.rb', line 15

def name
  @name
end

#pathObject

Returns the value of attribute path.



17
18
19
# File 'lib/authentik/api/models/blueprint_instance.rb', line 17

def path
  @path
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/blueprint_instance.rb', line 13

def pk
  @pk
end

#statusObject

Returns the value of attribute status.



25
26
27
# File 'lib/authentik/api/models/blueprint_instance.rb', line 25

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/authentik/api/models/blueprint_instance.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/authentik/api/models/blueprint_instance.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/authentik/api/models/blueprint_instance.rb', line 58

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'path' => :'path',
    :'context' => :'context',
    :'last_applied' => :'last_applied',
    :'last_applied_hash' => :'last_applied_hash',
    :'status' => :'status',
    :'enabled' => :'enabled',
    :'managed_models' => :'managed_models',
    :'metadata' => :'metadata',
    :'content' => :'content'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/authentik/api/models/blueprint_instance.rb', line 343

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/authentik/api/models/blueprint_instance.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/authentik/api/models/blueprint_instance.rb', line 85

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'path' => :'String',
    :'context' => :'Hash<String, Object>',
    :'last_applied' => :'Time',
    :'last_applied_hash' => :'String',
    :'status' => :'BlueprintInstanceStatusEnum',
    :'enabled' => :'Boolean',
    :'managed_models' => :'Array<String>',
    :'metadata' => :'Hash<String, Object>',
    :'content' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/authentik/api/models/blueprint_instance.rb', line 312

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      path == o.path &&
      context == o.context &&
      last_applied == o.last_applied &&
      last_applied_hash == o.last_applied_hash &&
      status == o.status &&
      enabled == o.enabled &&
      managed_models == o.managed_models &&
       == o. &&
      content == o.content
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


330
331
332
# File 'lib/authentik/api/models/blueprint_instance.rb', line 330

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



336
337
338
# File 'lib/authentik/api/models/blueprint_instance.rb', line 336

def hash
  [pk, name, path, context, last_applied, last_applied_hash, status, enabled, managed_models, , content].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/authentik/api/models/blueprint_instance.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @last_applied.nil?
    invalid_properties.push('invalid value for "last_applied", last_applied cannot be nil.')
  end

  if @last_applied_hash.nil?
    invalid_properties.push('invalid value for "last_applied_hash", last_applied_hash cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @managed_models.nil?
    invalid_properties.push('invalid value for "managed_models", managed_models cannot be nil.')
  end

  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/authentik/api/models/blueprint_instance.rb', line 365

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



228
229
230
231
232
233
234
235
236
237
238
# File 'lib/authentik/api/models/blueprint_instance.rb', line 228

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @last_applied.nil?
  return false if @last_applied_hash.nil?
  return false if @status.nil?
  return false if @managed_models.nil?
  return false if @metadata.nil?
  true
end