Class: Authentik::Api::CaptchaChallenge
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::CaptchaChallenge
- Defined in:
- lib/authentik/api/models/captcha_challenge.rb
Overview
Site public key
Instance Attribute Summary collapse
-
#component ⇒ Object
Returns the value of attribute component.
-
#flow_info ⇒ Object
Returns the value of attribute flow_info.
-
#interactive ⇒ Object
Returns the value of attribute interactive.
-
#js_url ⇒ Object
Returns the value of attribute js_url.
-
#pending_user ⇒ Object
Returns the value of attribute pending_user.
-
#pending_user_avatar ⇒ Object
Returns the value of attribute pending_user_avatar.
-
#response_errors ⇒ Object
Returns the value of attribute response_errors.
-
#site_key ⇒ Object
Returns the value of attribute site_key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CaptchaChallenge
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CaptchaChallenge
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::CaptchaChallenge` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::CaptchaChallenge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'flow_info') self.flow_info = attributes[:'flow_info'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = 'ak-stage-captcha' end if attributes.key?(:'response_errors') if (value = attributes[:'response_errors']).is_a?(Hash) self.response_errors = value end end if attributes.key?(:'pending_user') self.pending_user = attributes[:'pending_user'] else self.pending_user = nil end if attributes.key?(:'pending_user_avatar') self.pending_user_avatar = attributes[:'pending_user_avatar'] else self.pending_user_avatar = nil end if attributes.key?(:'site_key') self.site_key = attributes[:'site_key'] else self.site_key = nil end if attributes.key?(:'js_url') self.js_url = attributes[:'js_url'] else self.js_url = nil end if attributes.key?(:'interactive') self.interactive = attributes[:'interactive'] else self.interactive = nil end end |
Instance Attribute Details
#component ⇒ Object
Returns the value of attribute component.
15 16 17 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 15 def component @component end |
#flow_info ⇒ Object
Returns the value of attribute flow_info.
13 14 15 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 13 def flow_info @flow_info end |
#interactive ⇒ Object
Returns the value of attribute interactive.
27 28 29 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 27 def interactive @interactive end |
#js_url ⇒ Object
Returns the value of attribute js_url.
25 26 27 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 25 def js_url @js_url end |
#pending_user ⇒ Object
Returns the value of attribute pending_user.
19 20 21 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 19 def pending_user @pending_user end |
#pending_user_avatar ⇒ Object
Returns the value of attribute pending_user_avatar.
21 22 23 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 21 def pending_user_avatar @pending_user_avatar end |
#response_errors ⇒ Object
Returns the value of attribute response_errors.
17 18 19 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 17 def response_errors @response_errors end |
#site_key ⇒ Object
Returns the value of attribute site_key.
23 24 25 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 23 def site_key @site_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 30 def self.attribute_map { :'flow_info' => :'flow_info', :'component' => :'component', :'response_errors' => :'response_errors', :'pending_user' => :'pending_user', :'pending_user_avatar' => :'pending_user_avatar', :'site_key' => :'site_key', :'js_url' => :'js_url', :'interactive' => :'interactive' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 256 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 54 def self.openapi_types { :'flow_info' => :'ContextualFlowInfo', :'component' => :'String', :'response_errors' => :'Hash<String, Array<ErrorDetail>>', :'pending_user' => :'String', :'pending_user_avatar' => :'String', :'site_key' => :'String', :'js_url' => :'String', :'interactive' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && flow_info == o.flow_info && component == o.component && response_errors == o.response_errors && pending_user == o.pending_user && pending_user_avatar == o.pending_user_avatar && site_key == o.site_key && js_url == o.js_url && interactive == o.interactive end |
#eql?(o) ⇒ Boolean
243 244 245 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 243 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 249 def hash [flow_info, component, response_errors, pending_user, pending_user_avatar, site_key, js_url, interactive].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pending_user.nil? invalid_properties.push('invalid value for "pending_user", pending_user cannot be nil.') end if @pending_user_avatar.nil? invalid_properties.push('invalid value for "pending_user_avatar", pending_user_avatar cannot be nil.') end if @site_key.nil? invalid_properties.push('invalid value for "site_key", site_key cannot be nil.') end if @js_url.nil? invalid_properties.push('invalid value for "js_url", js_url cannot be nil.') end if @interactive.nil? invalid_properties.push('invalid value for "interactive", interactive cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 278 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 171 172 173 174 |
# File 'lib/authentik/api/models/captcha_challenge.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pending_user.nil? return false if @pending_user_avatar.nil? return false if @site_key.nil? return false if @js_url.nil? return false if @interactive.nil? true end |