Class: Authentik::Api::CertificateGenerationRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/certificate_generation_request.rb

Overview

Certificate generation parameters

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CertificateGenerationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::CertificateGenerationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::CertificateGenerationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'common_name')
    self.common_name = attributes[:'common_name']
  else
    self.common_name = nil
  end

  if attributes.key?(:'subject_alt_name')
    self.subject_alt_name = attributes[:'subject_alt_name']
  end

  if attributes.key?(:'validity_days')
    self.validity_days = attributes[:'validity_days']
  else
    self.validity_days = nil
  end

  if attributes.key?(:'alg')
    self.alg = attributes[:'alg']
  end
end

Instance Attribute Details

#algObject

Returns the value of attribute alg.



19
20
21
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 19

def alg
  @alg
end

#common_nameObject

Returns the value of attribute common_name.



13
14
15
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 13

def common_name
  @common_name
end

#subject_alt_nameObject

Returns the value of attribute subject_alt_name.



15
16
17
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 15

def subject_alt_name
  @subject_alt_name
end

#validity_daysObject

Returns the value of attribute validity_days.



17
18
19
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 17

def validity_days
  @validity_days
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 44

def self.attribute_map
  {
    :'common_name' => :'common_name',
    :'subject_alt_name' => :'subject_alt_name',
    :'validity_days' => :'validity_days',
    :'alg' => :'alg'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 64

def self.openapi_types
  {
    :'common_name' => :'String',
    :'subject_alt_name' => :'String',
    :'validity_days' => :'Integer',
    :'alg' => :'AlgEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      common_name == o.common_name &&
      subject_alt_name == o.subject_alt_name &&
      validity_days == o.validity_days &&
      alg == o.alg
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 189

def hash
  [common_name, subject_alt_name, validity_days, alg].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @common_name.nil?
    invalid_properties.push('invalid value for "common_name", common_name cannot be nil.')
  end

  if @common_name.to_s.length < 1
    invalid_properties.push('invalid value for "common_name", the character length must be greater than or equal to 1.')
  end

  if @validity_days.nil?
    invalid_properties.push('invalid value for "validity_days", validity_days cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
142
143
144
# File 'lib/authentik/api/models/certificate_generation_request.rb', line 138

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @common_name.nil?
  return false if @common_name.to_s.length < 1
  return false if @validity_days.nil?
  true
end