Class: Authentik::Api::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/authentik/api/configuration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|_self| ... } ⇒ Configuration

Returns a new instance of Configuration.

Yields:

  • (_self)

Yield Parameters:



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/authentik/api/configuration.rb', line 153

def initialize
  @scheme = 'http'
  @host = 'localhost'
  @base_path = '/api/v3'
  @server_index = nil
  @server_operation_index = {}
  @server_variables = {}
  @server_operation_variables = {}
  @api_key = {}
  @api_key_prefix = {}
  @client_side_validation = true
  @verify_ssl = true
  @verify_ssl_host = true
  @cert_file = nil
  @key_file = nil
  @timeout = 0
  @params_encoding = nil
  @debugging = false
  @ignore_operation_servers = false
  @inject_format = false
  @force_ending_format = false
  @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT)

  yield(self) if block_given?
end

Instance Attribute Details

#access_tokenObject

Defines the access token (Bearer) used with OAuth2.



57
58
59
# File 'lib/authentik/api/configuration.rb', line 57

def access_token
  @access_token
end

#access_token_getterProc

Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2. Overrides the access_token if set

Returns:

  • (Proc)


62
63
64
# File 'lib/authentik/api/configuration.rb', line 62

def access_token_getter
  @access_token_getter
end

#api_keyHash

Defines API keys used with API Key authentications.

Examples:

parameter name is “api_key”, API key is “xxx” (e.g. “api_key=xxx” in query string)

config.api_key['api_key'] = 'xxx'

Returns:

  • (Hash)

    key: parameter name, value: parameter value (API key)



36
37
38
# File 'lib/authentik/api/configuration.rb', line 36

def api_key
  @api_key
end

#api_key_prefixHash

Defines API key prefixes used with API Key authentications.

Examples:

parameter name is “Authorization”, API key prefix is “Token” (e.g. “Authorization: Token xxx” in headers)

config.api_key_prefix['api_key'] = 'Token'

Returns:

  • (Hash)

    key: parameter name, value: API key prefix



44
45
46
# File 'lib/authentik/api/configuration.rb', line 44

def api_key_prefix
  @api_key_prefix
end

#base_pathObject

Defines url base path



16
17
18
# File 'lib/authentik/api/configuration.rb', line 16

def base_path
  @base_path
end

#cert_fileObject

TLS/SSL setting Client certificate file (for client certificate)



135
136
137
# File 'lib/authentik/api/configuration.rb', line 135

def cert_file
  @cert_file
end

#client_side_validationtrue, false

Set this to false to skip client side validation in the operation. Default to true.

Returns:

  • (true, false)


104
105
106
# File 'lib/authentik/api/configuration.rb', line 104

def client_side_validation
  @client_side_validation
end

#debuggingtrue, false

Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with ‘logger.debug` (see the `logger` attribute). Default to false.

Returns:

  • (true, false)


74
75
76
# File 'lib/authentik/api/configuration.rb', line 74

def debugging
  @debugging
end

#force_ending_formatObject

Returns the value of attribute force_ending_format.



151
152
153
# File 'lib/authentik/api/configuration.rb', line 151

def force_ending_format
  @force_ending_format
end

#hostObject

Defines url host



13
14
15
# File 'lib/authentik/api/configuration.rb', line 13

def host
  @host
end

#ignore_operation_serverstrue, false

Set this to ignore operation servers for the API client. This is useful when you need to send requests to a different server than the one specified in the OpenAPI document. Will default to the base url defined in the spec but can be overridden by setting ‘scheme`, `host`, `base_path` directly. Default to false.

Returns:

  • (true, false)


82
83
84
# File 'lib/authentik/api/configuration.rb', line 82

def ignore_operation_servers
  @ignore_operation_servers
end

#inject_formatObject

Returns the value of attribute inject_format.



149
150
151
# File 'lib/authentik/api/configuration.rb', line 149

def inject_format
  @inject_format
end

#key_fileObject

TLS/SSL setting Client private key file (for client certificate)



139
140
141
# File 'lib/authentik/api/configuration.rb', line 139

def key_file
  @key_file
end

#logger#debug

Defines the logger used for debugging. Default to ‘Rails.logger` (when in Rails) or logging to STDOUT.

Returns:

  • (#debug)


88
89
90
# File 'lib/authentik/api/configuration.rb', line 88

def logger
  @logger
end

#params_encodingObject

Set this to customize parameters encoding of array parameter with multi collectionFormat. Default to nil.

github.com/typhoeus/ethon/blob/master/lib/ethon/easy/queryable.rb#L96

See Also:

  • params_encoding option of Ethon. Related source code:


146
147
148
# File 'lib/authentik/api/configuration.rb', line 146

def params_encoding
  @params_encoding
end

#passwordString

Defines the password used with HTTP basic authentication.

Returns:

  • (String)


54
55
56
# File 'lib/authentik/api/configuration.rb', line 54

def password
  @password
end

#return_binary_dataObject

Set this to return data as binary instead of downloading a temp file. When enabled (set to true) HTTP responses with return type ‘File` will be returned as a stream of binary data. Default to false.



67
68
69
# File 'lib/authentik/api/configuration.rb', line 67

def return_binary_data
  @return_binary_data
end

#schemeObject

Defines url scheme



10
11
12
# File 'lib/authentik/api/configuration.rb', line 10

def scheme
  @scheme
end

#server_indexObject

Define server configuration index



19
20
21
# File 'lib/authentik/api/configuration.rb', line 19

def server_index
  @server_index
end

#server_operation_indexObject

Define server operation configuration index



22
23
24
# File 'lib/authentik/api/configuration.rb', line 22

def server_operation_index
  @server_operation_index
end

#server_operation_variablesObject

Default server operation variables



28
29
30
# File 'lib/authentik/api/configuration.rb', line 28

def server_operation_variables
  @server_operation_variables
end

#server_variablesObject

Default server variables



25
26
27
# File 'lib/authentik/api/configuration.rb', line 25

def server_variables
  @server_variables
end

#ssl_ca_certString

TLS/SSL setting Set this to customize the certificate file to verify the peer.

github.com/typhoeus/typhoeus/blob/master/lib/typhoeus/easy_factory.rb#L145

Returns:

  • (String)

    the path to the certificate file

See Also:

  • `cainfo` option of Typhoeus, `--cert` option of libcurl. Related source code:


131
132
133
# File 'lib/authentik/api/configuration.rb', line 131

def ssl_ca_cert
  @ssl_ca_cert
end

#temp_folder_pathString

Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use ‘Tempfile`.

Returns:

  • (String)


95
96
97
# File 'lib/authentik/api/configuration.rb', line 95

def temp_folder_path
  @temp_folder_path
end

#timeoutObject

The time limit for HTTP request in seconds. Default to 0 (never times out).



99
100
101
# File 'lib/authentik/api/configuration.rb', line 99

def timeout
  @timeout
end

#usernameString

Defines the username used with HTTP basic authentication.

Returns:

  • (String)


49
50
51
# File 'lib/authentik/api/configuration.rb', line 49

def username
  @username
end

#verify_ssltrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.

Returns:

  • (true, false)


113
114
115
# File 'lib/authentik/api/configuration.rb', line 113

def verify_ssl
  @verify_ssl
end

#verify_ssl_hosttrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.

Returns:

  • (true, false)


122
123
124
# File 'lib/authentik/api/configuration.rb', line 122

def verify_ssl_host
  @verify_ssl_host
end

Class Method Details

.defaultObject

The default Configuration object.



180
181
182
# File 'lib/authentik/api/configuration.rb', line 180

def self.default
  @@default ||= Configuration.new
end

Instance Method Details

#access_token_with_refreshObject

Gets access_token using access_token_getter or uses the static access_token



228
229
230
231
# File 'lib/authentik/api/configuration.rb', line 228

def access_token_with_refresh
  return access_token if access_token_getter.nil?
  access_token_getter.call
end

#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object

Gets API key (with prefix if set).

Parameters:

  • param_name (String)

    the parameter name of API key auth



217
218
219
220
221
222
223
224
225
# File 'lib/authentik/api/configuration.rb', line 217

def api_key_with_prefix(param_name, param_alias = nil)
  key = @api_key[param_name]
  key = @api_key.fetch(param_alias, key) unless param_alias.nil?
  if @api_key_prefix[param_name]
    "#{@api_key_prefix[param_name]} #{key}"
  else
    key
  end
end

#auth_settingsObject

Returns Auth Settings hash for api client.



239
240
241
242
243
244
245
246
247
248
249
# File 'lib/authentik/api/configuration.rb', line 239

def auth_settings
  {
    'authentik' =>
      {
        type: 'bearer',
        in: 'header',
        key: 'Authorization',
        value: "Bearer #{access_token_with_refresh}"
      },
  }
end

#base_url(operation = nil) ⇒ Object

Returns base URL for specified operation based on server settings



205
206
207
208
209
210
211
212
213
# File 'lib/authentik/api/configuration.rb', line 205

def base_url(operation = nil)
  return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if ignore_operation_servers
  if operation_server_settings.key?(operation) then
    index = server_operation_index.fetch(operation, server_index)
    server_url(index.nil? ? 0 : index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation])
  else
    server_index.nil? ? "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') : server_url(server_index, server_variables, nil)
  end
end

#basic_auth_tokenObject

Gets Basic Auth token string



234
235
236
# File 'lib/authentik/api/configuration.rb', line 234

def basic_auth_token
  'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n")
end

#configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:



184
185
186
# File 'lib/authentik/api/configuration.rb', line 184

def configure
  yield(self) if block_given?
end

#operation_server_settingsObject



261
262
263
264
# File 'lib/authentik/api/configuration.rb', line 261

def operation_server_settings
  {
  }
end

#server_settingsObject

Returns an array of Server setting



252
253
254
255
256
257
258
259
# File 'lib/authentik/api/configuration.rb', line 252

def server_settings
  [
    {
      url: "/api/v3",
      description: "No description provided",
    }
  ]
end

#server_url(index, variables = {}, servers = nil) ⇒ Object

Returns URL based on server settings

Parameters:

  • index

    array index of the server settings

  • variables (defaults to: {})

    hash of variable and the corresponding value



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/authentik/api/configuration.rb', line 270

def server_url(index, variables = {}, servers = nil)
  servers = server_settings if servers == nil

  # check array index out of bound
  if (index.nil? || index < 0 || index >= servers.size)
    fail ArgumentError, "Invalid index #{index} when selecting the server. Must not be nil and must be less than #{servers.size}"
  end

  server = servers[index]
  url = server[:url]

  return url unless server.key? :variables

  # go through variable and assign a value
  server[:variables].each do |name, variable|
    if variables.key?(name)
      if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name]))
        url.gsub! "{" + name.to_s + "}", variables[name]
      else
        fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}."
      end
    else
      # use default value
      url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value]
    end
  end

  url
end