Class: Authentik::Api::ConnectionToken

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/connection_token.rb

Overview

ConnectionToken Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConnectionToken

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/authentik/api/models/connection_token.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ConnectionToken` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ConnectionToken`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'provider_obj')
    self.provider_obj = attributes[:'provider_obj']
  else
    self.provider_obj = nil
  end

  if attributes.key?(:'endpoint')
    self.endpoint = attributes[:'endpoint']
  else
    self.endpoint = nil
  end

  if attributes.key?(:'endpoint_obj')
    self.endpoint_obj = attributes[:'endpoint_obj']
  else
    self.endpoint_obj = nil
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end
end

Instance Attribute Details

#endpointObject

Returns the value of attribute endpoint.



19
20
21
# File 'lib/authentik/api/models/connection_token.rb', line 19

def endpoint
  @endpoint
end

#endpoint_objObject

Returns the value of attribute endpoint_obj.



21
22
23
# File 'lib/authentik/api/models/connection_token.rb', line 21

def endpoint_obj
  @endpoint_obj
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/connection_token.rb', line 13

def pk
  @pk
end

#providerObject

Returns the value of attribute provider.



15
16
17
# File 'lib/authentik/api/models/connection_token.rb', line 15

def provider
  @provider
end

#provider_objObject

Returns the value of attribute provider_obj.



17
18
19
# File 'lib/authentik/api/models/connection_token.rb', line 17

def provider_obj
  @provider_obj
end

#userObject

Returns the value of attribute user.



23
24
25
# File 'lib/authentik/api/models/connection_token.rb', line 23

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/authentik/api/models/connection_token.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/authentik/api/models/connection_token.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
35
# File 'lib/authentik/api/models/connection_token.rb', line 26

def self.attribute_map
  {
    :'pk' => :'pk',
    :'provider' => :'provider',
    :'provider_obj' => :'provider_obj',
    :'endpoint' => :'endpoint',
    :'endpoint_obj' => :'endpoint_obj',
    :'user' => :'user'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/authentik/api/models/connection_token.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/authentik/api/models/connection_token.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
# File 'lib/authentik/api/models/connection_token.rb', line 48

def self.openapi_types
  {
    :'pk' => :'String',
    :'provider' => :'Integer',
    :'provider_obj' => :'RACProvider',
    :'endpoint' => :'String',
    :'endpoint_obj' => :'Endpoint',
    :'user' => :'PartialUser'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
217
# File 'lib/authentik/api/models/connection_token.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      provider == o.provider &&
      provider_obj == o.provider_obj &&
      endpoint == o.endpoint &&
      endpoint_obj == o.endpoint_obj &&
      user == o.user
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/authentik/api/models/connection_token.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/authentik/api/models/connection_token.rb', line 227

def hash
  [pk, provider, provider_obj, endpoint, endpoint_obj, user].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/authentik/api/models/connection_token.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @provider_obj.nil?
    invalid_properties.push('invalid value for "provider_obj", provider_obj cannot be nil.')
  end

  if @endpoint.nil?
    invalid_properties.push('invalid value for "endpoint", endpoint cannot be nil.')
  end

  if @endpoint_obj.nil?
    invalid_properties.push('invalid value for "endpoint_obj", endpoint_obj cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/authentik/api/models/connection_token.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
152
153
154
# File 'lib/authentik/api/models/connection_token.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @provider.nil?
  return false if @provider_obj.nil?
  return false if @endpoint.nil?
  return false if @endpoint_obj.nil?
  return false if @user.nil?
  true
end