Class: Authentik::Api::ConsentChallenge
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ConsentChallenge
- Defined in:
- lib/authentik/api/models/consent_challenge.rb
Overview
Challenge info for consent screens
Instance Attribute Summary collapse
-
#additional_permissions ⇒ Object
Returns the value of attribute additional_permissions.
-
#component ⇒ Object
Returns the value of attribute component.
-
#flow_info ⇒ Object
Returns the value of attribute flow_info.
-
#header_text ⇒ Object
Returns the value of attribute header_text.
-
#pending_user ⇒ Object
Returns the value of attribute pending_user.
-
#pending_user_avatar ⇒ Object
Returns the value of attribute pending_user_avatar.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
-
#response_errors ⇒ Object
Returns the value of attribute response_errors.
-
#token ⇒ Object
Returns the value of attribute token.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConsentChallenge
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConsentChallenge
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ConsentChallenge` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ConsentChallenge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'flow_info') self.flow_info = attributes[:'flow_info'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = 'ak-stage-consent' end if attributes.key?(:'response_errors') if (value = attributes[:'response_errors']).is_a?(Hash) self.response_errors = value end end if attributes.key?(:'pending_user') self.pending_user = attributes[:'pending_user'] else self.pending_user = nil end if attributes.key?(:'pending_user_avatar') self.pending_user_avatar = attributes[:'pending_user_avatar'] else self.pending_user_avatar = nil end if attributes.key?(:'header_text') self.header_text = attributes[:'header_text'] end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'additional_permissions') if (value = attributes[:'additional_permissions']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'token') self.token = attributes[:'token'] else self.token = nil end end |
Instance Attribute Details
#additional_permissions ⇒ Object
Returns the value of attribute additional_permissions.
27 28 29 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 27 def @additional_permissions end |
#component ⇒ Object
Returns the value of attribute component.
15 16 17 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 15 def component @component end |
#flow_info ⇒ Object
Returns the value of attribute flow_info.
13 14 15 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 13 def flow_info @flow_info end |
#header_text ⇒ Object
Returns the value of attribute header_text.
23 24 25 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 23 def header_text @header_text end |
#pending_user ⇒ Object
Returns the value of attribute pending_user.
19 20 21 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 19 def pending_user @pending_user end |
#pending_user_avatar ⇒ Object
Returns the value of attribute pending_user_avatar.
21 22 23 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 21 def pending_user_avatar @pending_user_avatar end |
#permissions ⇒ Object
Returns the value of attribute permissions.
25 26 27 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 25 def @permissions end |
#response_errors ⇒ Object
Returns the value of attribute response_errors.
17 18 19 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 17 def response_errors @response_errors end |
#token ⇒ Object
Returns the value of attribute token.
29 30 31 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 29 def token @token end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 32 def self.attribute_map { :'flow_info' => :'flow_info', :'component' => :'component', :'response_errors' => :'response_errors', :'pending_user' => :'pending_user', :'pending_user_avatar' => :'pending_user_avatar', :'header_text' => :'header_text', :'permissions' => :'permissions', :'additional_permissions' => :'additional_permissions', :'token' => :'token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 269 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 57 def self.openapi_types { :'flow_info' => :'ContextualFlowInfo', :'component' => :'String', :'response_errors' => :'Hash<String, Array<ErrorDetail>>', :'pending_user' => :'String', :'pending_user_avatar' => :'String', :'header_text' => :'String', :'permissions' => :'Array<ConsentPermission>', :'additional_permissions' => :'Array<ConsentPermission>', :'token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && flow_info == o.flow_info && component == o.component && response_errors == o.response_errors && pending_user == o.pending_user && pending_user_avatar == o.pending_user_avatar && header_text == o.header_text && == o. && == o. && token == o.token end |
#eql?(o) ⇒ Boolean
256 257 258 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 256 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 262 def hash [flow_info, component, response_errors, pending_user, pending_user_avatar, header_text, , , token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 150 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pending_user.nil? invalid_properties.push('invalid value for "pending_user", pending_user cannot be nil.') end if @pending_user_avatar.nil? invalid_properties.push('invalid value for "pending_user_avatar", pending_user_avatar cannot be nil.') end if @permissions.nil? invalid_properties.push('invalid value for "permissions", permissions cannot be nil.') end if @additional_permissions.nil? invalid_properties.push('invalid value for "additional_permissions", additional_permissions cannot be nil.') end if @token.nil? invalid_properties.push('invalid value for "token", token cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 291 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 184 185 186 |
# File 'lib/authentik/api/models/consent_challenge.rb', line 178 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pending_user.nil? return false if @pending_user_avatar.nil? return false if @permissions.nil? return false if @additional_permissions.nil? return false if @token.nil? true end |