Class: Authentik::Api::ConsentChallengeResponseRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/consent_challenge_response_request.rb

Overview

Consent challenge response, any valid response request is valid

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConsentChallengeResponseRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 51

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ConsentChallengeResponseRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ConsentChallengeResponseRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = 'ak-stage-consent'
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  else
    self.token = nil
  end
end

Instance Attribute Details

#componentObject

Returns the value of attribute component.



13
14
15
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 13

def component
  @component
end

#tokenObject

Returns the value of attribute token.



15
16
17
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 15

def token
  @token
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



26
27
28
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 26

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



31
32
33
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 31

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



18
19
20
21
22
23
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 18

def self.attribute_map
  {
    :'component' => :'component',
    :'token' => :'token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



44
45
46
47
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 44

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



36
37
38
39
40
41
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 36

def self.openapi_types
  {
    :'component' => :'String',
    :'token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



138
139
140
141
142
143
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 138

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      component == o.component &&
      token == o.token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 147

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



153
154
155
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 153

def hash
  [component, token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 80

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@component.nil? && @component.to_s.length < 1
    invalid_properties.push('invalid value for "component", the character length must be greater than or equal to 1.')
  end

  if @token.nil?
    invalid_properties.push('invalid value for "token", token cannot be nil.')
  end

  if @token.to_s.length < 1
    invalid_properties.push('invalid value for "token", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



100
101
102
103
104
105
106
# File 'lib/authentik/api/models/consent_challenge_response_request.rb', line 100

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@component.nil? && @component.to_s.length < 1
  return false if @token.nil?
  return false if @token.to_s.length < 1
  true
end