Class: Authentik::Api::ContentType

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/content_type.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ContentType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/authentik/api/models/content_type.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ContentType` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ContentType`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'app_label')
    self.app_label = attributes[:'app_label']
  else
    self.app_label = nil
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  else
    self.model = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'fully_qualified_model')
    self.fully_qualified_model = attributes[:'fully_qualified_model']
  else
    self.fully_qualified_model = nil
  end
end

Instance Attribute Details

#app_labelObject

Returns the value of attribute app_label.



14
15
16
# File 'lib/authentik/api/models/content_type.rb', line 14

def app_label
  @app_label
end

#fully_qualified_modelObject

Returns the value of attribute fully_qualified_model.



20
21
22
# File 'lib/authentik/api/models/content_type.rb', line 20

def fully_qualified_model
  @fully_qualified_model
end

#idObject

Returns the value of attribute id.



12
13
14
# File 'lib/authentik/api/models/content_type.rb', line 12

def id
  @id
end

#modelObject

Returns the value of attribute model.



16
17
18
# File 'lib/authentik/api/models/content_type.rb', line 16

def model
  @model
end

#verbose_name_pluralObject

Returns the value of attribute verbose_name_plural.



18
19
20
# File 'lib/authentik/api/models/content_type.rb', line 18

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/authentik/api/models/content_type.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/authentik/api/models/content_type.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/authentik/api/models/content_type.rb', line 23

def self.attribute_map
  {
    :'id' => :'id',
    :'app_label' => :'app_label',
    :'model' => :'model',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'fully_qualified_model' => :'fully_qualified_model'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/authentik/api/models/content_type.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



55
56
57
58
# File 'lib/authentik/api/models/content_type.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
# File 'lib/authentik/api/models/content_type.rb', line 44

def self.openapi_types
  {
    :'id' => :'Integer',
    :'app_label' => :'String',
    :'model' => :'String',
    :'verbose_name_plural' => :'String',
    :'fully_qualified_model' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



199
200
201
202
203
204
205
206
207
# File 'lib/authentik/api/models/content_type.rb', line 199

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      app_label == o.app_label &&
      model == o.model &&
      verbose_name_plural == o.verbose_name_plural &&
      fully_qualified_model == o.fully_qualified_model
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/authentik/api/models/content_type.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/authentik/api/models/content_type.rb', line 217

def hash
  [id, app_label, model, verbose_name_plural, fully_qualified_model].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/authentik/api/models/content_type.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @app_label.nil?
    invalid_properties.push('invalid value for "app_label", app_label cannot be nil.')
  end

  if @model.nil?
    invalid_properties.push('invalid value for "model", model cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @fully_qualified_model.nil?
    invalid_properties.push('invalid value for "fully_qualified_model", fully_qualified_model cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/authentik/api/models/content_type.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
143
144
145
# File 'lib/authentik/api/models/content_type.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @app_label.nil?
  return false if @model.nil?
  return false if @verbose_name_plural.nil?
  return false if @fully_qualified_model.nil?
  true
end