Class: Authentik::Api::CryptoApi

Inherits:
Object
  • Object
show all
Defined in:
lib/authentik/api/api/crypto_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CryptoApi

Returns a new instance of CryptoApi.



13
14
15
# File 'lib/authentik/api/api/crypto_api.rb', line 13

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



11
12
13
# File 'lib/authentik/api/api/crypto_api.rb', line 11

def api_client
  @api_client
end

Instance Method Details

#crypto_certificatekeypairs_create(certificate_key_pair_request, opts = {}) ⇒ CertificateKeyPair

CertificateKeyPair Viewset

Parameters:

Returns:



20
21
22
23
# File 'lib/authentik/api/api/crypto_api.rb', line 20

def crypto_certificatekeypairs_create(certificate_key_pair_request, opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_create_with_http_info(certificate_key_pair_request, opts)
  data
end

#crypto_certificatekeypairs_create_with_http_info(certificate_key_pair_request, opts = {}) ⇒ Array<(CertificateKeyPair, Integer, Hash)>

CertificateKeyPair Viewset

Parameters:

Returns:

  • (Array<(CertificateKeyPair, Integer, Hash)>)

    CertificateKeyPair data, response status code and response headers



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/authentik/api/api/crypto_api.rb', line 29

def crypto_certificatekeypairs_create_with_http_info(certificate_key_pair_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_create ...'
  end
  # verify the required parameter 'certificate_key_pair_request' is set
  if @api_client.config.client_side_validation && certificate_key_pair_request.nil?
    fail ArgumentError, "Missing the required parameter 'certificate_key_pair_request' when calling CryptoApi.crypto_certificatekeypairs_create"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(certificate_key_pair_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CertificateKeyPair'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_destroy(kp_uuid, opts = {}) ⇒ nil

CertificateKeyPair Viewset

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


86
87
88
89
# File 'lib/authentik/api/api/crypto_api.rb', line 86

def crypto_certificatekeypairs_destroy(kp_uuid, opts = {})
  crypto_certificatekeypairs_destroy_with_http_info(kp_uuid, opts)
  nil
end

#crypto_certificatekeypairs_destroy_with_http_info(kp_uuid, opts = {}) ⇒ Array<(nil, Integer, Hash)>

CertificateKeyPair Viewset

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/authentik/api/api/crypto_api.rb', line 95

def crypto_certificatekeypairs_destroy_with_http_info(kp_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_destroy ...'
  end
  # verify the required parameter 'kp_uuid' is set
  if @api_client.config.client_side_validation && kp_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'kp_uuid' when calling CryptoApi.crypto_certificatekeypairs_destroy"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/{kp_uuid}/'.sub('{kp_uuid}', CGI.escape(kp_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_destroy",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_generate_create(certificate_generation_request, opts = {}) ⇒ CertificateKeyPair

Generate a new, self-signed certificate-key pair

Parameters:

Returns:



147
148
149
150
# File 'lib/authentik/api/api/crypto_api.rb', line 147

def crypto_certificatekeypairs_generate_create(certificate_generation_request, opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_generate_create_with_http_info(certificate_generation_request, opts)
  data
end

#crypto_certificatekeypairs_generate_create_with_http_info(certificate_generation_request, opts = {}) ⇒ Array<(CertificateKeyPair, Integer, Hash)>

Generate a new, self-signed certificate-key pair

Parameters:

Returns:

  • (Array<(CertificateKeyPair, Integer, Hash)>)

    CertificateKeyPair data, response status code and response headers



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/authentik/api/api/crypto_api.rb', line 156

def crypto_certificatekeypairs_generate_create_with_http_info(certificate_generation_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_generate_create ...'
  end
  # verify the required parameter 'certificate_generation_request' is set
  if @api_client.config.client_side_validation && certificate_generation_request.nil?
    fail ArgumentError, "Missing the required parameter 'certificate_generation_request' when calling CryptoApi.crypto_certificatekeypairs_generate_create"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/generate/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(certificate_generation_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CertificateKeyPair'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_generate_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_generate_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_list(opts = {}) ⇒ PaginatedCertificateKeyPairList

CertificateKeyPair Viewset

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :has_key (Boolean)

    Only return certificate-key pairs with keys

  • :key_type (Array<KeyTypeEnum>)
  • :managed (String)
  • :name (String)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :search (String)

    A search term.

Returns:



220
221
222
223
# File 'lib/authentik/api/api/crypto_api.rb', line 220

def crypto_certificatekeypairs_list(opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_list_with_http_info(opts)
  data
end

#crypto_certificatekeypairs_list_with_http_info(opts = {}) ⇒ Array<(PaginatedCertificateKeyPairList, Integer, Hash)>

CertificateKeyPair Viewset

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :has_key (Boolean)

    Only return certificate-key pairs with keys

  • :key_type (Array<KeyTypeEnum>)
  • :managed (String)
  • :name (String)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :search (String)

    A search term.

Returns:



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/authentik/api/api/crypto_api.rb', line 236

def crypto_certificatekeypairs_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_list ...'
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'has_key'] = opts[:'has_key'] if !opts[:'has_key'].nil?
  query_params[:'key_type'] = @api_client.build_collection_param(opts[:'key_type'], :multi) if !opts[:'key_type'].nil?
  query_params[:'managed'] = opts[:'managed'] if !opts[:'managed'].nil?
  query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
  query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedCertificateKeyPairList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_partial_update(kp_uuid, opts = {}) ⇒ CertificateKeyPair

CertificateKeyPair Viewset

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



293
294
295
296
# File 'lib/authentik/api/api/crypto_api.rb', line 293

def crypto_certificatekeypairs_partial_update(kp_uuid, opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_partial_update_with_http_info(kp_uuid, opts)
  data
end

#crypto_certificatekeypairs_partial_update_with_http_info(kp_uuid, opts = {}) ⇒ Array<(CertificateKeyPair, Integer, Hash)>

CertificateKeyPair Viewset

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(CertificateKeyPair, Integer, Hash)>)

    CertificateKeyPair data, response status code and response headers



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/authentik/api/api/crypto_api.rb', line 303

def crypto_certificatekeypairs_partial_update_with_http_info(kp_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_partial_update ...'
  end
  # verify the required parameter 'kp_uuid' is set
  if @api_client.config.client_side_validation && kp_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'kp_uuid' when calling CryptoApi.crypto_certificatekeypairs_partial_update"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/{kp_uuid}/'.sub('{kp_uuid}', CGI.escape(kp_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_certificate_key_pair_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'CertificateKeyPair'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_partial_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_retrieve(kp_uuid, opts = {}) ⇒ CertificateKeyPair

CertificateKeyPair Viewset

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



360
361
362
363
# File 'lib/authentik/api/api/crypto_api.rb', line 360

def crypto_certificatekeypairs_retrieve(kp_uuid, opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_retrieve_with_http_info(kp_uuid, opts)
  data
end

#crypto_certificatekeypairs_retrieve_with_http_info(kp_uuid, opts = {}) ⇒ Array<(CertificateKeyPair, Integer, Hash)>

CertificateKeyPair Viewset

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CertificateKeyPair, Integer, Hash)>)

    CertificateKeyPair data, response status code and response headers



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/authentik/api/api/crypto_api.rb', line 369

def crypto_certificatekeypairs_retrieve_with_http_info(kp_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_retrieve ...'
  end
  # verify the required parameter 'kp_uuid' is set
  if @api_client.config.client_side_validation && kp_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'kp_uuid' when calling CryptoApi.crypto_certificatekeypairs_retrieve"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/{kp_uuid}/'.sub('{kp_uuid}', CGI.escape(kp_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CertificateKeyPair'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_update(kp_uuid, certificate_key_pair_request, opts = {}) ⇒ CertificateKeyPair

CertificateKeyPair Viewset

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • certificate_key_pair_request (CertificateKeyPairRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



422
423
424
425
# File 'lib/authentik/api/api/crypto_api.rb', line 422

def crypto_certificatekeypairs_update(kp_uuid, certificate_key_pair_request, opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_update_with_http_info(kp_uuid, certificate_key_pair_request, opts)
  data
end

#crypto_certificatekeypairs_update_with_http_info(kp_uuid, certificate_key_pair_request, opts = {}) ⇒ Array<(CertificateKeyPair, Integer, Hash)>

CertificateKeyPair Viewset

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • certificate_key_pair_request (CertificateKeyPairRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CertificateKeyPair, Integer, Hash)>)

    CertificateKeyPair data, response status code and response headers



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/authentik/api/api/crypto_api.rb', line 432

def crypto_certificatekeypairs_update_with_http_info(kp_uuid, certificate_key_pair_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_update ...'
  end
  # verify the required parameter 'kp_uuid' is set
  if @api_client.config.client_side_validation && kp_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'kp_uuid' when calling CryptoApi.crypto_certificatekeypairs_update"
  end
  # verify the required parameter 'certificate_key_pair_request' is set
  if @api_client.config.client_side_validation && certificate_key_pair_request.nil?
    fail ArgumentError, "Missing the required parameter 'certificate_key_pair_request' when calling CryptoApi.crypto_certificatekeypairs_update"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/{kp_uuid}/'.sub('{kp_uuid}', CGI.escape(kp_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(certificate_key_pair_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CertificateKeyPair'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_used_by_list(kp_uuid, opts = {}) ⇒ Array<UsedBy>

Get a list of all objects that use this object

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



493
494
495
496
# File 'lib/authentik/api/api/crypto_api.rb', line 493

def crypto_certificatekeypairs_used_by_list(kp_uuid, opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_used_by_list_with_http_info(kp_uuid, opts)
  data
end

#crypto_certificatekeypairs_used_by_list_with_http_info(kp_uuid, opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>

Get a list of all objects that use this object

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<UsedBy>, Integer, Hash)>)

    Array<UsedBy> data, response status code and response headers



502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/authentik/api/api/crypto_api.rb', line 502

def crypto_certificatekeypairs_used_by_list_with_http_info(kp_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_used_by_list ...'
  end
  # verify the required parameter 'kp_uuid' is set
  if @api_client.config.client_side_validation && kp_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'kp_uuid' when calling CryptoApi.crypto_certificatekeypairs_used_by_list"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/{kp_uuid}/used_by/'.sub('{kp_uuid}', CGI.escape(kp_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<UsedBy>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_used_by_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_used_by_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_view_certificate_retrieve(kp_uuid, opts = {}) ⇒ CertificateData

Return certificate-key pairs certificate and log access

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :download (Boolean)

Returns:



555
556
557
558
# File 'lib/authentik/api/api/crypto_api.rb', line 555

def crypto_certificatekeypairs_view_certificate_retrieve(kp_uuid, opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_view_certificate_retrieve_with_http_info(kp_uuid, opts)
  data
end

#crypto_certificatekeypairs_view_certificate_retrieve_with_http_info(kp_uuid, opts = {}) ⇒ Array<(CertificateData, Integer, Hash)>

Return certificate-key pairs certificate and log access

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :download (Boolean)

Returns:

  • (Array<(CertificateData, Integer, Hash)>)

    CertificateData data, response status code and response headers



565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/authentik/api/api/crypto_api.rb', line 565

def crypto_certificatekeypairs_view_certificate_retrieve_with_http_info(kp_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_view_certificate_retrieve ...'
  end
  # verify the required parameter 'kp_uuid' is set
  if @api_client.config.client_side_validation && kp_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'kp_uuid' when calling CryptoApi.crypto_certificatekeypairs_view_certificate_retrieve"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/{kp_uuid}/view_certificate/'.sub('{kp_uuid}', CGI.escape(kp_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'download'] = opts[:'download'] if !opts[:'download'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CertificateData'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_view_certificate_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_view_certificate_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#crypto_certificatekeypairs_view_private_key_retrieve(kp_uuid, opts = {}) ⇒ CertificateData

Return certificate-key pairs private key and log access

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :download (Boolean)

Returns:



619
620
621
622
# File 'lib/authentik/api/api/crypto_api.rb', line 619

def crypto_certificatekeypairs_view_private_key_retrieve(kp_uuid, opts = {})
  data, _status_code, _headers = crypto_certificatekeypairs_view_private_key_retrieve_with_http_info(kp_uuid, opts)
  data
end

#crypto_certificatekeypairs_view_private_key_retrieve_with_http_info(kp_uuid, opts = {}) ⇒ Array<(CertificateData, Integer, Hash)>

Return certificate-key pairs private key and log access

Parameters:

  • kp_uuid (String)

    A UUID string identifying this Certificate-Key Pair.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :download (Boolean)

Returns:

  • (Array<(CertificateData, Integer, Hash)>)

    CertificateData data, response status code and response headers



629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/authentik/api/api/crypto_api.rb', line 629

def crypto_certificatekeypairs_view_private_key_retrieve_with_http_info(kp_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CryptoApi.crypto_certificatekeypairs_view_private_key_retrieve ...'
  end
  # verify the required parameter 'kp_uuid' is set
  if @api_client.config.client_side_validation && kp_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'kp_uuid' when calling CryptoApi.crypto_certificatekeypairs_view_private_key_retrieve"
  end
  # resource path
  local_var_path = '/crypto/certificatekeypairs/{kp_uuid}/view_private_key/'.sub('{kp_uuid}', CGI.escape(kp_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'download'] = opts[:'download'] if !opts[:'download'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CertificateData'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"CryptoApi.crypto_certificatekeypairs_view_private_key_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CryptoApi#crypto_certificatekeypairs_view_private_key_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end