Class: Authentik::Api::CurrentBrandFlags

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/current_brand_flags.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CurrentBrandFlags

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/authentik/api/models/current_brand_flags.rb', line 52

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::CurrentBrandFlags` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::CurrentBrandFlags`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flows_continuous_login')
    self. = attributes[:'flows_continuous_login']
  else
    self. = nil
  end

  if attributes.key?(:'flows_refresh_others')
    self.flows_refresh_others = attributes[:'flows_refresh_others']
  else
    self.flows_refresh_others = nil
  end
end

Instance Attribute Details

#flows_continuous_loginObject

Upon successful authentication, re-start authentication in other open tabs.



13
14
15
# File 'lib/authentik/api/models/current_brand_flags.rb', line 13

def 
  @flows_continuous_login
end

#flows_refresh_othersObject

Refresh other tabs after successful authentication.



16
17
18
# File 'lib/authentik/api/models/current_brand_flags.rb', line 16

def flows_refresh_others
  @flows_refresh_others
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



27
28
29
# File 'lib/authentik/api/models/current_brand_flags.rb', line 27

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



32
33
34
# File 'lib/authentik/api/models/current_brand_flags.rb', line 32

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



19
20
21
22
23
24
# File 'lib/authentik/api/models/current_brand_flags.rb', line 19

def self.attribute_map
  {
    :'flows_continuous_login' => :'flows_continuous_login',
    :'flows_refresh_others' => :'flows_refresh_others'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/authentik/api/models/current_brand_flags.rb', line 148

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



45
46
47
48
# File 'lib/authentik/api/models/current_brand_flags.rb', line 45

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



37
38
39
40
41
42
# File 'lib/authentik/api/models/current_brand_flags.rb', line 37

def self.openapi_types
  {
    :'flows_continuous_login' => :'Boolean',
    :'flows_refresh_others' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
# File 'lib/authentik/api/models/current_brand_flags.rb', line 126

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      flows_refresh_others == o.flows_refresh_others
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/authentik/api/models/current_brand_flags.rb', line 135

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



141
142
143
# File 'lib/authentik/api/models/current_brand_flags.rb', line 141

def hash
  [, flows_refresh_others].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/authentik/api/models/current_brand_flags.rb', line 81

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @flows_continuous_login.nil?
    invalid_properties.push('invalid value for "flows_continuous_login", flows_continuous_login cannot be nil.')
  end

  if @flows_refresh_others.nil?
    invalid_properties.push('invalid value for "flows_refresh_others", flows_refresh_others cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/authentik/api/models/current_brand_flags.rb', line 170

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



97
98
99
100
101
102
# File 'lib/authentik/api/models/current_brand_flags.rb', line 97

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @flows_continuous_login.nil?
  return false if @flows_refresh_others.nil?
  true
end