Class: Authentik::Api::DeviceAccessGroup
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::DeviceAccessGroup
- Defined in:
- lib/authentik/api/models/device_access_group.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pbm_uuid ⇒ Object
Returns the value of attribute pbm_uuid.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeviceAccessGroup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeviceAccessGroup
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/authentik/api/models/device_access_group.rb', line 54 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DeviceAccessGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DeviceAccessGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pbm_uuid') self.pbm_uuid = attributes[:'pbm_uuid'] else self.pbm_uuid = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
16 17 18 |
# File 'lib/authentik/api/models/device_access_group.rb', line 16 def attributes @attributes end |
#name ⇒ Object
Returns the value of attribute name.
14 15 16 |
# File 'lib/authentik/api/models/device_access_group.rb', line 14 def name @name end |
#pbm_uuid ⇒ Object
Returns the value of attribute pbm_uuid.
12 13 14 |
# File 'lib/authentik/api/models/device_access_group.rb', line 12 def pbm_uuid @pbm_uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
28 29 30 |
# File 'lib/authentik/api/models/device_access_group.rb', line 28 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
33 34 35 |
# File 'lib/authentik/api/models/device_access_group.rb', line 33 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
19 20 21 22 23 24 25 |
# File 'lib/authentik/api/models/device_access_group.rb', line 19 def self.attribute_map { :'pbm_uuid' => :'pbm_uuid', :'name' => :'name', :'attributes' => :'attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/authentik/api/models/device_access_group.rb', line 157 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
47 48 49 50 |
# File 'lib/authentik/api/models/device_access_group.rb', line 47 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 |
# File 'lib/authentik/api/models/device_access_group.rb', line 38 def self.openapi_types { :'pbm_uuid' => :'String', :'name' => :'String', :'attributes' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 |
# File 'lib/authentik/api/models/device_access_group.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && pbm_uuid == o.pbm_uuid && name == o.name && attributes == o.attributes end |
#eql?(o) ⇒ Boolean
144 145 146 |
# File 'lib/authentik/api/models/device_access_group.rb', line 144 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/authentik/api/models/device_access_group.rb', line 150 def hash [pbm_uuid, name, attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/authentik/api/models/device_access_group.rb', line 89 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pbm_uuid.nil? invalid_properties.push('invalid value for "pbm_uuid", pbm_uuid cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/authentik/api/models/device_access_group.rb', line 179 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
105 106 107 108 109 110 |
# File 'lib/authentik/api/models/device_access_group.rb', line 105 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pbm_uuid.nil? return false if @name.nil? true end |