Class: Authentik::Api::DeviceChallengeRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::DeviceChallengeRequest
- Defined in:
- lib/authentik/api/models/device_challenge_request.rb
Overview
Single device challenge
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#challenge ⇒ Object
Returns the value of attribute challenge.
-
#device_class ⇒ Object
Returns the value of attribute device_class.
-
#device_uid ⇒ Object
Returns the value of attribute device_uid.
-
#last_used ⇒ Object
Returns the value of attribute last_used.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeviceChallengeRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeviceChallengeRequest
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DeviceChallengeRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DeviceChallengeRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'device_class') self.device_class = attributes[:'device_class'] else self.device_class = nil end if attributes.key?(:'device_uid') self.device_uid = attributes[:'device_uid'] else self.device_uid = nil end if attributes.key?(:'challenge') if (value = attributes[:'challenge']).is_a?(Hash) self.challenge = value end else self.challenge = nil end if attributes.key?(:'last_used') self.last_used = attributes[:'last_used'] else self.last_used = nil end end |
Instance Attribute Details
#challenge ⇒ Object
Returns the value of attribute challenge.
17 18 19 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 17 def challenge @challenge end |
#device_class ⇒ Object
Returns the value of attribute device_class.
13 14 15 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 13 def device_class @device_class end |
#device_uid ⇒ Object
Returns the value of attribute device_uid.
15 16 17 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 15 def device_uid @device_uid end |
#last_used ⇒ Object
Returns the value of attribute last_used.
19 20 21 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 19 def last_used @last_used end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 44 def self.attribute_map { :'device_class' => :'device_class', :'device_uid' => :'device_uid', :'challenge' => :'challenge', :'last_used' => :'last_used' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 218 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 78 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 74 def self.openapi_nullable Set.new([ :'last_used' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 64 def self.openapi_types { :'device_class' => :'DeviceClassesEnum', :'device_uid' => :'String', :'challenge' => :'Hash<String, Object>', :'last_used' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && device_class == o.device_class && device_uid == o.device_uid && challenge == o.challenge && last_used == o.last_used end |
#eql?(o) ⇒ Boolean
205 206 207 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 205 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 211 def hash [device_class, device_uid, challenge, last_used].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @device_class.nil? invalid_properties.push('invalid value for "device_class", device_class cannot be nil.') end if @device_uid.nil? invalid_properties.push('invalid value for "device_uid", device_uid cannot be nil.') end if @device_uid.to_s.length < 1 invalid_properties.push('invalid value for "device_uid", the character length must be greater than or equal to 1.') end if @challenge.nil? invalid_properties.push('invalid value for "challenge", challenge cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 155 156 |
# File 'lib/authentik/api/models/device_challenge_request.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @device_class.nil? return false if @device_uid.nil? return false if @device_uid.to_s.length < 1 return false if @challenge.nil? true end |