Class: Authentik::Api::DeviceFactSnapshot

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/device_fact_snapshot.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeviceFactSnapshot

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DeviceFactSnapshot` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DeviceFactSnapshot`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  else
    self.data = nil
  end

  if attributes.key?(:'connection')
    self.connection = attributes[:'connection']
  else
    self.connection = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  else
    self.expires = nil
  end

  if attributes.key?(:'vendor')
    self.vendor = attributes[:'vendor']
  else
    self.vendor = nil
  end
end

Instance Attribute Details

#connectionObject

Returns the value of attribute connection.



14
15
16
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 14

def connection
  @connection
end

#createdObject

Returns the value of attribute created.



16
17
18
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 16

def created
  @created
end

#dataObject

Returns the value of attribute data.



12
13
14
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 12

def data
  @data
end

#expiresObject

Returns the value of attribute expires.



18
19
20
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 18

def expires
  @expires
end

#vendorObject

Returns the value of attribute vendor.



20
21
22
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 20

def vendor
  @vendor
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 45

def self.attribute_map
  {
    :'data' => :'data',
    :'connection' => :'connection',
    :'created' => :'created',
    :'expires' => :'expires',
    :'vendor' => :'vendor'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 232

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 77

def self.openapi_nullable
  Set.new([
    :'expires',
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 66

def self.openapi_types
  {
    :'data' => :'DeviceFacts',
    :'connection' => :'String',
    :'created' => :'Time',
    :'expires' => :'Time',
    :'vendor' => :'VendorEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
215
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      data == o.data &&
      connection == o.connection &&
      created == o.created &&
      expires == o.expires &&
      vendor == o.vendor
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 225

def hash
  [data, connection, created, expires, vendor].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @data.nil?
    invalid_properties.push('invalid value for "data", data cannot be nil.')
  end

  if @connection.nil?
    invalid_properties.push('invalid value for "connection", connection cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @vendor.nil?
    invalid_properties.push('invalid value for "vendor", vendor cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 254

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
162
163
# File 'lib/authentik/api/models/device_fact_snapshot.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @data.nil?
  return false if @connection.nil?
  return false if @created.nil?
  return false if @vendor.nil?
  true
end