Class: Authentik::Api::DeviceFacts
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::DeviceFacts
- Defined in:
- lib/authentik/api/models/device_facts.rb
Instance Attribute Summary collapse
-
#disks ⇒ Object
Returns the value of attribute disks.
-
#groups ⇒ Object
Returns the value of attribute groups.
-
#hardware ⇒ Object
Returns the value of attribute hardware.
-
#network ⇒ Object
Returns the value of attribute network.
-
#os ⇒ Object
Returns the value of attribute os.
-
#processes ⇒ Object
Returns the value of attribute processes.
-
#software ⇒ Object
Returns the value of attribute software.
-
#users ⇒ Object
Returns the value of attribute users.
-
#vendor ⇒ Object
Returns the value of attribute vendor.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeviceFacts
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeviceFacts
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/authentik/api/models/device_facts.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DeviceFacts` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DeviceFacts`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'os') self.os = attributes[:'os'] end if attributes.key?(:'disks') if (value = attributes[:'disks']).is_a?(Array) self.disks = value end end if attributes.key?(:'network') self.network = attributes[:'network'] end if attributes.key?(:'hardware') self.hardware = attributes[:'hardware'] end if attributes.key?(:'software') if (value = attributes[:'software']).is_a?(Array) self.software = value end end if attributes.key?(:'processes') if (value = attributes[:'processes']).is_a?(Array) self.processes = value end end if attributes.key?(:'users') if (value = attributes[:'users']).is_a?(Array) self.users = value end end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'vendor') if (value = attributes[:'vendor']).is_a?(Hash) self.vendor = value end end end |
Instance Attribute Details
#disks ⇒ Object
Returns the value of attribute disks.
14 15 16 |
# File 'lib/authentik/api/models/device_facts.rb', line 14 def disks @disks end |
#groups ⇒ Object
Returns the value of attribute groups.
26 27 28 |
# File 'lib/authentik/api/models/device_facts.rb', line 26 def groups @groups end |
#hardware ⇒ Object
Returns the value of attribute hardware.
18 19 20 |
# File 'lib/authentik/api/models/device_facts.rb', line 18 def hardware @hardware end |
#network ⇒ Object
Returns the value of attribute network.
16 17 18 |
# File 'lib/authentik/api/models/device_facts.rb', line 16 def network @network end |
#os ⇒ Object
Returns the value of attribute os.
12 13 14 |
# File 'lib/authentik/api/models/device_facts.rb', line 12 def os @os end |
#processes ⇒ Object
Returns the value of attribute processes.
22 23 24 |
# File 'lib/authentik/api/models/device_facts.rb', line 22 def processes @processes end |
#software ⇒ Object
Returns the value of attribute software.
20 21 22 |
# File 'lib/authentik/api/models/device_facts.rb', line 20 def software @software end |
#users ⇒ Object
Returns the value of attribute users.
24 25 26 |
# File 'lib/authentik/api/models/device_facts.rb', line 24 def users @users end |
#vendor ⇒ Object
Returns the value of attribute vendor.
28 29 30 |
# File 'lib/authentik/api/models/device_facts.rb', line 28 def vendor @vendor end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/authentik/api/models/device_facts.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/authentik/api/models/device_facts.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/authentik/api/models/device_facts.rb', line 31 def self.attribute_map { :'os' => :'os', :'disks' => :'disks', :'network' => :'network', :'hardware' => :'hardware', :'software' => :'software', :'processes' => :'processes', :'users' => :'users', :'groups' => :'groups', :'vendor' => :'vendor' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/authentik/api/models/device_facts.rb', line 195 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/authentik/api/models/device_facts.rb', line 71 def self.openapi_nullable Set.new([ :'os', :'disks', :'network', :'hardware', :'software', :'processes', :'users', :'groups', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/authentik/api/models/device_facts.rb', line 56 def self.openapi_types { :'os' => :'OperatingSystem', :'disks' => :'Array<Disk>', :'network' => :'Network', :'hardware' => :'Hardware', :'software' => :'Array<Software>', :'processes' => :'Array<Process>', :'users' => :'Array<DeviceUser>', :'groups' => :'Array<DeviceGroup>', :'vendor' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/authentik/api/models/device_facts.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && os == o.os && disks == o.disks && network == o.network && hardware == o.hardware && software == o.software && processes == o.processes && users == o.users && groups == o.groups && vendor == o.vendor end |
#eql?(o) ⇒ Boolean
182 183 184 |
# File 'lib/authentik/api/models/device_facts.rb', line 182 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/authentik/api/models/device_facts.rb', line 188 def hash [os, disks, network, hardware, software, processes, users, groups, vendor].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 |
# File 'lib/authentik/api/models/device_facts.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/authentik/api/models/device_facts.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 |
# File 'lib/authentik/api/models/device_facts.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |