Class: Authentik::Api::DeviceUserBinding

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/device_user_binding.rb

Overview

PolicyBinding Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeviceUserBinding

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/authentik/api/models/device_user_binding.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DeviceUserBinding` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DeviceUserBinding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end

  if attributes.key?(:'group')
    self.group = attributes[:'group']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'policy_obj')
    self.policy_obj = attributes[:'policy_obj']
  else
    self.policy_obj = nil
  end

  if attributes.key?(:'group_obj')
    self.group_obj = attributes[:'group_obj']
  else
    self.group_obj = nil
  end

  if attributes.key?(:'user_obj')
    self.user_obj = attributes[:'user_obj']
  else
    self.user_obj = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'negate')
    self.negate = attributes[:'negate']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  else
    self.order = nil
  end

  if attributes.key?(:'timeout')
    self.timeout = attributes[:'timeout']
  end

  if attributes.key?(:'failure_result')
    self.failure_result = attributes[:'failure_result']
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  else
    self.expires = nil
  end

  if attributes.key?(:'expiring')
    self.expiring = attributes[:'expiring']
  else
    self.expiring = nil
  end

  if attributes.key?(:'is_primary')
    self.is_primary = attributes[:'is_primary']
  end

  if attributes.key?(:'connector')
    self.connector = attributes[:'connector']
  else
    self.connector = nil
  end

  if attributes.key?(:'connector_obj')
    self.connector_obj = attributes[:'connector_obj']
  else
    self.connector_obj = nil
  end
end

Instance Attribute Details

#connectorObject

Returns the value of attribute connector.



48
49
50
# File 'lib/authentik/api/models/device_user_binding.rb', line 48

def connector
  @connector
end

#connector_objObject

Returns the value of attribute connector_obj.



50
51
52
# File 'lib/authentik/api/models/device_user_binding.rb', line 50

def connector_obj
  @connector_obj
end

#enabledObject

Returns the value of attribute enabled.



32
33
34
# File 'lib/authentik/api/models/device_user_binding.rb', line 32

def enabled
  @enabled
end

#expiresObject

Returns the value of attribute expires.



42
43
44
# File 'lib/authentik/api/models/device_user_binding.rb', line 42

def expires
  @expires
end

#expiringObject

Returns the value of attribute expiring.



44
45
46
# File 'lib/authentik/api/models/device_user_binding.rb', line 44

def expiring
  @expiring
end

#failure_resultObject

Result if the Policy execution fails.



40
41
42
# File 'lib/authentik/api/models/device_user_binding.rb', line 40

def failure_result
  @failure_result
end

#groupObject

Returns the value of attribute group.



17
18
19
# File 'lib/authentik/api/models/device_user_binding.rb', line 17

def group
  @group
end

#group_objObject

Returns the value of attribute group_obj.



23
24
25
# File 'lib/authentik/api/models/device_user_binding.rb', line 23

def group_obj
  @group_obj
end

#is_primaryObject

Returns the value of attribute is_primary.



46
47
48
# File 'lib/authentik/api/models/device_user_binding.rb', line 46

def is_primary
  @is_primary
end

#negateObject

Negates the outcome of the policy. Messages are unaffected.



30
31
32
# File 'lib/authentik/api/models/device_user_binding.rb', line 30

def negate
  @negate
end

#orderObject

Returns the value of attribute order.



34
35
36
# File 'lib/authentik/api/models/device_user_binding.rb', line 34

def order
  @order
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/device_user_binding.rb', line 13

def pk
  @pk
end

#policyObject

Returns the value of attribute policy.



15
16
17
# File 'lib/authentik/api/models/device_user_binding.rb', line 15

def policy
  @policy
end

#policy_objObject

Returns the value of attribute policy_obj.



21
22
23
# File 'lib/authentik/api/models/device_user_binding.rb', line 21

def policy_obj
  @policy_obj
end

#targetObject

Returns the value of attribute target.



27
28
29
# File 'lib/authentik/api/models/device_user_binding.rb', line 27

def target
  @target
end

#timeoutObject

Timeout after which Policy execution is terminated.



37
38
39
# File 'lib/authentik/api/models/device_user_binding.rb', line 37

def timeout
  @timeout
end

#userObject

Returns the value of attribute user.



19
20
21
# File 'lib/authentik/api/models/device_user_binding.rb', line 19

def user
  @user
end

#user_objObject

Returns the value of attribute user_obj.



25
26
27
# File 'lib/authentik/api/models/device_user_binding.rb', line 25

def user_obj
  @user_obj
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/authentik/api/models/device_user_binding.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/authentik/api/models/device_user_binding.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/authentik/api/models/device_user_binding.rb', line 53

def self.attribute_map
  {
    :'pk' => :'pk',
    :'policy' => :'policy',
    :'group' => :'group',
    :'user' => :'user',
    :'policy_obj' => :'policy_obj',
    :'group_obj' => :'group_obj',
    :'user_obj' => :'user_obj',
    :'target' => :'target',
    :'negate' => :'negate',
    :'enabled' => :'enabled',
    :'order' => :'order',
    :'timeout' => :'timeout',
    :'failure_result' => :'failure_result',
    :'expires' => :'expires',
    :'expiring' => :'expiring',
    :'is_primary' => :'is_primary',
    :'connector' => :'connector',
    :'connector_obj' => :'connector_obj'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/authentik/api/models/device_user_binding.rb', line 409

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/authentik/api/models/device_user_binding.rb', line 111

def self.openapi_nullable
  Set.new([
    :'policy',
    :'group',
    :'user',
    :'policy_obj',
    :'group_obj',
    :'user_obj',
    :'expires',
    :'connector',
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/authentik/api/models/device_user_binding.rb', line 87

def self.openapi_types
  {
    :'pk' => :'String',
    :'policy' => :'String',
    :'group' => :'String',
    :'user' => :'Integer',
    :'policy_obj' => :'Policy',
    :'group_obj' => :'PartialGroup',
    :'user_obj' => :'PartialUser',
    :'target' => :'String',
    :'negate' => :'Boolean',
    :'enabled' => :'Boolean',
    :'order' => :'Integer',
    :'timeout' => :'Integer',
    :'failure_result' => :'Boolean',
    :'expires' => :'Time',
    :'expiring' => :'Boolean',
    :'is_primary' => :'Boolean',
    :'connector' => :'String',
    :'connector_obj' => :'Connector'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/authentik/api/models/device_user_binding.rb', line 371

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      policy == o.policy &&
      group == o.group &&
      user == o.user &&
      policy_obj == o.policy_obj &&
      group_obj == o.group_obj &&
      user_obj == o.user_obj &&
      target == o.target &&
      negate == o.negate &&
      enabled == o.enabled &&
      order == o.order &&
      timeout == o.timeout &&
      failure_result == o.failure_result &&
      expires == o.expires &&
      expiring == o.expiring &&
      is_primary == o.is_primary &&
      connector == o.connector &&
      connector_obj == o.connector_obj
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


396
397
398
# File 'lib/authentik/api/models/device_user_binding.rb', line 396

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



402
403
404
# File 'lib/authentik/api/models/device_user_binding.rb', line 402

def hash
  [pk, policy, group, user, policy_obj, group_obj, user_obj, target, negate, enabled, order, timeout, failure_result, expires, expiring, is_primary, connector, connector_obj].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/authentik/api/models/device_user_binding.rb', line 235

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @order.nil?
    invalid_properties.push('invalid value for "order", order cannot be nil.')
  end

  if @order > 2147483647
    invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.')
  end

  if @order < -2147483648
    invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.')
  end

  if !@timeout.nil? && @timeout > 2147483647
    invalid_properties.push('invalid value for "timeout", must be smaller than or equal to 2147483647.')
  end

  if !@timeout.nil? && @timeout < 0
    invalid_properties.push('invalid value for "timeout", must be greater than or equal to 0.')
  end

  if @expiring.nil?
    invalid_properties.push('invalid value for "expiring", expiring cannot be nil.')
  end

  if @connector_obj.nil?
    invalid_properties.push('invalid value for "connector_obj", connector_obj cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/authentik/api/models/device_user_binding.rb', line 431

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/authentik/api/models/device_user_binding.rb', line 279

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @target.nil?
  return false if @order.nil?
  return false if @order > 2147483647
  return false if @order < -2147483648
  return false if !@timeout.nil? && @timeout > 2147483647
  return false if !@timeout.nil? && @timeout < 0
  return false if @expiring.nil?
  return false if @connector_obj.nil?
  true
end