Class: Authentik::Api::DeviceUserBindingRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/device_user_binding_request.rb

Overview

PolicyBinding Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DeviceUserBindingRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DeviceUserBindingRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DeviceUserBindingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end

  if attributes.key?(:'group')
    self.group = attributes[:'group']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'negate')
    self.negate = attributes[:'negate']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  else
    self.order = nil
  end

  if attributes.key?(:'timeout')
    self.timeout = attributes[:'timeout']
  end

  if attributes.key?(:'failure_result')
    self.failure_result = attributes[:'failure_result']
  end

  if attributes.key?(:'is_primary')
    self.is_primary = attributes[:'is_primary']
  end
end

Instance Attribute Details

#enabledObject

Returns the value of attribute enabled.



24
25
26
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 24

def enabled
  @enabled
end

#failure_resultObject

Result if the Policy execution fails.



32
33
34
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 32

def failure_result
  @failure_result
end

#groupObject

Returns the value of attribute group.



15
16
17
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 15

def group
  @group
end

#is_primaryObject

Returns the value of attribute is_primary.



34
35
36
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 34

def is_primary
  @is_primary
end

#negateObject

Negates the outcome of the policy. Messages are unaffected.



22
23
24
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 22

def negate
  @negate
end

#orderObject

Returns the value of attribute order.



26
27
28
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 26

def order
  @order
end

#policyObject

Returns the value of attribute policy.



13
14
15
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 13

def policy
  @policy
end

#targetObject

Returns the value of attribute target.



19
20
21
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 19

def target
  @target
end

#timeoutObject

Timeout after which Policy execution is terminated.



29
30
31
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 29

def timeout
  @timeout
end

#userObject

Returns the value of attribute user.



17
18
19
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 17

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 37

def self.attribute_map
  {
    :'policy' => :'policy',
    :'group' => :'group',
    :'user' => :'user',
    :'target' => :'target',
    :'negate' => :'negate',
    :'enabled' => :'enabled',
    :'order' => :'order',
    :'timeout' => :'timeout',
    :'failure_result' => :'failure_result',
    :'is_primary' => :'is_primary'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 271

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
83
84
85
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 79

def self.openapi_nullable
  Set.new([
    :'policy',
    :'group',
    :'user',
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 63

def self.openapi_types
  {
    :'policy' => :'String',
    :'group' => :'String',
    :'user' => :'Integer',
    :'target' => :'String',
    :'negate' => :'Boolean',
    :'enabled' => :'Boolean',
    :'order' => :'Integer',
    :'timeout' => :'Integer',
    :'failure_result' => :'Boolean',
    :'is_primary' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 241

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      policy == o.policy &&
      group == o.group &&
      user == o.user &&
      target == o.target &&
      negate == o.negate &&
      enabled == o.enabled &&
      order == o.order &&
      timeout == o.timeout &&
      failure_result == o.failure_result &&
      is_primary == o.is_primary
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


258
259
260
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 258

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



264
265
266
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 264

def hash
  [policy, group, user, target, negate, enabled, order, timeout, failure_result, is_primary].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @order.nil?
    invalid_properties.push('invalid value for "order", order cannot be nil.')
  end

  if @order > 2147483647
    invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.')
  end

  if @order < -2147483648
    invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.')
  end

  if !@timeout.nil? && @timeout > 2147483647
    invalid_properties.push('invalid value for "timeout", must be smaller than or equal to 2147483647.')
  end

  if !@timeout.nil? && @timeout < 0
    invalid_properties.push('invalid value for "timeout", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
188
189
190
191
# File 'lib/authentik/api/models/device_user_binding_request.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @target.nil?
  return false if @order.nil?
  return false if @order > 2147483647
  return false if @order < -2147483648
  return false if !@timeout.nil? && @timeout > 2147483647
  return false if !@timeout.nil? && @timeout < 0
  true
end