Class: Authentik::Api::DeviceUserRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::DeviceUserRequest
- Defined in:
- lib/authentik/api/models/device_user_request.rb
Instance Attribute Summary collapse
-
#home ⇒ Object
Returns the value of attribute home.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeviceUserRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeviceUserRequest
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/authentik/api/models/device_user_request.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DeviceUserRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DeviceUserRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'home') self.home = attributes[:'home'] end end |
Instance Attribute Details
#home ⇒ Object
Returns the value of attribute home.
18 19 20 |
# File 'lib/authentik/api/models/device_user_request.rb', line 18 def home @home end |
#id ⇒ Object
Returns the value of attribute id.
12 13 14 |
# File 'lib/authentik/api/models/device_user_request.rb', line 12 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
16 17 18 |
# File 'lib/authentik/api/models/device_user_request.rb', line 16 def name @name end |
#username ⇒ Object
Returns the value of attribute username.
14 15 16 |
# File 'lib/authentik/api/models/device_user_request.rb', line 14 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
31 32 33 |
# File 'lib/authentik/api/models/device_user_request.rb', line 31 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
36 37 38 |
# File 'lib/authentik/api/models/device_user_request.rb', line 36 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 28 |
# File 'lib/authentik/api/models/device_user_request.rb', line 21 def self.attribute_map { :'id' => :'id', :'username' => :'username', :'name' => :'name', :'home' => :'home' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/authentik/api/models/device_user_request.rb', line 213 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/authentik/api/models/device_user_request.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 |
# File 'lib/authentik/api/models/device_user_request.rb', line 41 def self.openapi_types { :'id' => :'String', :'username' => :'String', :'name' => :'String', :'home' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
189 190 191 192 193 194 195 196 |
# File 'lib/authentik/api/models/device_user_request.rb', line 189 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && username == o.username && name == o.name && home == o.home end |
#eql?(o) ⇒ Boolean
200 201 202 |
# File 'lib/authentik/api/models/device_user_request.rb', line 200 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/authentik/api/models/device_user_request.rb', line 206 def hash [id, username, name, home].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/authentik/api/models/device_user_request.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id.to_s.length < 1 invalid_properties.push('invalid value for "id", the character length must be greater than or equal to 1.') end if !@username.nil? && @username.to_s.length < 1 invalid_properties.push('invalid value for "username", the character length must be greater than or equal to 1.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@home.nil? && @home.to_s.length < 1 invalid_properties.push('invalid value for "home", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/authentik/api/models/device_user_request.rb', line 235 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 125 126 127 128 129 |
# File 'lib/authentik/api/models/device_user_request.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id.to_s.length < 1 return false if !@username.nil? && @username.to_s.length < 1 return false if !@name.nil? && @name.to_s.length < 1 return false if !@home.nil? && @home.to_s.length < 1 true end |