Class: Authentik::Api::DiskRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/disk_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DiskRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/authentik/api/models/disk_request.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DiskRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DiskRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'mountpoint')
    self.mountpoint = attributes[:'mountpoint']
  else
    self.mountpoint = nil
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'capacity_total_bytes')
    self.capacity_total_bytes = attributes[:'capacity_total_bytes']
  end

  if attributes.key?(:'capacity_used_bytes')
    self.capacity_used_bytes = attributes[:'capacity_used_bytes']
  end

  if attributes.key?(:'encryption_enabled')
    self.encryption_enabled = attributes[:'encryption_enabled']
  else
    self.encryption_enabled = false
  end
end

Instance Attribute Details

#capacity_total_bytesObject

Returns the value of attribute capacity_total_bytes.



18
19
20
# File 'lib/authentik/api/models/disk_request.rb', line 18

def capacity_total_bytes
  @capacity_total_bytes
end

#capacity_used_bytesObject

Returns the value of attribute capacity_used_bytes.



20
21
22
# File 'lib/authentik/api/models/disk_request.rb', line 20

def capacity_used_bytes
  @capacity_used_bytes
end

#encryption_enabledObject

Returns the value of attribute encryption_enabled.



22
23
24
# File 'lib/authentik/api/models/disk_request.rb', line 22

def encryption_enabled
  @encryption_enabled
end

#labelObject

Returns the value of attribute label.



16
17
18
# File 'lib/authentik/api/models/disk_request.rb', line 16

def label
  @label
end

#mountpointObject

Returns the value of attribute mountpoint.



14
15
16
# File 'lib/authentik/api/models/disk_request.rb', line 14

def mountpoint
  @mountpoint
end

#nameObject

Returns the value of attribute name.



12
13
14
# File 'lib/authentik/api/models/disk_request.rb', line 12

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/authentik/api/models/disk_request.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/authentik/api/models/disk_request.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
32
33
34
# File 'lib/authentik/api/models/disk_request.rb', line 25

def self.attribute_map
  {
    :'name' => :'name',
    :'mountpoint' => :'mountpoint',
    :'label' => :'label',
    :'capacity_total_bytes' => :'capacity_total_bytes',
    :'capacity_used_bytes' => :'capacity_used_bytes',
    :'encryption_enabled' => :'encryption_enabled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/authentik/api/models/disk_request.rb', line 202

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
# File 'lib/authentik/api/models/disk_request.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
56
# File 'lib/authentik/api/models/disk_request.rb', line 47

def self.openapi_types
  {
    :'name' => :'String',
    :'mountpoint' => :'String',
    :'label' => :'String',
    :'capacity_total_bytes' => :'Integer',
    :'capacity_used_bytes' => :'Integer',
    :'encryption_enabled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



176
177
178
179
180
181
182
183
184
185
# File 'lib/authentik/api/models/disk_request.rb', line 176

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      mountpoint == o.mountpoint &&
      label == o.label &&
      capacity_total_bytes == o.capacity_total_bytes &&
      capacity_used_bytes == o.capacity_used_bytes &&
      encryption_enabled == o.encryption_enabled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


189
190
191
# File 'lib/authentik/api/models/disk_request.rb', line 189

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



195
196
197
# File 'lib/authentik/api/models/disk_request.rb', line 195

def hash
  [name, mountpoint, label, capacity_total_bytes, capacity_used_bytes, encryption_enabled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/authentik/api/models/disk_request.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @mountpoint.nil?
    invalid_properties.push('invalid value for "mountpoint", mountpoint cannot be nil.')
  end

  if @mountpoint.to_s.length < 1
    invalid_properties.push('invalid value for "mountpoint", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/authentik/api/models/disk_request.rb', line 224

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
143
144
# File 'lib/authentik/api/models/disk_request.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @mountpoint.nil?
  return false if @mountpoint.to_s.length < 1
  true
end