Class: Authentik::Api::DockerServiceConnectionRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/docker_service_connection_request.rb

Overview

DockerServiceConnection Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DockerServiceConnectionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DockerServiceConnectionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DockerServiceConnectionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'local')
    self.local = attributes[:'local']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'tls_verification')
    self.tls_verification = attributes[:'tls_verification']
  end

  if attributes.key?(:'tls_authentication')
    self.tls_authentication = attributes[:'tls_authentication']
  end
end

Instance Attribute Details

#localObject

If enabled, use the local connection. Required Docker socket/Kubernetes Integration



16
17
18
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 16

def local
  @local
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 13

def name
  @name
end

#tls_authenticationObject

Certificate/Key used for authentication. Can be left empty for no authentication.



25
26
27
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 25

def tls_authentication
  @tls_authentication
end

#tls_verificationObject

CA which the endpoint’s Certificate is verified against. Can be left empty for no validation.



22
23
24
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 22

def tls_verification
  @tls_verification
end

#urlObject

Can be in the format of ‘unix://<path>’ when connecting to a local docker daemon, or ‘https://<hostname>:2376’ when connecting to a remote system.



19
20
21
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 19

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



39
40
41
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 39

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 44

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 28

def self.attribute_map
  {
    :'name' => :'name',
    :'local' => :'local',
    :'url' => :'url',
    :'tls_verification' => :'tls_verification',
    :'tls_authentication' => :'tls_authentication'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 198

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
64
65
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 60

def self.openapi_nullable
  Set.new([
    :'tls_verification',
    :'tls_authentication'
  ])
end

.openapi_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 49

def self.openapi_types
  {
    :'name' => :'String',
    :'local' => :'Boolean',
    :'url' => :'String',
    :'tls_verification' => :'String',
    :'tls_authentication' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      local == o.local &&
      url == o.url &&
      tls_verification == o.tls_verification &&
      tls_authentication == o.tls_authentication
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 185

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



191
192
193
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 191

def hash
  [name, local, url, tls_verification, tls_authentication].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 110

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length < 1
    invalid_properties.push('invalid value for "url", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
139
140
141
# File 'lib/authentik/api/models/docker_service_connection_request.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @url.nil?
  return false if @url.to_s.length < 1
  true
end