Class: Authentik::Api::DummyPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::DummyPolicy
- Defined in:
- lib/authentik/api/models/dummy_policy.rb
Overview
Dummy Policy Serializer
Instance Attribute Summary collapse
-
#bound_to ⇒ Object
Return objects policy is bound to.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#result ⇒ Object
Returns the value of attribute result.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
-
#wait_max ⇒ Object
Returns the value of attribute wait_max.
-
#wait_min ⇒ Object
Returns the value of attribute wait_min.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DummyPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DummyPolicy
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DummyPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DummyPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'execution_logging') self.execution_logging = attributes[:'execution_logging'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'bound_to') self.bound_to = attributes[:'bound_to'] else self.bound_to = nil end if attributes.key?(:'result') self.result = attributes[:'result'] end if attributes.key?(:'wait_min') self.wait_min = attributes[:'wait_min'] end if attributes.key?(:'wait_max') self.wait_max = attributes[:'wait_max'] end end |
Instance Attribute Details
#bound_to ⇒ Object
Return objects policy is bound to
33 34 35 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 33 def bound_to @bound_to end |
#component ⇒ Object
Get object component so that we know how to edit the object
21 22 23 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 21 def component @component end |
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.
18 19 20 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 18 def execution_logging @execution_logging end |
#meta_model_name ⇒ Object
Return internal model name
30 31 32 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 30 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 13 def pk @pk end |
#result ⇒ Object
Returns the value of attribute result.
35 36 37 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 35 def result @result end |
#verbose_name ⇒ Object
Return object’s verbose_name
24 25 26 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 24 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
27 28 29 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 27 def verbose_name_plural @verbose_name_plural end |
#wait_max ⇒ Object
Returns the value of attribute wait_max.
39 40 41 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 39 def wait_max @wait_max end |
#wait_min ⇒ Object
Returns the value of attribute wait_min.
37 38 39 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 37 def wait_min @wait_min end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 42 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'execution_logging' => :'execution_logging', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'bound_to' => :'bound_to', :'result' => :'result', :'wait_min' => :'wait_min', :'wait_max' => :'wait_max' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 375 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 69 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'execution_logging' => :'Boolean', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'bound_to' => :'Integer', :'result' => :'Boolean', :'wait_min' => :'Integer', :'wait_max' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 344 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && execution_logging == o.execution_logging && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && bound_to == o.bound_to && result == o.result && wait_min == o.wait_min && wait_max == o.wait_max end |
#eql?(o) ⇒ Boolean
362 363 364 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 362 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
368 369 370 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 368 def hash [pk, name, execution_logging, component, verbose_name, verbose_name_plural, , bound_to, result, wait_min, wait_max].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 168 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @bound_to.nil? invalid_properties.push('invalid value for "bound_to", bound_to cannot be nil.') end if !@wait_min.nil? && @wait_min > 2147483647 invalid_properties.push('invalid value for "wait_min", must be smaller than or equal to 2147483647.') end if !@wait_min.nil? && @wait_min < -2147483648 invalid_properties.push('invalid value for "wait_min", must be greater than or equal to -2147483648.') end if !@wait_max.nil? && @wait_max > 2147483647 invalid_properties.push('invalid value for "wait_max", must be smaller than or equal to 2147483647.') end if !@wait_max.nil? && @wait_max < -2147483648 invalid_properties.push('invalid value for "wait_max", must be greater than or equal to -2147483648.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 397 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/authentik/api/models/dummy_policy.rb', line 220 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @bound_to.nil? return false if !@wait_min.nil? && @wait_min > 2147483647 return false if !@wait_min.nil? && @wait_min < -2147483648 return false if !@wait_max.nil? && @wait_max > 2147483647 return false if !@wait_max.nil? && @wait_max < -2147483648 true end |