Class: Authentik::Api::DummyPolicyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::DummyPolicyRequest
- Defined in:
- lib/authentik/api/models/dummy_policy_request.rb
Overview
Dummy Policy Serializer
Instance Attribute Summary collapse
-
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged.
-
#name ⇒ Object
Returns the value of attribute name.
-
#result ⇒ Object
Returns the value of attribute result.
-
#wait_max ⇒ Object
Returns the value of attribute wait_max.
-
#wait_min ⇒ Object
Returns the value of attribute wait_min.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DummyPolicyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DummyPolicyRequest
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DummyPolicyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DummyPolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'execution_logging') self.execution_logging = attributes[:'execution_logging'] end if attributes.key?(:'result') self.result = attributes[:'result'] end if attributes.key?(:'wait_min') self.wait_min = attributes[:'wait_min'] end if attributes.key?(:'wait_max') self.wait_max = attributes[:'wait_max'] end end |
Instance Attribute Details
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.
16 17 18 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 16 def execution_logging @execution_logging end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 13 def name @name end |
#result ⇒ Object
Returns the value of attribute result.
18 19 20 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 18 def result @result end |
#wait_max ⇒ Object
Returns the value of attribute wait_max.
22 23 24 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 22 def wait_max @wait_max end |
#wait_min ⇒ Object
Returns the value of attribute wait_min.
20 21 22 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 20 def wait_min @wait_min end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 25 def self.attribute_map { :'name' => :'name', :'execution_logging' => :'execution_logging', :'result' => :'result', :'wait_min' => :'wait_min', :'wait_max' => :'wait_max' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 46 def self.openapi_types { :'name' => :'String', :'execution_logging' => :'Boolean', :'result' => :'Boolean', :'wait_min' => :'Integer', :'wait_max' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && execution_logging == o.execution_logging && result == o.result && wait_min == o.wait_min && wait_max == o.wait_max end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 216 def hash [name, execution_logging, result, wait_min, wait_max].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@wait_min.nil? && @wait_min > 2147483647 invalid_properties.push('invalid value for "wait_min", must be smaller than or equal to 2147483647.') end if !@wait_min.nil? && @wait_min < -2147483648 invalid_properties.push('invalid value for "wait_min", must be greater than or equal to -2147483648.') end if !@wait_max.nil? && @wait_max > 2147483647 invalid_properties.push('invalid value for "wait_max", must be smaller than or equal to 2147483647.') end if !@wait_max.nil? && @wait_max < -2147483648 invalid_properties.push('invalid value for "wait_max", must be greater than or equal to -2147483648.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 140 141 142 143 144 |
# File 'lib/authentik/api/models/dummy_policy_request.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if !@wait_min.nil? && @wait_min > 2147483647 return false if !@wait_min.nil? && @wait_min < -2147483648 return false if !@wait_max.nil? && @wait_max > 2147483647 return false if !@wait_max.nil? && @wait_max < -2147483648 true end |