Class: Authentik::Api::DuoDeviceEnrollmentStatus
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::DuoDeviceEnrollmentStatus
- Defined in:
- lib/authentik/api/models/duo_device_enrollment_status.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#duo_response ⇒ Object
Returns the value of attribute duo_response.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DuoDeviceEnrollmentStatus
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DuoDeviceEnrollmentStatus
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DuoDeviceEnrollmentStatus` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DuoDeviceEnrollmentStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'duo_response') self.duo_response = attributes[:'duo_response'] else self.duo_response = nil end end |
Instance Attribute Details
#duo_response ⇒ Object
Returns the value of attribute duo_response.
12 13 14 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 12 def duo_response @duo_response end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 37 def self.attribute_map { :'duo_response' => :'duo_response' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 142 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 54 def self.openapi_types { :'duo_response' => :'DuoResponseEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
121 122 123 124 125 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 121 def ==(o) return true if self.equal?(o) self.class == o.class && duo_response == o.duo_response end |
#eql?(o) ⇒ Boolean
129 130 131 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 129 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
135 136 137 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 135 def hash [duo_response].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
91 92 93 94 95 96 97 98 99 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 91 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @duo_response.nil? invalid_properties.push('invalid value for "duo_response", duo_response cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
103 104 105 106 107 |
# File 'lib/authentik/api/models/duo_device_enrollment_status.rb', line 103 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @duo_response.nil? true end |