Class: Authentik::Api::Endpoint

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/endpoint.rb

Overview

Endpoint Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Endpoint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/authentik/api/models/endpoint.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Endpoint` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Endpoint`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'provider_obj')
    self.provider_obj = attributes[:'provider_obj']
  else
    self.provider_obj = nil
  end

  if attributes.key?(:'protocol')
    self.protocol = attributes[:'protocol']
  else
    self.protocol = nil
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  else
    self.host = nil
  end

  if attributes.key?(:'settings')
    if (value = attributes[:'settings']).is_a?(Hash)
      self.settings = value
    end
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'auth_mode')
    self.auth_mode = attributes[:'auth_mode']
  else
    self.auth_mode = nil
  end

  if attributes.key?(:'launch_url')
    self.launch_url = attributes[:'launch_url']
  else
    self.launch_url = nil
  end

  if attributes.key?(:'maximum_connections')
    self.maximum_connections = attributes[:'maximum_connections']
  end
end

Instance Attribute Details

#auth_modeObject

Returns the value of attribute auth_mode.



29
30
31
# File 'lib/authentik/api/models/endpoint.rb', line 29

def auth_mode
  @auth_mode
end

#hostObject

Returns the value of attribute host.



23
24
25
# File 'lib/authentik/api/models/endpoint.rb', line 23

def host
  @host
end

#launch_urlObject

Build actual launch URL (the provider itself does not have one, just individual endpoints)



32
33
34
# File 'lib/authentik/api/models/endpoint.rb', line 32

def launch_url
  @launch_url
end

#maximum_connectionsObject

Returns the value of attribute maximum_connections.



34
35
36
# File 'lib/authentik/api/models/endpoint.rb', line 34

def maximum_connections
  @maximum_connections
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/endpoint.rb', line 15

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/endpoint.rb', line 13

def pk
  @pk
end

#property_mappingsObject

Returns the value of attribute property_mappings.



27
28
29
# File 'lib/authentik/api/models/endpoint.rb', line 27

def property_mappings
  @property_mappings
end

#protocolObject

Returns the value of attribute protocol.



21
22
23
# File 'lib/authentik/api/models/endpoint.rb', line 21

def protocol
  @protocol
end

#providerObject

Returns the value of attribute provider.



17
18
19
# File 'lib/authentik/api/models/endpoint.rb', line 17

def provider
  @provider
end

#provider_objObject

Returns the value of attribute provider_obj.



19
20
21
# File 'lib/authentik/api/models/endpoint.rb', line 19

def provider_obj
  @provider_obj
end

#settingsObject

Returns the value of attribute settings.



25
26
27
# File 'lib/authentik/api/models/endpoint.rb', line 25

def settings
  @settings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/authentik/api/models/endpoint.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/authentik/api/models/endpoint.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/authentik/api/models/endpoint.rb', line 59

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'provider' => :'provider',
    :'provider_obj' => :'provider_obj',
    :'protocol' => :'protocol',
    :'host' => :'host',
    :'settings' => :'settings',
    :'property_mappings' => :'property_mappings',
    :'auth_mode' => :'auth_mode',
    :'launch_url' => :'launch_url',
    :'maximum_connections' => :'maximum_connections'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/authentik/api/models/endpoint.rb', line 371

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
107
# File 'lib/authentik/api/models/endpoint.rb', line 103

def self.openapi_nullable
  Set.new([
    :'launch_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/authentik/api/models/endpoint.rb', line 86

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'provider' => :'Integer',
    :'provider_obj' => :'RACProvider',
    :'protocol' => :'ProtocolEnum',
    :'host' => :'String',
    :'settings' => :'Hash<String, Object>',
    :'property_mappings' => :'Array<String>',
    :'auth_mode' => :'EndpointAuthModeEnum',
    :'launch_url' => :'String',
    :'maximum_connections' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/authentik/api/models/endpoint.rb', line 340

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      provider == o.provider &&
      provider_obj == o.provider_obj &&
      protocol == o.protocol &&
      host == o.host &&
      settings == o.settings &&
      property_mappings == o.property_mappings &&
      auth_mode == o.auth_mode &&
      launch_url == o.launch_url &&
      maximum_connections == o.maximum_connections
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


358
359
360
# File 'lib/authentik/api/models/endpoint.rb', line 358

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



364
365
366
# File 'lib/authentik/api/models/endpoint.rb', line 364

def hash
  [pk, name, provider, provider_obj, protocol, host, settings, property_mappings, auth_mode, launch_url, maximum_connections].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/authentik/api/models/endpoint.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @provider_obj.nil?
    invalid_properties.push('invalid value for "provider_obj", provider_obj cannot be nil.')
  end

  if @protocol.nil?
    invalid_properties.push('invalid value for "protocol", protocol cannot be nil.')
  end

  if @host.nil?
    invalid_properties.push('invalid value for "host", host cannot be nil.')
  end

  if @auth_mode.nil?
    invalid_properties.push('invalid value for "auth_mode", auth_mode cannot be nil.')
  end

  if !@maximum_connections.nil? && @maximum_connections > 2147483647
    invalid_properties.push('invalid value for "maximum_connections", must be smaller than or equal to 2147483647.')
  end

  if !@maximum_connections.nil? && @maximum_connections < -2147483648
    invalid_properties.push('invalid value for "maximum_connections", must be greater than or equal to -2147483648.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/authentik/api/models/endpoint.rb', line 393

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/authentik/api/models/endpoint.rb', line 236

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @provider.nil?
  return false if @provider_obj.nil?
  return false if @protocol.nil?
  return false if @host.nil?
  return false if @auth_mode.nil?
  return false if !@maximum_connections.nil? && @maximum_connections > 2147483647
  return false if !@maximum_connections.nil? && @maximum_connections < -2147483648
  true
end