Class: Authentik::Api::EndpointDeviceDetails

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/endpoint_device_details.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EndpointDeviceDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::EndpointDeviceDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::EndpointDeviceDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'device_uuid')
    self.device_uuid = attributes[:'device_uuid']
  end

  if attributes.key?(:'pbm_uuid')
    self.pbm_uuid = attributes[:'pbm_uuid']
  else
    self.pbm_uuid = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'access_group')
    self.access_group = attributes[:'access_group']
  end

  if attributes.key?(:'access_group_obj')
    self.access_group_obj = attributes[:'access_group_obj']
  end

  if attributes.key?(:'expiring')
    self.expiring = attributes[:'expiring']
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  end

  if attributes.key?(:'facts')
    self.facts = attributes[:'facts']
  else
    self.facts = nil
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end

  if attributes.key?(:'connections_obj')
    if (value = attributes[:'connections_obj']).is_a?(Array)
      self.connections_obj = value
    end
  else
    self.connections_obj = nil
  end

  if attributes.key?(:'policies')
    if (value = attributes[:'policies']).is_a?(Array)
      self.policies = value
    end
  else
    self.policies = nil
  end

  if attributes.key?(:'connections')
    if (value = attributes[:'connections']).is_a?(Array)
      self.connections = value
    end
  else
    self.connections = nil
  end
end

Instance Attribute Details

#access_groupObject

Returns the value of attribute access_group.



18
19
20
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 18

def access_group
  @access_group
end

#access_group_objObject

Returns the value of attribute access_group_obj.



20
21
22
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 20

def access_group_obj
  @access_group_obj
end

#attributesObject

Returns the value of attribute attributes.



28
29
30
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 28

def attributes
  @attributes
end

#connectionsObject

Returns the value of attribute connections.



34
35
36
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 34

def connections
  @connections
end

#connections_objObject

Returns the value of attribute connections_obj.



30
31
32
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 30

def connections_obj
  @connections_obj
end

#device_uuidObject

Returns the value of attribute device_uuid.



12
13
14
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 12

def device_uuid
  @device_uuid
end

#expiresObject

Returns the value of attribute expires.



24
25
26
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 24

def expires
  @expires
end

#expiringObject

Returns the value of attribute expiring.



22
23
24
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 22

def expiring
  @expiring
end

#factsObject

Returns the value of attribute facts.



26
27
28
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 26

def facts
  @facts
end

#nameObject

Returns the value of attribute name.



16
17
18
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 16

def name
  @name
end

#pbm_uuidObject

Returns the value of attribute pbm_uuid.



14
15
16
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 14

def pbm_uuid
  @pbm_uuid
end

#policiesObject

Returns the value of attribute policies.



32
33
34
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 32

def policies
  @policies
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 37

def self.attribute_map
  {
    :'device_uuid' => :'device_uuid',
    :'pbm_uuid' => :'pbm_uuid',
    :'name' => :'name',
    :'access_group' => :'access_group',
    :'access_group_obj' => :'access_group_obj',
    :'expiring' => :'expiring',
    :'expires' => :'expires',
    :'facts' => :'facts',
    :'attributes' => :'attributes',
    :'connections_obj' => :'connections_obj',
    :'policies' => :'policies',
    :'connections' => :'connections'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 300

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
87
88
89
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 83

def self.openapi_nullable
  Set.new([
    :'access_group',
    :'expires',
    :'facts',
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 65

def self.openapi_types
  {
    :'device_uuid' => :'String',
    :'pbm_uuid' => :'String',
    :'name' => :'String',
    :'access_group' => :'String',
    :'access_group_obj' => :'DeviceAccessGroup',
    :'expiring' => :'Boolean',
    :'expires' => :'Time',
    :'facts' => :'DeviceFactSnapshot',
    :'attributes' => :'Hash<String, Object>',
    :'connections_obj' => :'Array<DeviceConnection>',
    :'policies' => :'Array<String>',
    :'connections' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 268

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      device_uuid == o.device_uuid &&
      pbm_uuid == o.pbm_uuid &&
      name == o.name &&
      access_group == o.access_group &&
      access_group_obj == o.access_group_obj &&
      expiring == o.expiring &&
      expires == o.expires &&
      facts == o.facts &&
      attributes == o.attributes &&
      connections_obj == o.connections_obj &&
      policies == o.policies &&
      connections == o.connections
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


287
288
289
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 287

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



293
294
295
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 293

def hash
  [device_uuid, pbm_uuid, name, access_group, access_group_obj, expiring, expires, facts, attributes, connections_obj, policies, connections].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 178

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pbm_uuid.nil?
    invalid_properties.push('invalid value for "pbm_uuid", pbm_uuid cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @connections_obj.nil?
    invalid_properties.push('invalid value for "connections_obj", connections_obj cannot be nil.')
  end

  if @policies.nil?
    invalid_properties.push('invalid value for "policies", policies cannot be nil.')
  end

  if @connections.nil?
    invalid_properties.push('invalid value for "connections", connections cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 322

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
# File 'lib/authentik/api/models/endpoint_device_details.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pbm_uuid.nil?
  return false if @name.nil?
  return false if @connections_obj.nil?
  return false if @policies.nil?
  return false if @connections.nil?
  true
end