Class: Authentik::Api::EndpointDeviceRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/endpoint_device_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EndpointDeviceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::EndpointDeviceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::EndpointDeviceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'device_uuid')
    self.device_uuid = attributes[:'device_uuid']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'access_group')
    self.access_group = attributes[:'access_group']
  end

  if attributes.key?(:'access_group_obj')
    self.access_group_obj = attributes[:'access_group_obj']
  end

  if attributes.key?(:'expiring')
    self.expiring = attributes[:'expiring']
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end
end

Instance Attribute Details

#access_groupObject

Returns the value of attribute access_group.



16
17
18
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 16

def access_group
  @access_group
end

#access_group_objObject

Returns the value of attribute access_group_obj.



18
19
20
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 18

def access_group_obj
  @access_group_obj
end

#attributesObject

Returns the value of attribute attributes.



24
25
26
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 24

def attributes
  @attributes
end

#device_uuidObject

Returns the value of attribute device_uuid.



12
13
14
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 12

def device_uuid
  @device_uuid
end

#expiresObject

Returns the value of attribute expires.



22
23
24
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 22

def expires
  @expires
end

#expiringObject

Returns the value of attribute expiring.



20
21
22
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 20

def expiring
  @expiring
end

#nameObject

Returns the value of attribute name.



14
15
16
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 14

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
37
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 27

def self.attribute_map
  {
    :'device_uuid' => :'device_uuid',
    :'name' => :'name',
    :'access_group' => :'access_group',
    :'access_group_obj' => :'access_group_obj',
    :'expiring' => :'expiring',
    :'expires' => :'expires',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 187

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
67
68
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 63

def self.openapi_nullable
  Set.new([
    :'access_group',
    :'expires',
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 50

def self.openapi_types
  {
    :'device_uuid' => :'String',
    :'name' => :'String',
    :'access_group' => :'String',
    :'access_group_obj' => :'DeviceAccessGroupRequest',
    :'expiring' => :'Boolean',
    :'expires' => :'Time',
    :'attributes' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



160
161
162
163
164
165
166
167
168
169
170
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      device_uuid == o.device_uuid &&
      name == o.name &&
      access_group == o.access_group &&
      access_group_obj == o.access_group_obj &&
      expiring == o.expiring &&
      expires == o.expires &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 180

def hash
  [device_uuid, name, access_group, access_group_obj, expiring, expires, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
# File 'lib/authentik/api/models/endpoint_device_request.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  true
end