Class: Authentik::Api::EnrollmentToken

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/enrollment_token.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EnrollmentToken

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/authentik/api/models/enrollment_token.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::EnrollmentToken` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::EnrollmentToken`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'token_uuid')
    self.token_uuid = attributes[:'token_uuid']
  else
    self.token_uuid = nil
  end

  if attributes.key?(:'device_group')
    self.device_group = attributes[:'device_group']
  end

  if attributes.key?(:'device_group_obj')
    self.device_group_obj = attributes[:'device_group_obj']
  else
    self.device_group_obj = nil
  end

  if attributes.key?(:'connector')
    self.connector = attributes[:'connector']
  else
    self.connector = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'expiring')
    self.expiring = attributes[:'expiring']
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  end
end

Instance Attribute Details

#connectorObject

Returns the value of attribute connector.



18
19
20
# File 'lib/authentik/api/models/enrollment_token.rb', line 18

def connector
  @connector
end

#device_groupObject

Returns the value of attribute device_group.



14
15
16
# File 'lib/authentik/api/models/enrollment_token.rb', line 14

def device_group
  @device_group
end

#device_group_objObject

Returns the value of attribute device_group_obj.



16
17
18
# File 'lib/authentik/api/models/enrollment_token.rb', line 16

def device_group_obj
  @device_group_obj
end

#expiresObject

Returns the value of attribute expires.



24
25
26
# File 'lib/authentik/api/models/enrollment_token.rb', line 24

def expires
  @expires
end

#expiringObject

Returns the value of attribute expiring.



22
23
24
# File 'lib/authentik/api/models/enrollment_token.rb', line 22

def expiring
  @expiring
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/authentik/api/models/enrollment_token.rb', line 20

def name
  @name
end

#token_uuidObject

Returns the value of attribute token_uuid.



12
13
14
# File 'lib/authentik/api/models/enrollment_token.rb', line 12

def token_uuid
  @token_uuid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/authentik/api/models/enrollment_token.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/authentik/api/models/enrollment_token.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
37
# File 'lib/authentik/api/models/enrollment_token.rb', line 27

def self.attribute_map
  {
    :'token_uuid' => :'token_uuid',
    :'device_group' => :'device_group',
    :'device_group_obj' => :'device_group_obj',
    :'connector' => :'connector',
    :'name' => :'name',
    :'expiring' => :'expiring',
    :'expires' => :'expires'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/authentik/api/models/enrollment_token.rb', line 213

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
67
68
69
# File 'lib/authentik/api/models/enrollment_token.rb', line 63

def self.openapi_nullable
  Set.new([
    :'device_group',
    :'device_group_obj',
    :'expires'
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/authentik/api/models/enrollment_token.rb', line 50

def self.openapi_types
  {
    :'token_uuid' => :'String',
    :'device_group' => :'String',
    :'device_group_obj' => :'DeviceAccessGroup',
    :'connector' => :'String',
    :'name' => :'String',
    :'expiring' => :'Boolean',
    :'expires' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
194
195
196
# File 'lib/authentik/api/models/enrollment_token.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      token_uuid == o.token_uuid &&
      device_group == o.device_group &&
      device_group_obj == o.device_group_obj &&
      connector == o.connector &&
      name == o.name &&
      expiring == o.expiring &&
      expires == o.expires
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/authentik/api/models/enrollment_token.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



206
207
208
# File 'lib/authentik/api/models/enrollment_token.rb', line 206

def hash
  [token_uuid, device_group, device_group_obj, connector, name, expiring, expires].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/authentik/api/models/enrollment_token.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @token_uuid.nil?
    invalid_properties.push('invalid value for "token_uuid", token_uuid cannot be nil.')
  end

  if @connector.nil?
    invalid_properties.push('invalid value for "connector", connector cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/authentik/api/models/enrollment_token.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
152
# File 'lib/authentik/api/models/enrollment_token.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @token_uuid.nil?
  return false if @connector.nil?
  return false if @name.nil?
  true
end