Class: Authentik::Api::EnterpriseApi

Inherits:
Object
  • Object
show all
Defined in:
lib/authentik/api/api/enterprise_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ EnterpriseApi

Returns a new instance of EnterpriseApi.



13
14
15
# File 'lib/authentik/api/api/enterprise_api.rb', line 13

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



11
12
13
# File 'lib/authentik/api/api/enterprise_api.rb', line 11

def api_client
  @api_client
end

Instance Method Details

#enterprise_license_create(license_request, opts = {}) ⇒ License

License Viewset

Parameters:

  • license_request (LicenseRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



20
21
22
23
# File 'lib/authentik/api/api/enterprise_api.rb', line 20

def enterprise_license_create(license_request, opts = {})
  data, _status_code, _headers = enterprise_license_create_with_http_info(license_request, opts)
  data
end

#enterprise_license_create_with_http_info(license_request, opts = {}) ⇒ Array<(License, Integer, Hash)>

License Viewset

Parameters:

  • license_request (LicenseRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(License, Integer, Hash)>)

    License data, response status code and response headers



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/authentik/api/api/enterprise_api.rb', line 29

def enterprise_license_create_with_http_info(license_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_create ...'
  end
  # verify the required parameter 'license_request' is set
  if @api_client.config.client_side_validation && license_request.nil?
    fail ArgumentError, "Missing the required parameter 'license_request' when calling EnterpriseApi.enterprise_license_create"
  end
  # resource path
  local_var_path = '/enterprise/license/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(license_request)

  # return_type
  return_type = opts[:debug_return_type] || 'License'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_destroy(license_uuid, opts = {}) ⇒ nil

License Viewset

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


86
87
88
89
# File 'lib/authentik/api/api/enterprise_api.rb', line 86

def enterprise_license_destroy(license_uuid, opts = {})
  enterprise_license_destroy_with_http_info(license_uuid, opts)
  nil
end

#enterprise_license_destroy_with_http_info(license_uuid, opts = {}) ⇒ Array<(nil, Integer, Hash)>

License Viewset

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/authentik/api/api/enterprise_api.rb', line 95

def enterprise_license_destroy_with_http_info(license_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_destroy ...'
  end
  # verify the required parameter 'license_uuid' is set
  if @api_client.config.client_side_validation && license_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'license_uuid' when calling EnterpriseApi.enterprise_license_destroy"
  end
  # resource path
  local_var_path = '/enterprise/license/{license_uuid}/'.sub('{license_uuid}', CGI.escape(license_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_destroy",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_forecast_retrieve(opts = {}) ⇒ LicenseForecast

Forecast how many users will be required in a year

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



146
147
148
149
# File 'lib/authentik/api/api/enterprise_api.rb', line 146

def enterprise_license_forecast_retrieve(opts = {})
  data, _status_code, _headers = enterprise_license_forecast_retrieve_with_http_info(opts)
  data
end

#enterprise_license_forecast_retrieve_with_http_info(opts = {}) ⇒ Array<(LicenseForecast, Integer, Hash)>

Forecast how many users will be required in a year

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(LicenseForecast, Integer, Hash)>)

    LicenseForecast data, response status code and response headers



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/authentik/api/api/enterprise_api.rb', line 154

def enterprise_license_forecast_retrieve_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_forecast_retrieve ...'
  end
  # resource path
  local_var_path = '/enterprise/license/forecast/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'LicenseForecast'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_forecast_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_forecast_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_install_id_retrieve(opts = {}) ⇒ InstallID

Get install_id

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



201
202
203
204
# File 'lib/authentik/api/api/enterprise_api.rb', line 201

def enterprise_license_install_id_retrieve(opts = {})
  data, _status_code, _headers = enterprise_license_install_id_retrieve_with_http_info(opts)
  data
end

#enterprise_license_install_id_retrieve_with_http_info(opts = {}) ⇒ Array<(InstallID, Integer, Hash)>

Get install_id

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(InstallID, Integer, Hash)>)

    InstallID data, response status code and response headers



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/authentik/api/api/enterprise_api.rb', line 209

def enterprise_license_install_id_retrieve_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_install_id_retrieve ...'
  end
  # resource path
  local_var_path = '/enterprise/license/install_id/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InstallID'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_install_id_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_install_id_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_list(opts = {}) ⇒ PaginatedLicenseList

License Viewset

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :name (String)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :search (String)

    A search term.

Returns:



261
262
263
264
# File 'lib/authentik/api/api/enterprise_api.rb', line 261

def enterprise_license_list(opts = {})
  data, _status_code, _headers = enterprise_license_list_with_http_info(opts)
  data
end

#enterprise_license_list_with_http_info(opts = {}) ⇒ Array<(PaginatedLicenseList, Integer, Hash)>

License Viewset

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :name (String)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :search (String)

    A search term.

Returns:

  • (Array<(PaginatedLicenseList, Integer, Hash)>)

    PaginatedLicenseList data, response status code and response headers



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/authentik/api/api/enterprise_api.rb', line 274

def enterprise_license_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_list ...'
  end
  # resource path
  local_var_path = '/enterprise/license/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
  query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedLicenseList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_partial_update(license_uuid, opts = {}) ⇒ License

License Viewset

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



328
329
330
331
# File 'lib/authentik/api/api/enterprise_api.rb', line 328

def enterprise_license_partial_update(license_uuid, opts = {})
  data, _status_code, _headers = enterprise_license_partial_update_with_http_info(license_uuid, opts)
  data
end

#enterprise_license_partial_update_with_http_info(license_uuid, opts = {}) ⇒ Array<(License, Integer, Hash)>

License Viewset

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(License, Integer, Hash)>)

    License data, response status code and response headers



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/authentik/api/api/enterprise_api.rb', line 338

def enterprise_license_partial_update_with_http_info(license_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_partial_update ...'
  end
  # verify the required parameter 'license_uuid' is set
  if @api_client.config.client_side_validation && license_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'license_uuid' when calling EnterpriseApi.enterprise_license_partial_update"
  end
  # resource path
  local_var_path = '/enterprise/license/{license_uuid}/'.sub('{license_uuid}', CGI.escape(license_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_license_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'License'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_partial_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_retrieve(license_uuid, opts = {}) ⇒ License

License Viewset

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



395
396
397
398
# File 'lib/authentik/api/api/enterprise_api.rb', line 395

def enterprise_license_retrieve(license_uuid, opts = {})
  data, _status_code, _headers = enterprise_license_retrieve_with_http_info(license_uuid, opts)
  data
end

#enterprise_license_retrieve_with_http_info(license_uuid, opts = {}) ⇒ Array<(License, Integer, Hash)>

License Viewset

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(License, Integer, Hash)>)

    License data, response status code and response headers



404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/authentik/api/api/enterprise_api.rb', line 404

def enterprise_license_retrieve_with_http_info(license_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_retrieve ...'
  end
  # verify the required parameter 'license_uuid' is set
  if @api_client.config.client_side_validation && license_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'license_uuid' when calling EnterpriseApi.enterprise_license_retrieve"
  end
  # resource path
  local_var_path = '/enterprise/license/{license_uuid}/'.sub('{license_uuid}', CGI.escape(license_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'License'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_summary_retrieve(opts = {}) ⇒ LicenseSummary

Get the total license status

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :cached (Boolean) — default: default to true

Returns:



456
457
458
459
# File 'lib/authentik/api/api/enterprise_api.rb', line 456

def enterprise_license_summary_retrieve(opts = {})
  data, _status_code, _headers = enterprise_license_summary_retrieve_with_http_info(opts)
  data
end

#enterprise_license_summary_retrieve_with_http_info(opts = {}) ⇒ Array<(LicenseSummary, Integer, Hash)>

Get the total license status

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :cached (Boolean) — default: default to true

Returns:

  • (Array<(LicenseSummary, Integer, Hash)>)

    LicenseSummary data, response status code and response headers



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/authentik/api/api/enterprise_api.rb', line 465

def enterprise_license_summary_retrieve_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_summary_retrieve ...'
  end
  # resource path
  local_var_path = '/enterprise/license/summary/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'cached'] = opts[:'cached'] if !opts[:'cached'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'LicenseSummary'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_summary_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_summary_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_update(license_uuid, license_request, opts = {}) ⇒ License

License Viewset

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • license_request (LicenseRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



515
516
517
518
# File 'lib/authentik/api/api/enterprise_api.rb', line 515

def enterprise_license_update(license_uuid, license_request, opts = {})
  data, _status_code, _headers = enterprise_license_update_with_http_info(license_uuid, license_request, opts)
  data
end

#enterprise_license_update_with_http_info(license_uuid, license_request, opts = {}) ⇒ Array<(License, Integer, Hash)>

License Viewset

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • license_request (LicenseRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(License, Integer, Hash)>)

    License data, response status code and response headers



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
# File 'lib/authentik/api/api/enterprise_api.rb', line 525

def enterprise_license_update_with_http_info(license_uuid, license_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_update ...'
  end
  # verify the required parameter 'license_uuid' is set
  if @api_client.config.client_side_validation && license_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'license_uuid' when calling EnterpriseApi.enterprise_license_update"
  end
  # verify the required parameter 'license_request' is set
  if @api_client.config.client_side_validation && license_request.nil?
    fail ArgumentError, "Missing the required parameter 'license_request' when calling EnterpriseApi.enterprise_license_update"
  end
  # resource path
  local_var_path = '/enterprise/license/{license_uuid}/'.sub('{license_uuid}', CGI.escape(license_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(license_request)

  # return_type
  return_type = opts[:debug_return_type] || 'License'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#enterprise_license_used_by_list(license_uuid, opts = {}) ⇒ Array<UsedBy>

Get a list of all objects that use this object

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



586
587
588
589
# File 'lib/authentik/api/api/enterprise_api.rb', line 586

def enterprise_license_used_by_list(license_uuid, opts = {})
  data, _status_code, _headers = enterprise_license_used_by_list_with_http_info(license_uuid, opts)
  data
end

#enterprise_license_used_by_list_with_http_info(license_uuid, opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>

Get a list of all objects that use this object

Parameters:

  • license_uuid (String)

    A UUID string identifying this License.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<UsedBy>, Integer, Hash)>)

    Array<UsedBy> data, response status code and response headers



595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/authentik/api/api/enterprise_api.rb', line 595

def enterprise_license_used_by_list_with_http_info(license_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnterpriseApi.enterprise_license_used_by_list ...'
  end
  # verify the required parameter 'license_uuid' is set
  if @api_client.config.client_side_validation && license_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'license_uuid' when calling EnterpriseApi.enterprise_license_used_by_list"
  end
  # resource path
  local_var_path = '/enterprise/license/{license_uuid}/used_by/'.sub('{license_uuid}', CGI.escape(license_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<UsedBy>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"EnterpriseApi.enterprise_license_used_by_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnterpriseApi#enterprise_license_used_by_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end