Class: Authentik::Api::EventRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/event_request.rb

Overview

Event Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EventRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/authentik/api/models/event_request.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::EventRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::EventRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'user')
    if (value = attributes[:'user']).is_a?(Hash)
      self.user = value
    end
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  else
    self.action = nil
  end

  if attributes.key?(:'app')
    self.app = attributes[:'app']
  else
    self.app = nil
  end

  if attributes.key?(:'context')
    if (value = attributes[:'context']).is_a?(Hash)
      self.context = value
    end
  end

  if attributes.key?(:'client_ip')
    self.client_ip = attributes[:'client_ip']
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  end

  if attributes.key?(:'brand')
    if (value = attributes[:'brand']).is_a?(Hash)
      self.brand = value
    end
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



15
16
17
# File 'lib/authentik/api/models/event_request.rb', line 15

def action
  @action
end

#appObject

Returns the value of attribute app.



17
18
19
# File 'lib/authentik/api/models/event_request.rb', line 17

def app
  @app
end

#brandObject

Returns the value of attribute brand.



25
26
27
# File 'lib/authentik/api/models/event_request.rb', line 25

def brand
  @brand
end

#client_ipObject

Returns the value of attribute client_ip.



21
22
23
# File 'lib/authentik/api/models/event_request.rb', line 21

def client_ip
  @client_ip
end

#contextObject

Returns the value of attribute context.



19
20
21
# File 'lib/authentik/api/models/event_request.rb', line 19

def context
  @context
end

#expiresObject

Returns the value of attribute expires.



23
24
25
# File 'lib/authentik/api/models/event_request.rb', line 23

def expires
  @expires
end

#userObject

Returns the value of attribute user.



13
14
15
# File 'lib/authentik/api/models/event_request.rb', line 13

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/authentik/api/models/event_request.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/authentik/api/models/event_request.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/authentik/api/models/event_request.rb', line 50

def self.attribute_map
  {
    :'user' => :'user',
    :'action' => :'action',
    :'app' => :'app',
    :'context' => :'context',
    :'client_ip' => :'client_ip',
    :'expires' => :'expires',
    :'brand' => :'brand'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/authentik/api/models/event_request.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
90
# File 'lib/authentik/api/models/event_request.rb', line 86

def self.openapi_nullable
  Set.new([
    :'client_ip',
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
# File 'lib/authentik/api/models/event_request.rb', line 73

def self.openapi_types
  {
    :'user' => :'Hash<String, Object>',
    :'action' => :'EventActions',
    :'app' => :'String',
    :'context' => :'Hash<String, Object>',
    :'client_ip' => :'String',
    :'expires' => :'Time',
    :'brand' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
227
228
# File 'lib/authentik/api/models/event_request.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      user == o.user &&
      action == o.action &&
      app == o.app &&
      context == o.context &&
      client_ip == o.client_ip &&
      expires == o.expires &&
      brand == o.brand
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/authentik/api/models/event_request.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/authentik/api/models/event_request.rb', line 238

def hash
  [user, action, app, context, client_ip, expires, brand].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/authentik/api/models/event_request.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @action.nil?
    invalid_properties.push('invalid value for "action", action cannot be nil.')
  end

  if @app.nil?
    invalid_properties.push('invalid value for "app", app cannot be nil.')
  end

  if @app.to_s.length < 1
    invalid_properties.push('invalid value for "app", the character length must be greater than or equal to 1.')
  end

  if !@client_ip.nil? && @client_ip.to_s.length < 1
    invalid_properties.push('invalid value for "client_ip", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/authentik/api/models/event_request.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
180
# File 'lib/authentik/api/models/event_request.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @action.nil?
  return false if @app.nil?
  return false if @app.to_s.length < 1
  return false if !@client_ip.nil? && @client_ip.to_s.length < 1
  true
end