Class: Authentik::Api::ExpiringBaseGrantModel
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ExpiringBaseGrantModel
- Defined in:
- lib/authentik/api/models/expiring_base_grant_model.rb
Overview
Serializer for BaseGrantModel and ExpiringBaseGrant
Instance Attribute Summary collapse
-
#expires ⇒ Object
Returns the value of attribute expires.
-
#is_expired ⇒ Object
Check if token is expired yet.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#scope ⇒ Object
Returns the value of attribute scope.
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExpiringBaseGrantModel
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExpiringBaseGrantModel
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ExpiringBaseGrantModel` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ExpiringBaseGrantModel`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'user') self.user = attributes[:'user'] else self.user = nil end if attributes.key?(:'is_expired') self.is_expired = attributes[:'is_expired'] else self.is_expired = nil end if attributes.key?(:'expires') self.expires = attributes[:'expires'] end if attributes.key?(:'scope') if (value = attributes[:'scope']).is_a?(Array) self.scope = value end else self.scope = nil end end |
Instance Attribute Details
#expires ⇒ Object
Returns the value of attribute expires.
22 23 24 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 22 def expires @expires end |
#is_expired ⇒ Object
Check if token is expired yet.
20 21 22 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 20 def is_expired @is_expired end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 13 def pk @pk end |
#provider ⇒ Object
Returns the value of attribute provider.
15 16 17 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 15 def provider @provider end |
#scope ⇒ Object
Returns the value of attribute scope.
24 25 26 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 24 def scope @scope end |
#user ⇒ Object
Returns the value of attribute user.
17 18 19 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 17 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 27 def self.attribute_map { :'pk' => :'pk', :'provider' => :'provider', :'user' => :'user', :'is_expired' => :'is_expired', :'expires' => :'expires', :'scope' => :'scope' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 238 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 65 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 61 def self.openapi_nullable Set.new([ :'expires', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 58 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 49 def self.openapi_types { :'pk' => :'Integer', :'provider' => :'Provider', :'user' => :'User', :'is_expired' => :'Boolean', :'expires' => :'Time', :'scope' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && provider == o.provider && user == o.user && is_expired == o.is_expired && expires == o.expires && scope == o.scope end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 231 def hash [pk, provider, user, is_expired, expires, scope].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 122 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if @user.nil? invalid_properties.push('invalid value for "user", user cannot be nil.') end if @is_expired.nil? invalid_properties.push('invalid value for "is_expired", is_expired cannot be nil.') end if @scope.nil? invalid_properties.push('invalid value for "scope", scope cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 155 156 157 158 |
# File 'lib/authentik/api/models/expiring_base_grant_model.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @provider.nil? return false if @user.nil? return false if @is_expired.nil? return false if @scope.nil? true end |