Class: Authentik::Api::ExtraRoleObjectPermission

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/extra_role_object_permission.rb

Overview

Role permission with additional object-related data

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExtraRoleObjectPermission

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ExtraRoleObjectPermission` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ExtraRoleObjectPermission`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'codename')
    self.codename = attributes[:'codename']
  else
    self.codename = nil
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  else
    self.model = nil
  end

  if attributes.key?(:'app_label')
    self.app_label = attributes[:'app_label']
  else
    self.app_label = nil
  end

  if attributes.key?(:'object_pk')
    self.object_pk = attributes[:'object_pk']
  else
    self.object_pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'app_label_verbose')
    self.app_label_verbose = attributes[:'app_label_verbose']
  else
    self.app_label_verbose = nil
  end

  if attributes.key?(:'model_verbose')
    self.model_verbose = attributes[:'model_verbose']
  else
    self.model_verbose = nil
  end

  if attributes.key?(:'object_description')
    self.object_description = attributes[:'object_description']
  else
    self.object_description = nil
  end
end

Instance Attribute Details

#app_labelObject

Returns the value of attribute app_label.



19
20
21
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 19

def app_label
  @app_label
end

#app_label_verboseObject

Get app label from permission’s model



26
27
28
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 26

def app_label_verbose
  @app_label_verbose
end

#codenameObject

Returns the value of attribute codename.



15
16
17
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 15

def codename
  @codename
end

#idObject

Returns the value of attribute id.



13
14
15
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 13

def id
  @id
end

#modelObject

Returns the value of attribute model.



17
18
19
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 17

def model
  @model
end

#model_verboseObject

Get model label from permission’s model



29
30
31
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 29

def model_verbose
  @model_verbose
end

#nameObject

Returns the value of attribute name.



23
24
25
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 23

def name
  @name
end

#object_descriptionObject

Get model description from attached model. This operation takes at least one additional query, and the description is only shown if the role has the view_ permission on the object



32
33
34
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 32

def object_description
  @object_description
end

#object_pkObject

Returns the value of attribute object_pk.



21
22
23
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 21

def object_pk
  @object_pk
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 35

def self.attribute_map
  {
    :'id' => :'id',
    :'codename' => :'codename',
    :'model' => :'model',
    :'app_label' => :'app_label',
    :'object_pk' => :'object_pk',
    :'name' => :'name',
    :'app_label_verbose' => :'app_label_verbose',
    :'model_verbose' => :'model_verbose',
    :'object_description' => :'object_description'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 318

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
79
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 75

def self.openapi_nullable
  Set.new([
    :'object_description'
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 60

def self.openapi_types
  {
    :'id' => :'Integer',
    :'codename' => :'String',
    :'model' => :'String',
    :'app_label' => :'String',
    :'object_pk' => :'String',
    :'name' => :'String',
    :'app_label_verbose' => :'String',
    :'model_verbose' => :'String',
    :'object_description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      codename == o.codename &&
      model == o.model &&
      app_label == o.app_label &&
      object_pk == o.object_pk &&
      name == o.name &&
      app_label_verbose == o.app_label_verbose &&
      model_verbose == o.model_verbose &&
      object_description == o.object_description
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


305
306
307
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 305

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



311
312
313
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 311

def hash
  [id, codename, model, app_label, object_pk, name, app_label_verbose, model_verbose, object_description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @codename.nil?
    invalid_properties.push('invalid value for "codename", codename cannot be nil.')
  end

  if @model.nil?
    invalid_properties.push('invalid value for "model", model cannot be nil.')
  end

  if @app_label.nil?
    invalid_properties.push('invalid value for "app_label", app_label cannot be nil.')
  end

  if @object_pk.nil?
    invalid_properties.push('invalid value for "object_pk", object_pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @app_label_verbose.nil?
    invalid_properties.push('invalid value for "app_label_verbose", app_label_verbose cannot be nil.')
  end

  if @model_verbose.nil?
    invalid_properties.push('invalid value for "model_verbose", model_verbose cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 340

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/authentik/api/models/extra_role_object_permission.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @codename.nil?
  return false if @model.nil?
  return false if @app_label.nil?
  return false if @object_pk.nil?
  return false if @name.nil?
  return false if @app_label_verbose.nil?
  return false if @model_verbose.nil?
  true
end