Class: Authentik::Api::FleetConnector

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/fleet_connector.rb

Overview

FleetConnector Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FleetConnector

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/authentik/api/models/fleet_connector.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::FleetConnector` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::FleetConnector`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'connector_uuid')
    self.connector_uuid = attributes[:'connector_uuid']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'headers_mapping')
    self.headers_mapping = attributes[:'headers_mapping']
  end

  if attributes.key?(:'map_users')
    self.map_users = attributes[:'map_users']
  end

  if attributes.key?(:'map_teams_access_group')
    self.map_teams_access_group = attributes[:'map_teams_access_group']
  end
end

Instance Attribute Details

#componentObject

Get object component so that we know how to edit the object



20
21
22
# File 'lib/authentik/api/models/fleet_connector.rb', line 20

def component
  @component
end

#connector_uuidObject

Returns the value of attribute connector_uuid.



13
14
15
# File 'lib/authentik/api/models/fleet_connector.rb', line 13

def connector_uuid
  @connector_uuid
end

#enabledObject

Returns the value of attribute enabled.



17
18
19
# File 'lib/authentik/api/models/fleet_connector.rb', line 17

def enabled
  @enabled
end

#headers_mappingObject

Configure additional headers to be sent. Mapping should return a dictionary of key-value pairs



34
35
36
# File 'lib/authentik/api/models/fleet_connector.rb', line 34

def headers_mapping
  @headers_mapping
end

#map_teams_access_groupObject

Returns the value of attribute map_teams_access_group.



38
39
40
# File 'lib/authentik/api/models/fleet_connector.rb', line 38

def map_teams_access_group
  @map_teams_access_group
end

#map_usersObject

Returns the value of attribute map_users.



36
37
38
# File 'lib/authentik/api/models/fleet_connector.rb', line 36

def map_users
  @map_users
end

#meta_model_nameObject

Return internal model name



29
30
31
# File 'lib/authentik/api/models/fleet_connector.rb', line 29

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/fleet_connector.rb', line 15

def name
  @name
end

#urlObject

Returns the value of attribute url.



31
32
33
# File 'lib/authentik/api/models/fleet_connector.rb', line 31

def url
  @url
end

#verbose_nameObject

Return object’s verbose_name



23
24
25
# File 'lib/authentik/api/models/fleet_connector.rb', line 23

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



26
27
28
# File 'lib/authentik/api/models/fleet_connector.rb', line 26

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/authentik/api/models/fleet_connector.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/authentik/api/models/fleet_connector.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/authentik/api/models/fleet_connector.rb', line 41

def self.attribute_map
  {
    :'connector_uuid' => :'connector_uuid',
    :'name' => :'name',
    :'enabled' => :'enabled',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'url' => :'url',
    :'headers_mapping' => :'headers_mapping',
    :'map_users' => :'map_users',
    :'map_teams_access_group' => :'map_teams_access_group'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/authentik/api/models/fleet_connector.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
89
# File 'lib/authentik/api/models/fleet_connector.rb', line 85

def self.openapi_nullable
  Set.new([
    :'headers_mapping',
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/authentik/api/models/fleet_connector.rb', line 68

def self.openapi_types
  {
    :'connector_uuid' => :'String',
    :'name' => :'String',
    :'enabled' => :'Boolean',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'url' => :'String',
    :'headers_mapping' => :'String',
    :'map_users' => :'Boolean',
    :'map_teams_access_group' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/authentik/api/models/fleet_connector.rb', line 280

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      connector_uuid == o.connector_uuid &&
      name == o.name &&
      enabled == o.enabled &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      url == o.url &&
      headers_mapping == o.headers_mapping &&
      map_users == o.map_users &&
      map_teams_access_group == o.map_teams_access_group
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/authentik/api/models/fleet_connector.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/authentik/api/models/fleet_connector.rb', line 304

def hash
  [connector_uuid, name, enabled, component, verbose_name, verbose_name_plural, meta_model_name, url, headers_mapping, map_users, map_teams_access_group].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/authentik/api/models/fleet_connector.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length > 200
    invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 200.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/authentik/api/models/fleet_connector.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



202
203
204
205
206
207
208
209
210
211
212
# File 'lib/authentik/api/models/fleet_connector.rb', line 202

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @url.nil?
  return false if @url.to_s.length > 200
  true
end