Class: Authentik::Api::FlowImportResult
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::FlowImportResult
- Defined in:
- lib/authentik/api/models/flow_import_result.rb
Overview
Logs of an attempted flow import
Instance Attribute Summary collapse
-
#logs ⇒ Object
Returns the value of attribute logs.
-
#success ⇒ Object
Returns the value of attribute success.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FlowImportResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FlowImportResult
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 51 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::FlowImportResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::FlowImportResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'logs') if (value = attributes[:'logs']).is_a?(Array) self.logs = value end else self.logs = nil end if attributes.key?(:'success') self.success = attributes[:'success'] else self.success = nil end end |
Instance Attribute Details
#logs ⇒ Object
Returns the value of attribute logs.
13 14 15 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 13 def logs @logs end |
#success ⇒ Object
Returns the value of attribute success.
15 16 17 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 15 def success @success end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
26 27 28 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 26 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
31 32 33 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 31 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 18 def self.attribute_map { :'logs' => :'logs', :'success' => :'success' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 149 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
44 45 46 47 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 44 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 36 def self.openapi_types { :'logs' => :'Array<LogEvent>', :'success' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 127 def ==(o) return true if self.equal?(o) self.class == o.class && logs == o.logs && success == o.success end |
#eql?(o) ⇒ Boolean
136 137 138 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 136 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 142 def hash [logs, success].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 82 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @logs.nil? invalid_properties.push('invalid value for "logs", logs cannot be nil.') end if @success.nil? invalid_properties.push('invalid value for "success", success cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
98 99 100 101 102 103 |
# File 'lib/authentik/api/models/flow_import_result.rb', line 98 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @logs.nil? return false if @success.nil? true end |