Class: Authentik::Api::FlowInspectorPlan

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/flow_inspector_plan.rb

Overview

Serializer for an active FlowPlan

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlowInspectorPlan

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 61

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::FlowInspectorPlan` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::FlowInspectorPlan`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'current_stage')
    self.current_stage = attributes[:'current_stage']
  else
    self.current_stage = nil
  end

  if attributes.key?(:'next_planned_stage')
    self.next_planned_stage = attributes[:'next_planned_stage']
  else
    self.next_planned_stage = nil
  end

  if attributes.key?(:'plan_context')
    if (value = attributes[:'plan_context']).is_a?(Hash)
      self.plan_context = value
    end
  else
    self.plan_context = nil
  end

  if attributes.key?(:'session_id')
    self.session_id = attributes[:'session_id']
  else
    self.session_id = nil
  end
end

Instance Attribute Details

#current_stageObject

Returns the value of attribute current_stage.



13
14
15
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 13

def current_stage
  @current_stage
end

#next_planned_stageObject

Returns the value of attribute next_planned_stage.



15
16
17
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 15

def next_planned_stage
  @next_planned_stage
end

#plan_contextObject

Get the plan’s context, sanitized



18
19
20
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 18

def plan_context
  @plan_context
end

#session_idObject

Get a unique session ID



21
22
23
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 21

def session_id
  @session_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
30
31
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 24

def self.attribute_map
  {
    :'current_stage' => :'current_stage',
    :'next_planned_stage' => :'next_planned_stage',
    :'plan_context' => :'plan_context',
    :'session_id' => :'session_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 203

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



54
55
56
57
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 54

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 44

def self.openapi_types
  {
    :'current_stage' => :'FlowStageBinding',
    :'next_planned_stage' => :'FlowStageBinding',
    :'plan_context' => :'Hash<String, Object>',
    :'session_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



179
180
181
182
183
184
185
186
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      current_stage == o.current_stage &&
      next_planned_stage == o.next_planned_stage &&
      plan_context == o.plan_context &&
      session_id == o.session_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


190
191
192
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 190

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



196
197
198
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 196

def hash
  [current_stage, next_planned_stage, plan_context, session_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 104

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @current_stage.nil?
    invalid_properties.push('invalid value for "current_stage", current_stage cannot be nil.')
  end

  if @next_planned_stage.nil?
    invalid_properties.push('invalid value for "next_planned_stage", next_planned_stage cannot be nil.')
  end

  if @plan_context.nil?
    invalid_properties.push('invalid value for "plan_context", plan_context cannot be nil.')
  end

  if @session_id.nil?
    invalid_properties.push('invalid value for "session_id", session_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 225

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



128
129
130
131
132
133
134
135
# File 'lib/authentik/api/models/flow_inspector_plan.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @current_stage.nil?
  return false if @next_planned_stage.nil?
  return false if @plan_context.nil?
  return false if @session_id.nil?
  true
end