Class: Authentik::Api::FlowRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/flow_request.rb

Overview

Flow Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlowRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/authentik/api/models/flow_request.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::FlowRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::FlowRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'designation')
    self.designation = attributes[:'designation']
  else
    self.designation = nil
  end

  if attributes.key?(:'background')
    self.background = attributes[:'background']
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'compatibility_mode')
    self.compatibility_mode = attributes[:'compatibility_mode']
  end

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'denied_action')
    self.denied_action = attributes[:'denied_action']
  end

  if attributes.key?(:'authentication')
    self.authentication = attributes[:'authentication']
  end
end

Instance Attribute Details

#authenticationObject

Required level of authentication and authorization to access a flow.



38
39
40
# File 'lib/authentik/api/models/flow_request.rb', line 38

def authentication
  @authentication
end

#backgroundObject

Background shown during execution



25
26
27
# File 'lib/authentik/api/models/flow_request.rb', line 25

def background
  @background
end

#compatibility_modeObject

Enable compatibility mode, increases compatibility with password managers on mobile devices.



30
31
32
# File 'lib/authentik/api/models/flow_request.rb', line 30

def compatibility_mode
  @compatibility_mode
end

#denied_actionObject

Configure what should happen when a flow denies access to a user.



35
36
37
# File 'lib/authentik/api/models/flow_request.rb', line 35

def denied_action
  @denied_action
end

#designationObject

Decides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik.



22
23
24
# File 'lib/authentik/api/models/flow_request.rb', line 22

def designation
  @designation
end

#layoutObject

Returns the value of attribute layout.



32
33
34
# File 'lib/authentik/api/models/flow_request.rb', line 32

def layout
  @layout
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/flow_request.rb', line 13

def name
  @name
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



27
28
29
# File 'lib/authentik/api/models/flow_request.rb', line 27

def policy_engine_mode
  @policy_engine_mode
end

#slugObject

Visible in the URL.



16
17
18
# File 'lib/authentik/api/models/flow_request.rb', line 16

def slug
  @slug
end

#titleObject

Shown as the Title in Flow pages.



19
20
21
# File 'lib/authentik/api/models/flow_request.rb', line 19

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/authentik/api/models/flow_request.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/authentik/api/models/flow_request.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/authentik/api/models/flow_request.rb', line 63

def self.attribute_map
  {
    :'name' => :'name',
    :'slug' => :'slug',
    :'title' => :'title',
    :'designation' => :'designation',
    :'background' => :'background',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'compatibility_mode' => :'compatibility_mode',
    :'layout' => :'layout',
    :'denied_action' => :'denied_action',
    :'authentication' => :'authentication'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/authentik/api/models/flow_request.rb', line 320

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
# File 'lib/authentik/api/models/flow_request.rb', line 105

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/authentik/api/models/flow_request.rb', line 89

def self.openapi_types
  {
    :'name' => :'String',
    :'slug' => :'String',
    :'title' => :'String',
    :'designation' => :'FlowDesignationEnum',
    :'background' => :'String',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'compatibility_mode' => :'Boolean',
    :'layout' => :'FlowLayoutEnum',
    :'denied_action' => :'DeniedActionEnum',
    :'authentication' => :'AuthenticationEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/authentik/api/models/flow_request.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      slug == o.slug &&
      title == o.title &&
      designation == o.designation &&
      background == o.background &&
      policy_engine_mode == o.policy_engine_mode &&
      compatibility_mode == o.compatibility_mode &&
      layout == o.layout &&
      denied_action == o.denied_action &&
      authentication == o.authentication
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


307
308
309
# File 'lib/authentik/api/models/flow_request.rb', line 307

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



313
314
315
# File 'lib/authentik/api/models/flow_request.rb', line 313

def hash
  [name, slug, title, designation, background, policy_engine_mode, compatibility_mode, layout, denied_action, authentication].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/authentik/api/models/flow_request.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  if @slug.to_s.length < 1
    invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  if @designation.nil?
    invalid_properties.push('invalid value for "designation", designation cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/authentik/api/models/flow_request.rb', line 342

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/authentik/api/models/flow_request.rb', line 218

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @slug.nil?
  return false if @slug.to_s.length < 1
  return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if @title.nil?
  return false if @title.to_s.length < 1
  return false if @designation.nil?
  true
end