Class: Authentik::Api::FlowSet

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/flow_set.rb

Overview

Stripped down flow serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlowSet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/authentik/api/models/flow_set.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::FlowSet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::FlowSet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'policybindingmodel_ptr_id')
    self.policybindingmodel_ptr_id = attributes[:'policybindingmodel_ptr_id']
  else
    self.policybindingmodel_ptr_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'designation')
    self.designation = attributes[:'designation']
  else
    self.designation = nil
  end

  if attributes.key?(:'background_url')
    self.background_url = attributes[:'background_url']
  else
    self.background_url = nil
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'compatibility_mode')
    self.compatibility_mode = attributes[:'compatibility_mode']
  end

  if attributes.key?(:'export_url')
    self.export_url = attributes[:'export_url']
  else
    self.export_url = nil
  end

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'denied_action')
    self.denied_action = attributes[:'denied_action']
  end
end

Instance Attribute Details

#background_urlObject

Get the URL to the background image



29
30
31
# File 'lib/authentik/api/models/flow_set.rb', line 29

def background_url
  @background_url
end

#compatibility_modeObject

Enable compatibility mode, increases compatibility with password managers on mobile devices.



34
35
36
# File 'lib/authentik/api/models/flow_set.rb', line 34

def compatibility_mode
  @compatibility_mode
end

#denied_actionObject

Configure what should happen when a flow denies access to a user.



42
43
44
# File 'lib/authentik/api/models/flow_set.rb', line 42

def denied_action
  @denied_action
end

#designationObject

Decides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik.



26
27
28
# File 'lib/authentik/api/models/flow_set.rb', line 26

def designation
  @designation
end

#export_urlObject

Get export URL for flow



37
38
39
# File 'lib/authentik/api/models/flow_set.rb', line 37

def export_url
  @export_url
end

#layoutObject

Returns the value of attribute layout.



39
40
41
# File 'lib/authentik/api/models/flow_set.rb', line 39

def layout
  @layout
end

#nameObject

Returns the value of attribute name.



17
18
19
# File 'lib/authentik/api/models/flow_set.rb', line 17

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/flow_set.rb', line 13

def pk
  @pk
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



31
32
33
# File 'lib/authentik/api/models/flow_set.rb', line 31

def policy_engine_mode
  @policy_engine_mode
end

#policybindingmodel_ptr_idObject

Returns the value of attribute policybindingmodel_ptr_id.



15
16
17
# File 'lib/authentik/api/models/flow_set.rb', line 15

def policybindingmodel_ptr_id
  @policybindingmodel_ptr_id
end

#slugObject

Visible in the URL.



20
21
22
# File 'lib/authentik/api/models/flow_set.rb', line 20

def slug
  @slug
end

#titleObject

Shown as the Title in Flow pages.



23
24
25
# File 'lib/authentik/api/models/flow_set.rb', line 23

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/authentik/api/models/flow_set.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/authentik/api/models/flow_set.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/authentik/api/models/flow_set.rb', line 67

def self.attribute_map
  {
    :'pk' => :'pk',
    :'policybindingmodel_ptr_id' => :'policybindingmodel_ptr_id',
    :'name' => :'name',
    :'slug' => :'slug',
    :'title' => :'title',
    :'designation' => :'designation',
    :'background_url' => :'background_url',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'compatibility_mode' => :'compatibility_mode',
    :'export_url' => :'export_url',
    :'layout' => :'layout',
    :'denied_action' => :'denied_action'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/authentik/api/models/flow_set.rb', line 379

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
# File 'lib/authentik/api/models/flow_set.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/authentik/api/models/flow_set.rb', line 95

def self.openapi_types
  {
    :'pk' => :'String',
    :'policybindingmodel_ptr_id' => :'String',
    :'name' => :'String',
    :'slug' => :'String',
    :'title' => :'String',
    :'designation' => :'FlowDesignationEnum',
    :'background_url' => :'String',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'compatibility_mode' => :'Boolean',
    :'export_url' => :'String',
    :'layout' => :'FlowLayoutEnum',
    :'denied_action' => :'DeniedActionEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/authentik/api/models/flow_set.rb', line 347

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      policybindingmodel_ptr_id == o.policybindingmodel_ptr_id &&
      name == o.name &&
      slug == o.slug &&
      title == o.title &&
      designation == o.designation &&
      background_url == o.background_url &&
      policy_engine_mode == o.policy_engine_mode &&
      compatibility_mode == o.compatibility_mode &&
      export_url == o.export_url &&
      layout == o.layout &&
      denied_action == o.denied_action
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


366
367
368
# File 'lib/authentik/api/models/flow_set.rb', line 366

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



372
373
374
# File 'lib/authentik/api/models/flow_set.rb', line 372

def hash
  [pk, policybindingmodel_ptr_id, name, slug, title, designation, background_url, policy_engine_mode, compatibility_mode, export_url, layout, denied_action].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/authentik/api/models/flow_set.rb', line 201

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @policybindingmodel_ptr_id.nil?
    invalid_properties.push('invalid value for "policybindingmodel_ptr_id", policybindingmodel_ptr_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @designation.nil?
    invalid_properties.push('invalid value for "designation", designation cannot be nil.')
  end

  if @background_url.nil?
    invalid_properties.push('invalid value for "background_url", background_url cannot be nil.')
  end

  if @export_url.nil?
    invalid_properties.push('invalid value for "export_url", export_url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/authentik/api/models/flow_set.rb', line 401

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/authentik/api/models/flow_set.rb', line 246

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @policybindingmodel_ptr_id.nil?
  return false if @name.nil?
  return false if @slug.nil?
  return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if @title.nil?
  return false if @designation.nil?
  return false if @background_url.nil?
  return false if @export_url.nil?
  true
end