Class: Authentik::Api::FlowStageBinding

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/flow_stage_binding.rb

Overview

FlowStageBinding Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlowStageBinding

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::FlowStageBinding` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::FlowStageBinding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'policybindingmodel_ptr_id')
    self.policybindingmodel_ptr_id = attributes[:'policybindingmodel_ptr_id']
  else
    self.policybindingmodel_ptr_id = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'stage')
    self.stage = attributes[:'stage']
  else
    self.stage = nil
  end

  if attributes.key?(:'stage_obj')
    self.stage_obj = attributes[:'stage_obj']
  else
    self.stage_obj = nil
  end

  if attributes.key?(:'evaluate_on_plan')
    self.evaluate_on_plan = attributes[:'evaluate_on_plan']
  end

  if attributes.key?(:'re_evaluate_policies')
    self.re_evaluate_policies = attributes[:'re_evaluate_policies']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  else
    self.order = nil
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'invalid_response_action')
    self.invalid_response_action = attributes[:'invalid_response_action']
  end
end

Instance Attribute Details

#evaluate_on_planObject

Evaluate policies during the Flow planning process.



24
25
26
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 24

def evaluate_on_plan
  @evaluate_on_plan
end

#invalid_response_actionObject

Configure how the flow executor should handle an invalid response to a challenge. RETRY returns the error message and a similar challenge to the executor. RESTART restarts the flow from the beginning, and RESTART_WITH_CONTEXT restarts the flow while keeping the current context.



34
35
36
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 34

def invalid_response_action
  @invalid_response_action
end

#orderObject

Returns the value of attribute order.



29
30
31
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 29

def order
  @order
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 13

def pk
  @pk
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



31
32
33
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 31

def policy_engine_mode
  @policy_engine_mode
end

#policybindingmodel_ptr_idObject

Returns the value of attribute policybindingmodel_ptr_id.



15
16
17
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 15

def policybindingmodel_ptr_id
  @policybindingmodel_ptr_id
end

#re_evaluate_policiesObject

Evaluate policies when the Stage is presented to the user.



27
28
29
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 27

def re_evaluate_policies
  @re_evaluate_policies
end

#stageObject

Returns the value of attribute stage.



19
20
21
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 19

def stage
  @stage
end

#stage_objObject

Returns the value of attribute stage_obj.



21
22
23
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 21

def stage_obj
  @stage_obj
end

#targetObject

Returns the value of attribute target.



17
18
19
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 17

def target
  @target
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 59

def self.attribute_map
  {
    :'pk' => :'pk',
    :'policybindingmodel_ptr_id' => :'policybindingmodel_ptr_id',
    :'target' => :'target',
    :'stage' => :'stage',
    :'stage_obj' => :'stage_obj',
    :'evaluate_on_plan' => :'evaluate_on_plan',
    :'re_evaluate_policies' => :'re_evaluate_policies',
    :'order' => :'order',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'invalid_response_action' => :'invalid_response_action'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 330

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 85

def self.openapi_types
  {
    :'pk' => :'String',
    :'policybindingmodel_ptr_id' => :'String',
    :'target' => :'String',
    :'stage' => :'String',
    :'stage_obj' => :'Stage',
    :'evaluate_on_plan' => :'Boolean',
    :'re_evaluate_policies' => :'Boolean',
    :'order' => :'Integer',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'invalid_response_action' => :'InvalidResponseActionEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 300

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      policybindingmodel_ptr_id == o.policybindingmodel_ptr_id &&
      target == o.target &&
      stage == o.stage &&
      stage_obj == o.stage_obj &&
      evaluate_on_plan == o.evaluate_on_plan &&
      re_evaluate_policies == o.re_evaluate_policies &&
      order == o.order &&
      policy_engine_mode == o.policy_engine_mode &&
      invalid_response_action == o.invalid_response_action
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


317
318
319
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 317

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



323
324
325
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 323

def hash
  [pk, policybindingmodel_ptr_id, target, stage, stage_obj, evaluate_on_plan, re_evaluate_policies, order, policy_engine_mode, invalid_response_action].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @policybindingmodel_ptr_id.nil?
    invalid_properties.push('invalid value for "policybindingmodel_ptr_id", policybindingmodel_ptr_id cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @stage.nil?
    invalid_properties.push('invalid value for "stage", stage cannot be nil.')
  end

  if @stage_obj.nil?
    invalid_properties.push('invalid value for "stage_obj", stage_obj cannot be nil.')
  end

  if @order.nil?
    invalid_properties.push('invalid value for "order", order cannot be nil.')
  end

  if @order > 2147483647
    invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.')
  end

  if @order < -2147483648
    invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 352

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/authentik/api/models/flow_stage_binding.rb', line 217

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @policybindingmodel_ptr_id.nil?
  return false if @target.nil?
  return false if @stage.nil?
  return false if @stage_obj.nil?
  return false if @order.nil?
  return false if @order > 2147483647
  return false if @order < -2147483648
  true
end