Class: Authentik::Api::GeoIPPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::GeoIPPolicy
- Defined in:
- lib/authentik/api/models/geo_ip_policy.rb
Overview
GeoIP Policy Serializer
Instance Attribute Summary collapse
-
#asns ⇒ Object
Returns the value of attribute asns.
-
#bound_to ⇒ Object
Return objects policy is bound to.
-
#check_history_distance ⇒ Object
Returns the value of attribute check_history_distance.
-
#check_impossible_travel ⇒ Object
Returns the value of attribute check_impossible_travel.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#countries ⇒ Object
Returns the value of attribute countries.
-
#countries_obj ⇒ Object
Returns the value of attribute countries_obj.
-
#distance_tolerance_km ⇒ Object
Returns the value of attribute distance_tolerance_km.
-
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged.
-
#history_login_count ⇒ Object
Returns the value of attribute history_login_count.
-
#history_max_distance_km ⇒ Object
Returns the value of attribute history_max_distance_km.
-
#impossible_tolerance_km ⇒ Object
Returns the value of attribute impossible_tolerance_km.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GeoIPPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GeoIPPolicy
Initializes the object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 117 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::GeoIPPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::GeoIPPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'execution_logging') self.execution_logging = attributes[:'execution_logging'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'bound_to') self.bound_to = attributes[:'bound_to'] else self.bound_to = nil end if attributes.key?(:'asns') if (value = attributes[:'asns']).is_a?(Array) self.asns = value end end if attributes.key?(:'countries') if (value = attributes[:'countries']).is_a?(Array) self.countries = value end else self.countries = nil end if attributes.key?(:'countries_obj') if (value = attributes[:'countries_obj']).is_a?(Array) self.countries_obj = value end else self.countries_obj = nil end if attributes.key?(:'check_history_distance') self.check_history_distance = attributes[:'check_history_distance'] end if attributes.key?(:'history_max_distance_km') self.history_max_distance_km = attributes[:'history_max_distance_km'] end if attributes.key?(:'distance_tolerance_km') self.distance_tolerance_km = attributes[:'distance_tolerance_km'] end if attributes.key?(:'history_login_count') self.history_login_count = attributes[:'history_login_count'] end if attributes.key?(:'check_impossible_travel') self.check_impossible_travel = attributes[:'check_impossible_travel'] end if attributes.key?(:'impossible_tolerance_km') self.impossible_tolerance_km = attributes[:'impossible_tolerance_km'] end end |
Instance Attribute Details
#asns ⇒ Object
Returns the value of attribute asns.
35 36 37 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 35 def asns @asns end |
#bound_to ⇒ Object
Return objects policy is bound to
33 34 35 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 33 def bound_to @bound_to end |
#check_history_distance ⇒ Object
Returns the value of attribute check_history_distance.
41 42 43 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 41 def check_history_distance @check_history_distance end |
#check_impossible_travel ⇒ Object
Returns the value of attribute check_impossible_travel.
49 50 51 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 49 def check_impossible_travel @check_impossible_travel end |
#component ⇒ Object
Get object component so that we know how to edit the object
21 22 23 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 21 def component @component end |
#countries ⇒ Object
Returns the value of attribute countries.
37 38 39 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 37 def countries @countries end |
#countries_obj ⇒ Object
Returns the value of attribute countries_obj.
39 40 41 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 39 def countries_obj @countries_obj end |
#distance_tolerance_km ⇒ Object
Returns the value of attribute distance_tolerance_km.
45 46 47 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 45 def distance_tolerance_km @distance_tolerance_km end |
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.
18 19 20 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 18 def execution_logging @execution_logging end |
#history_login_count ⇒ Object
Returns the value of attribute history_login_count.
47 48 49 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 47 def history_login_count @history_login_count end |
#history_max_distance_km ⇒ Object
Returns the value of attribute history_max_distance_km.
43 44 45 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 43 def history_max_distance_km @history_max_distance_km end |
#impossible_tolerance_km ⇒ Object
Returns the value of attribute impossible_tolerance_km.
51 52 53 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 51 def impossible_tolerance_km @impossible_tolerance_km end |
#meta_model_name ⇒ Object
Return internal model name
30 31 32 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 30 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 13 def pk @pk end |
#verbose_name ⇒ Object
Return object’s verbose_name
24 25 26 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 24 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
27 28 29 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 27 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 54 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'execution_logging' => :'execution_logging', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'bound_to' => :'bound_to', :'asns' => :'asns', :'countries' => :'countries', :'countries_obj' => :'countries_obj', :'check_history_distance' => :'check_history_distance', :'history_max_distance_km' => :'history_max_distance_km', :'distance_tolerance_km' => :'distance_tolerance_km', :'history_login_count' => :'history_login_count', :'check_impossible_travel' => :'check_impossible_travel', :'impossible_tolerance_km' => :'impossible_tolerance_km' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 534 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
110 111 112 113 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 110 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 87 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'execution_logging' => :'Boolean', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'bound_to' => :'Integer', :'asns' => :'Array<Integer>', :'countries' => :'Array<CountryCodeEnum>', :'countries_obj' => :'Array<DetailedCountryField>', :'check_history_distance' => :'Boolean', :'history_max_distance_km' => :'Integer', :'distance_tolerance_km' => :'Integer', :'history_login_count' => :'Integer', :'check_impossible_travel' => :'Boolean', :'impossible_tolerance_km' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 497 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && execution_logging == o.execution_logging && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && bound_to == o.bound_to && asns == o.asns && countries == o.countries && countries_obj == o.countries_obj && check_history_distance == o.check_history_distance && history_max_distance_km == o.history_max_distance_km && distance_tolerance_km == o.distance_tolerance_km && history_login_count == o.history_login_count && check_impossible_travel == o.check_impossible_travel && impossible_tolerance_km == o.impossible_tolerance_km end |
#eql?(o) ⇒ Boolean
521 522 523 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 521 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
527 528 529 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 527 def hash [pk, name, execution_logging, component, verbose_name, verbose_name_plural, , bound_to, asns, countries, countries_obj, check_history_distance, history_max_distance_km, distance_tolerance_km, history_login_count, check_impossible_travel, impossible_tolerance_km].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 226 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @bound_to.nil? invalid_properties.push('invalid value for "bound_to", bound_to cannot be nil.') end if @countries.nil? invalid_properties.push('invalid value for "countries", countries cannot be nil.') end if @countries.length > 249 invalid_properties.push('invalid value for "countries", number of items must be less than or equal to 249.') end if @countries_obj.nil? invalid_properties.push('invalid value for "countries_obj", countries_obj cannot be nil.') end if !@history_max_distance_km.nil? && @history_max_distance_km > 9223372036854775807 invalid_properties.push('invalid value for "history_max_distance_km", must be smaller than or equal to 9223372036854775807.') end if !@history_max_distance_km.nil? && @history_max_distance_km < 0 invalid_properties.push('invalid value for "history_max_distance_km", must be greater than or equal to 0.') end if !@distance_tolerance_km.nil? && @distance_tolerance_km > 2147483647 invalid_properties.push('invalid value for "distance_tolerance_km", must be smaller than or equal to 2147483647.') end if !@distance_tolerance_km.nil? && @distance_tolerance_km < 0 invalid_properties.push('invalid value for "distance_tolerance_km", must be greater than or equal to 0.') end if !@history_login_count.nil? && @history_login_count > 2147483647 invalid_properties.push('invalid value for "history_login_count", must be smaller than or equal to 2147483647.') end if !@history_login_count.nil? && @history_login_count < 0 invalid_properties.push('invalid value for "history_login_count", must be greater than or equal to 0.') end if !@impossible_tolerance_km.nil? && @impossible_tolerance_km > 2147483647 invalid_properties.push('invalid value for "impossible_tolerance_km", must be smaller than or equal to 2147483647.') end if !@impossible_tolerance_km.nil? && @impossible_tolerance_km < 0 invalid_properties.push('invalid value for "impossible_tolerance_km", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 556 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/authentik/api/models/geo_ip_policy.rb', line 306 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @bound_to.nil? return false if @countries.nil? return false if @countries.length > 249 return false if @countries_obj.nil? return false if !@history_max_distance_km.nil? && @history_max_distance_km > 9223372036854775807 return false if !@history_max_distance_km.nil? && @history_max_distance_km < 0 return false if !@distance_tolerance_km.nil? && @distance_tolerance_km > 2147483647 return false if !@distance_tolerance_km.nil? && @distance_tolerance_km < 0 return false if !@history_login_count.nil? && @history_login_count > 2147483647 return false if !@history_login_count.nil? && @history_login_count < 0 return false if !@impossible_tolerance_km.nil? && @impossible_tolerance_km > 2147483647 return false if !@impossible_tolerance_km.nil? && @impossible_tolerance_km < 0 true end |