Class: Authentik::Api::Group
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::Group
- Defined in:
- lib/authentik/api/models/group.rb
Overview
Group Serializer
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#children ⇒ Object
Returns the value of attribute children.
-
#children_obj ⇒ Object
Returns the value of attribute children_obj.
-
#inherited_roles_obj ⇒ Object
Returns the value of attribute inherited_roles_obj.
-
#is_superuser ⇒ Object
Users added to this group will be superusers.
-
#name ⇒ Object
Returns the value of attribute name.
-
#num_pk ⇒ Object
Returns the value of attribute num_pk.
-
#parents ⇒ Object
Returns the value of attribute parents.
-
#parents_obj ⇒ Object
Returns the value of attribute parents_obj.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#roles ⇒ Object
Returns the value of attribute roles.
-
#roles_obj ⇒ Object
Returns the value of attribute roles_obj.
-
#users ⇒ Object
Returns the value of attribute users.
-
#users_obj ⇒ Object
Returns the value of attribute users_obj.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Group
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Group
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/authentik/api/models/group.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Group` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Group`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'num_pk') self.num_pk = attributes[:'num_pk'] else self.num_pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'is_superuser') self.is_superuser = attributes[:'is_superuser'] end if attributes.key?(:'parents') if (value = attributes[:'parents']).is_a?(Array) self.parents = value end end if attributes.key?(:'parents_obj') if (value = attributes[:'parents_obj']).is_a?(Array) self.parents_obj = value end else self.parents_obj = nil end if attributes.key?(:'users') if (value = attributes[:'users']).is_a?(Array) self.users = value end end if attributes.key?(:'users_obj') if (value = attributes[:'users_obj']).is_a?(Array) self.users_obj = value end else self.users_obj = nil end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end if attributes.key?(:'roles') if (value = attributes[:'roles']).is_a?(Array) self.roles = value end end if attributes.key?(:'roles_obj') if (value = attributes[:'roles_obj']).is_a?(Array) self.roles_obj = value end else self.roles_obj = nil end if attributes.key?(:'inherited_roles_obj') if (value = attributes[:'inherited_roles_obj']).is_a?(Array) self.inherited_roles_obj = value end else self.inherited_roles_obj = nil end if attributes.key?(:'children') if (value = attributes[:'children']).is_a?(Array) self.children = value end else self.children = nil end if attributes.key?(:'children_obj') if (value = attributes[:'children_obj']).is_a?(Array) self.children_obj = value end else self.children_obj = nil end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
30 31 32 |
# File 'lib/authentik/api/models/group.rb', line 30 def attributes @attributes end |
#children ⇒ Object
Returns the value of attribute children.
38 39 40 |
# File 'lib/authentik/api/models/group.rb', line 38 def children @children end |
#children_obj ⇒ Object
Returns the value of attribute children_obj.
40 41 42 |
# File 'lib/authentik/api/models/group.rb', line 40 def children_obj @children_obj end |
#inherited_roles_obj ⇒ Object
Returns the value of attribute inherited_roles_obj.
36 37 38 |
# File 'lib/authentik/api/models/group.rb', line 36 def inherited_roles_obj @inherited_roles_obj end |
#is_superuser ⇒ Object
Users added to this group will be superusers.
20 21 22 |
# File 'lib/authentik/api/models/group.rb', line 20 def is_superuser @is_superuser end |
#name ⇒ Object
Returns the value of attribute name.
17 18 19 |
# File 'lib/authentik/api/models/group.rb', line 17 def name @name end |
#num_pk ⇒ Object
Returns the value of attribute num_pk.
15 16 17 |
# File 'lib/authentik/api/models/group.rb', line 15 def num_pk @num_pk end |
#parents ⇒ Object
Returns the value of attribute parents.
22 23 24 |
# File 'lib/authentik/api/models/group.rb', line 22 def parents @parents end |
#parents_obj ⇒ Object
Returns the value of attribute parents_obj.
24 25 26 |
# File 'lib/authentik/api/models/group.rb', line 24 def parents_obj @parents_obj end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/group.rb', line 13 def pk @pk end |
#roles ⇒ Object
Returns the value of attribute roles.
32 33 34 |
# File 'lib/authentik/api/models/group.rb', line 32 def roles @roles end |
#roles_obj ⇒ Object
Returns the value of attribute roles_obj.
34 35 36 |
# File 'lib/authentik/api/models/group.rb', line 34 def roles_obj @roles_obj end |
#users ⇒ Object
Returns the value of attribute users.
26 27 28 |
# File 'lib/authentik/api/models/group.rb', line 26 def users @users end |
#users_obj ⇒ Object
Returns the value of attribute users_obj.
28 29 30 |
# File 'lib/authentik/api/models/group.rb', line 28 def users_obj @users_obj end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/authentik/api/models/group.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/authentik/api/models/group.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/authentik/api/models/group.rb', line 43 def self.attribute_map { :'pk' => :'pk', :'num_pk' => :'num_pk', :'name' => :'name', :'is_superuser' => :'is_superuser', :'parents' => :'parents', :'parents_obj' => :'parents_obj', :'users' => :'users', :'users_obj' => :'users_obj', :'attributes' => :'attributes', :'roles' => :'roles', :'roles_obj' => :'roles_obj', :'inherited_roles_obj' => :'inherited_roles_obj', :'children' => :'children', :'children_obj' => :'children_obj' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/authentik/api/models/group.rb', line 339 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 97 98 99 100 |
# File 'lib/authentik/api/models/group.rb', line 93 def self.openapi_nullable Set.new([ :'parents_obj', :'users_obj', :'inherited_roles_obj', :'children_obj' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/authentik/api/models/group.rb', line 73 def self.openapi_types { :'pk' => :'String', :'num_pk' => :'Integer', :'name' => :'String', :'is_superuser' => :'Boolean', :'parents' => :'Array<String>', :'parents_obj' => :'Array<RelatedGroup>', :'users' => :'Array<Integer>', :'users_obj' => :'Array<PartialUser>', :'attributes' => :'Hash<String, Object>', :'roles' => :'Array<String>', :'roles_obj' => :'Array<Role>', :'inherited_roles_obj' => :'Array<Role>', :'children' => :'Array<String>', :'children_obj' => :'Array<RelatedGroup>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/authentik/api/models/group.rb', line 305 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && num_pk == o.num_pk && name == o.name && is_superuser == o.is_superuser && parents == o.parents && parents_obj == o.parents_obj && users == o.users && users_obj == o.users_obj && attributes == o.attributes && roles == o.roles && roles_obj == o.roles_obj && inherited_roles_obj == o.inherited_roles_obj && children == o.children && children_obj == o.children_obj end |
#eql?(o) ⇒ Boolean
326 327 328 |
# File 'lib/authentik/api/models/group.rb', line 326 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
332 333 334 |
# File 'lib/authentik/api/models/group.rb', line 332 def hash [pk, num_pk, name, is_superuser, parents, parents_obj, users, users_obj, attributes, roles, roles_obj, inherited_roles_obj, children, children_obj].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/authentik/api/models/group.rb', line 215 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @num_pk.nil? invalid_properties.push('invalid value for "num_pk", num_pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @roles_obj.nil? invalid_properties.push('invalid value for "roles_obj", roles_obj cannot be nil.') end if @children.nil? invalid_properties.push('invalid value for "children", children cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/authentik/api/models/group.rb', line 361 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
243 244 245 246 247 248 249 250 251 |
# File 'lib/authentik/api/models/group.rb', line 243 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @num_pk.nil? return false if @name.nil? return false if @roles_obj.nil? return false if @children.nil? true end |