Class: Authentik::Api::GroupLDAPSourceConnection
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::GroupLDAPSourceConnection
- Defined in:
- lib/authentik/api/models/group_ldap_source_connection.rb
Overview
Group Source Connection
Instance Attribute Summary collapse
-
#created ⇒ Object
Returns the value of attribute created.
-
#group ⇒ Object
Returns the value of attribute group.
-
#group_obj ⇒ Object
Returns the value of attribute group_obj.
-
#identifier ⇒ Object
Returns the value of attribute identifier.
-
#last_updated ⇒ Object
Returns the value of attribute last_updated.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#source ⇒ Object
Returns the value of attribute source.
-
#source_obj ⇒ Object
Returns the value of attribute source_obj.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GroupLDAPSourceConnection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GroupLDAPSourceConnection
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::GroupLDAPSourceConnection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::GroupLDAPSourceConnection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'group') self.group = attributes[:'group'] else self.group = nil end if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'source_obj') self.source_obj = attributes[:'source_obj'] else self.source_obj = nil end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] else self.identifier = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] else self.last_updated = nil end if attributes.key?(:'group_obj') self.group_obj = attributes[:'group_obj'] else self.group_obj = nil end end |
Instance Attribute Details
#created ⇒ Object
Returns the value of attribute created.
23 24 25 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 23 def created @created end |
#group ⇒ Object
Returns the value of attribute group.
15 16 17 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 15 def group @group end |
#group_obj ⇒ Object
Returns the value of attribute group_obj.
27 28 29 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 27 def group_obj @group_obj end |
#identifier ⇒ Object
Returns the value of attribute identifier.
21 22 23 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 21 def identifier @identifier end |
#last_updated ⇒ Object
Returns the value of attribute last_updated.
25 26 27 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 25 def last_updated @last_updated end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 13 def pk @pk end |
#source ⇒ Object
Returns the value of attribute source.
17 18 19 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 17 def source @source end |
#source_obj ⇒ Object
Returns the value of attribute source_obj.
19 20 21 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 19 def source_obj @source_obj end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 30 def self.attribute_map { :'pk' => :'pk', :'group' => :'group', :'source' => :'source', :'source_obj' => :'source_obj', :'identifier' => :'identifier', :'created' => :'created', :'last_updated' => :'last_updated', :'group_obj' => :'group_obj' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 303 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 54 def self.openapi_types { :'pk' => :'Integer', :'group' => :'String', :'source' => :'String', :'source_obj' => :'Source', :'identifier' => :'String', :'created' => :'Time', :'last_updated' => :'Time', :'group_obj' => :'PartialGroup' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 275 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && group == o.group && source == o.source && source_obj == o.source_obj && identifier == o.identifier && created == o.created && last_updated == o.last_updated && group_obj == o.group_obj end |
#eql?(o) ⇒ Boolean
290 291 292 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 290 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
296 297 298 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 296 def hash [pk, group, source, source_obj, identifier, created, last_updated, group_obj].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @group.nil? invalid_properties.push('invalid value for "group", group cannot be nil.') end if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end if @source_obj.nil? invalid_properties.push('invalid value for "source_obj", source_obj cannot be nil.') end if @identifier.nil? invalid_properties.push('invalid value for "identifier", identifier cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @last_updated.nil? invalid_properties.push('invalid value for "last_updated", last_updated cannot be nil.') end if @group_obj.nil? invalid_properties.push('invalid value for "group_obj", group_obj cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 325 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @group.nil? return false if @source.nil? return false if @source_obj.nil? return false if @identifier.nil? return false if @created.nil? return false if @last_updated.nil? return false if @group_obj.nil? true end |