Class: Authentik::Api::Hardware

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/hardware.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Hardware

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/authentik/api/models/hardware.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Hardware` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Hardware`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  end

  if attributes.key?(:'manufacturer')
    self.manufacturer = attributes[:'manufacturer']
  end

  if attributes.key?(:'serial')
    self.serial = attributes[:'serial']
  else
    self.serial = nil
  end

  if attributes.key?(:'cpu_name')
    self.cpu_name = attributes[:'cpu_name']
  end

  if attributes.key?(:'cpu_count')
    self.cpu_count = attributes[:'cpu_count']
  end

  if attributes.key?(:'memory_bytes')
    self.memory_bytes = attributes[:'memory_bytes']
  end
end

Instance Attribute Details

#cpu_countObject

Returns the value of attribute cpu_count.



20
21
22
# File 'lib/authentik/api/models/hardware.rb', line 20

def cpu_count
  @cpu_count
end

#cpu_nameObject

Returns the value of attribute cpu_name.



18
19
20
# File 'lib/authentik/api/models/hardware.rb', line 18

def cpu_name
  @cpu_name
end

#manufacturerObject

Returns the value of attribute manufacturer.



14
15
16
# File 'lib/authentik/api/models/hardware.rb', line 14

def manufacturer
  @manufacturer
end

#memory_bytesObject

Returns the value of attribute memory_bytes.



22
23
24
# File 'lib/authentik/api/models/hardware.rb', line 22

def memory_bytes
  @memory_bytes
end

#modelObject

Returns the value of attribute model.



12
13
14
# File 'lib/authentik/api/models/hardware.rb', line 12

def model
  @model
end

#serialObject

Returns the value of attribute serial.



16
17
18
# File 'lib/authentik/api/models/hardware.rb', line 16

def serial
  @serial
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/authentik/api/models/hardware.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/authentik/api/models/hardware.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
32
33
34
# File 'lib/authentik/api/models/hardware.rb', line 25

def self.attribute_map
  {
    :'model' => :'model',
    :'manufacturer' => :'manufacturer',
    :'serial' => :'serial',
    :'cpu_name' => :'cpu_name',
    :'cpu_count' => :'cpu_count',
    :'memory_bytes' => :'memory_bytes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/authentik/api/models/hardware.rb', line 165

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
# File 'lib/authentik/api/models/hardware.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
56
# File 'lib/authentik/api/models/hardware.rb', line 47

def self.openapi_types
  {
    :'model' => :'String',
    :'manufacturer' => :'String',
    :'serial' => :'String',
    :'cpu_name' => :'String',
    :'cpu_count' => :'Integer',
    :'memory_bytes' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



139
140
141
142
143
144
145
146
147
148
# File 'lib/authentik/api/models/hardware.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      model == o.model &&
      manufacturer == o.manufacturer &&
      serial == o.serial &&
      cpu_name == o.cpu_name &&
      cpu_count == o.cpu_count &&
      memory_bytes == o.memory_bytes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/authentik/api/models/hardware.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/authentik/api/models/hardware.rb', line 158

def hash
  [model, manufacturer, serial, cpu_name, cpu_count, memory_bytes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
# File 'lib/authentik/api/models/hardware.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @serial.nil?
    invalid_properties.push('invalid value for "serial", serial cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/authentik/api/models/hardware.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



121
122
123
124
125
# File 'lib/authentik/api/models/hardware.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @serial.nil?
  true
end