Class: Authentik::Api::ImpersonationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ImpersonationRequest
- Defined in:
- lib/authentik/api/models/impersonation_request.rb
Instance Attribute Summary collapse
-
#reason ⇒ Object
Returns the value of attribute reason.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImpersonationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ImpersonationRequest
Initializes the object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 46 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ImpersonationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ImpersonationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'reason') self.reason = attributes[:'reason'] else self.reason = nil end end |
Instance Attribute Details
#reason ⇒ Object
Returns the value of attribute reason.
12 13 14 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 12 def reason @reason end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
22 23 24 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 22 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
27 28 29 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 27 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 15 def self.attribute_map { :'reason' => :'reason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 129 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
39 40 41 42 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 39 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
32 33 34 35 36 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 32 def self.openapi_types { :'reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 108 def ==(o) return true if self.equal?(o) self.class == o.class && reason == o.reason end |
#eql?(o) ⇒ Boolean
116 117 118 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 116 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
122 123 124 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 122 def hash [reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 69 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @reason.nil? invalid_properties.push('invalid value for "reason", reason cannot be nil.') end if @reason.to_s.length < 1 invalid_properties.push('invalid value for "reason", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 151 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
85 86 87 88 89 90 |
# File 'lib/authentik/api/models/impersonation_request.rb', line 85 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @reason.nil? return false if @reason.to_s.length < 1 true end |