Class: Authentik::Api::InvitationRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/invitation_request.rb

Overview

Invitation Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvitationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/authentik/api/models/invitation_request.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::InvitationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::InvitationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  end

  if attributes.key?(:'fixed_data')
    if (value = attributes[:'fixed_data']).is_a?(Hash)
      self.fixed_data = value
    end
  end

  if attributes.key?(:'single_use')
    self.single_use = attributes[:'single_use']
  end

  if attributes.key?(:'flow')
    self.flow = attributes[:'flow']
  end
end

Instance Attribute Details

#expiresObject

Returns the value of attribute expires.



15
16
17
# File 'lib/authentik/api/models/invitation_request.rb', line 15

def expires
  @expires
end

#fixed_dataObject

Returns the value of attribute fixed_data.



17
18
19
# File 'lib/authentik/api/models/invitation_request.rb', line 17

def fixed_data
  @fixed_data
end

#flowObject

When set, only the configured flow can use this invitation.



23
24
25
# File 'lib/authentik/api/models/invitation_request.rb', line 23

def flow
  @flow
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/invitation_request.rb', line 13

def name
  @name
end

#single_useObject

When enabled, the invitation will be deleted after usage.



20
21
22
# File 'lib/authentik/api/models/invitation_request.rb', line 20

def single_use
  @single_use
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/authentik/api/models/invitation_request.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/authentik/api/models/invitation_request.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
# File 'lib/authentik/api/models/invitation_request.rb', line 26

def self.attribute_map
  {
    :'name' => :'name',
    :'expires' => :'expires',
    :'fixed_data' => :'fixed_data',
    :'single_use' => :'single_use',
    :'flow' => :'flow'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/authentik/api/models/invitation_request.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
62
63
# File 'lib/authentik/api/models/invitation_request.rb', line 58

def self.openapi_nullable
  Set.new([
    :'expires',
    :'flow'
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
# File 'lib/authentik/api/models/invitation_request.rb', line 47

def self.openapi_types
  {
    :'name' => :'String',
    :'expires' => :'Time',
    :'fixed_data' => :'Hash<String, Object>',
    :'single_use' => :'Boolean',
    :'flow' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



158
159
160
161
162
163
164
165
166
# File 'lib/authentik/api/models/invitation_request.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      expires == o.expires &&
      fixed_data == o.fixed_data &&
      single_use == o.single_use &&
      flow == o.flow
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/authentik/api/models/invitation_request.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



176
177
178
# File 'lib/authentik/api/models/invitation_request.rb', line 176

def hash
  [name, expires, fixed_data, single_use, flow].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/authentik/api/models/invitation_request.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/authentik/api/models/invitation_request.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
134
135
# File 'lib/authentik/api/models/invitation_request.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  true
end