Class: Authentik::Api::InvitationStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::InvitationStageRequest
- Defined in:
- lib/authentik/api/models/invitation_stage_request.rb
Overview
InvitationStage Serializer
Instance Attribute Summary collapse
-
#continue_flow_without_invitation ⇒ Object
If this flag is set, this Stage will jump to the next Stage when no Invitation is given.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InvitationStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InvitationStageRequest
Initializes the object
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 52 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::InvitationStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::InvitationStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'continue_flow_without_invitation') self.continue_flow_without_invitation = attributes[:'continue_flow_without_invitation'] end end |
Instance Attribute Details
#continue_flow_without_invitation ⇒ Object
If this flag is set, this Stage will jump to the next Stage when no Invitation is given. By default this Stage will cancel the Flow when no invitation is given.
16 17 18 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 16 def continue_flow_without_invitation @continue_flow_without_invitation end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 13 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
27 28 29 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 27 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
32 33 34 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 32 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
19 20 21 22 23 24 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 19 def self.attribute_map { :'name' => :'name', :'continue_flow_without_invitation' => :'continue_flow_without_invitation' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 140 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
45 46 47 48 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 45 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 37 def self.openapi_types { :'name' => :'String', :'continue_flow_without_invitation' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 118 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && continue_flow_without_invitation == o.continue_flow_without_invitation end |
#eql?(o) ⇒ Boolean
127 128 129 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 127 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
133 134 135 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 133 def hash [name, continue_flow_without_invitation].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 79 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 162 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
95 96 97 98 99 100 |
# File 'lib/authentik/api/models/invitation_stage_request.rb', line 95 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 true end |