Class: Authentik::Api::KubernetesServiceConnection

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/kubernetes_service_connection.rb

Overview

KubernetesServiceConnection Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KubernetesServiceConnection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::KubernetesServiceConnection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::KubernetesServiceConnection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'local')
    self.local = attributes[:'local']
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'kubeconfig')
    if (value = attributes[:'kubeconfig']).is_a?(Hash)
      self.kubeconfig = value
    end
  end

  if attributes.key?(:'verify_ssl')
    self.verify_ssl = attributes[:'verify_ssl']
  end
end

Instance Attribute Details

#componentObject

Returns the value of attribute component.



20
21
22
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 20

def component
  @component
end

#kubeconfigObject

Paste your kubeconfig here. authentik will automatically use the currently selected context.



32
33
34
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 32

def kubeconfig
  @kubeconfig
end

#localObject

If enabled, use the local connection. Required Docker socket/Kubernetes Integration



18
19
20
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 18

def local
  @local
end

#meta_model_nameObject

Return internal model name



29
30
31
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 29

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 15

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 13

def pk
  @pk
end

#verbose_nameObject

Return object’s verbose_name



23
24
25
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 23

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



26
27
28
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 26

def verbose_name_plural
  @verbose_name_plural
end

#verify_sslObject

Verify SSL Certificates of the Kubernetes API endpoint



35
36
37
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 35

def verify_ssl
  @verify_ssl
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 38

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'local' => :'local',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'kubeconfig' => :'kubeconfig',
    :'verify_ssl' => :'verify_ssl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 286

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 63

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'local' => :'Boolean',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'kubeconfig' => :'Hash<String, Object>',
    :'verify_ssl' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      local == o.local &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      kubeconfig == o.kubeconfig &&
      verify_ssl == o.verify_ssl
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


273
274
275
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 273

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



279
280
281
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 279

def hash
  [pk, name, local, component, verbose_name, verbose_name_plural, meta_model_name, kubeconfig, verify_ssl].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 152

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 308

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
193
# File 'lib/authentik/api/models/kubernetes_service_connection.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  true
end