Class: Authentik::Api::LDAPProvider

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/ldap_provider.rb

Overview

LDAPProvider Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LDAPProvider

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/authentik/api/models/ldap_provider.rb', line 178

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::LDAPProvider` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::LDAPProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'authorization_flow')
    self.authorization_flow = attributes[:'authorization_flow']
  else
    self.authorization_flow = nil
  end

  if attributes.key?(:'invalidation_flow')
    self.invalidation_flow = attributes[:'invalidation_flow']
  else
    self.invalidation_flow = nil
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'assigned_application_slug')
    self.assigned_application_slug = attributes[:'assigned_application_slug']
  else
    self.assigned_application_slug = nil
  end

  if attributes.key?(:'assigned_application_name')
    self.assigned_application_name = attributes[:'assigned_application_name']
  else
    self.assigned_application_name = nil
  end

  if attributes.key?(:'assigned_backchannel_application_slug')
    self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug']
  else
    self.assigned_backchannel_application_slug = nil
  end

  if attributes.key?(:'assigned_backchannel_application_name')
    self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name']
  else
    self.assigned_backchannel_application_name = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'base_dn')
    self.base_dn = attributes[:'base_dn']
  end

  if attributes.key?(:'certificate')
    self.certificate = attributes[:'certificate']
  end

  if attributes.key?(:'tls_server_name')
    self.tls_server_name = attributes[:'tls_server_name']
  end

  if attributes.key?(:'uid_start_number')
    self.uid_start_number = attributes[:'uid_start_number']
  end

  if attributes.key?(:'gid_start_number')
    self.gid_start_number = attributes[:'gid_start_number']
  end

  if attributes.key?(:'outpost_set')
    if (value = attributes[:'outpost_set']).is_a?(Array)
      self.outpost_set = value
    end
  else
    self.outpost_set = nil
  end

  if attributes.key?(:'search_mode')
    self.search_mode = attributes[:'search_mode']
  end

  if attributes.key?(:'bind_mode')
    self.bind_mode = attributes[:'bind_mode']
  end

  if attributes.key?(:'mfa_support')
    self.mfa_support = attributes[:'mfa_support']
  end
end

Instance Attribute Details

#assigned_application_nameObject

Application’s display Name.



35
36
37
# File 'lib/authentik/api/models/ldap_provider.rb', line 35

def assigned_application_name
  @assigned_application_name
end

#assigned_application_slugObject

Internal application name, used in URLs.



32
33
34
# File 'lib/authentik/api/models/ldap_provider.rb', line 32

def assigned_application_slug
  @assigned_application_slug
end

#assigned_backchannel_application_nameObject

Application’s display Name.



41
42
43
# File 'lib/authentik/api/models/ldap_provider.rb', line 41

def assigned_backchannel_application_name
  @assigned_backchannel_application_name
end

#assigned_backchannel_application_slugObject

Internal application name, used in URLs.



38
39
40
# File 'lib/authentik/api/models/ldap_provider.rb', line 38

def assigned_backchannel_application_slug
  @assigned_backchannel_application_slug
end

#authentication_flowObject

Flow used for authentication when the associated application is accessed by an un-authenticated user.



18
19
20
# File 'lib/authentik/api/models/ldap_provider.rb', line 18

def authentication_flow
  @authentication_flow
end

#authorization_flowObject

Flow used when authorizing this provider.



21
22
23
# File 'lib/authentik/api/models/ldap_provider.rb', line 21

def authorization_flow
  @authorization_flow
end

#base_dnObject

DN under which objects are accessible.



53
54
55
# File 'lib/authentik/api/models/ldap_provider.rb', line 53

def base_dn
  @base_dn
end

#bind_modeObject

Returns the value of attribute bind_mode.



69
70
71
# File 'lib/authentik/api/models/ldap_provider.rb', line 69

def bind_mode
  @bind_mode
end

#certificateObject

Returns the value of attribute certificate.



55
56
57
# File 'lib/authentik/api/models/ldap_provider.rb', line 55

def certificate
  @certificate
end

#componentObject

Get object component so that we know how to edit the object



29
30
31
# File 'lib/authentik/api/models/ldap_provider.rb', line 29

def component
  @component
end

#gid_start_numberObject

The start for gidNumbers, this number is added to a number generated from the group.pk to make sure that the numbers aren’t too low for POSIX groups. Default is 4000 to ensure that we don’t collide with local groups or users primary groups gidNumber



63
64
65
# File 'lib/authentik/api/models/ldap_provider.rb', line 63

def gid_start_number
  @gid_start_number
end

#invalidation_flowObject

Flow used ending the session from a provider.



24
25
26
# File 'lib/authentik/api/models/ldap_provider.rb', line 24

def invalidation_flow
  @invalidation_flow
end

#meta_model_nameObject

Return internal model name



50
51
52
# File 'lib/authentik/api/models/ldap_provider.rb', line 50

def meta_model_name
  @meta_model_name
end

#mfa_supportObject

When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon.



72
73
74
# File 'lib/authentik/api/models/ldap_provider.rb', line 72

def mfa_support
  @mfa_support
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/ldap_provider.rb', line 15

def name
  @name
end

#outpost_setObject

Returns the value of attribute outpost_set.



65
66
67
# File 'lib/authentik/api/models/ldap_provider.rb', line 65

def outpost_set
  @outpost_set
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/ldap_provider.rb', line 13

def pk
  @pk
end

#property_mappingsObject

Returns the value of attribute property_mappings.



26
27
28
# File 'lib/authentik/api/models/ldap_provider.rb', line 26

def property_mappings
  @property_mappings
end

#search_modeObject

Returns the value of attribute search_mode.



67
68
69
# File 'lib/authentik/api/models/ldap_provider.rb', line 67

def search_mode
  @search_mode
end

#tls_server_nameObject

Returns the value of attribute tls_server_name.



57
58
59
# File 'lib/authentik/api/models/ldap_provider.rb', line 57

def tls_server_name
  @tls_server_name
end

#uid_start_numberObject

The start for uidNumbers, this number is added to the user.pk to make sure that the numbers aren’t too low for POSIX users. Default is 2000 to ensure that we don’t collide with local users uidNumber



60
61
62
# File 'lib/authentik/api/models/ldap_provider.rb', line 60

def uid_start_number
  @uid_start_number
end

#verbose_nameObject

Return object’s verbose_name



44
45
46
# File 'lib/authentik/api/models/ldap_provider.rb', line 44

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



47
48
49
# File 'lib/authentik/api/models/ldap_provider.rb', line 47

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



126
127
128
# File 'lib/authentik/api/models/ldap_provider.rb', line 126

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



131
132
133
# File 'lib/authentik/api/models/ldap_provider.rb', line 131

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/authentik/api/models/ldap_provider.rb', line 97

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'authentication_flow' => :'authentication_flow',
    :'authorization_flow' => :'authorization_flow',
    :'invalidation_flow' => :'invalidation_flow',
    :'property_mappings' => :'property_mappings',
    :'component' => :'component',
    :'assigned_application_slug' => :'assigned_application_slug',
    :'assigned_application_name' => :'assigned_application_name',
    :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug',
    :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'base_dn' => :'base_dn',
    :'certificate' => :'certificate',
    :'tls_server_name' => :'tls_server_name',
    :'uid_start_number' => :'uid_start_number',
    :'gid_start_number' => :'gid_start_number',
    :'outpost_set' => :'outpost_set',
    :'search_mode' => :'search_mode',
    :'bind_mode' => :'bind_mode',
    :'mfa_support' => :'mfa_support'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/authentik/api/models/ldap_provider.rb', line 566

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



165
166
167
168
169
170
171
172
173
174
# File 'lib/authentik/api/models/ldap_provider.rb', line 165

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
    :'assigned_application_slug',
    :'assigned_application_name',
    :'assigned_backchannel_application_slug',
    :'assigned_backchannel_application_name',
    :'certificate',
  ])
end

.openapi_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/authentik/api/models/ldap_provider.rb', line 136

def self.openapi_types
  {
    :'pk' => :'Integer',
    :'name' => :'String',
    :'authentication_flow' => :'String',
    :'authorization_flow' => :'String',
    :'invalidation_flow' => :'String',
    :'property_mappings' => :'Array<String>',
    :'component' => :'String',
    :'assigned_application_slug' => :'String',
    :'assigned_application_name' => :'String',
    :'assigned_backchannel_application_slug' => :'String',
    :'assigned_backchannel_application_name' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'base_dn' => :'String',
    :'certificate' => :'String',
    :'tls_server_name' => :'String',
    :'uid_start_number' => :'Integer',
    :'gid_start_number' => :'Integer',
    :'outpost_set' => :'Array<String>',
    :'search_mode' => :'LDAPAPIAccessMode',
    :'bind_mode' => :'LDAPAPIAccessMode',
    :'mfa_support' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'lib/authentik/api/models/ldap_provider.rb', line 523

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      authentication_flow == o.authentication_flow &&
      authorization_flow == o.authorization_flow &&
      invalidation_flow == o.invalidation_flow &&
      property_mappings == o.property_mappings &&
      component == o.component &&
      assigned_application_slug == o.assigned_application_slug &&
      assigned_application_name == o.assigned_application_name &&
      assigned_backchannel_application_slug == o.assigned_backchannel_application_slug &&
      assigned_backchannel_application_name == o.assigned_backchannel_application_name &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      base_dn == o.base_dn &&
      certificate == o.certificate &&
      tls_server_name == o.tls_server_name &&
      uid_start_number == o.uid_start_number &&
      gid_start_number == o.gid_start_number &&
      outpost_set == o.outpost_set &&
      search_mode == o.search_mode &&
      bind_mode == o.bind_mode &&
      mfa_support == o.mfa_support
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


553
554
555
# File 'lib/authentik/api/models/ldap_provider.rb', line 553

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



559
560
561
# File 'lib/authentik/api/models/ldap_provider.rb', line 559

def hash
  [pk, name, authentication_flow, authorization_flow, invalidation_flow, property_mappings, component, assigned_application_slug, assigned_application_name, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, meta_model_name, base_dn, certificate, tls_server_name, uid_start_number, gid_start_number, outpost_set, search_mode, bind_mode, mfa_support].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/authentik/api/models/ldap_provider.rb', line 317

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @authorization_flow.nil?
    invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.')
  end

  if @invalidation_flow.nil?
    invalid_properties.push('invalid value for "invalidation_flow", invalidation_flow cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if !@uid_start_number.nil? && @uid_start_number > 2147483647
    invalid_properties.push('invalid value for "uid_start_number", must be smaller than or equal to 2147483647.')
  end

  if !@uid_start_number.nil? && @uid_start_number < -2147483648
    invalid_properties.push('invalid value for "uid_start_number", must be greater than or equal to -2147483648.')
  end

  if !@gid_start_number.nil? && @gid_start_number > 2147483647
    invalid_properties.push('invalid value for "gid_start_number", must be smaller than or equal to 2147483647.')
  end

  if !@gid_start_number.nil? && @gid_start_number < -2147483648
    invalid_properties.push('invalid value for "gid_start_number", must be greater than or equal to -2147483648.')
  end

  if @outpost_set.nil?
    invalid_properties.push('invalid value for "outpost_set", outpost_set cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/authentik/api/models/ldap_provider.rb', line 588

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/authentik/api/models/ldap_provider.rb', line 377

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @authorization_flow.nil?
  return false if @invalidation_flow.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if !@uid_start_number.nil? && @uid_start_number > 2147483647
  return false if !@uid_start_number.nil? && @uid_start_number < -2147483648
  return false if !@gid_start_number.nil? && @gid_start_number > 2147483647
  return false if !@gid_start_number.nil? && @gid_start_number < -2147483648
  return false if @outpost_set.nil?
  true
end