Class: Authentik::Api::LDAPSourcePropertyMapping
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::LDAPSourcePropertyMapping
- Defined in:
- lib/authentik/api/models/ldap_source_property_mapping.rb
Overview
LDAP PropertyMapping Serializer
Instance Attribute Summary collapse
-
#component ⇒ Object
Get object’s component so that we know how to edit the object.
-
#expression ⇒ Object
Returns the value of attribute expression.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LDAPSourcePropertyMapping
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LDAPSourcePropertyMapping
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::LDAPSourcePropertyMapping` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::LDAPSourcePropertyMapping`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'managed') self.managed = attributes[:'managed'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'expression') self.expression = attributes[:'expression'] else self.expression = nil end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end end |
Instance Attribute Details
#component ⇒ Object
Get object’s component so that we know how to edit the object
23 24 25 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 23 def component @component end |
#expression ⇒ Object
Returns the value of attribute expression.
20 21 22 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 20 def expression @expression end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
16 17 18 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 16 def managed @managed end |
#meta_model_name ⇒ Object
Return internal model name
32 33 34 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 32 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 18 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 13 def pk @pk end |
#verbose_name ⇒ Object
Return object’s verbose_name
26 27 28 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 26 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
29 30 31 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 29 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 35 def self.attribute_map { :'pk' => :'pk', :'managed' => :'managed', :'name' => :'name', :'expression' => :'expression', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 292 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 77 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 73 def self.openapi_nullable Set.new([ :'managed', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 59 def self.openapi_types { :'pk' => :'String', :'managed' => :'String', :'name' => :'String', :'expression' => :'String', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 264 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && managed == o.managed && name == o.name && expression == o.expression && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 285 def hash [pk, managed, name, expression, component, verbose_name, verbose_name_plural, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 144 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @expression.nil? invalid_properties.push('invalid value for "expression", expression cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/authentik/api/models/ldap_source_property_mapping.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @expression.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? true end |