Class: Authentik::Api::LicenseSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::LicenseSummary
- Defined in:
- lib/authentik/api/models/license_summary.rb
Overview
Serializer for license status
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#external_users ⇒ Object
Returns the value of attribute external_users.
-
#internal_users ⇒ Object
Returns the value of attribute internal_users.
-
#latest_valid ⇒ Object
Returns the value of attribute latest_valid.
-
#license_flags ⇒ Object
Returns the value of attribute license_flags.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LicenseSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LicenseSummary
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/authentik/api/models/license_summary.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::LicenseSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::LicenseSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'internal_users') self.internal_users = attributes[:'internal_users'] else self.internal_users = nil end if attributes.key?(:'external_users') self.external_users = attributes[:'external_users'] else self.external_users = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'latest_valid') self.latest_valid = attributes[:'latest_valid'] else self.latest_valid = nil end if attributes.key?(:'license_flags') if (value = attributes[:'license_flags']).is_a?(Array) self.license_flags = value end else self.license_flags = nil end end |
Instance Attribute Details
#external_users ⇒ Object
Returns the value of attribute external_users.
15 16 17 |
# File 'lib/authentik/api/models/license_summary.rb', line 15 def external_users @external_users end |
#internal_users ⇒ Object
Returns the value of attribute internal_users.
13 14 15 |
# File 'lib/authentik/api/models/license_summary.rb', line 13 def internal_users @internal_users end |
#latest_valid ⇒ Object
Returns the value of attribute latest_valid.
19 20 21 |
# File 'lib/authentik/api/models/license_summary.rb', line 19 def latest_valid @latest_valid end |
#license_flags ⇒ Object
Returns the value of attribute license_flags.
21 22 23 |
# File 'lib/authentik/api/models/license_summary.rb', line 21 def license_flags @license_flags end |
#status ⇒ Object
Returns the value of attribute status.
17 18 19 |
# File 'lib/authentik/api/models/license_summary.rb', line 17 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/authentik/api/models/license_summary.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/authentik/api/models/license_summary.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 |
# File 'lib/authentik/api/models/license_summary.rb', line 46 def self.attribute_map { :'internal_users' => :'internal_users', :'external_users' => :'external_users', :'status' => :'status', :'latest_valid' => :'latest_valid', :'license_flags' => :'license_flags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/authentik/api/models/license_summary.rb', line 249 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/authentik/api/models/license_summary.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 |
# File 'lib/authentik/api/models/license_summary.rb', line 67 def self.openapi_types { :'internal_users' => :'Integer', :'external_users' => :'Integer', :'status' => :'LicenseSummaryStatusEnum', :'latest_valid' => :'Time', :'license_flags' => :'Array<LicenseFlagsEnum>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 |
# File 'lib/authentik/api/models/license_summary.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && internal_users == o.internal_users && external_users == o.external_users && status == o.status && latest_valid == o.latest_valid && license_flags == o.license_flags end |
#eql?(o) ⇒ Boolean
236 237 238 |
# File 'lib/authentik/api/models/license_summary.rb', line 236 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/authentik/api/models/license_summary.rb', line 242 def hash [internal_users, external_users, status, latest_valid, license_flags].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/authentik/api/models/license_summary.rb', line 134 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @internal_users.nil? invalid_properties.push('invalid value for "internal_users", internal_users cannot be nil.') end if @external_users.nil? invalid_properties.push('invalid value for "external_users", external_users cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @latest_valid.nil? invalid_properties.push('invalid value for "latest_valid", latest_valid cannot be nil.') end if @license_flags.nil? invalid_properties.push('invalid value for "license_flags", license_flags cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/authentik/api/models/license_summary.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 167 168 169 170 |
# File 'lib/authentik/api/models/license_summary.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @internal_users.nil? return false if @external_users.nil? return false if @status.nil? return false if @latest_valid.nil? return false if @license_flags.nil? true end |