Class: Authentik::Api::LifecycleRule

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/lifecycle_rule.rb

Overview

Mixin to validate that a valid enterprise license exists before allowing to save the object

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LifecycleRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::LifecycleRule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::LifecycleRule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  else
    self.content_type = nil
  end

  if attributes.key?(:'obj_id')
    self.obj_id = attributes[:'obj_id']
  end

  if attributes.key?(:'interval')
    self.interval = attributes[:'interval']
  end

  if attributes.key?(:'grace_period')
    self.grace_period = attributes[:'grace_period']
  end

  if attributes.key?(:'reviewer_groups')
    if (value = attributes[:'reviewer_groups']).is_a?(Array)
      self.reviewer_groups = value
    end
  end

  if attributes.key?(:'reviewer_groups_obj')
    if (value = attributes[:'reviewer_groups_obj']).is_a?(Array)
      self.reviewer_groups_obj = value
    end
  else
    self.reviewer_groups_obj = nil
  end

  if attributes.key?(:'min_reviewers')
    self.min_reviewers = attributes[:'min_reviewers']
  end

  if attributes.key?(:'min_reviewers_is_per_group')
    self.min_reviewers_is_per_group = attributes[:'min_reviewers_is_per_group']
  end

  if attributes.key?(:'reviewers')
    if (value = attributes[:'reviewers']).is_a?(Array)
      self.reviewers = value
    end
  else
    self.reviewers = nil
  end

  if attributes.key?(:'reviewers_obj')
    if (value = attributes[:'reviewers_obj']).is_a?(Array)
      self.reviewers_obj = value
    end
  else
    self.reviewers_obj = nil
  end

  if attributes.key?(:'notification_transports')
    if (value = attributes[:'notification_transports']).is_a?(Array)
      self.notification_transports = value
    end
  end

  if attributes.key?(:'target_verbose')
    self.target_verbose = attributes[:'target_verbose']
  else
    self.target_verbose = nil
  end
end

Instance Attribute Details

#content_typeObject

Returns the value of attribute content_type.



17
18
19
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 17

def content_type
  @content_type
end

#grace_periodObject

Returns the value of attribute grace_period.



23
24
25
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 23

def grace_period
  @grace_period
end

#idObject

Returns the value of attribute id.



13
14
15
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 13

def id
  @id
end

#intervalObject

Returns the value of attribute interval.



21
22
23
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 21

def interval
  @interval
end

#min_reviewersObject

Returns the value of attribute min_reviewers.



29
30
31
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 29

def min_reviewers
  @min_reviewers
end

#min_reviewers_is_per_groupObject

Returns the value of attribute min_reviewers_is_per_group.



31
32
33
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 31

def min_reviewers_is_per_group
  @min_reviewers_is_per_group
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 15

def name
  @name
end

#notification_transportsObject

Select which transports should be used to notify the reviewers. If none are selected, the notification will only be shown in the authentik UI.



38
39
40
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 38

def notification_transports
  @notification_transports
end

#obj_idObject

Returns the value of attribute obj_id.



19
20
21
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 19

def obj_id
  @obj_id
end

#reviewer_groupsObject

Returns the value of attribute reviewer_groups.



25
26
27
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 25

def reviewer_groups
  @reviewer_groups
end

#reviewer_groups_objObject

Returns the value of attribute reviewer_groups_obj.



27
28
29
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 27

def reviewer_groups_obj
  @reviewer_groups_obj
end

#reviewersObject

Returns the value of attribute reviewers.



33
34
35
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 33

def reviewers
  @reviewers
end

#reviewers_objObject

Returns the value of attribute reviewers_obj.



35
36
37
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 35

def reviewers_obj
  @reviewers_obj
end

#target_verboseObject

Returns the value of attribute target_verbose.



40
41
42
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 40

def target_verbose
  @target_verbose
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'content_type' => :'content_type',
    :'obj_id' => :'object_id',
    :'interval' => :'interval',
    :'grace_period' => :'grace_period',
    :'reviewer_groups' => :'reviewer_groups',
    :'reviewer_groups_obj' => :'reviewer_groups_obj',
    :'min_reviewers' => :'min_reviewers',
    :'min_reviewers_is_per_group' => :'min_reviewers_is_per_group',
    :'reviewers' => :'reviewers',
    :'reviewers_obj' => :'reviewers_obj',
    :'notification_transports' => :'notification_transports',
    :'target_verbose' => :'target_verbose'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 402

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
119
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 115

def self.openapi_nullable
  Set.new([
    :'obj_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 95

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'content_type' => :'ContentTypeEnum',
    :'obj_id' => :'String',
    :'interval' => :'String',
    :'grace_period' => :'String',
    :'reviewer_groups' => :'Array<String>',
    :'reviewer_groups_obj' => :'Array<ReviewerGroup>',
    :'min_reviewers' => :'Integer',
    :'min_reviewers_is_per_group' => :'Boolean',
    :'reviewers' => :'Array<String>',
    :'reviewers_obj' => :'Array<ReviewerUser>',
    :'notification_transports' => :'Array<String>',
    :'target_verbose' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 368

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      content_type == o.content_type &&
      obj_id == o.obj_id &&
      interval == o.interval &&
      grace_period == o.grace_period &&
      reviewer_groups == o.reviewer_groups &&
      reviewer_groups_obj == o.reviewer_groups_obj &&
      min_reviewers == o.min_reviewers &&
      min_reviewers_is_per_group == o.min_reviewers_is_per_group &&
      reviewers == o.reviewers &&
      reviewers_obj == o.reviewers_obj &&
      notification_transports == o.notification_transports &&
      target_verbose == o.target_verbose
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


389
390
391
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 389

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



395
396
397
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 395

def hash
  [id, name, content_type, obj_id, interval, grace_period, reviewer_groups, reviewer_groups_obj, min_reviewers, min_reviewers_is_per_group, reviewers, reviewers_obj, notification_transports, target_verbose].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 220

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @content_type.nil?
    invalid_properties.push('invalid value for "content_type", content_type cannot be nil.')
  end

  if @reviewer_groups_obj.nil?
    invalid_properties.push('invalid value for "reviewer_groups_obj", reviewer_groups_obj cannot be nil.')
  end

  if !@min_reviewers.nil? && @min_reviewers > 32767
    invalid_properties.push('invalid value for "min_reviewers", must be smaller than or equal to 32767.')
  end

  if !@min_reviewers.nil? && @min_reviewers < 0
    invalid_properties.push('invalid value for "min_reviewers", must be greater than or equal to 0.')
  end

  if @reviewers.nil?
    invalid_properties.push('invalid value for "reviewers", reviewers cannot be nil.')
  end

  if @reviewers_obj.nil?
    invalid_properties.push('invalid value for "reviewers_obj", reviewers_obj cannot be nil.')
  end

  if @target_verbose.nil?
    invalid_properties.push('invalid value for "target_verbose", target_verbose cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 424

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/authentik/api/models/lifecycle_rule.rb', line 264

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @content_type.nil?
  return false if @reviewer_groups_obj.nil?
  return false if !@min_reviewers.nil? && @min_reviewers > 32767
  return false if !@min_reviewers.nil? && @min_reviewers < 0
  return false if @reviewers.nil?
  return false if @reviewers_obj.nil?
  return false if @target_verbose.nil?
  true
end