Class: Authentik::Api::LogoutURL

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/logout_url.rb

Overview

Data for a single logout URL

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LogoutURL

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/authentik/api/models/logout_url.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::LogoutURL` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::LogoutURL`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'provider_name')
    self.provider_name = attributes[:'provider_name']
  end

  if attributes.key?(:'binding')
    self.binding = attributes[:'binding']
  end

  if attributes.key?(:'saml_request')
    self.saml_request = attributes[:'saml_request']
  end

  if attributes.key?(:'saml_response')
    self.saml_response = attributes[:'saml_response']
  end

  if attributes.key?(:'saml_relay_state')
    self.saml_relay_state = attributes[:'saml_relay_state']
  end
end

Instance Attribute Details

#bindingObject

Returns the value of attribute binding.



17
18
19
# File 'lib/authentik/api/models/logout_url.rb', line 17

def binding
  @binding
end

#provider_nameObject

Returns the value of attribute provider_name.



15
16
17
# File 'lib/authentik/api/models/logout_url.rb', line 15

def provider_name
  @provider_name
end

#saml_relay_stateObject

Returns the value of attribute saml_relay_state.



23
24
25
# File 'lib/authentik/api/models/logout_url.rb', line 23

def saml_relay_state
  @saml_relay_state
end

#saml_requestObject

Returns the value of attribute saml_request.



19
20
21
# File 'lib/authentik/api/models/logout_url.rb', line 19

def saml_request
  @saml_request
end

#saml_responseObject

Returns the value of attribute saml_response.



21
22
23
# File 'lib/authentik/api/models/logout_url.rb', line 21

def saml_response
  @saml_response
end

#urlObject

Returns the value of attribute url.



13
14
15
# File 'lib/authentik/api/models/logout_url.rb', line 13

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/authentik/api/models/logout_url.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/authentik/api/models/logout_url.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
35
# File 'lib/authentik/api/models/logout_url.rb', line 26

def self.attribute_map
  {
    :'url' => :'url',
    :'provider_name' => :'provider_name',
    :'binding' => :'binding',
    :'saml_request' => :'saml_request',
    :'saml_response' => :'saml_response',
    :'saml_relay_state' => :'saml_relay_state'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/authentik/api/models/logout_url.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
64
65
66
67
68
# File 'lib/authentik/api/models/logout_url.rb', line 60

def self.openapi_nullable
  Set.new([
    :'provider_name',
    :'binding',
    :'saml_request',
    :'saml_response',
    :'saml_relay_state'
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
# File 'lib/authentik/api/models/logout_url.rb', line 48

def self.openapi_types
  {
    :'url' => :'String',
    :'provider_name' => :'String',
    :'binding' => :'String',
    :'saml_request' => :'String',
    :'saml_response' => :'String',
    :'saml_relay_state' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



145
146
147
148
149
150
151
152
153
154
# File 'lib/authentik/api/models/logout_url.rb', line 145

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url == o.url &&
      provider_name == o.provider_name &&
      binding == o.binding &&
      saml_request == o.saml_request &&
      saml_response == o.saml_response &&
      saml_relay_state == o.saml_relay_state
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/authentik/api/models/logout_url.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/authentik/api/models/logout_url.rb', line 164

def hash
  [url, provider_name, binding, saml_request, saml_response, saml_relay_state].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



115
116
117
118
119
120
121
122
123
# File 'lib/authentik/api/models/logout_url.rb', line 115

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/authentik/api/models/logout_url.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
131
# File 'lib/authentik/api/models/logout_url.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @url.nil?
  true
end