Class: Authentik::Api::MDMConfigResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::MDMConfigResponse
- Defined in:
- lib/authentik/api/models/mdm_config_response.rb
Overview
Base serializer class which doesn’t implement create/update methods
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
-
#filename ⇒ Object
Returns the value of attribute filename.
-
#mime_type ⇒ Object
Returns the value of attribute mime_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MDMConfigResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MDMConfigResponse
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 55 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::MDMConfigResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::MDMConfigResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'config') self.config = attributes[:'config'] else self.config = nil end if attributes.key?(:'mime_type') self.mime_type = attributes[:'mime_type'] else self.mime_type = nil end if attributes.key?(:'filename') self.filename = attributes[:'filename'] else self.filename = nil end end |
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config.
13 14 15 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 13 def config @config end |
#filename ⇒ Object
Returns the value of attribute filename.
17 18 19 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 17 def filename @filename end |
#mime_type ⇒ Object
Returns the value of attribute mime_type.
15 16 17 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 15 def mime_type @mime_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
29 30 31 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 29 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
34 35 36 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 34 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 20 def self.attribute_map { :'config' => :'config', :'mime_type' => :'mime_type', :'filename' => :'filename' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 51 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 48 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 39 def self.openapi_types { :'config' => :'String', :'mime_type' => :'String', :'filename' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && config == o.config && mime_type == o.mime_type && filename == o.filename end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 166 def hash [config, mime_type, filename].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 90 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @config.nil? invalid_properties.push('invalid value for "config", config cannot be nil.') end if @mime_type.nil? invalid_properties.push('invalid value for "mime_type", mime_type cannot be nil.') end if @filename.nil? invalid_properties.push('invalid value for "filename", filename cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
110 111 112 113 114 115 116 |
# File 'lib/authentik/api/models/mdm_config_response.rb', line 110 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @config.nil? return false if @mime_type.nil? return false if @filename.nil? true end |