Class: Authentik::Api::ManagedApi

Inherits:
Object
  • Object
show all
Defined in:
lib/authentik/api/api/managed_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ManagedApi

Returns a new instance of ManagedApi.



13
14
15
# File 'lib/authentik/api/api/managed_api.rb', line 13

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



11
12
13
# File 'lib/authentik/api/api/managed_api.rb', line 11

def api_client
  @api_client
end

Instance Method Details

#managed_blueprints_apply_create(instance_uuid, opts = {}) ⇒ BlueprintInstance

Apply a blueprint

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



20
21
22
23
# File 'lib/authentik/api/api/managed_api.rb', line 20

def managed_blueprints_apply_create(instance_uuid, opts = {})
  data, _status_code, _headers = managed_blueprints_apply_create_with_http_info(instance_uuid, opts)
  data
end

#managed_blueprints_apply_create_with_http_info(instance_uuid, opts = {}) ⇒ Array<(BlueprintInstance, Integer, Hash)>

Apply a blueprint

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BlueprintInstance, Integer, Hash)>)

    BlueprintInstance data, response status code and response headers



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/authentik/api/api/managed_api.rb', line 29

def managed_blueprints_apply_create_with_http_info(instance_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_apply_create ...'
  end
  # verify the required parameter 'instance_uuid' is set
  if @api_client.config.client_side_validation && instance_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'instance_uuid' when calling ManagedApi.managed_blueprints_apply_create"
  end
  # resource path
  local_var_path = '/managed/blueprints/{instance_uuid}/apply/'.sub('{instance_uuid}', CGI.escape(instance_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BlueprintInstance'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_apply_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_apply_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#managed_blueprints_available_list(opts = {}) ⇒ Array<BlueprintFile>

Get blueprints

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



80
81
82
83
# File 'lib/authentik/api/api/managed_api.rb', line 80

def managed_blueprints_available_list(opts = {})
  data, _status_code, _headers = managed_blueprints_available_list_with_http_info(opts)
  data
end

#managed_blueprints_available_list_with_http_info(opts = {}) ⇒ Array<(Array<BlueprintFile>, Integer, Hash)>

Get blueprints

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<BlueprintFile>, Integer, Hash)>)

    Array<BlueprintFile> data, response status code and response headers



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/authentik/api/api/managed_api.rb', line 88

def managed_blueprints_available_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_available_list ...'
  end
  # resource path
  local_var_path = '/managed/blueprints/available/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<BlueprintFile>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_available_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_available_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#managed_blueprints_create(blueprint_instance_request, opts = {}) ⇒ BlueprintInstance

Blueprint instances

Parameters:

Returns:



136
137
138
139
# File 'lib/authentik/api/api/managed_api.rb', line 136

def managed_blueprints_create(blueprint_instance_request, opts = {})
  data, _status_code, _headers = managed_blueprints_create_with_http_info(blueprint_instance_request, opts)
  data
end

#managed_blueprints_create_with_http_info(blueprint_instance_request, opts = {}) ⇒ Array<(BlueprintInstance, Integer, Hash)>

Blueprint instances

Parameters:

Returns:

  • (Array<(BlueprintInstance, Integer, Hash)>)

    BlueprintInstance data, response status code and response headers



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/authentik/api/api/managed_api.rb', line 145

def managed_blueprints_create_with_http_info(blueprint_instance_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_create ...'
  end
  # verify the required parameter 'blueprint_instance_request' is set
  if @api_client.config.client_side_validation && blueprint_instance_request.nil?
    fail ArgumentError, "Missing the required parameter 'blueprint_instance_request' when calling ManagedApi.managed_blueprints_create"
  end
  # resource path
  local_var_path = '/managed/blueprints/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(blueprint_instance_request)

  # return_type
  return_type = opts[:debug_return_type] || 'BlueprintInstance'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#managed_blueprints_destroy(instance_uuid, opts = {}) ⇒ nil

Blueprint instances

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


202
203
204
205
# File 'lib/authentik/api/api/managed_api.rb', line 202

def managed_blueprints_destroy(instance_uuid, opts = {})
  managed_blueprints_destroy_with_http_info(instance_uuid, opts)
  nil
end

#managed_blueprints_destroy_with_http_info(instance_uuid, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Blueprint instances

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/authentik/api/api/managed_api.rb', line 211

def managed_blueprints_destroy_with_http_info(instance_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_destroy ...'
  end
  # verify the required parameter 'instance_uuid' is set
  if @api_client.config.client_side_validation && instance_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'instance_uuid' when calling ManagedApi.managed_blueprints_destroy"
  end
  # resource path
  local_var_path = '/managed/blueprints/{instance_uuid}/'.sub('{instance_uuid}', CGI.escape(instance_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_destroy",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#managed_blueprints_list(opts = {}) ⇒ PaginatedBlueprintInstanceList

Blueprint instances

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :name (String)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :path (String)
  • :search (String)

    A search term.

Returns:



268
269
270
271
# File 'lib/authentik/api/api/managed_api.rb', line 268

def managed_blueprints_list(opts = {})
  data, _status_code, _headers = managed_blueprints_list_with_http_info(opts)
  data
end

#managed_blueprints_list_with_http_info(opts = {}) ⇒ Array<(PaginatedBlueprintInstanceList, Integer, Hash)>

Blueprint instances

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :name (String)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :path (String)
  • :search (String)

    A search term.

Returns:



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/authentik/api/api/managed_api.rb', line 282

def managed_blueprints_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_list ...'
  end
  # resource path
  local_var_path = '/managed/blueprints/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
  query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'path'] = opts[:'path'] if !opts[:'path'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedBlueprintInstanceList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#managed_blueprints_partial_update(instance_uuid, opts = {}) ⇒ BlueprintInstance

Blueprint instances

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



337
338
339
340
# File 'lib/authentik/api/api/managed_api.rb', line 337

def managed_blueprints_partial_update(instance_uuid, opts = {})
  data, _status_code, _headers = managed_blueprints_partial_update_with_http_info(instance_uuid, opts)
  data
end

#managed_blueprints_partial_update_with_http_info(instance_uuid, opts = {}) ⇒ Array<(BlueprintInstance, Integer, Hash)>

Blueprint instances

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(BlueprintInstance, Integer, Hash)>)

    BlueprintInstance data, response status code and response headers



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/authentik/api/api/managed_api.rb', line 347

def managed_blueprints_partial_update_with_http_info(instance_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_partial_update ...'
  end
  # verify the required parameter 'instance_uuid' is set
  if @api_client.config.client_side_validation && instance_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'instance_uuid' when calling ManagedApi.managed_blueprints_partial_update"
  end
  # resource path
  local_var_path = '/managed/blueprints/{instance_uuid}/'.sub('{instance_uuid}', CGI.escape(instance_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_blueprint_instance_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'BlueprintInstance'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_partial_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#managed_blueprints_retrieve(instance_uuid, opts = {}) ⇒ BlueprintInstance

Blueprint instances

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



404
405
406
407
# File 'lib/authentik/api/api/managed_api.rb', line 404

def managed_blueprints_retrieve(instance_uuid, opts = {})
  data, _status_code, _headers = managed_blueprints_retrieve_with_http_info(instance_uuid, opts)
  data
end

#managed_blueprints_retrieve_with_http_info(instance_uuid, opts = {}) ⇒ Array<(BlueprintInstance, Integer, Hash)>

Blueprint instances

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BlueprintInstance, Integer, Hash)>)

    BlueprintInstance data, response status code and response headers



413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/authentik/api/api/managed_api.rb', line 413

def managed_blueprints_retrieve_with_http_info(instance_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_retrieve ...'
  end
  # verify the required parameter 'instance_uuid' is set
  if @api_client.config.client_side_validation && instance_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'instance_uuid' when calling ManagedApi.managed_blueprints_retrieve"
  end
  # resource path
  local_var_path = '/managed/blueprints/{instance_uuid}/'.sub('{instance_uuid}', CGI.escape(instance_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BlueprintInstance'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#managed_blueprints_update(instance_uuid, blueprint_instance_request, opts = {}) ⇒ BlueprintInstance

Blueprint instances

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • blueprint_instance_request (BlueprintInstanceRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



466
467
468
469
# File 'lib/authentik/api/api/managed_api.rb', line 466

def managed_blueprints_update(instance_uuid, blueprint_instance_request, opts = {})
  data, _status_code, _headers = managed_blueprints_update_with_http_info(instance_uuid, blueprint_instance_request, opts)
  data
end

#managed_blueprints_update_with_http_info(instance_uuid, blueprint_instance_request, opts = {}) ⇒ Array<(BlueprintInstance, Integer, Hash)>

Blueprint instances

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • blueprint_instance_request (BlueprintInstanceRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BlueprintInstance, Integer, Hash)>)

    BlueprintInstance data, response status code and response headers



476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/authentik/api/api/managed_api.rb', line 476

def managed_blueprints_update_with_http_info(instance_uuid, blueprint_instance_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_update ...'
  end
  # verify the required parameter 'instance_uuid' is set
  if @api_client.config.client_side_validation && instance_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'instance_uuid' when calling ManagedApi.managed_blueprints_update"
  end
  # verify the required parameter 'blueprint_instance_request' is set
  if @api_client.config.client_side_validation && blueprint_instance_request.nil?
    fail ArgumentError, "Missing the required parameter 'blueprint_instance_request' when calling ManagedApi.managed_blueprints_update"
  end
  # resource path
  local_var_path = '/managed/blueprints/{instance_uuid}/'.sub('{instance_uuid}', CGI.escape(instance_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(blueprint_instance_request)

  # return_type
  return_type = opts[:debug_return_type] || 'BlueprintInstance'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#managed_blueprints_used_by_list(instance_uuid, opts = {}) ⇒ Array<UsedBy>

Get a list of all objects that use this object

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



537
538
539
540
# File 'lib/authentik/api/api/managed_api.rb', line 537

def managed_blueprints_used_by_list(instance_uuid, opts = {})
  data, _status_code, _headers = managed_blueprints_used_by_list_with_http_info(instance_uuid, opts)
  data
end

#managed_blueprints_used_by_list_with_http_info(instance_uuid, opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>

Get a list of all objects that use this object

Parameters:

  • instance_uuid (String)

    A UUID string identifying this Blueprint Instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<UsedBy>, Integer, Hash)>)

    Array<UsedBy> data, response status code and response headers



546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/authentik/api/api/managed_api.rb', line 546

def managed_blueprints_used_by_list_with_http_info(instance_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ManagedApi.managed_blueprints_used_by_list ...'
  end
  # verify the required parameter 'instance_uuid' is set
  if @api_client.config.client_side_validation && instance_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'instance_uuid' when calling ManagedApi.managed_blueprints_used_by_list"
  end
  # resource path
  local_var_path = '/managed/blueprints/{instance_uuid}/used_by/'.sub('{instance_uuid}', CGI.escape(instance_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<UsedBy>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"ManagedApi.managed_blueprints_used_by_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ManagedApi#managed_blueprints_used_by_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end