Class: Authentik::Api::MicrosoftEntraProviderRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::MicrosoftEntraProviderRequest
- Defined in:
- lib/authentik/api/models/microsoft_entra_provider_request.rb
Overview
MicrosoftEntraProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#client_secret ⇒ Object
Returns the value of attribute client_secret.
-
#dry_run ⇒ Object
When enabled, provider will not modify or create objects in the remote system.
-
#exclude_users_service_account ⇒ Object
Returns the value of attribute exclude_users_service_account.
-
#filter_group ⇒ Object
Returns the value of attribute filter_group.
-
#group_delete_action ⇒ Object
Returns the value of attribute group_delete_action.
-
#name ⇒ Object
Returns the value of attribute name.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#property_mappings_group ⇒ Object
Property mappings used for group creation/updating.
-
#sync_page_size ⇒ Object
Controls the number of objects synced in a single task.
-
#sync_page_timeout ⇒ Object
Timeout for synchronization of a single page.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
-
#user_delete_action ⇒ Object
Returns the value of attribute user_delete_action.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MicrosoftEntraProviderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MicrosoftEntraProviderRequest
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::MicrosoftEntraProviderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::MicrosoftEntraProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'property_mappings_group') if (value = attributes[:'property_mappings_group']).is_a?(Array) self.property_mappings_group = value end end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] else self.client_id = nil end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] else self.client_secret = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'exclude_users_service_account') self.exclude_users_service_account = attributes[:'exclude_users_service_account'] end if attributes.key?(:'filter_group') self.filter_group = attributes[:'filter_group'] end if attributes.key?(:'user_delete_action') self.user_delete_action = attributes[:'user_delete_action'] end if attributes.key?(:'group_delete_action') self.group_delete_action = attributes[:'group_delete_action'] end if attributes.key?(:'sync_page_size') self.sync_page_size = attributes[:'sync_page_size'] end if attributes.key?(:'sync_page_timeout') self.sync_page_timeout = attributes[:'sync_page_timeout'] end if attributes.key?(:'dry_run') self.dry_run = attributes[:'dry_run'] end end |
Instance Attribute Details
#client_id ⇒ Object
Returns the value of attribute client_id.
20 21 22 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 20 def client_id @client_id end |
#client_secret ⇒ Object
Returns the value of attribute client_secret.
22 23 24 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 22 def client_secret @client_secret end |
#dry_run ⇒ Object
When enabled, provider will not modify or create objects in the remote system.
41 42 43 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 41 def dry_run @dry_run end |
#exclude_users_service_account ⇒ Object
Returns the value of attribute exclude_users_service_account.
26 27 28 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 26 def exclude_users_service_account @exclude_users_service_account end |
#filter_group ⇒ Object
Returns the value of attribute filter_group.
28 29 30 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 28 def filter_group @filter_group end |
#group_delete_action ⇒ Object
Returns the value of attribute group_delete_action.
32 33 34 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 32 def group_delete_action @group_delete_action end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 13 def name @name end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
15 16 17 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 15 def property_mappings @property_mappings end |
#property_mappings_group ⇒ Object
Property mappings used for group creation/updating.
18 19 20 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 18 def property_mappings_group @property_mappings_group end |
#sync_page_size ⇒ Object
Controls the number of objects synced in a single task
35 36 37 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 35 def sync_page_size @sync_page_size end |
#sync_page_timeout ⇒ Object
Timeout for synchronization of a single page
38 39 40 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 38 def sync_page_timeout @sync_page_timeout end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
24 25 26 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 24 def tenant_id @tenant_id end |
#user_delete_action ⇒ Object
Returns the value of attribute user_delete_action.
30 31 32 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 30 def user_delete_action @user_delete_action end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
85 86 87 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
90 91 92 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 90 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 66 def self.attribute_map { :'name' => :'name', :'property_mappings' => :'property_mappings', :'property_mappings_group' => :'property_mappings_group', :'client_id' => :'client_id', :'client_secret' => :'client_secret', :'tenant_id' => :'tenant_id', :'exclude_users_service_account' => :'exclude_users_service_account', :'filter_group' => :'filter_group', :'user_delete_action' => :'user_delete_action', :'group_delete_action' => :'group_delete_action', :'sync_page_size' => :'sync_page_size', :'sync_page_timeout' => :'sync_page_timeout', :'dry_run' => :'dry_run' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 394 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 118 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 114 def self.openapi_nullable Set.new([ :'filter_group', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 95 def self.openapi_types { :'name' => :'String', :'property_mappings' => :'Array<String>', :'property_mappings_group' => :'Array<String>', :'client_id' => :'String', :'client_secret' => :'String', :'tenant_id' => :'String', :'exclude_users_service_account' => :'Boolean', :'filter_group' => :'String', :'user_delete_action' => :'OutgoingSyncDeleteAction', :'group_delete_action' => :'OutgoingSyncDeleteAction', :'sync_page_size' => :'Integer', :'sync_page_timeout' => :'String', :'dry_run' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 361 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && property_mappings == o.property_mappings && property_mappings_group == o.property_mappings_group && client_id == o.client_id && client_secret == o.client_secret && tenant_id == o.tenant_id && exclude_users_service_account == o.exclude_users_service_account && filter_group == o.filter_group && user_delete_action == o.user_delete_action && group_delete_action == o.group_delete_action && sync_page_size == o.sync_page_size && sync_page_timeout == o.sync_page_timeout && dry_run == o.dry_run end |
#eql?(o) ⇒ Boolean
381 382 383 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 381 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
387 388 389 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 387 def hash [name, property_mappings, property_mappings_group, client_id, client_secret, tenant_id, exclude_users_service_account, filter_group, user_delete_action, group_delete_action, sync_page_size, sync_page_timeout, dry_run].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 203 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @client_id.nil? invalid_properties.push('invalid value for "client_id", client_id cannot be nil.') end if @client_id.to_s.length < 1 invalid_properties.push('invalid value for "client_id", the character length must be greater than or equal to 1.') end if @client_secret.nil? invalid_properties.push('invalid value for "client_secret", client_secret cannot be nil.') end if @client_secret.to_s.length < 1 invalid_properties.push('invalid value for "client_secret", the character length must be greater than or equal to 1.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if @tenant_id.to_s.length < 1 invalid_properties.push('invalid value for "tenant_id", the character length must be greater than or equal to 1.') end if !@sync_page_size.nil? && @sync_page_size > 2147483647 invalid_properties.push('invalid value for "sync_page_size", must be smaller than or equal to 2147483647.') end if !@sync_page_size.nil? && @sync_page_size < 1 invalid_properties.push('invalid value for "sync_page_size", must be greater than or equal to 1.') end if !@sync_page_timeout.nil? && @sync_page_timeout.to_s.length < 1 invalid_properties.push('invalid value for "sync_page_timeout", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 416 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/authentik/api/models/microsoft_entra_provider_request.rb', line 255 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @client_id.nil? return false if @client_id.to_s.length < 1 return false if @client_secret.nil? return false if @client_secret.to_s.length < 1 return false if @tenant_id.nil? return false if @tenant_id.to_s.length < 1 return false if !@sync_page_size.nil? && @sync_page_size > 2147483647 return false if !@sync_page_size.nil? && @sync_page_size < 1 return false if !@sync_page_timeout.nil? && @sync_page_timeout.to_s.length < 1 true end |