Class: Authentik::Api::NativeLogoutChallenge

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/native_logout_challenge.rb

Overview

Challenge for native browser logout

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NativeLogoutChallenge

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::NativeLogoutChallenge` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::NativeLogoutChallenge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flow_info')
    self.flow_info = attributes[:'flow_info']
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = 'ak-provider-saml-native-logout'
  end

  if attributes.key?(:'response_errors')
    if (value = attributes[:'response_errors']).is_a?(Hash)
      self.response_errors = value
    end
  end

  if attributes.key?(:'provider_name')
    self.provider_name = attributes[:'provider_name']
  end

  if attributes.key?(:'is_complete')
    self.is_complete = attributes[:'is_complete']
  else
    self.is_complete = false
  end

  if attributes.key?(:'post_url')
    self.post_url = attributes[:'post_url']
  end

  if attributes.key?(:'redirect_url')
    self.redirect_url = attributes[:'redirect_url']
  end

  if attributes.key?(:'saml_binding')
    self.saml_binding = attributes[:'saml_binding']
  end

  if attributes.key?(:'saml_request')
    self.saml_request = attributes[:'saml_request']
  end

  if attributes.key?(:'saml_response')
    self.saml_response = attributes[:'saml_response']
  end

  if attributes.key?(:'saml_relay_state')
    self.saml_relay_state = attributes[:'saml_relay_state']
  end
end

Instance Attribute Details

#componentObject

Returns the value of attribute component.



15
16
17
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 15

def component
  @component
end

#flow_infoObject

Returns the value of attribute flow_info.



13
14
15
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 13

def flow_info
  @flow_info
end

#is_completeObject

Returns the value of attribute is_complete.



21
22
23
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 21

def is_complete
  @is_complete
end

#post_urlObject

Returns the value of attribute post_url.



23
24
25
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 23

def post_url
  @post_url
end

#provider_nameObject

Returns the value of attribute provider_name.



19
20
21
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 19

def provider_name
  @provider_name
end

#redirect_urlObject

Returns the value of attribute redirect_url.



25
26
27
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 25

def redirect_url
  @redirect_url
end

#response_errorsObject

Returns the value of attribute response_errors.



17
18
19
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 17

def response_errors
  @response_errors
end

#saml_bindingObject

Returns the value of attribute saml_binding.



27
28
29
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 27

def saml_binding
  @saml_binding
end

#saml_relay_stateObject

Returns the value of attribute saml_relay_state.



33
34
35
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 33

def saml_relay_state
  @saml_relay_state
end

#saml_requestObject

Returns the value of attribute saml_request.



29
30
31
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 29

def saml_request
  @saml_request
end

#saml_responseObject

Returns the value of attribute saml_response.



31
32
33
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 31

def saml_response
  @saml_response
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 58

def self.attribute_map
  {
    :'flow_info' => :'flow_info',
    :'component' => :'component',
    :'response_errors' => :'response_errors',
    :'provider_name' => :'provider_name',
    :'is_complete' => :'is_complete',
    :'post_url' => :'post_url',
    :'redirect_url' => :'redirect_url',
    :'saml_binding' => :'saml_binding',
    :'saml_request' => :'saml_request',
    :'saml_response' => :'saml_response',
    :'saml_relay_state' => :'saml_relay_state'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 85

def self.openapi_types
  {
    :'flow_info' => :'ContextualFlowInfo',
    :'component' => :'String',
    :'response_errors' => :'Hash<String, Array<ErrorDetail>>',
    :'provider_name' => :'String',
    :'is_complete' => :'Boolean',
    :'post_url' => :'String',
    :'redirect_url' => :'String',
    :'saml_binding' => :'SAMLBindingsEnum',
    :'saml_request' => :'String',
    :'saml_response' => :'String',
    :'saml_relay_state' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flow_info == o.flow_info &&
      component == o.component &&
      response_errors == o.response_errors &&
      provider_name == o.provider_name &&
      is_complete == o.is_complete &&
      post_url == o.post_url &&
      redirect_url == o.redirect_url &&
      saml_binding == o.saml_binding &&
      saml_request == o.saml_request &&
      saml_response == o.saml_response &&
      saml_relay_state == o.saml_relay_state
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 215

def hash
  [flow_info, component, response_errors, provider_name, is_complete, post_url, redirect_url, saml_binding, saml_request, saml_response, saml_relay_state].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end