Class: Authentik::Api::NetworkInterface

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/network_interface.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetworkInterface

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/authentik/api/models/network_interface.rb', line 58

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::NetworkInterface` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::NetworkInterface`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'hardware_address')
    self.hardware_address = attributes[:'hardware_address']
  else
    self.hardware_address = nil
  end

  if attributes.key?(:'ip_addresses')
    if (value = attributes[:'ip_addresses']).is_a?(Array)
      self.ip_addresses = value
    end
  end

  if attributes.key?(:'dns_servers')
    if (value = attributes[:'dns_servers']).is_a?(Array)
      self.dns_servers = value
    end
  end
end

Instance Attribute Details

#dns_serversObject

Returns the value of attribute dns_servers.



18
19
20
# File 'lib/authentik/api/models/network_interface.rb', line 18

def dns_servers
  @dns_servers
end

#hardware_addressObject

Returns the value of attribute hardware_address.



14
15
16
# File 'lib/authentik/api/models/network_interface.rb', line 14

def hardware_address
  @hardware_address
end

#ip_addressesObject

Returns the value of attribute ip_addresses.



16
17
18
# File 'lib/authentik/api/models/network_interface.rb', line 16

def ip_addresses
  @ip_addresses
end

#nameObject

Returns the value of attribute name.



12
13
14
# File 'lib/authentik/api/models/network_interface.rb', line 12

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



31
32
33
# File 'lib/authentik/api/models/network_interface.rb', line 31

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



36
37
38
# File 'lib/authentik/api/models/network_interface.rb', line 36

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
28
# File 'lib/authentik/api/models/network_interface.rb', line 21

def self.attribute_map
  {
    :'name' => :'name',
    :'hardware_address' => :'hardware_address',
    :'ip_addresses' => :'ip_addresses',
    :'dns_servers' => :'dns_servers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/authentik/api/models/network_interface.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
# File 'lib/authentik/api/models/network_interface.rb', line 51

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



41
42
43
44
45
46
47
48
# File 'lib/authentik/api/models/network_interface.rb', line 41

def self.openapi_types
  {
    :'name' => :'String',
    :'hardware_address' => :'String',
    :'ip_addresses' => :'Array<String>',
    :'dns_servers' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
# File 'lib/authentik/api/models/network_interface.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      hardware_address == o.hardware_address &&
      ip_addresses == o.ip_addresses &&
      dns_servers == o.dns_servers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/authentik/api/models/network_interface.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/authentik/api/models/network_interface.rb', line 161

def hash
  [name, hardware_address, ip_addresses, dns_servers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/authentik/api/models/network_interface.rb', line 99

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @hardware_address.nil?
    invalid_properties.push('invalid value for "hardware_address", hardware_address cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/authentik/api/models/network_interface.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



115
116
117
118
119
120
# File 'lib/authentik/api/models/network_interface.rb', line 115

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @hardware_address.nil?
  true
end