Class: Authentik::Api::NetworkRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/network_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetworkRequest

Initializes the object



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/authentik/api/models/network_request.rb', line 58

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::NetworkRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::NetworkRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  else
    self.hostname = nil
  end

  if attributes.key?(:'firewall_enabled')
    self.firewall_enabled = attributes[:'firewall_enabled']
  end

  if attributes.key?(:'interfaces')
    if (value = attributes[:'interfaces']).is_a?(Array)
      self.interfaces = value
    end
  else
    self.interfaces = nil
  end

  if attributes.key?(:'gateway')
    self.gateway = attributes[:'gateway']
  end
end

Instance Attribute Details

#firewall_enabled ⇒ Object

Returns the value of attribute firewall_enabled.



14
15
16
# File 'lib/authentik/api/models/network_request.rb', line 14

def firewall_enabled
  @firewall_enabled
end

#gateway ⇒ Object

Returns the value of attribute gateway.



18
19
20
# File 'lib/authentik/api/models/network_request.rb', line 18

def gateway
  @gateway
end

#hostname ⇒ Object

Returns the value of attribute hostname.



12
13
14
# File 'lib/authentik/api/models/network_request.rb', line 12

def hostname
  @hostname
end

#interfaces ⇒ Object

Returns the value of attribute interfaces.



16
17
18
# File 'lib/authentik/api/models/network_request.rb', line 16

def interfaces
  @interfaces
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



31
32
33
# File 'lib/authentik/api/models/network_request.rb', line 31

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



36
37
38
# File 'lib/authentik/api/models/network_request.rb', line 36

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
28
# File 'lib/authentik/api/models/network_request.rb', line 21

def self.attribute_map
  {
    :'hostname' => :'hostname',
    :'firewall_enabled' => :'firewall_enabled',
    :'interfaces' => :'interfaces',
    :'gateway' => :'gateway'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/authentik/api/models/network_request.rb', line 194

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



51
52
53
54
# File 'lib/authentik/api/models/network_request.rb', line 51

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



41
42
43
44
45
46
47
48
# File 'lib/authentik/api/models/network_request.rb', line 41

def self.openapi_types
  {
    :'hostname' => :'String',
    :'firewall_enabled' => :'Boolean',
    :'interfaces' => :'Array<NetworkInterfaceRequest>',
    :'gateway' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



170
171
172
173
174
175
176
177
# File 'lib/authentik/api/models/network_request.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      hostname == o.hostname &&
      firewall_enabled == o.firewall_enabled &&
      interfaces == o.interfaces &&
      gateway == o.gateway
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


181
182
183
# File 'lib/authentik/api/models/network_request.rb', line 181

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



187
188
189
# File 'lib/authentik/api/models/network_request.rb', line 187

def hash
  [hostname, firewall_enabled, interfaces, gateway].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/authentik/api/models/network_request.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @hostname.nil?
    invalid_properties.push('invalid value for "hostname", hostname cannot be nil.')
  end

  if @hostname.to_s.length < 1
    invalid_properties.push('invalid value for "hostname", the character length must be greater than or equal to 1.')
  end

  if @interfaces.nil?
    invalid_properties.push('invalid value for "interfaces", interfaces cannot be nil.')
  end

  if !@gateway.nil? && @gateway.to_s.length < 1
    invalid_properties.push('invalid value for "gateway", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/authentik/api/models/network_request.rb', line 216

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



121
122
123
124
125
126
127
128
# File 'lib/authentik/api/models/network_request.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @hostname.nil?
  return false if @hostname.to_s.length < 1
  return false if @interfaces.nil?
  return false if !@gateway.nil? && @gateway.to_s.length < 1
  true
end