Class: Authentik::Api::Notification

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/notification.rb

Overview

Notification Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Notification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/authentik/api/models/notification.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Notification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Notification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  else
    self.severity = nil
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'hyperlink')
    self.hyperlink = attributes[:'hyperlink']
  end

  if attributes.key?(:'hyperlink_label')
    self.hyperlink_label = attributes[:'hyperlink_label']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'seen')
    self.seen = attributes[:'seen']
  end
end

Instance Attribute Details

#bodyObject

Returns the value of attribute body.



17
18
19
# File 'lib/authentik/api/models/notification.rb', line 17

def body
  @body
end

#createdObject

Returns the value of attribute created.



23
24
25
# File 'lib/authentik/api/models/notification.rb', line 23

def created
  @created
end

#eventObject

Returns the value of attribute event.



25
26
27
# File 'lib/authentik/api/models/notification.rb', line 25

def event
  @event
end

Returns the value of attribute hyperlink.



19
20
21
# File 'lib/authentik/api/models/notification.rb', line 19

def hyperlink
  @hyperlink
end

Returns the value of attribute hyperlink_label.



21
22
23
# File 'lib/authentik/api/models/notification.rb', line 21

def hyperlink_label
  @hyperlink_label
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/notification.rb', line 13

def pk
  @pk
end

#seenObject

Returns the value of attribute seen.



27
28
29
# File 'lib/authentik/api/models/notification.rb', line 27

def seen
  @seen
end

#severityObject

Returns the value of attribute severity.



15
16
17
# File 'lib/authentik/api/models/notification.rb', line 15

def severity
  @severity
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/authentik/api/models/notification.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/authentik/api/models/notification.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/authentik/api/models/notification.rb', line 52

def self.attribute_map
  {
    :'pk' => :'pk',
    :'severity' => :'severity',
    :'body' => :'body',
    :'hyperlink' => :'hyperlink',
    :'hyperlink_label' => :'hyperlink_label',
    :'created' => :'created',
    :'event' => :'event',
    :'seen' => :'seen'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/authentik/api/models/notification.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
94
95
# File 'lib/authentik/api/models/notification.rb', line 90

def self.openapi_nullable
  Set.new([
    :'hyperlink',
    :'hyperlink_label',
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/authentik/api/models/notification.rb', line 76

def self.openapi_types
  {
    :'pk' => :'String',
    :'severity' => :'SeverityEnum',
    :'body' => :'String',
    :'hyperlink' => :'String',
    :'hyperlink_label' => :'String',
    :'created' => :'Time',
    :'event' => :'Event',
    :'seen' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/authentik/api/models/notification.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      severity == o.severity &&
      body == o.body &&
      hyperlink == o.hyperlink &&
      hyperlink_label == o.hyperlink_label &&
      created == o.created &&
      event == o.event &&
      seen == o.seen
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/authentik/api/models/notification.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



267
268
269
# File 'lib/authentik/api/models/notification.rb', line 267

def hash
  [pk, severity, body, hyperlink, hyperlink_label, created, event, seen].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/authentik/api/models/notification.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @severity.nil?
    invalid_properties.push('invalid value for "severity", severity cannot be nil.')
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if !@hyperlink.nil? && @hyperlink.to_s.length > 4096
    invalid_properties.push('invalid value for "hyperlink", the character length must be smaller than or equal to 4096.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/authentik/api/models/notification.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
# File 'lib/authentik/api/models/notification.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @severity.nil?
  return false if @body.nil?
  return false if !@hyperlink.nil? && @hyperlink.to_s.length > 4096
  return false if @created.nil?
  true
end