Class: Authentik::Api::NotificationRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/notification_request.rb

Overview

Notification Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NotificationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/authentik/api/models/notification_request.rb', line 61

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::NotificationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::NotificationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'hyperlink')
    self.hyperlink = attributes[:'hyperlink']
  end

  if attributes.key?(:'hyperlink_label')
    self.hyperlink_label = attributes[:'hyperlink_label']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'seen')
    self.seen = attributes[:'seen']
  end
end

Instance Attribute Details

#eventObject

Returns the value of attribute event.



17
18
19
# File 'lib/authentik/api/models/notification_request.rb', line 17

def event
  @event
end

Returns the value of attribute hyperlink.



13
14
15
# File 'lib/authentik/api/models/notification_request.rb', line 13

def hyperlink
  @hyperlink
end

Returns the value of attribute hyperlink_label.



15
16
17
# File 'lib/authentik/api/models/notification_request.rb', line 15

def hyperlink_label
  @hyperlink_label
end

#seenObject

Returns the value of attribute seen.



19
20
21
# File 'lib/authentik/api/models/notification_request.rb', line 19

def seen
  @seen
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



32
33
34
# File 'lib/authentik/api/models/notification_request.rb', line 32

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



37
38
39
# File 'lib/authentik/api/models/notification_request.rb', line 37

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



22
23
24
25
26
27
28
29
# File 'lib/authentik/api/models/notification_request.rb', line 22

def self.attribute_map
  {
    :'hyperlink' => :'hyperlink',
    :'hyperlink_label' => :'hyperlink_label',
    :'event' => :'event',
    :'seen' => :'seen'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/authentik/api/models/notification_request.rb', line 148

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
56
57
# File 'lib/authentik/api/models/notification_request.rb', line 52

def self.openapi_nullable
  Set.new([
    :'hyperlink',
    :'hyperlink_label',
  ])
end

.openapi_typesObject

Attribute type mapping.



42
43
44
45
46
47
48
49
# File 'lib/authentik/api/models/notification_request.rb', line 42

def self.openapi_types
  {
    :'hyperlink' => :'String',
    :'hyperlink_label' => :'String',
    :'event' => :'EventRequest',
    :'seen' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



124
125
126
127
128
129
130
131
# File 'lib/authentik/api/models/notification_request.rb', line 124

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      hyperlink == o.hyperlink &&
      hyperlink_label == o.hyperlink_label &&
      event == o.event &&
      seen == o.seen
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/authentik/api/models/notification_request.rb', line 135

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



141
142
143
# File 'lib/authentik/api/models/notification_request.rb', line 141

def hash
  [hyperlink, hyperlink_label, event, seen].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



94
95
96
97
98
99
100
101
102
# File 'lib/authentik/api/models/notification_request.rb', line 94

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@hyperlink.nil? && @hyperlink.to_s.length > 4096
    invalid_properties.push('invalid value for "hyperlink", the character length must be smaller than or equal to 4096.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/authentik/api/models/notification_request.rb', line 170

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



106
107
108
109
110
# File 'lib/authentik/api/models/notification_request.rb', line 106

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@hyperlink.nil? && @hyperlink.to_s.length > 4096
  true
end