Class: Authentik::Api::NotificationRule
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::NotificationRule
- Defined in:
- lib/authentik/api/models/notification_rule.rb
Overview
NotificationRule Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#destination_event_user ⇒ Object
When enabled, notification will be sent to user the user that triggered the event.When destination_group is configured, notification is sent to both.
-
#destination_group ⇒ Object
Define which group of users this notification should be sent and shown to.
-
#destination_group_obj ⇒ Object
Returns the value of attribute destination_group_obj.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#severity ⇒ Object
Controls which severity level the created notifications will have.
-
#transports ⇒ Object
Select which transports should be used to notify the user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NotificationRule
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NotificationRule
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/authentik/api/models/notification_rule.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::NotificationRule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::NotificationRule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'transports') if (value = attributes[:'transports']).is_a?(Array) self.transports = value end end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'destination_group') self.destination_group = attributes[:'destination_group'] end if attributes.key?(:'destination_group_obj') self.destination_group_obj = attributes[:'destination_group_obj'] else self.destination_group_obj = nil end if attributes.key?(:'destination_event_user') self.destination_event_user = attributes[:'destination_event_user'] end end |
Instance Attribute Details
#destination_event_user ⇒ Object
When enabled, notification will be sent to user the user that triggered the event.When destination_group is configured, notification is sent to both.
29 30 31 |
# File 'lib/authentik/api/models/notification_rule.rb', line 29 def destination_event_user @destination_event_user end |
#destination_group ⇒ Object
Define which group of users this notification should be sent and shown to. If left empty, Notification won’t ben sent.
24 25 26 |
# File 'lib/authentik/api/models/notification_rule.rb', line 24 def destination_group @destination_group end |
#destination_group_obj ⇒ Object
Returns the value of attribute destination_group_obj.
26 27 28 |
# File 'lib/authentik/api/models/notification_rule.rb', line 26 def destination_group_obj @destination_group_obj end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/notification_rule.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/notification_rule.rb', line 13 def pk @pk end |
#severity ⇒ Object
Controls which severity level the created notifications will have.
21 22 23 |
# File 'lib/authentik/api/models/notification_rule.rb', line 21 def severity @severity end |
#transports ⇒ Object
Select which transports should be used to notify the user. If none are selected, the notification will only be shown in the authentik UI.
18 19 20 |
# File 'lib/authentik/api/models/notification_rule.rb', line 18 def transports @transports end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/authentik/api/models/notification_rule.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/authentik/api/models/notification_rule.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/authentik/api/models/notification_rule.rb', line 54 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'transports' => :'transports', :'severity' => :'severity', :'destination_group' => :'destination_group', :'destination_group_obj' => :'destination_group_obj', :'destination_event_user' => :'destination_event_user' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/authentik/api/models/notification_rule.rb', line 224 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 94 95 |
# File 'lib/authentik/api/models/notification_rule.rb', line 90 def self.openapi_nullable Set.new([ :'destination_group', :'destination_group_obj', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/authentik/api/models/notification_rule.rb', line 77 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'transports' => :'Array<String>', :'severity' => :'SeverityEnum', :'destination_group' => :'String', :'destination_group_obj' => :'Group', :'destination_event_user' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/authentik/api/models/notification_rule.rb', line 197 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && transports == o.transports && severity == o.severity && destination_group == o.destination_group && destination_group_obj == o.destination_group_obj && destination_event_user == o.destination_event_user end |
#eql?(o) ⇒ Boolean
211 212 213 |
# File 'lib/authentik/api/models/notification_rule.rb', line 211 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/authentik/api/models/notification_rule.rb', line 217 def hash [pk, name, transports, severity, destination_group, destination_group_obj, destination_event_user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/authentik/api/models/notification_rule.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/authentik/api/models/notification_rule.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 173 |
# File 'lib/authentik/api/models/notification_rule.rb', line 168 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? true end |