Class: Authentik::Api::NotificationTransport

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/notification_transport.rb

Overview

NotificationTransport Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NotificationTransport

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/authentik/api/models/notification_transport.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::NotificationTransport` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::NotificationTransport`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'mode_verbose')
    self.mode_verbose = attributes[:'mode_verbose']
  else
    self.mode_verbose = nil
  end

  if attributes.key?(:'webhook_url')
    self.webhook_url = attributes[:'webhook_url']
  end

  if attributes.key?(:'webhook_ca')
    self.webhook_ca = attributes[:'webhook_ca']
  end

  if attributes.key?(:'webhook_mapping_body')
    self.webhook_mapping_body = attributes[:'webhook_mapping_body']
  end

  if attributes.key?(:'webhook_mapping_headers')
    self.webhook_mapping_headers = attributes[:'webhook_mapping_headers']
  end

  if attributes.key?(:'email_subject_prefix')
    self.email_subject_prefix = attributes[:'email_subject_prefix']
  end

  if attributes.key?(:'email_template')
    self.email_template = attributes[:'email_template']
  end

  if attributes.key?(:'send_once')
    self.send_once = attributes[:'send_once']
  end
end

Instance Attribute Details

#email_subject_prefixObject

Returns the value of attribute email_subject_prefix.



33
34
35
# File 'lib/authentik/api/models/notification_transport.rb', line 33

def email_subject_prefix
  @email_subject_prefix
end

#email_templateObject

Returns the value of attribute email_template.



35
36
37
# File 'lib/authentik/api/models/notification_transport.rb', line 35

def email_template
  @email_template
end

#modeObject

Returns the value of attribute mode.



17
18
19
# File 'lib/authentik/api/models/notification_transport.rb', line 17

def mode
  @mode
end

#mode_verboseObject

Return selected mode with a UI Label



20
21
22
# File 'lib/authentik/api/models/notification_transport.rb', line 20

def mode_verbose
  @mode_verbose
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/notification_transport.rb', line 15

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/notification_transport.rb', line 13

def pk
  @pk
end

#send_onceObject

Only send notification once, for example when sending a webhook into a chat channel.



38
39
40
# File 'lib/authentik/api/models/notification_transport.rb', line 38

def send_once
  @send_once
end

#webhook_caObject

When set, the selected ceritifcate is used to validate the certificate of the webhook server.



25
26
27
# File 'lib/authentik/api/models/notification_transport.rb', line 25

def webhook_ca
  @webhook_ca
end

#webhook_mapping_bodyObject

Customize the body of the request. Mapping should return data that is JSON-serializable.



28
29
30
# File 'lib/authentik/api/models/notification_transport.rb', line 28

def webhook_mapping_body
  @webhook_mapping_body
end

#webhook_mapping_headersObject

Configure additional headers to be sent. Mapping should return a dictionary of key-value pairs



31
32
33
# File 'lib/authentik/api/models/notification_transport.rb', line 31

def webhook_mapping_headers
  @webhook_mapping_headers
end

#webhook_urlObject

Returns the value of attribute webhook_url.



22
23
24
# File 'lib/authentik/api/models/notification_transport.rb', line 22

def webhook_url
  @webhook_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/authentik/api/models/notification_transport.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/authentik/api/models/notification_transport.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/authentik/api/models/notification_transport.rb', line 63

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'mode' => :'mode',
    :'mode_verbose' => :'mode_verbose',
    :'webhook_url' => :'webhook_url',
    :'webhook_ca' => :'webhook_ca',
    :'webhook_mapping_body' => :'webhook_mapping_body',
    :'webhook_mapping_headers' => :'webhook_mapping_headers',
    :'email_subject_prefix' => :'email_subject_prefix',
    :'email_template' => :'email_template',
    :'send_once' => :'send_once'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/authentik/api/models/notification_transport.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
113
# File 'lib/authentik/api/models/notification_transport.rb', line 107

def self.openapi_nullable
  Set.new([
    :'webhook_ca',
    :'webhook_mapping_body',
    :'webhook_mapping_headers',
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/authentik/api/models/notification_transport.rb', line 90

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'mode' => :'TransportModeEnum',
    :'mode_verbose' => :'String',
    :'webhook_url' => :'String',
    :'webhook_ca' => :'String',
    :'webhook_mapping_body' => :'String',
    :'webhook_mapping_headers' => :'String',
    :'email_subject_prefix' => :'String',
    :'email_template' => :'String',
    :'send_once' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/authentik/api/models/notification_transport.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      mode == o.mode &&
      mode_verbose == o.mode_verbose &&
      webhook_url == o.webhook_url &&
      webhook_ca == o.webhook_ca &&
      webhook_mapping_body == o.webhook_mapping_body &&
      webhook_mapping_headers == o.webhook_mapping_headers &&
      email_subject_prefix == o.email_subject_prefix &&
      email_template == o.email_template &&
      send_once == o.send_once
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/authentik/api/models/notification_transport.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/authentik/api/models/notification_transport.rb', line 268

def hash
  [pk, name, mode, mode_verbose, webhook_url, webhook_ca, webhook_mapping_body, webhook_mapping_headers, email_subject_prefix, email_template, send_once].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/authentik/api/models/notification_transport.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @mode_verbose.nil?
    invalid_properties.push('invalid value for "mode_verbose", mode_verbose cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/authentik/api/models/notification_transport.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
210
# File 'lib/authentik/api/models/notification_transport.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @mode_verbose.nil?
  true
end