Class: Authentik::Api::OAuth2ProviderSetupURLs

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/o_auth2_provider_setup_urls.rb

Overview

OAuth2 Provider Metadata serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OAuth2ProviderSetupURLs

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::OAuth2ProviderSetupURLs` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::OAuth2ProviderSetupURLs`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'issuer')
    self.issuer = attributes[:'issuer']
  else
    self.issuer = nil
  end

  if attributes.key?(:'authorize')
    self.authorize = attributes[:'authorize']
  else
    self.authorize = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  else
    self.token = nil
  end

  if attributes.key?(:'user_info')
    self. = attributes[:'user_info']
  else
    self. = nil
  end

  if attributes.key?(:'provider_info')
    self.provider_info = attributes[:'provider_info']
  else
    self.provider_info = nil
  end

  if attributes.key?(:'logout')
    self.logout = attributes[:'logout']
  else
    self.logout = nil
  end

  if attributes.key?(:'jwks')
    self.jwks = attributes[:'jwks']
  else
    self.jwks = nil
  end

  if attributes.key?(:'dcr_registration')
    self.dcr_registration = attributes[:'dcr_registration']
  else
    self.dcr_registration = nil
  end
end

Instance Attribute Details

#authorizeObject

Returns the value of attribute authorize.



15
16
17
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 15

def authorize
  @authorize
end

#dcr_registrationObject

Returns the value of attribute dcr_registration.



27
28
29
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 27

def dcr_registration
  @dcr_registration
end

#issuerObject

Returns the value of attribute issuer.



13
14
15
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 13

def issuer
  @issuer
end

#jwksObject

Returns the value of attribute jwks.



25
26
27
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 25

def jwks
  @jwks
end

#logoutObject

Returns the value of attribute logout.



23
24
25
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 23

def logout
  @logout
end

#provider_infoObject

Returns the value of attribute provider_info.



21
22
23
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 21

def provider_info
  @provider_info
end

#tokenObject

Returns the value of attribute token.



17
18
19
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 17

def token
  @token
end

#user_infoObject

Returns the value of attribute user_info.



19
20
21
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 19

def 
  @user_info
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 30

def self.attribute_map
  {
    :'issuer' => :'issuer',
    :'authorize' => :'authorize',
    :'token' => :'token',
    :'user_info' => :'user_info',
    :'provider_info' => :'provider_info',
    :'logout' => :'logout',
    :'jwks' => :'jwks',
    :'dcr_registration' => :'dcr_registration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 289

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
72
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 68

def self.openapi_nullable
  Set.new([
    :'dcr_registration'
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 54

def self.openapi_types
  {
    :'issuer' => :'String',
    :'authorize' => :'String',
    :'token' => :'String',
    :'user_info' => :'String',
    :'provider_info' => :'String',
    :'logout' => :'String',
    :'jwks' => :'String',
    :'dcr_registration' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      issuer == o.issuer &&
      authorize == o.authorize &&
      token == o.token &&
       == o. &&
      provider_info == o.provider_info &&
      logout == o.logout &&
      jwks == o.jwks &&
      dcr_registration == o.dcr_registration
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


276
277
278
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 276

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



282
283
284
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 282

def hash
  [issuer, authorize, token, , provider_info, logout, jwks, dcr_registration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @issuer.nil?
    invalid_properties.push('invalid value for "issuer", issuer cannot be nil.')
  end

  if @authorize.nil?
    invalid_properties.push('invalid value for "authorize", authorize cannot be nil.')
  end

  if @token.nil?
    invalid_properties.push('invalid value for "token", token cannot be nil.')
  end

  if @user_info.nil?
    invalid_properties.push('invalid value for "user_info", user_info cannot be nil.')
  end

  if @provider_info.nil?
    invalid_properties.push('invalid value for "provider_info", provider_info cannot be nil.')
  end

  if @logout.nil?
    invalid_properties.push('invalid value for "logout", logout cannot be nil.')
  end

  if @jwks.nil?
    invalid_properties.push('invalid value for "jwks", jwks cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 311

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
184
185
186
187
# File 'lib/authentik/api/models/o_auth2_provider_setup_urls.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @issuer.nil?
  return false if @authorize.nil?
  return false if @token.nil?
  return false if @user_info.nil?
  return false if @provider_info.nil?
  return false if @logout.nil?
  return false if @jwks.nil?
  true
end