Class: Authentik::Api::OAuthDeviceCodeFinishChallenge
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::OAuthDeviceCodeFinishChallenge
- Defined in:
- lib/authentik/api/models/o_auth_device_code_finish_challenge.rb
Overview
Final challenge after user enters their code
Instance Attribute Summary collapse
-
#component ⇒ Object
Returns the value of attribute component.
-
#flow_info ⇒ Object
Returns the value of attribute flow_info.
-
#response_errors ⇒ Object
Returns the value of attribute response_errors.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OAuthDeviceCodeFinishChallenge
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OAuthDeviceCodeFinishChallenge
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 55 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::OAuthDeviceCodeFinishChallenge` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::OAuthDeviceCodeFinishChallenge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'flow_info') self.flow_info = attributes[:'flow_info'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = 'ak-provider-oauth2-device-code-finish' end if attributes.key?(:'response_errors') if (value = attributes[:'response_errors']).is_a?(Hash) self.response_errors = value end end end |
Instance Attribute Details
#component ⇒ Object
Returns the value of attribute component.
15 16 17 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 15 def component @component end |
#flow_info ⇒ Object
Returns the value of attribute flow_info.
13 14 15 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 13 def flow_info @flow_info end |
#response_errors ⇒ Object
Returns the value of attribute response_errors.
17 18 19 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 17 def response_errors @response_errors end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
29 30 31 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 29 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
34 35 36 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 34 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 20 def self.attribute_map { :'flow_info' => :'flow_info', :'component' => :'component', :'response_errors' => :'response_errors' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 126 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 51 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 48 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 39 def self.openapi_types { :'flow_info' => :'ContextualFlowInfo', :'component' => :'String', :'response_errors' => :'Hash<String, Array<ErrorDetail>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
103 104 105 106 107 108 109 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 103 def ==(o) return true if self.equal?(o) self.class == o.class && flow_info == o.flow_info && component == o.component && response_errors == o.response_errors end |
#eql?(o) ⇒ Boolean
113 114 115 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 113 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
119 120 121 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 119 def hash [flow_info, component, response_errors].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
88 89 90 91 92 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 88 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 148 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
96 97 98 99 |
# File 'lib/authentik/api/models/o_auth_device_code_finish_challenge.rb', line 96 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |