Class: Authentik::Api::OAuthSource
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::OAuthSource
- Defined in:
- lib/authentik/api/models/o_auth_source.rb
Overview
OAuth Source Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_token_url ⇒ Object
URL used by authentik to retrieve tokens.
-
#additional_scopes ⇒ Object
Returns the value of attribute additional_scopes.
-
#authentication_flow ⇒ Object
Flow to use when authenticating existing users.
-
#authorization_code_auth_method ⇒ Object
How to perform authentication during an authorization_code token request flow.
-
#authorization_url ⇒ Object
URL the user is redirect to to conest the flow.
-
#callback_url ⇒ Object
Get OAuth Callback URL.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#consumer_key ⇒ Object
Returns the value of attribute consumer_key.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#enrollment_flow ⇒ Object
Flow to use when enrolling new users.
-
#group_matching_mode ⇒ Object
How the source determines if an existing group should be used or a new group created.
-
#group_property_mappings ⇒ Object
Returns the value of attribute group_property_mappings.
-
#icon ⇒ Object
Returns the value of attribute icon.
-
#icon_themed_urls ⇒ Object
Returns the value of attribute icon_themed_urls.
-
#icon_url ⇒ Object
Returns the value of attribute icon_url.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Source’s display Name.
-
#oidc_jwks ⇒ Object
Returns the value of attribute oidc_jwks.
-
#oidc_jwks_url ⇒ Object
Returns the value of attribute oidc_jwks_url.
-
#oidc_well_known_url ⇒ Object
Returns the value of attribute oidc_well_known_url.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#pkce ⇒ Object
Returns the value of attribute pkce.
-
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
-
#profile_url ⇒ Object
URL used by authentik to get user information.
-
#promoted ⇒ Object
When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
-
#provider_type ⇒ Object
Returns the value of attribute provider_type.
-
#request_token_url ⇒ Object
URL used to request the initial token.
-
#slug ⇒ Object
Internal source name, used in URLs.
-
#type ⇒ Object
Returns the value of attribute type.
-
#user_matching_mode ⇒ Object
How the source determines if an existing user should be authenticated or a new user enrolled.
-
#user_path_template ⇒ Object
Returns the value of attribute user_path_template.
-
#user_property_mappings ⇒ Object
Returns the value of attribute user_property_mappings.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OAuthSource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OAuthSource
Initializes the object
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 232 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::OAuthSource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::OAuthSource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'promoted') self.promoted = attributes[:'promoted'] end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'enrollment_flow') self.enrollment_flow = attributes[:'enrollment_flow'] end if attributes.key?(:'user_property_mappings') if (value = attributes[:'user_property_mappings']).is_a?(Array) self.user_property_mappings = value end end if attributes.key?(:'group_property_mappings') if (value = attributes[:'group_property_mappings']).is_a?(Array) self.group_property_mappings = value end end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'policy_engine_mode') self.policy_engine_mode = attributes[:'policy_engine_mode'] end if attributes.key?(:'user_matching_mode') self.user_matching_mode = attributes[:'user_matching_mode'] end if attributes.key?(:'managed') self.managed = attributes[:'managed'] else self.managed = nil end if attributes.key?(:'user_path_template') self.user_path_template = attributes[:'user_path_template'] end if attributes.key?(:'icon') self.icon = attributes[:'icon'] end if attributes.key?(:'icon_url') self.icon_url = attributes[:'icon_url'] else self.icon_url = nil end if attributes.key?(:'icon_themed_urls') self.icon_themed_urls = attributes[:'icon_themed_urls'] else self.icon_themed_urls = nil end if attributes.key?(:'group_matching_mode') self.group_matching_mode = attributes[:'group_matching_mode'] end if attributes.key?(:'provider_type') self.provider_type = attributes[:'provider_type'] else self.provider_type = nil end if attributes.key?(:'request_token_url') self.request_token_url = attributes[:'request_token_url'] end if attributes.key?(:'authorization_url') self. = attributes[:'authorization_url'] end if attributes.key?(:'access_token_url') self.access_token_url = attributes[:'access_token_url'] end if attributes.key?(:'profile_url') self.profile_url = attributes[:'profile_url'] end if attributes.key?(:'pkce') self.pkce = attributes[:'pkce'] end if attributes.key?(:'consumer_key') self.consumer_key = attributes[:'consumer_key'] else self.consumer_key = nil end if attributes.key?(:'callback_url') self.callback_url = attributes[:'callback_url'] else self.callback_url = nil end if attributes.key?(:'additional_scopes') self.additional_scopes = attributes[:'additional_scopes'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'oidc_well_known_url') self.oidc_well_known_url = attributes[:'oidc_well_known_url'] end if attributes.key?(:'oidc_jwks_url') self.oidc_jwks_url = attributes[:'oidc_jwks_url'] end if attributes.key?(:'oidc_jwks') if (value = attributes[:'oidc_jwks']).is_a?(Hash) self.oidc_jwks = value end end if attributes.key?(:'authorization_code_auth_method') self. = attributes[:'authorization_code_auth_method'] end end |
Instance Attribute Details
#access_token_url ⇒ Object
URL used by authentik to retrieve tokens.
76 77 78 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 76 def access_token_url @access_token_url end |
#additional_scopes ⇒ Object
Returns the value of attribute additional_scopes.
88 89 90 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 88 def additional_scopes @additional_scopes end |
#authentication_flow ⇒ Object
Flow to use when authenticating existing users.
27 28 29 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 27 def authentication_flow @authentication_flow end |
#authorization_code_auth_method ⇒ Object
How to perform authentication during an authorization_code token request flow
99 100 101 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 99 def @authorization_code_auth_method end |
#authorization_url ⇒ Object
URL the user is redirect to to conest the flow.
73 74 75 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 73 def @authorization_url end |
#callback_url ⇒ Object
Get OAuth Callback URL
86 87 88 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 86 def callback_url @callback_url end |
#component ⇒ Object
Get object component so that we know how to edit the object
37 38 39 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 37 def component @component end |
#consumer_key ⇒ Object
Returns the value of attribute consumer_key.
83 84 85 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 83 def consumer_key @consumer_key end |
#enabled ⇒ Object
Returns the value of attribute enabled.
21 22 23 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 21 def enabled @enabled end |
#enrollment_flow ⇒ Object
Flow to use when enrolling new users.
30 31 32 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 30 def enrollment_flow @enrollment_flow end |
#group_matching_mode ⇒ Object
How the source determines if an existing group should be used or a new group created.
65 66 67 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 65 def group_matching_mode @group_matching_mode end |
#group_property_mappings ⇒ Object
Returns the value of attribute group_property_mappings.
34 35 36 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 34 def group_property_mappings @group_property_mappings end |
#icon ⇒ Object
Returns the value of attribute icon.
58 59 60 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 58 def icon @icon end |
#icon_themed_urls ⇒ Object
Returns the value of attribute icon_themed_urls.
62 63 64 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 62 def icon_themed_urls @icon_themed_urls end |
#icon_url ⇒ Object
Returns the value of attribute icon_url.
60 61 62 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 60 def icon_url @icon_url end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
54 55 56 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 54 def managed @managed end |
#meta_model_name ⇒ Object
Return internal model name
46 47 48 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 46 def @meta_model_name end |
#name ⇒ Object
Source’s display Name.
16 17 18 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 16 def name @name end |
#oidc_jwks ⇒ Object
Returns the value of attribute oidc_jwks.
96 97 98 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 96 def oidc_jwks @oidc_jwks end |
#oidc_jwks_url ⇒ Object
Returns the value of attribute oidc_jwks_url.
94 95 96 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 94 def oidc_jwks_url @oidc_jwks_url end |
#oidc_well_known_url ⇒ Object
Returns the value of attribute oidc_well_known_url.
92 93 94 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 92 def oidc_well_known_url @oidc_well_known_url end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 13 def pk @pk end |
#pkce ⇒ Object
Returns the value of attribute pkce.
81 82 83 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 81 def pkce @pkce end |
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
48 49 50 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 48 def policy_engine_mode @policy_engine_mode end |
#profile_url ⇒ Object
URL used by authentik to get user information.
79 80 81 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 79 def profile_url @profile_url end |
#promoted ⇒ Object
When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
24 25 26 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 24 def promoted @promoted end |
#provider_type ⇒ Object
Returns the value of attribute provider_type.
67 68 69 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 67 def provider_type @provider_type end |
#request_token_url ⇒ Object
URL used to request the initial token. This URL is only required for OAuth 1.
70 71 72 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 70 def request_token_url @request_token_url end |
#slug ⇒ Object
Internal source name, used in URLs.
19 20 21 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 19 def slug @slug end |
#type ⇒ Object
Returns the value of attribute type.
90 91 92 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 90 def type @type end |
#user_matching_mode ⇒ Object
How the source determines if an existing user should be authenticated or a new user enrolled.
51 52 53 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 51 def user_matching_mode @user_matching_mode end |
#user_path_template ⇒ Object
Returns the value of attribute user_path_template.
56 57 58 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 56 def user_path_template @user_path_template end |
#user_property_mappings ⇒ Object
Returns the value of attribute user_property_mappings.
32 33 34 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 32 def user_property_mappings @user_property_mappings end |
#verbose_name ⇒ Object
Return object’s verbose_name
40 41 42 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 40 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
43 44 45 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 43 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
165 166 167 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 165 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
170 171 172 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 170 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 124 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'slug' => :'slug', :'enabled' => :'enabled', :'promoted' => :'promoted', :'authentication_flow' => :'authentication_flow', :'enrollment_flow' => :'enrollment_flow', :'user_property_mappings' => :'user_property_mappings', :'group_property_mappings' => :'group_property_mappings', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'policy_engine_mode' => :'policy_engine_mode', :'user_matching_mode' => :'user_matching_mode', :'managed' => :'managed', :'user_path_template' => :'user_path_template', :'icon' => :'icon', :'icon_url' => :'icon_url', :'icon_themed_urls' => :'icon_themed_urls', :'group_matching_mode' => :'group_matching_mode', :'provider_type' => :'provider_type', :'request_token_url' => :'request_token_url', :'authorization_url' => :'authorization_url', :'access_token_url' => :'access_token_url', :'profile_url' => :'profile_url', :'pkce' => :'pkce', :'consumer_key' => :'consumer_key', :'callback_url' => :'callback_url', :'additional_scopes' => :'additional_scopes', :'type' => :'type', :'oidc_well_known_url' => :'oidc_well_known_url', :'oidc_jwks_url' => :'oidc_jwks_url', :'oidc_jwks' => :'oidc_jwks', :'authorization_code_auth_method' => :'authorization_code_auth_method' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 729 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 216 def self.openapi_nullable Set.new([ :'authentication_flow', :'enrollment_flow', :'managed', :'icon_url', :'icon_themed_urls', :'request_token_url', :'authorization_url', :'access_token_url', :'profile_url', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 175 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'slug' => :'String', :'enabled' => :'Boolean', :'promoted' => :'Boolean', :'authentication_flow' => :'String', :'enrollment_flow' => :'String', :'user_property_mappings' => :'Array<String>', :'group_property_mappings' => :'Array<String>', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'policy_engine_mode' => :'PolicyEngineMode', :'user_matching_mode' => :'UserMatchingModeEnum', :'managed' => :'String', :'user_path_template' => :'String', :'icon' => :'String', :'icon_url' => :'String', :'icon_themed_urls' => :'ThemedUrls', :'group_matching_mode' => :'GroupMatchingModeEnum', :'provider_type' => :'ProviderTypeEnum', :'request_token_url' => :'String', :'authorization_url' => :'String', :'access_token_url' => :'String', :'profile_url' => :'String', :'pkce' => :'PKCEMethodEnum', :'consumer_key' => :'String', :'callback_url' => :'String', :'additional_scopes' => :'String', :'type' => :'SourceType', :'oidc_well_known_url' => :'String', :'oidc_jwks_url' => :'String', :'oidc_jwks' => :'Hash<String, Object>', :'authorization_code_auth_method' => :'AuthorizationCodeAuthMethodEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 674 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && slug == o.slug && enabled == o.enabled && promoted == o.promoted && authentication_flow == o.authentication_flow && enrollment_flow == o.enrollment_flow && user_property_mappings == o.user_property_mappings && group_property_mappings == o.group_property_mappings && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && policy_engine_mode == o.policy_engine_mode && user_matching_mode == o.user_matching_mode && managed == o.managed && user_path_template == o.user_path_template && icon == o.icon && icon_url == o.icon_url && icon_themed_urls == o.icon_themed_urls && group_matching_mode == o.group_matching_mode && provider_type == o.provider_type && request_token_url == o.request_token_url && == o. && access_token_url == o.access_token_url && profile_url == o.profile_url && pkce == o.pkce && consumer_key == o.consumer_key && callback_url == o.callback_url && additional_scopes == o.additional_scopes && type == o.type && oidc_well_known_url == o.oidc_well_known_url && oidc_jwks_url == o.oidc_jwks_url && oidc_jwks == o.oidc_jwks && == o. end |
#eql?(o) ⇒ Boolean
716 717 718 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 716 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
722 723 724 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 722 def hash [pk, name, slug, enabled, promoted, authentication_flow, enrollment_flow, user_property_mappings, group_property_mappings, component, verbose_name, verbose_name_plural, , policy_engine_mode, user_matching_mode, managed, user_path_template, icon, icon_url, icon_themed_urls, group_matching_mode, provider_type, request_token_url, , access_token_url, profile_url, pkce, consumer_key, callback_url, additional_scopes, type, oidc_well_known_url, oidc_jwks_url, oidc_jwks, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 423 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/) if @slug !~ pattern invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.") end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @provider_type.nil? invalid_properties.push('invalid value for "provider_type", provider_type cannot be nil.') end if !@request_token_url.nil? && @request_token_url.to_s.length > 255 invalid_properties.push('invalid value for "request_token_url", the character length must be smaller than or equal to 255.') end if !@authorization_url.nil? && @authorization_url.to_s.length > 255 invalid_properties.push('invalid value for "authorization_url", the character length must be smaller than or equal to 255.') end if !@access_token_url.nil? && @access_token_url.to_s.length > 255 invalid_properties.push('invalid value for "access_token_url", the character length must be smaller than or equal to 255.') end if !@profile_url.nil? && @profile_url.to_s.length > 255 invalid_properties.push('invalid value for "profile_url", the character length must be smaller than or equal to 255.') end if @consumer_key.nil? invalid_properties.push('invalid value for "consumer_key", consumer_key cannot be nil.') end if @callback_url.nil? invalid_properties.push('invalid value for "callback_url", callback_url cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 751 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'lib/authentik/api/models/o_auth_source.rb', line 496 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @slug.nil? return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/) return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @provider_type.nil? return false if !@request_token_url.nil? && @request_token_url.to_s.length > 255 return false if !@authorization_url.nil? && @authorization_url.to_s.length > 255 return false if !@access_token_url.nil? && @access_token_url.to_s.length > 255 return false if !@profile_url.nil? && @profile_url.to_s.length > 255 return false if @consumer_key.nil? return false if @callback_url.nil? return false if @type.nil? true end |