Class: Authentik::Api::OAuthSourceRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/o_auth_source_request.rb

Overview

OAuth Source Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OAuthSourceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 187

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::OAuthSourceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::OAuthSourceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'promoted')
    self.promoted = attributes[:'promoted']
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'enrollment_flow')
    self.enrollment_flow = attributes[:'enrollment_flow']
  end

  if attributes.key?(:'user_property_mappings')
    if (value = attributes[:'user_property_mappings']).is_a?(Array)
      self.user_property_mappings = value
    end
  end

  if attributes.key?(:'group_property_mappings')
    if (value = attributes[:'group_property_mappings']).is_a?(Array)
      self.group_property_mappings = value
    end
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'user_matching_mode')
    self.user_matching_mode = attributes[:'user_matching_mode']
  end

  if attributes.key?(:'user_path_template')
    self.user_path_template = attributes[:'user_path_template']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'group_matching_mode')
    self.group_matching_mode = attributes[:'group_matching_mode']
  end

  if attributes.key?(:'provider_type')
    self.provider_type = attributes[:'provider_type']
  else
    self.provider_type = nil
  end

  if attributes.key?(:'request_token_url')
    self.request_token_url = attributes[:'request_token_url']
  end

  if attributes.key?(:'authorization_url')
    self.authorization_url = attributes[:'authorization_url']
  end

  if attributes.key?(:'access_token_url')
    self.access_token_url = attributes[:'access_token_url']
  end

  if attributes.key?(:'profile_url')
    self.profile_url = attributes[:'profile_url']
  end

  if attributes.key?(:'pkce')
    self.pkce = attributes[:'pkce']
  end

  if attributes.key?(:'consumer_key')
    self.consumer_key = attributes[:'consumer_key']
  else
    self.consumer_key = nil
  end

  if attributes.key?(:'consumer_secret')
    self.consumer_secret = attributes[:'consumer_secret']
  else
    self.consumer_secret = nil
  end

  if attributes.key?(:'additional_scopes')
    self.additional_scopes = attributes[:'additional_scopes']
  end

  if attributes.key?(:'oidc_well_known_url')
    self.oidc_well_known_url = attributes[:'oidc_well_known_url']
  end

  if attributes.key?(:'oidc_jwks_url')
    self.oidc_jwks_url = attributes[:'oidc_jwks_url']
  end

  if attributes.key?(:'oidc_jwks')
    if (value = attributes[:'oidc_jwks']).is_a?(Hash)
      self.oidc_jwks = value
    end
  end

  if attributes.key?(:'authorization_code_auth_method')
    self.authorization_code_auth_method = attributes[:'authorization_code_auth_method']
  end
end

Instance Attribute Details

#access_token_urlObject

URL used by authentik to retrieve tokens.



55
56
57
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 55

def access_token_url
  @access_token_url
end

#additional_scopesObject

Returns the value of attribute additional_scopes.



66
67
68
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 66

def additional_scopes
  @additional_scopes
end

#authentication_flowObject

Flow to use when authenticating existing users.



25
26
27
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 25

def authentication_flow
  @authentication_flow
end

#authorization_code_auth_methodObject

How to perform authentication during an authorization_code token request flow



75
76
77
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 75

def authorization_code_auth_method
  @authorization_code_auth_method
end

#authorization_urlObject

URL the user is redirect to to conest the flow.



52
53
54
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 52

def authorization_url
  @authorization_url
end

#consumer_keyObject

Returns the value of attribute consumer_key.



62
63
64
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 62

def consumer_key
  @consumer_key
end

#consumer_secretObject

Returns the value of attribute consumer_secret.



64
65
66
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 64

def consumer_secret
  @consumer_secret
end

#enabledObject

Returns the value of attribute enabled.



19
20
21
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 19

def enabled
  @enabled
end

#enrollment_flowObject

Flow to use when enrolling new users.



28
29
30
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 28

def enrollment_flow
  @enrollment_flow
end

#group_matching_modeObject

How the source determines if an existing group should be used or a new group created.



44
45
46
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 44

def group_matching_mode
  @group_matching_mode
end

#group_property_mappingsObject

Returns the value of attribute group_property_mappings.



32
33
34
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 32

def group_property_mappings
  @group_property_mappings
end

#iconObject

Returns the value of attribute icon.



41
42
43
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 41

def icon
  @icon
end

#nameObject

Source’s display Name.



14
15
16
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 14

def name
  @name
end

#oidc_jwksObject

Returns the value of attribute oidc_jwks.



72
73
74
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 72

def oidc_jwks
  @oidc_jwks
end

#oidc_jwks_urlObject

Returns the value of attribute oidc_jwks_url.



70
71
72
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 70

def oidc_jwks_url
  @oidc_jwks_url
end

#oidc_well_known_urlObject

Returns the value of attribute oidc_well_known_url.



68
69
70
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 68

def oidc_well_known_url
  @oidc_well_known_url
end

#pkceObject

Returns the value of attribute pkce.



60
61
62
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 60

def pkce
  @pkce
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



34
35
36
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 34

def policy_engine_mode
  @policy_engine_mode
end

#profile_urlObject

URL used by authentik to get user information.



58
59
60
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 58

def profile_url
  @profile_url
end

When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.



22
23
24
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 22

def promoted
  @promoted
end

#provider_typeObject

Returns the value of attribute provider_type.



46
47
48
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 46

def provider_type
  @provider_type
end

#request_token_urlObject

URL used to request the initial token. This URL is only required for OAuth 1.



49
50
51
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 49

def request_token_url
  @request_token_url
end

#slugObject

Internal source name, used in URLs.



17
18
19
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 17

def slug
  @slug
end

#user_matching_modeObject

How the source determines if an existing user should be authenticated or a new user enrolled.



37
38
39
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 37

def user_matching_mode
  @user_matching_mode
end

#user_path_templateObject

Returns the value of attribute user_path_template.



39
40
41
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 39

def user_path_template
  @user_path_template
end

#user_property_mappingsObject

Returns the value of attribute user_property_mappings.



30
31
32
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 30

def user_property_mappings
  @user_property_mappings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



132
133
134
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 132

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



137
138
139
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 137

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 100

def self.attribute_map
  {
    :'name' => :'name',
    :'slug' => :'slug',
    :'enabled' => :'enabled',
    :'promoted' => :'promoted',
    :'authentication_flow' => :'authentication_flow',
    :'enrollment_flow' => :'enrollment_flow',
    :'user_property_mappings' => :'user_property_mappings',
    :'group_property_mappings' => :'group_property_mappings',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'user_matching_mode' => :'user_matching_mode',
    :'user_path_template' => :'user_path_template',
    :'icon' => :'icon',
    :'group_matching_mode' => :'group_matching_mode',
    :'provider_type' => :'provider_type',
    :'request_token_url' => :'request_token_url',
    :'authorization_url' => :'authorization_url',
    :'access_token_url' => :'access_token_url',
    :'profile_url' => :'profile_url',
    :'pkce' => :'pkce',
    :'consumer_key' => :'consumer_key',
    :'consumer_secret' => :'consumer_secret',
    :'additional_scopes' => :'additional_scopes',
    :'oidc_well_known_url' => :'oidc_well_known_url',
    :'oidc_jwks_url' => :'oidc_jwks_url',
    :'oidc_jwks' => :'oidc_jwks',
    :'authorization_code_auth_method' => :'authorization_code_auth_method'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 586

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



174
175
176
177
178
179
180
181
182
183
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 174

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
    :'enrollment_flow',
    :'request_token_url',
    :'authorization_url',
    :'access_token_url',
    :'profile_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 142

def self.openapi_types
  {
    :'name' => :'String',
    :'slug' => :'String',
    :'enabled' => :'Boolean',
    :'promoted' => :'Boolean',
    :'authentication_flow' => :'String',
    :'enrollment_flow' => :'String',
    :'user_property_mappings' => :'Array<String>',
    :'group_property_mappings' => :'Array<String>',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'user_matching_mode' => :'UserMatchingModeEnum',
    :'user_path_template' => :'String',
    :'icon' => :'String',
    :'group_matching_mode' => :'GroupMatchingModeEnum',
    :'provider_type' => :'ProviderTypeEnum',
    :'request_token_url' => :'String',
    :'authorization_url' => :'String',
    :'access_token_url' => :'String',
    :'profile_url' => :'String',
    :'pkce' => :'PKCEMethodEnum',
    :'consumer_key' => :'String',
    :'consumer_secret' => :'String',
    :'additional_scopes' => :'String',
    :'oidc_well_known_url' => :'String',
    :'oidc_jwks_url' => :'String',
    :'oidc_jwks' => :'Hash<String, Object>',
    :'authorization_code_auth_method' => :'AuthorizationCodeAuthMethodEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 540

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      slug == o.slug &&
      enabled == o.enabled &&
      promoted == o.promoted &&
      authentication_flow == o.authentication_flow &&
      enrollment_flow == o.enrollment_flow &&
      user_property_mappings == o.user_property_mappings &&
      group_property_mappings == o.group_property_mappings &&
      policy_engine_mode == o.policy_engine_mode &&
      user_matching_mode == o.user_matching_mode &&
      user_path_template == o.user_path_template &&
      icon == o.icon &&
      group_matching_mode == o.group_matching_mode &&
      provider_type == o.provider_type &&
      request_token_url == o.request_token_url &&
      authorization_url == o.authorization_url &&
      access_token_url == o.access_token_url &&
      profile_url == o.profile_url &&
      pkce == o.pkce &&
      consumer_key == o.consumer_key &&
      consumer_secret == o.consumer_secret &&
      additional_scopes == o.additional_scopes &&
      oidc_well_known_url == o.oidc_well_known_url &&
      oidc_jwks_url == o.oidc_jwks_url &&
      oidc_jwks == o.oidc_jwks &&
      authorization_code_auth_method == o.authorization_code_auth_method
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


573
574
575
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 573

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



579
580
581
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 579

def hash
  [name, slug, enabled, promoted, authentication_flow, enrollment_flow, user_property_mappings, group_property_mappings, policy_engine_mode, user_matching_mode, user_path_template, icon, group_matching_mode, provider_type, request_token_url, authorization_url, access_token_url, profile_url, pkce, consumer_key, consumer_secret, additional_scopes, oidc_well_known_url, oidc_jwks_url, oidc_jwks, authorization_code_auth_method].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 324

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  if @slug.to_s.length < 1
    invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if !@user_path_template.nil? && @user_path_template.to_s.length < 1
    invalid_properties.push('invalid value for "user_path_template", the character length must be greater than or equal to 1.')
  end

  if @provider_type.nil?
    invalid_properties.push('invalid value for "provider_type", provider_type cannot be nil.')
  end

  if !@request_token_url.nil? && @request_token_url.to_s.length > 255
    invalid_properties.push('invalid value for "request_token_url", the character length must be smaller than or equal to 255.')
  end

  if !@authorization_url.nil? && @authorization_url.to_s.length > 255
    invalid_properties.push('invalid value for "authorization_url", the character length must be smaller than or equal to 255.')
  end

  if !@access_token_url.nil? && @access_token_url.to_s.length > 255
    invalid_properties.push('invalid value for "access_token_url", the character length must be smaller than or equal to 255.')
  end

  if !@profile_url.nil? && @profile_url.to_s.length > 255
    invalid_properties.push('invalid value for "profile_url", the character length must be smaller than or equal to 255.')
  end

  if @consumer_key.nil?
    invalid_properties.push('invalid value for "consumer_key", consumer_key cannot be nil.')
  end

  if @consumer_key.to_s.length < 1
    invalid_properties.push('invalid value for "consumer_key", the character length must be greater than or equal to 1.')
  end

  if @consumer_secret.nil?
    invalid_properties.push('invalid value for "consumer_secret", consumer_secret cannot be nil.')
  end

  if @consumer_secret.to_s.length < 1
    invalid_properties.push('invalid value for "consumer_secret", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 608

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/authentik/api/models/o_auth_source_request.rb', line 393

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @slug.nil?
  return false if @slug.to_s.length < 1
  return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if !@user_path_template.nil? && @user_path_template.to_s.length < 1
  return false if @provider_type.nil?
  return false if !@request_token_url.nil? && @request_token_url.to_s.length > 255
  return false if !@authorization_url.nil? && @authorization_url.to_s.length > 255
  return false if !@access_token_url.nil? && @access_token_url.to_s.length > 255
  return false if !@profile_url.nil? && @profile_url.to_s.length > 255
  return false if @consumer_key.nil?
  return false if @consumer_key.to_s.length < 1
  return false if @consumer_secret.nil?
  return false if @consumer_secret.to_s.length < 1
  true
end