Class: Authentik::Api::OperatingSystem

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/operating_system.rb

Overview

For example: LTS (Noble Numbat)","arch":"amd64" "windows","name":"Server 2022 Datacenter","version":"10.0.20348.4405","arch":"amd64" "windows","name":"Server 2022 Datacenter","version":"10.0.20348.4405","arch":"amd64" "mac_os", "name": "", "version": "26.2", "arch": "arm64"

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OperatingSystem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/authentik/api/models/operating_system.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::OperatingSystem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::OperatingSystem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'family')
    self.family = attributes[:'family']
  else
    self.family = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'arch')
    self.arch = attributes[:'arch']
  end
end

Instance Attribute Details

#archObject

Returns the value of attribute arch.



21
22
23
# File 'lib/authentik/api/models/operating_system.rb', line 21

def arch
  @arch
end

#familyObject

Returns the value of attribute family.



13
14
15
# File 'lib/authentik/api/models/operating_system.rb', line 13

def family
  @family
end

#nameObject

Operating System name, such as ‘Server 2022’ or ‘Ubuntu’



16
17
18
# File 'lib/authentik/api/models/operating_system.rb', line 16

def name
  @name
end

#versionObject

Operating System version, must always be the version number but may contain build name



19
20
21
# File 'lib/authentik/api/models/operating_system.rb', line 19

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/authentik/api/models/operating_system.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/authentik/api/models/operating_system.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
# File 'lib/authentik/api/models/operating_system.rb', line 46

def self.attribute_map
  {
    :'family' => :'family',
    :'name' => :'name',
    :'version' => :'version',
    :'arch' => :'arch'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/authentik/api/models/operating_system.rb', line 172

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/authentik/api/models/operating_system.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
# File 'lib/authentik/api/models/operating_system.rb', line 66

def self.openapi_types
  {
    :'family' => :'DeviceFactsOSFamily',
    :'name' => :'String',
    :'version' => :'String',
    :'arch' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



148
149
150
151
152
153
154
155
# File 'lib/authentik/api/models/operating_system.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      family == o.family &&
      name == o.name &&
      version == o.version &&
      arch == o.arch
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/authentik/api/models/operating_system.rb', line 159

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



165
166
167
# File 'lib/authentik/api/models/operating_system.rb', line 165

def hash
  [family, name, version, arch].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
# File 'lib/authentik/api/models/operating_system.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @family.nil?
    invalid_properties.push('invalid value for "family", family cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/authentik/api/models/operating_system.rb', line 194

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
# File 'lib/authentik/api/models/operating_system.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @family.nil?
  true
end