Class: Authentik::Api::Outpost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::Outpost
- Defined in:
- lib/authentik/api/models/outpost.rb
Overview
Outpost Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#providers ⇒ Object
Returns the value of attribute providers.
-
#providers_obj ⇒ Object
Returns the value of attribute providers_obj.
-
#refresh_interval_s ⇒ Object
Returns the value of attribute refresh_interval_s.
-
#service_connection ⇒ Object
Select Service-Connection authentik should use to manage this outpost.
-
#service_connection_obj ⇒ Object
Returns the value of attribute service_connection_obj.
-
#token_identifier ⇒ Object
Get Token identifier.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Outpost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Outpost
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/authentik/api/models/outpost.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Outpost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Outpost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'providers') if (value = attributes[:'providers']).is_a?(Array) self.providers = value end else self.providers = nil end if attributes.key?(:'providers_obj') if (value = attributes[:'providers_obj']).is_a?(Array) self.providers_obj = value end else self.providers_obj = nil end if attributes.key?(:'service_connection') self.service_connection = attributes[:'service_connection'] end if attributes.key?(:'service_connection_obj') self.service_connection_obj = attributes[:'service_connection_obj'] else self.service_connection_obj = nil end if attributes.key?(:'refresh_interval_s') self.refresh_interval_s = attributes[:'refresh_interval_s'] else self.refresh_interval_s = nil end if attributes.key?(:'token_identifier') self.token_identifier = attributes[:'token_identifier'] else self.token_identifier = nil end if attributes.key?(:'config') if (value = attributes[:'config']).is_a?(Hash) self.config = value end else self.config = nil end if attributes.key?(:'managed') self.managed = attributes[:'managed'] end end |
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config.
33 34 35 |
# File 'lib/authentik/api/models/outpost.rb', line 33 def config @config end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
36 37 38 |
# File 'lib/authentik/api/models/outpost.rb', line 36 def managed @managed end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/outpost.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/outpost.rb', line 13 def pk @pk end |
#providers ⇒ Object
Returns the value of attribute providers.
19 20 21 |
# File 'lib/authentik/api/models/outpost.rb', line 19 def providers @providers end |
#providers_obj ⇒ Object
Returns the value of attribute providers_obj.
21 22 23 |
# File 'lib/authentik/api/models/outpost.rb', line 21 def providers_obj @providers_obj end |
#refresh_interval_s ⇒ Object
Returns the value of attribute refresh_interval_s.
28 29 30 |
# File 'lib/authentik/api/models/outpost.rb', line 28 def refresh_interval_s @refresh_interval_s end |
#service_connection ⇒ Object
Select Service-Connection authentik should use to manage this outpost. Leave empty if authentik should not handle the deployment.
24 25 26 |
# File 'lib/authentik/api/models/outpost.rb', line 24 def service_connection @service_connection end |
#service_connection_obj ⇒ Object
Returns the value of attribute service_connection_obj.
26 27 28 |
# File 'lib/authentik/api/models/outpost.rb', line 26 def service_connection_obj @service_connection_obj end |
#token_identifier ⇒ Object
Get Token identifier
31 32 33 |
# File 'lib/authentik/api/models/outpost.rb', line 31 def token_identifier @token_identifier end |
#type ⇒ Object
Returns the value of attribute type.
17 18 19 |
# File 'lib/authentik/api/models/outpost.rb', line 17 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/authentik/api/models/outpost.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/authentik/api/models/outpost.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/authentik/api/models/outpost.rb', line 61 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'type' => :'type', :'providers' => :'providers', :'providers_obj' => :'providers_obj', :'service_connection' => :'service_connection', :'service_connection_obj' => :'service_connection_obj', :'refresh_interval_s' => :'refresh_interval_s', :'token_identifier' => :'token_identifier', :'config' => :'config', :'managed' => :'managed' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/authentik/api/models/outpost.rb', line 366 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 110 111 |
# File 'lib/authentik/api/models/outpost.rb', line 105 def self.openapi_nullable Set.new([ :'service_connection', :'service_connection_obj', :'managed' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/authentik/api/models/outpost.rb', line 88 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'type' => :'OutpostTypeEnum', :'providers' => :'Array<Integer>', :'providers_obj' => :'Array<Provider>', :'service_connection' => :'String', :'service_connection_obj' => :'ServiceConnection', :'refresh_interval_s' => :'Integer', :'token_identifier' => :'String', :'config' => :'Hash<String, Object>', :'managed' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/authentik/api/models/outpost.rb', line 335 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && type == o.type && providers == o.providers && providers_obj == o.providers_obj && service_connection == o.service_connection && service_connection_obj == o.service_connection_obj && refresh_interval_s == o.refresh_interval_s && token_identifier == o.token_identifier && config == o.config && managed == o.managed end |
#eql?(o) ⇒ Boolean
353 354 355 |
# File 'lib/authentik/api/models/outpost.rb', line 353 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
359 360 361 |
# File 'lib/authentik/api/models/outpost.rb', line 359 def hash [pk, name, type, providers, providers_obj, service_connection, service_connection_obj, refresh_interval_s, token_identifier, config, managed].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/authentik/api/models/outpost.rb', line 200 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @providers.nil? invalid_properties.push('invalid value for "providers", providers cannot be nil.') end if @providers_obj.nil? invalid_properties.push('invalid value for "providers_obj", providers_obj cannot be nil.') end if @refresh_interval_s.nil? invalid_properties.push('invalid value for "refresh_interval_s", refresh_interval_s cannot be nil.') end if @token_identifier.nil? invalid_properties.push('invalid value for "token_identifier", token_identifier cannot be nil.') end if @config.nil? invalid_properties.push('invalid value for "config", config cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/authentik/api/models/outpost.rb', line 388 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/authentik/api/models/outpost.rb', line 240 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @type.nil? return false if @providers.nil? return false if @providers_obj.nil? return false if @refresh_interval_s.nil? return false if @token_identifier.nil? return false if @config.nil? true end |