Class: Authentik::Api::PaginatedExtraRoleObjectPermissionList
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PaginatedExtraRoleObjectPermissionList
- Defined in:
- lib/authentik/api/models/paginated_extra_role_object_permission_list.rb
Instance Attribute Summary collapse
-
#pagination ⇒ Object
Returns the value of attribute pagination.
-
#results ⇒ Object
Returns the value of attribute results.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaginatedExtraRoleObjectPermissionList
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PaginatedExtraRoleObjectPermissionList
Initializes the object
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 50 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PaginatedExtraRoleObjectPermissionList` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PaginatedExtraRoleObjectPermissionList`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pagination') self.pagination = attributes[:'pagination'] else self.pagination = nil end if attributes.key?(:'results') if (value = attributes[:'results']).is_a?(Array) self.results = value end else self.results = nil end end |
Instance Attribute Details
#pagination ⇒ Object
Returns the value of attribute pagination.
12 13 14 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 12 def pagination @pagination end |
#results ⇒ Object
Returns the value of attribute results.
14 15 16 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 14 def results @results end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
25 26 27 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 25 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
30 31 32 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 30 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
17 18 19 20 21 22 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 17 def self.attribute_map { :'pagination' => :'pagination', :'results' => :'results' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 148 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
43 44 45 46 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 43 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
35 36 37 38 39 40 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 35 def self.openapi_types { :'pagination' => :'Pagination', :'results' => :'Array<ExtraRoleObjectPermission>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && pagination == o.pagination && results == o.results end |
#eql?(o) ⇒ Boolean
135 136 137 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 135 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 141 def hash [pagination, results].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 81 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pagination.nil? invalid_properties.push('invalid value for "pagination", pagination cannot be nil.') end if @results.nil? invalid_properties.push('invalid value for "results", results cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
97 98 99 100 101 102 |
# File 'lib/authentik/api/models/paginated_extra_role_object_permission_list.rb', line 97 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pagination.nil? return false if @results.nil? true end |