Class: Authentik::Api::Pagination

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/pagination.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Pagination

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/authentik/api/models/pagination.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Pagination` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Pagination`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_next')
    self._next = attributes[:'_next']
  else
    self._next = nil
  end

  if attributes.key?(:'previous')
    self.previous = attributes[:'previous']
  else
    self.previous = nil
  end

  if attributes.key?(:'count')
    self.count = attributes[:'count']
  else
    self.count = nil
  end

  if attributes.key?(:'current')
    self.current = attributes[:'current']
  else
    self.current = nil
  end

  if attributes.key?(:'total_pages')
    self.total_pages = attributes[:'total_pages']
  else
    self.total_pages = nil
  end

  if attributes.key?(:'start_index')
    self.start_index = attributes[:'start_index']
  else
    self.start_index = nil
  end

  if attributes.key?(:'end_index')
    self.end_index = attributes[:'end_index']
  else
    self.end_index = nil
  end
end

Instance Attribute Details

#_nextObject

Returns the value of attribute _next.



12
13
14
# File 'lib/authentik/api/models/pagination.rb', line 12

def _next
  @_next
end

#countObject

Returns the value of attribute count.



16
17
18
# File 'lib/authentik/api/models/pagination.rb', line 16

def count
  @count
end

#currentObject

Returns the value of attribute current.



18
19
20
# File 'lib/authentik/api/models/pagination.rb', line 18

def current
  @current
end

#end_indexObject

Returns the value of attribute end_index.



24
25
26
# File 'lib/authentik/api/models/pagination.rb', line 24

def end_index
  @end_index
end

#previousObject

Returns the value of attribute previous.



14
15
16
# File 'lib/authentik/api/models/pagination.rb', line 14

def previous
  @previous
end

#start_indexObject

Returns the value of attribute start_index.



22
23
24
# File 'lib/authentik/api/models/pagination.rb', line 22

def start_index
  @start_index
end

#total_pagesObject

Returns the value of attribute total_pages.



20
21
22
# File 'lib/authentik/api/models/pagination.rb', line 20

def total_pages
  @total_pages
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/authentik/api/models/pagination.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/authentik/api/models/pagination.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
37
# File 'lib/authentik/api/models/pagination.rb', line 27

def self.attribute_map
  {
    :'_next' => :'next',
    :'previous' => :'previous',
    :'count' => :'count',
    :'current' => :'current',
    :'total_pages' => :'total_pages',
    :'start_index' => :'start_index',
    :'end_index' => :'end_index'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/authentik/api/models/pagination.rb', line 276

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/authentik/api/models/pagination.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/authentik/api/models/pagination.rb', line 50

def self.openapi_types
  {
    :'_next' => :'Float',
    :'previous' => :'Float',
    :'count' => :'Float',
    :'current' => :'Float',
    :'total_pages' => :'Float',
    :'start_index' => :'Float',
    :'end_index' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
# File 'lib/authentik/api/models/pagination.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _next == o._next &&
      previous == o.previous &&
      count == o.count &&
      current == o.current &&
      total_pages == o.total_pages &&
      start_index == o.start_index &&
      end_index == o.end_index
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/authentik/api/models/pagination.rb', line 263

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



269
270
271
# File 'lib/authentik/api/models/pagination.rb', line 269

def hash
  [_next, previous, count, current, total_pages, start_index, end_index].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/authentik/api/models/pagination.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_next.nil?
    invalid_properties.push('invalid value for "_next", _next cannot be nil.')
  end

  if @previous.nil?
    invalid_properties.push('invalid value for "previous", previous cannot be nil.')
  end

  if @count.nil?
    invalid_properties.push('invalid value for "count", count cannot be nil.')
  end

  if @current.nil?
    invalid_properties.push('invalid value for "current", current cannot be nil.')
  end

  if @total_pages.nil?
    invalid_properties.push('invalid value for "total_pages", total_pages cannot be nil.')
  end

  if @start_index.nil?
    invalid_properties.push('invalid value for "start_index", start_index cannot be nil.')
  end

  if @end_index.nil?
    invalid_properties.push('invalid value for "end_index", end_index cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/authentik/api/models/pagination.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
171
172
173
174
175
# File 'lib/authentik/api/models/pagination.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_next.nil?
  return false if @previous.nil?
  return false if @count.nil?
  return false if @current.nil?
  return false if @total_pages.nil?
  return false if @start_index.nil?
  return false if @end_index.nil?
  true
end