Class: Authentik::Api::PartialGroup

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/partial_group.rb

Overview

Partial Group Serializer, does not include child relations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PartialGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/authentik/api/models/partial_group.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PartialGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PartialGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'num_pk')
    self.num_pk = attributes[:'num_pk']
  else
    self.num_pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'is_superuser')
    self.is_superuser = attributes[:'is_superuser']
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end
end

Instance Attribute Details

#attributesObject

Returns the value of attribute attributes.



23
24
25
# File 'lib/authentik/api/models/partial_group.rb', line 23

def attributes
  @attributes
end

#is_superuserObject

Users added to this group will be superusers.



21
22
23
# File 'lib/authentik/api/models/partial_group.rb', line 21

def is_superuser
  @is_superuser
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/authentik/api/models/partial_group.rb', line 18

def name
  @name
end

#num_pkObject

Get a numerical, int32 ID for the group



16
17
18
# File 'lib/authentik/api/models/partial_group.rb', line 16

def num_pk
  @num_pk
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/partial_group.rb', line 13

def pk
  @pk
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/authentik/api/models/partial_group.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/authentik/api/models/partial_group.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
# File 'lib/authentik/api/models/partial_group.rb', line 26

def self.attribute_map
  {
    :'pk' => :'pk',
    :'num_pk' => :'num_pk',
    :'name' => :'name',
    :'is_superuser' => :'is_superuser',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/authentik/api/models/partial_group.rb', line 195

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
# File 'lib/authentik/api/models/partial_group.rb', line 58

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
55
# File 'lib/authentik/api/models/partial_group.rb', line 47

def self.openapi_types
  {
    :'pk' => :'String',
    :'num_pk' => :'Integer',
    :'name' => :'String',
    :'is_superuser' => :'Boolean',
    :'attributes' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
# File 'lib/authentik/api/models/partial_group.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      num_pk == o.num_pk &&
      name == o.name &&
      is_superuser == o.is_superuser &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


182
183
184
# File 'lib/authentik/api/models/partial_group.rb', line 182

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



188
189
190
# File 'lib/authentik/api/models/partial_group.rb', line 188

def hash
  [pk, num_pk, name, is_superuser, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/authentik/api/models/partial_group.rb', line 110

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @num_pk.nil?
    invalid_properties.push('invalid value for "num_pk", num_pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/authentik/api/models/partial_group.rb', line 217

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
135
136
# File 'lib/authentik/api/models/partial_group.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @num_pk.nil?
  return false if @name.nil?
  true
end