Class: Authentik::Api::PasswordExpiryPolicy

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/password_expiry_policy.rb

Overview

Password Expiry Policy Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PasswordExpiryPolicy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PasswordExpiryPolicy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PasswordExpiryPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'execution_logging')
    self.execution_logging = attributes[:'execution_logging']
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'bound_to')
    self.bound_to = attributes[:'bound_to']
  else
    self.bound_to = nil
  end

  if attributes.key?(:'days')
    self.days = attributes[:'days']
  else
    self.days = nil
  end

  if attributes.key?(:'deny_only')
    self.deny_only = attributes[:'deny_only']
  end
end

Instance Attribute Details

#bound_toObject

Return objects policy is bound to



33
34
35
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 33

def bound_to
  @bound_to
end

#componentObject

Get object component so that we know how to edit the object



21
22
23
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 21

def component
  @component
end

#daysObject

Returns the value of attribute days.



35
36
37
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 35

def days
  @days
end

#deny_onlyObject

Returns the value of attribute deny_only.



37
38
39
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 37

def deny_only
  @deny_only
end

#execution_loggingObject

When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.



18
19
20
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 18

def execution_logging
  @execution_logging
end

#meta_model_nameObject

Return internal model name



30
31
32
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 30

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 15

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 13

def pk
  @pk
end

#verbose_nameObject

Return object’s verbose_name



24
25
26
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 24

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



27
28
29
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 27

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 40

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'execution_logging' => :'execution_logging',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'bound_to' => :'bound_to',
    :'days' => :'days',
    :'deny_only' => :'deny_only'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 345

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 66

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'execution_logging' => :'Boolean',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'bound_to' => :'Integer',
    :'days' => :'Integer',
    :'deny_only' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 315

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      execution_logging == o.execution_logging &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      bound_to == o.bound_to &&
      days == o.days &&
      deny_only == o.deny_only
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


332
333
334
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 332

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



338
339
340
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 338

def hash
  [pk, name, execution_logging, component, verbose_name, verbose_name_plural, meta_model_name, bound_to, days, deny_only].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @bound_to.nil?
    invalid_properties.push('invalid value for "bound_to", bound_to cannot be nil.')
  end

  if @days.nil?
    invalid_properties.push('invalid value for "days", days cannot be nil.')
  end

  if @days > 2147483647
    invalid_properties.push('invalid value for "days", must be smaller than or equal to 2147483647.')
  end

  if @days < -2147483648
    invalid_properties.push('invalid value for "days", must be greater than or equal to -2147483648.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 367

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/authentik/api/models/password_expiry_policy.rb', line 210

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @bound_to.nil?
  return false if @days.nil?
  return false if @days > 2147483647
  return false if @days < -2147483648
  true
end