Class: Authentik::Api::PatchedApplicationRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_application_request.rb

Overview

Application Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedApplicationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/authentik/api/models/patched_application_request.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedApplicationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedApplicationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'backchannel_providers')
    if (value = attributes[:'backchannel_providers']).is_a?(Array)
      self.backchannel_providers = value
    end
  end

  if attributes.key?(:'open_in_new_tab')
    self.open_in_new_tab = attributes[:'open_in_new_tab']
  end

  if attributes.key?(:'meta_launch_url')
    self.meta_launch_url = attributes[:'meta_launch_url']
  end

  if attributes.key?(:'meta_icon')
    self.meta_icon = attributes[:'meta_icon']
  end

  if attributes.key?(:'meta_description')
    self.meta_description = attributes[:'meta_description']
  end

  if attributes.key?(:'meta_publisher')
    self.meta_publisher = attributes[:'meta_publisher']
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'group')
    self.group = attributes[:'group']
  end

  if attributes.key?(:'meta_hide')
    self.meta_hide = attributes[:'meta_hide']
  end
end

Instance Attribute Details

#backchannel_providersObject

Returns the value of attribute backchannel_providers.



21
22
23
# File 'lib/authentik/api/models/patched_application_request.rb', line 21

def backchannel_providers
  @backchannel_providers
end

#groupObject

Returns the value of attribute group.



36
37
38
# File 'lib/authentik/api/models/patched_application_request.rb', line 36

def group
  @group
end

#meta_descriptionObject

Returns the value of attribute meta_description.



30
31
32
# File 'lib/authentik/api/models/patched_application_request.rb', line 30

def meta_description
  @meta_description
end

#meta_hideObject

Hide this application from the user’s My applications page.



39
40
41
# File 'lib/authentik/api/models/patched_application_request.rb', line 39

def meta_hide
  @meta_hide
end

#meta_iconObject

Returns the value of attribute meta_icon.



28
29
30
# File 'lib/authentik/api/models/patched_application_request.rb', line 28

def meta_icon
  @meta_icon
end

#meta_launch_urlObject

Returns the value of attribute meta_launch_url.



26
27
28
# File 'lib/authentik/api/models/patched_application_request.rb', line 26

def meta_launch_url
  @meta_launch_url
end

#meta_publisherObject

Returns the value of attribute meta_publisher.



32
33
34
# File 'lib/authentik/api/models/patched_application_request.rb', line 32

def meta_publisher
  @meta_publisher
end

#nameObject

Application’s display Name.



14
15
16
# File 'lib/authentik/api/models/patched_application_request.rb', line 14

def name
  @name
end

#open_in_new_tabObject

Open launch URL in a new browser tab or window.



24
25
26
# File 'lib/authentik/api/models/patched_application_request.rb', line 24

def open_in_new_tab
  @open_in_new_tab
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



34
35
36
# File 'lib/authentik/api/models/patched_application_request.rb', line 34

def policy_engine_mode
  @policy_engine_mode
end

#providerObject

Returns the value of attribute provider.



19
20
21
# File 'lib/authentik/api/models/patched_application_request.rb', line 19

def provider
  @provider
end

#slugObject

Internal application name, used in URLs.



17
18
19
# File 'lib/authentik/api/models/patched_application_request.rb', line 17

def slug
  @slug
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/authentik/api/models/patched_application_request.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/authentik/api/models/patched_application_request.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/authentik/api/models/patched_application_request.rb', line 64

def self.attribute_map
  {
    :'name' => :'name',
    :'slug' => :'slug',
    :'provider' => :'provider',
    :'backchannel_providers' => :'backchannel_providers',
    :'open_in_new_tab' => :'open_in_new_tab',
    :'meta_launch_url' => :'meta_launch_url',
    :'meta_icon' => :'meta_icon',
    :'meta_description' => :'meta_description',
    :'meta_publisher' => :'meta_publisher',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'group' => :'group',
    :'meta_hide' => :'meta_hide'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/authentik/api/models/patched_application_request.rb', line 281

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
114
# File 'lib/authentik/api/models/patched_application_request.rb', line 110

def self.openapi_nullable
  Set.new([
    :'provider',
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/authentik/api/models/patched_application_request.rb', line 92

def self.openapi_types
  {
    :'name' => :'String',
    :'slug' => :'String',
    :'provider' => :'Integer',
    :'backchannel_providers' => :'Array<Integer>',
    :'open_in_new_tab' => :'Boolean',
    :'meta_launch_url' => :'String',
    :'meta_icon' => :'String',
    :'meta_description' => :'String',
    :'meta_publisher' => :'String',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'group' => :'String',
    :'meta_hide' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/authentik/api/models/patched_application_request.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      slug == o.slug &&
      provider == o.provider &&
      backchannel_providers == o.backchannel_providers &&
      open_in_new_tab == o.open_in_new_tab &&
      meta_launch_url == o.meta_launch_url &&
      meta_icon == o.meta_icon &&
      meta_description == o.meta_description &&
      meta_publisher == o.meta_publisher &&
      policy_engine_mode == o.policy_engine_mode &&
      group == o.group &&
      meta_hide == o.meta_hide
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


268
269
270
# File 'lib/authentik/api/models/patched_application_request.rb', line 268

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



274
275
276
# File 'lib/authentik/api/models/patched_application_request.rb', line 274

def hash
  [name, slug, provider, backchannel_providers, open_in_new_tab, meta_launch_url, meta_icon, meta_description, meta_publisher, policy_engine_mode, group, meta_hide].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/authentik/api/models/patched_application_request.rb', line 185

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@slug.nil? && @slug.to_s.length < 1
    invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if !@slug.nil? && @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/authentik/api/models/patched_application_request.rb', line 303

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
# File 'lib/authentik/api/models/patched_application_request.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@slug.nil? && @slug.to_s.length < 1
  return false if !@slug.nil? && @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  true
end