Class: Authentik::Api::PatchedAuthenticatorEmailStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedAuthenticatorEmailStageRequest
- Defined in:
- lib/authentik/api/models/patched_authenticator_email_stage_request.rb
Overview
AuthenticatorEmailStage Serializer
Instance Attribute Summary collapse
-
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage.
-
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
-
#from_address ⇒ Object
Returns the value of attribute from_address.
-
#host ⇒ Object
Returns the value of attribute host.
-
#name ⇒ Object
Returns the value of attribute name.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#template ⇒ Object
Returns the value of attribute template.
-
#timeout ⇒ Object
Returns the value of attribute timeout.
-
#token_expiry ⇒ Object
Time the token sent is valid (Format: hours=3,minutes=17,seconds=300).
-
#use_global_settings ⇒ Object
When enabled, global Email connection settings will be used and connection settings below will be ignored.
-
#use_ssl ⇒ Object
Returns the value of attribute use_ssl.
-
#use_tls ⇒ Object
Returns the value of attribute use_tls.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedAuthenticatorEmailStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedAuthenticatorEmailStageRequest
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedAuthenticatorEmailStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedAuthenticatorEmailStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'configure_flow') self.configure_flow = attributes[:'configure_flow'] end if attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] end if attributes.key?(:'use_global_settings') self.use_global_settings = attributes[:'use_global_settings'] end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'port') self.port = attributes[:'port'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'use_tls') self.use_tls = attributes[:'use_tls'] end if attributes.key?(:'use_ssl') self.use_ssl = attributes[:'use_ssl'] end if attributes.key?(:'timeout') self.timeout = attributes[:'timeout'] end if attributes.key?(:'from_address') self.from_address = attributes[:'from_address'] end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'token_expiry') self.token_expiry = attributes[:'token_expiry'] end if attributes.key?(:'template') self.template = attributes[:'template'] end end |
Instance Attribute Details
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.
16 17 18 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 16 def configure_flow @configure_flow end |
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
18 19 20 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 18 def friendly_name @friendly_name end |
#from_address ⇒ Object
Returns the value of attribute from_address.
37 38 39 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 37 def from_address @from_address end |
#host ⇒ Object
Returns the value of attribute host.
23 24 25 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 23 def host @host end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 13 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
29 30 31 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 29 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
25 26 27 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 25 def port @port end |
#subject ⇒ Object
Returns the value of attribute subject.
39 40 41 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 39 def subject @subject end |
#template ⇒ Object
Returns the value of attribute template.
44 45 46 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 44 def template @template end |
#timeout ⇒ Object
Returns the value of attribute timeout.
35 36 37 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 35 def timeout @timeout end |
#token_expiry ⇒ Object
Time the token sent is valid (Format: hours=3,minutes=17,seconds=300).
42 43 44 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 42 def token_expiry @token_expiry end |
#use_global_settings ⇒ Object
When enabled, global Email connection settings will be used and connection settings below will be ignored.
21 22 23 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 21 def use_global_settings @use_global_settings end |
#use_ssl ⇒ Object
Returns the value of attribute use_ssl.
33 34 35 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 33 def use_ssl @use_ssl end |
#use_tls ⇒ Object
Returns the value of attribute use_tls.
31 32 33 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 31 def use_tls @use_tls end |
#username ⇒ Object
Returns the value of attribute username.
27 28 29 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 27 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 47 def self.attribute_map { :'name' => :'name', :'configure_flow' => :'configure_flow', :'friendly_name' => :'friendly_name', :'use_global_settings' => :'use_global_settings', :'host' => :'host', :'port' => :'port', :'username' => :'username', :'password' => :'password', :'use_tls' => :'use_tls', :'use_ssl' => :'use_ssl', :'timeout' => :'timeout', :'from_address' => :'from_address', :'subject' => :'subject', :'token_expiry' => :'token_expiry', :'template' => :'template' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 413 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 99 def self.openapi_nullable Set.new([ :'configure_flow', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 78 def self.openapi_types { :'name' => :'String', :'configure_flow' => :'String', :'friendly_name' => :'String', :'use_global_settings' => :'Boolean', :'host' => :'String', :'port' => :'Integer', :'username' => :'String', :'password' => :'String', :'use_tls' => :'Boolean', :'use_ssl' => :'Boolean', :'timeout' => :'Integer', :'from_address' => :'String', :'subject' => :'String', :'token_expiry' => :'String', :'template' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 378 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && configure_flow == o.configure_flow && friendly_name == o.friendly_name && use_global_settings == o.use_global_settings && host == o.host && port == o.port && username == o.username && password == o.password && use_tls == o.use_tls && use_ssl == o.use_ssl && timeout == o.timeout && from_address == o.from_address && subject == o.subject && token_expiry == o.token_expiry && template == o.template end |
#eql?(o) ⇒ Boolean
400 401 402 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 400 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
406 407 408 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 406 def hash [name, configure_flow, friendly_name, use_global_settings, host, port, username, password, use_tls, use_ssl, timeout, from_address, subject, token_expiry, template].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 184 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@host.nil? && @host.to_s.length < 1 invalid_properties.push('invalid value for "host", the character length must be greater than or equal to 1.') end if !@port.nil? && @port > 2147483647 invalid_properties.push('invalid value for "port", must be smaller than or equal to 2147483647.') end if !@port.nil? && @port < -2147483648 invalid_properties.push('invalid value for "port", must be greater than or equal to -2147483648.') end if !@timeout.nil? && @timeout > 2147483647 invalid_properties.push('invalid value for "timeout", must be smaller than or equal to 2147483647.') end if !@timeout.nil? && @timeout < -2147483648 invalid_properties.push('invalid value for "timeout", must be greater than or equal to -2147483648.') end if !@from_address.nil? && @from_address.to_s.length > 254 invalid_properties.push('invalid value for "from_address", the character length must be smaller than or equal to 254.') end if !@from_address.nil? && @from_address.to_s.length < 1 invalid_properties.push('invalid value for "from_address", the character length must be greater than or equal to 1.') end if !@subject.nil? && @subject.to_s.length < 1 invalid_properties.push('invalid value for "subject", the character length must be greater than or equal to 1.') end if !@token_expiry.nil? && @token_expiry.to_s.length < 1 invalid_properties.push('invalid value for "token_expiry", the character length must be greater than or equal to 1.') end if !@template.nil? && @template.to_s.length < 1 invalid_properties.push('invalid value for "template", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 435 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/authentik/api/models/patched_authenticator_email_stage_request.rb', line 236 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@host.nil? && @host.to_s.length < 1 return false if !@port.nil? && @port > 2147483647 return false if !@port.nil? && @port < -2147483648 return false if !@timeout.nil? && @timeout > 2147483647 return false if !@timeout.nil? && @timeout < -2147483648 return false if !@from_address.nil? && @from_address.to_s.length > 254 return false if !@from_address.nil? && @from_address.to_s.length < 1 return false if !@subject.nil? && @subject.to_s.length < 1 return false if !@token_expiry.nil? && @token_expiry.to_s.length < 1 return false if !@template.nil? && @template.to_s.length < 1 true end |