Class: Authentik::Api::PatchedAuthenticatorEndpointGDTCStageRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb

Overview

AuthenticatorEndpointGDTCStage Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedAuthenticatorEndpointGDTCStageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 61

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedAuthenticatorEndpointGDTCStageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedAuthenticatorEndpointGDTCStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'configure_flow')
    self.configure_flow = attributes[:'configure_flow']
  end

  if attributes.key?(:'friendly_name')
    self.friendly_name = attributes[:'friendly_name']
  end

  if attributes.key?(:'credentials')
    if (value = attributes[:'credentials']).is_a?(Hash)
      self.credentials = value
    end
  end
end

Instance Attribute Details

#configure_flowObject

Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.



16
17
18
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 16

def configure_flow
  @configure_flow
end

#credentialsObject

Returns the value of attribute credentials.



20
21
22
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 20

def credentials
  @credentials
end

#friendly_nameObject

Returns the value of attribute friendly_name.



18
19
20
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 18

def friendly_name
  @friendly_name
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 13

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



33
34
35
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 33

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 38

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 23

def self.attribute_map
  {
    :'name' => :'name',
    :'configure_flow' => :'configure_flow',
    :'friendly_name' => :'friendly_name',
    :'credentials' => :'credentials'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 154

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



53
54
55
56
57
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 53

def self.openapi_nullable
  Set.new([
    :'configure_flow',
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
50
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 43

def self.openapi_types
  {
    :'name' => :'String',
    :'configure_flow' => :'String',
    :'friendly_name' => :'String',
    :'credentials' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



130
131
132
133
134
135
136
137
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 130

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      configure_flow == o.configure_flow &&
      friendly_name == o.friendly_name &&
      credentials == o.credentials
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


141
142
143
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 141

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



147
148
149
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 147

def hash
  [name, configure_flow, friendly_name, credentials].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



96
97
98
99
100
101
102
103
104
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 96

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 176

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



108
109
110
111
112
# File 'lib/authentik/api/models/patched_authenticator_endpoint_gdtc_stage_request.rb', line 108

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  true
end