Class: Authentik::Api::PatchedAuthenticatorSMSStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedAuthenticatorSMSStageRequest
- Defined in:
- lib/authentik/api/models/patched_authenticator_sms_stage_request.rb
Overview
AuthenticatorSMSStage Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_sid ⇒ Object
Returns the value of attribute account_sid.
-
#auth ⇒ Object
Returns the value of attribute auth.
-
#auth_password ⇒ Object
Returns the value of attribute auth_password.
-
#auth_type ⇒ Object
Returns the value of attribute auth_type.
-
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage.
-
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
-
#from_number ⇒ Object
Returns the value of attribute from_number.
-
#mapping ⇒ Object
Optionally modify the payload being sent to custom providers.
-
#name ⇒ Object
Returns the value of attribute name.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#verify_only ⇒ Object
When enabled, the Phone number is only used during enrollment to verify the users authenticity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedAuthenticatorSMSStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedAuthenticatorSMSStageRequest
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedAuthenticatorSMSStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedAuthenticatorSMSStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'configure_flow') self.configure_flow = attributes[:'configure_flow'] end if attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'from_number') self.from_number = attributes[:'from_number'] end if attributes.key?(:'account_sid') self.account_sid = attributes[:'account_sid'] end if attributes.key?(:'auth') self.auth = attributes[:'auth'] end if attributes.key?(:'auth_password') self.auth_password = attributes[:'auth_password'] end if attributes.key?(:'auth_type') self.auth_type = attributes[:'auth_type'] end if attributes.key?(:'verify_only') self.verify_only = attributes[:'verify_only'] end if attributes.key?(:'mapping') self.mapping = attributes[:'mapping'] end end |
Instance Attribute Details
#account_sid ⇒ Object
Returns the value of attribute account_sid.
24 25 26 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 24 def account_sid @account_sid end |
#auth ⇒ Object
Returns the value of attribute auth.
26 27 28 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 26 def auth @auth end |
#auth_password ⇒ Object
Returns the value of attribute auth_password.
28 29 30 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 28 def auth_password @auth_password end |
#auth_type ⇒ Object
Returns the value of attribute auth_type.
30 31 32 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 30 def auth_type @auth_type end |
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.
16 17 18 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 16 def configure_flow @configure_flow end |
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
18 19 20 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 18 def friendly_name @friendly_name end |
#from_number ⇒ Object
Returns the value of attribute from_number.
22 23 24 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 22 def from_number @from_number end |
#mapping ⇒ Object
Optionally modify the payload being sent to custom providers.
36 37 38 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 36 def mapping @mapping end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 13 def name @name end |
#provider ⇒ Object
Returns the value of attribute provider.
20 21 22 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 20 def provider @provider end |
#verify_only ⇒ Object
When enabled, the Phone number is only used during enrollment to verify the users authenticity. Only a hash of the phone number is saved to ensure it is not reused in the future.
33 34 35 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 33 def verify_only @verify_only end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 61 def self.attribute_map { :'name' => :'name', :'configure_flow' => :'configure_flow', :'friendly_name' => :'friendly_name', :'provider' => :'provider', :'from_number' => :'from_number', :'account_sid' => :'account_sid', :'auth' => :'auth', :'auth_password' => :'auth_password', :'auth_type' => :'auth_type', :'verify_only' => :'verify_only', :'mapping' => :'mapping' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 297 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 110 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 105 def self.openapi_nullable Set.new([ :'configure_flow', :'mapping' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 88 def self.openapi_types { :'name' => :'String', :'configure_flow' => :'String', :'friendly_name' => :'String', :'provider' => :'ProviderEnum', :'from_number' => :'String', :'account_sid' => :'String', :'auth' => :'String', :'auth_password' => :'String', :'auth_type' => :'AuthTypeEnum', :'verify_only' => :'Boolean', :'mapping' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && configure_flow == o.configure_flow && friendly_name == o.friendly_name && provider == o.provider && from_number == o.from_number && account_sid == o.account_sid && auth == o.auth && auth_password == o.auth_password && auth_type == o.auth_type && verify_only == o.verify_only && mapping == o.mapping end |
#eql?(o) ⇒ Boolean
284 285 286 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 284 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
290 291 292 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 290 def hash [name, configure_flow, friendly_name, provider, from_number, account_sid, auth, auth_password, auth_type, verify_only, mapping].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@from_number.nil? && @from_number.to_s.length < 1 invalid_properties.push('invalid value for "from_number", the character length must be greater than or equal to 1.') end if !@account_sid.nil? && @account_sid.to_s.length < 1 invalid_properties.push('invalid value for "account_sid", the character length must be greater than or equal to 1.') end if !@auth.nil? && @auth.to_s.length < 1 invalid_properties.push('invalid value for "auth", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 319 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 |
# File 'lib/authentik/api/models/patched_authenticator_sms_stage_request.rb', line 199 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@from_number.nil? && @from_number.to_s.length < 1 return false if !@account_sid.nil? && @account_sid.to_s.length < 1 return false if !@auth.nil? && @auth.to_s.length < 1 true end |