Class: Authentik::Api::PatchedAuthenticatorTOTPStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedAuthenticatorTOTPStageRequest
- Defined in:
- lib/authentik/api/models/patched_authenticator_totp_stage_request.rb
Overview
AuthenticatorTOTPStage Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage.
-
#digits ⇒ Object
Returns the value of attribute digits.
-
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedAuthenticatorTOTPStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedAuthenticatorTOTPStageRequest
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedAuthenticatorTOTPStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedAuthenticatorTOTPStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'configure_flow') self.configure_flow = attributes[:'configure_flow'] end if attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] end if attributes.key?(:'digits') self.digits = attributes[:'digits'] end end |
Instance Attribute Details
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.
16 17 18 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 16 def configure_flow @configure_flow end |
#digits ⇒ Object
Returns the value of attribute digits.
20 21 22 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 20 def digits @digits end |
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
18 19 20 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 18 def friendly_name @friendly_name end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 13 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 45 def self.attribute_map { :'name' => :'name', :'configure_flow' => :'configure_flow', :'friendly_name' => :'friendly_name', :'digits' => :'digits' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 174 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 79 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 75 def self.openapi_nullable Set.new([ :'configure_flow', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 65 def self.openapi_types { :'name' => :'String', :'configure_flow' => :'String', :'friendly_name' => :'String', :'digits' => :'DigitsEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && configure_flow == o.configure_flow && friendly_name == o.friendly_name && digits == o.digits end |
#eql?(o) ⇒ Boolean
161 162 163 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 161 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 167 def hash [name, configure_flow, friendly_name, digits].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 |
# File 'lib/authentik/api/models/patched_authenticator_totp_stage_request.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 true end |