Class: Authentik::Api::PatchedAuthenticatorValidateStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedAuthenticatorValidateStageRequest
- Defined in:
- lib/authentik/api/models/patched_authenticator_validate_stage_request.rb
Overview
AuthenticatorValidateStage Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#configuration_stages ⇒ Object
Stages used to configure Authenticator when user doesn’t have any compatible devices.
-
#device_classes ⇒ Object
Device classes which can be used to authenticate.
-
#last_auth_threshold ⇒ Object
If any of the user’s device has been used within this threshold, this stage will be skipped.
-
#name ⇒ Object
Returns the value of attribute name.
-
#not_configured_action ⇒ Object
Returns the value of attribute not_configured_action.
-
#webauthn_allowed_device_types ⇒ Object
Returns the value of attribute webauthn_allowed_device_types.
-
#webauthn_user_verification ⇒ Object
Enforce user verification for WebAuthn devices.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedAuthenticatorValidateStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedAuthenticatorValidateStageRequest
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedAuthenticatorValidateStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedAuthenticatorValidateStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'not_configured_action') self.not_configured_action = attributes[:'not_configured_action'] end if attributes.key?(:'device_classes') if (value = attributes[:'device_classes']).is_a?(Array) self.device_classes = value end end if attributes.key?(:'configuration_stages') if (value = attributes[:'configuration_stages']).is_a?(Array) self.configuration_stages = value end end if attributes.key?(:'last_auth_threshold') self.last_auth_threshold = attributes[:'last_auth_threshold'] end if attributes.key?(:'webauthn_user_verification') self.webauthn_user_verification = attributes[:'webauthn_user_verification'] end if attributes.key?(:'webauthn_allowed_device_types') if (value = attributes[:'webauthn_allowed_device_types']).is_a?(Array) self.webauthn_allowed_device_types = value end end end |
Instance Attribute Details
#configuration_stages ⇒ Object
Stages used to configure Authenticator when user doesn’t have any compatible devices. After this configuration Stage passes, the user is not prompted again.
21 22 23 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 21 def configuration_stages @configuration_stages end |
#device_classes ⇒ Object
Device classes which can be used to authenticate
18 19 20 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 18 def device_classes @device_classes end |
#last_auth_threshold ⇒ Object
If any of the user’s device has been used within this threshold, this stage will be skipped
24 25 26 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 24 def last_auth_threshold @last_auth_threshold end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 13 def name @name end |
#not_configured_action ⇒ Object
Returns the value of attribute not_configured_action.
15 16 17 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 15 def not_configured_action @not_configured_action end |
#webauthn_allowed_device_types ⇒ Object
Returns the value of attribute webauthn_allowed_device_types.
29 30 31 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 29 def webauthn_allowed_device_types @webauthn_allowed_device_types end |
#webauthn_user_verification ⇒ Object
Enforce user verification for WebAuthn devices.
27 28 29 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 27 def webauthn_user_verification @webauthn_user_verification end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 54 def self.attribute_map { :'name' => :'name', :'not_configured_action' => :'not_configured_action', :'device_classes' => :'device_classes', :'configuration_stages' => :'configuration_stages', :'last_auth_threshold' => :'last_auth_threshold', :'webauthn_user_verification' => :'webauthn_user_verification', :'webauthn_allowed_device_types' => :'webauthn_allowed_device_types' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 228 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 77 def self.openapi_types { :'name' => :'String', :'not_configured_action' => :'NotConfiguredActionEnum', :'device_classes' => :'Array<DeviceClassesEnum>', :'configuration_stages' => :'Array<String>', :'last_auth_threshold' => :'String', :'webauthn_user_verification' => :'UserVerificationEnum', :'webauthn_allowed_device_types' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 201 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && not_configured_action == o.not_configured_action && device_classes == o.device_classes && configuration_stages == o.configuration_stages && last_auth_threshold == o.last_auth_threshold && webauthn_user_verification == o.webauthn_user_verification && webauthn_allowed_device_types == o.webauthn_allowed_device_types end |
#eql?(o) ⇒ Boolean
215 216 217 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 215 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 221 def hash [name, not_configured_action, device_classes, configuration_stages, last_auth_threshold, webauthn_user_verification, webauthn_allowed_device_types].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@last_auth_threshold.nil? && @last_auth_threshold.to_s.length < 1 invalid_properties.push('invalid value for "last_auth_threshold", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 |
# File 'lib/authentik/api/models/patched_authenticator_validate_stage_request.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@last_auth_threshold.nil? && @last_auth_threshold.to_s.length < 1 true end |