Class: Authentik::Api::PatchedBlueprintInstanceRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedBlueprintInstanceRequest
- Defined in:
- lib/authentik/api/models/patched_blueprint_instance_request.rb
Overview
Info about a single blueprint instance file
Instance Attribute Summary collapse
-
#content ⇒ Object
Returns the value of attribute content.
-
#context ⇒ Object
Returns the value of attribute context.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#name ⇒ Object
Returns the value of attribute name.
-
#path ⇒ Object
Returns the value of attribute path.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedBlueprintInstanceRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedBlueprintInstanceRequest
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedBlueprintInstanceRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedBlueprintInstanceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'path') self.path = attributes[:'path'] else self.path = '' end if attributes.key?(:'context') if (value = attributes[:'context']).is_a?(Hash) self.context = value end end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'content') self.content = attributes[:'content'] end end |
Instance Attribute Details
#content ⇒ Object
Returns the value of attribute content.
21 22 23 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 21 def content @content end |
#context ⇒ Object
Returns the value of attribute context.
17 18 19 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 17 def context @context end |
#enabled ⇒ Object
Returns the value of attribute enabled.
19 20 21 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 19 def enabled @enabled end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 13 def name @name end |
#path ⇒ Object
Returns the value of attribute path.
15 16 17 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 15 def path @path end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 24 def self.attribute_map { :'name' => :'name', :'path' => :'path', :'context' => :'context', :'enabled' => :'enabled', :'content' => :'content' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 163 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 45 def self.openapi_types { :'name' => :'String', :'path' => :'String', :'context' => :'Hash<String, Object>', :'enabled' => :'Boolean', :'content' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && path == o.path && context == o.context && enabled == o.enabled && content == o.content end |
#eql?(o) ⇒ Boolean
150 151 152 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 150 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 156 def hash [name, path, context, enabled, content].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 108 109 110 111 112 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 104 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 185 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
116 117 118 119 120 |
# File 'lib/authentik/api/models/patched_blueprint_instance_request.rb', line 116 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 true end |