Class: Authentik::Api::PatchedConsentStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedConsentStageRequest
- Defined in:
- lib/authentik/api/models/patched_consent_stage_request.rb
Overview
ConsentStage Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#consent_expire_in ⇒ Object
Offset after which consent expires.
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedConsentStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedConsentStageRequest
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedConsentStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedConsentStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'consent_expire_in') self. = attributes[:'consent_expire_in'] end end |
Instance Attribute Details
#consent_expire_in ⇒ Object
Offset after which consent expires. (Format: hours=1;minutes=2;seconds=3).
18 19 20 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 18 def @consent_expire_in end |
#mode ⇒ Object
Returns the value of attribute mode.
15 16 17 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 15 def mode @mode end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 13 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 43 def self.attribute_map { :'name' => :'name', :'mode' => :'mode', :'consent_expire_in' => :'consent_expire_in' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 183 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 62 def self.openapi_types { :'name' => :'String', :'mode' => :'ConsentModeEnum', :'consent_expire_in' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && mode == o.mode && == o. end |
#eql?(o) ⇒ Boolean
170 171 172 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 170 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 176 def hash [name, mode, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@consent_expire_in.nil? && @consent_expire_in.to_s.length < 1 invalid_properties.push('invalid value for "consent_expire_in", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 127 128 |
# File 'lib/authentik/api/models/patched_consent_stage_request.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@consent_expire_in.nil? && @consent_expire_in.to_s.length < 1 true end |