Class: Authentik::Api::PatchedEmailStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedEmailStageRequest
- Defined in:
- lib/authentik/api/models/patched_email_stage_request.rb
Overview
EmailStage Serializer
Instance Attribute Summary collapse
-
#activate_user_on_success ⇒ Object
Activate users upon completion of stage.
-
#from_address ⇒ Object
Returns the value of attribute from_address.
-
#host ⇒ Object
Returns the value of attribute host.
-
#name ⇒ Object
Returns the value of attribute name.
-
#password ⇒ Object
Returns the value of attribute password.
-
#port ⇒ Object
Returns the value of attribute port.
-
#recovery_cache_timeout ⇒ Object
The time window used to count recent account recovery attempts.
-
#recovery_max_attempts ⇒ Object
Returns the value of attribute recovery_max_attempts.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#template ⇒ Object
Returns the value of attribute template.
-
#timeout ⇒ Object
Returns the value of attribute timeout.
-
#token_expiry ⇒ Object
Time the token sent is valid (Format: hours=3,minutes=17,seconds=300).
-
#use_global_settings ⇒ Object
When enabled, global Email connection settings will be used and connection settings below will be ignored.
-
#use_ssl ⇒ Object
Returns the value of attribute use_ssl.
-
#use_tls ⇒ Object
Returns the value of attribute use_tls.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedEmailStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedEmailStageRequest
Initializes the object
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 111 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedEmailStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedEmailStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'use_global_settings') self.use_global_settings = attributes[:'use_global_settings'] end if attributes.key?(:'host') self.host = attributes[:'host'] end if attributes.key?(:'port') self.port = attributes[:'port'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'use_tls') self.use_tls = attributes[:'use_tls'] end if attributes.key?(:'use_ssl') self.use_ssl = attributes[:'use_ssl'] end if attributes.key?(:'timeout') self.timeout = attributes[:'timeout'] end if attributes.key?(:'from_address') self.from_address = attributes[:'from_address'] end if attributes.key?(:'token_expiry') self.token_expiry = attributes[:'token_expiry'] end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'activate_user_on_success') self.activate_user_on_success = attributes[:'activate_user_on_success'] end if attributes.key?(:'recovery_max_attempts') self.recovery_max_attempts = attributes[:'recovery_max_attempts'] end if attributes.key?(:'recovery_cache_timeout') self.recovery_cache_timeout = attributes[:'recovery_cache_timeout'] end end |
Instance Attribute Details
#activate_user_on_success ⇒ Object
Activate users upon completion of stage.
42 43 44 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 42 def activate_user_on_success @activate_user_on_success end |
#from_address ⇒ Object
Returns the value of attribute from_address.
32 33 34 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 32 def from_address @from_address end |
#host ⇒ Object
Returns the value of attribute host.
18 19 20 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 18 def host @host end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 13 def name @name end |
#password ⇒ Object
Returns the value of attribute password.
24 25 26 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 24 def password @password end |
#port ⇒ Object
Returns the value of attribute port.
20 21 22 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 20 def port @port end |
#recovery_cache_timeout ⇒ Object
The time window used to count recent account recovery attempts. If the number of attempts exceed recovery_max_attempts within this period, further attempts will be rate-limited. (Format: hours=1;minutes=2;seconds=3).
47 48 49 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 47 def recovery_cache_timeout @recovery_cache_timeout end |
#recovery_max_attempts ⇒ Object
Returns the value of attribute recovery_max_attempts.
44 45 46 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 44 def recovery_max_attempts @recovery_max_attempts end |
#subject ⇒ Object
Returns the value of attribute subject.
37 38 39 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 37 def subject @subject end |
#template ⇒ Object
Returns the value of attribute template.
39 40 41 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 39 def template @template end |
#timeout ⇒ Object
Returns the value of attribute timeout.
30 31 32 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 30 def timeout @timeout end |
#token_expiry ⇒ Object
Time the token sent is valid (Format: hours=3,minutes=17,seconds=300).
35 36 37 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 35 def token_expiry @token_expiry end |
#use_global_settings ⇒ Object
When enabled, global Email connection settings will be used and connection settings below will be ignored.
16 17 18 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 16 def use_global_settings @use_global_settings end |
#use_ssl ⇒ Object
Returns the value of attribute use_ssl.
28 29 30 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 28 def use_ssl @use_ssl end |
#use_tls ⇒ Object
Returns the value of attribute use_tls.
26 27 28 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 26 def use_tls @use_tls end |
#username ⇒ Object
Returns the value of attribute username.
22 23 24 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 22 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 50 def self.attribute_map { :'name' => :'name', :'use_global_settings' => :'use_global_settings', :'host' => :'host', :'port' => :'port', :'username' => :'username', :'password' => :'password', :'use_tls' => :'use_tls', :'use_ssl' => :'use_ssl', :'timeout' => :'timeout', :'from_address' => :'from_address', :'token_expiry' => :'token_expiry', :'subject' => :'subject', :'template' => :'template', :'activate_user_on_success' => :'activate_user_on_success', :'recovery_max_attempts' => :'recovery_max_attempts', :'recovery_cache_timeout' => :'recovery_cache_timeout' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 469 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 104 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 82 def self.openapi_types { :'name' => :'String', :'use_global_settings' => :'Boolean', :'host' => :'String', :'port' => :'Integer', :'username' => :'String', :'password' => :'String', :'use_tls' => :'Boolean', :'use_ssl' => :'Boolean', :'timeout' => :'Integer', :'from_address' => :'String', :'token_expiry' => :'String', :'subject' => :'String', :'template' => :'String', :'activate_user_on_success' => :'Boolean', :'recovery_max_attempts' => :'Integer', :'recovery_cache_timeout' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 433 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && use_global_settings == o.use_global_settings && host == o.host && port == o.port && username == o.username && password == o.password && use_tls == o.use_tls && use_ssl == o.use_ssl && timeout == o.timeout && from_address == o.from_address && token_expiry == o.token_expiry && subject == o.subject && template == o.template && activate_user_on_success == o.activate_user_on_success && recovery_max_attempts == o.recovery_max_attempts && recovery_cache_timeout == o.recovery_cache_timeout end |
#eql?(o) ⇒ Boolean
456 457 458 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 456 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
462 463 464 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 462 def hash [name, use_global_settings, host, port, username, password, use_tls, use_ssl, timeout, from_address, token_expiry, subject, template, activate_user_on_success, recovery_max_attempts, recovery_cache_timeout].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 192 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@host.nil? && @host.to_s.length < 1 invalid_properties.push('invalid value for "host", the character length must be greater than or equal to 1.') end if !@port.nil? && @port > 2147483647 invalid_properties.push('invalid value for "port", must be smaller than or equal to 2147483647.') end if !@port.nil? && @port < -2147483648 invalid_properties.push('invalid value for "port", must be greater than or equal to -2147483648.') end if !@timeout.nil? && @timeout > 2147483647 invalid_properties.push('invalid value for "timeout", must be smaller than or equal to 2147483647.') end if !@timeout.nil? && @timeout < -2147483648 invalid_properties.push('invalid value for "timeout", must be greater than or equal to -2147483648.') end if !@from_address.nil? && @from_address.to_s.length > 254 invalid_properties.push('invalid value for "from_address", the character length must be smaller than or equal to 254.') end if !@from_address.nil? && @from_address.to_s.length < 1 invalid_properties.push('invalid value for "from_address", the character length must be greater than or equal to 1.') end if !@token_expiry.nil? && @token_expiry.to_s.length < 1 invalid_properties.push('invalid value for "token_expiry", the character length must be greater than or equal to 1.') end if !@subject.nil? && @subject.to_s.length < 1 invalid_properties.push('invalid value for "subject", the character length must be greater than or equal to 1.') end if !@template.nil? && @template.to_s.length < 1 invalid_properties.push('invalid value for "template", the character length must be greater than or equal to 1.') end if !@recovery_max_attempts.nil? && @recovery_max_attempts > 2147483647 invalid_properties.push('invalid value for "recovery_max_attempts", must be smaller than or equal to 2147483647.') end if !@recovery_max_attempts.nil? && @recovery_max_attempts < 0 invalid_properties.push('invalid value for "recovery_max_attempts", must be greater than or equal to 0.') end if !@recovery_cache_timeout.nil? && @recovery_cache_timeout.to_s.length < 1 invalid_properties.push('invalid value for "recovery_cache_timeout", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 491 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/authentik/api/models/patched_email_stage_request.rb', line 256 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@host.nil? && @host.to_s.length < 1 return false if !@port.nil? && @port > 2147483647 return false if !@port.nil? && @port < -2147483648 return false if !@timeout.nil? && @timeout > 2147483647 return false if !@timeout.nil? && @timeout < -2147483648 return false if !@from_address.nil? && @from_address.to_s.length > 254 return false if !@from_address.nil? && @from_address.to_s.length < 1 return false if !@token_expiry.nil? && @token_expiry.to_s.length < 1 return false if !@subject.nil? && @subject.to_s.length < 1 return false if !@template.nil? && @template.to_s.length < 1 return false if !@recovery_max_attempts.nil? && @recovery_max_attempts > 2147483647 return false if !@recovery_max_attempts.nil? && @recovery_max_attempts < 0 return false if !@recovery_cache_timeout.nil? && @recovery_cache_timeout.to_s.length < 1 true end |