Class: Authentik::Api::PatchedEndpointRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_endpoint_request.rb

Overview

Endpoint Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedEndpointRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedEndpointRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedEndpointRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'protocol')
    self.protocol = attributes[:'protocol']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end

  if attributes.key?(:'settings')
    if (value = attributes[:'settings']).is_a?(Hash)
      self.settings = value
    end
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'auth_mode')
    self.auth_mode = attributes[:'auth_mode']
  end

  if attributes.key?(:'maximum_connections')
    self.maximum_connections = attributes[:'maximum_connections']
  end
end

Instance Attribute Details

#auth_modeObject

Returns the value of attribute auth_mode.



25
26
27
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 25

def auth_mode
  @auth_mode
end

#hostObject

Returns the value of attribute host.



19
20
21
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 19

def host
  @host
end

#maximum_connectionsObject

Returns the value of attribute maximum_connections.



27
28
29
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 27

def maximum_connections
  @maximum_connections
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 13

def name
  @name
end

#property_mappingsObject

Returns the value of attribute property_mappings.



23
24
25
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 23

def property_mappings
  @property_mappings
end

#protocolObject

Returns the value of attribute protocol.



17
18
19
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 17

def protocol
  @protocol
end

#providerObject

Returns the value of attribute provider.



15
16
17
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 15

def provider
  @provider
end

#settingsObject

Returns the value of attribute settings.



21
22
23
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 21

def settings
  @settings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 52

def self.attribute_map
  {
    :'name' => :'name',
    :'provider' => :'provider',
    :'protocol' => :'protocol',
    :'host' => :'host',
    :'settings' => :'settings',
    :'property_mappings' => :'property_mappings',
    :'auth_mode' => :'auth_mode',
    :'maximum_connections' => :'maximum_connections'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 76

def self.openapi_types
  {
    :'name' => :'String',
    :'provider' => :'Integer',
    :'protocol' => :'ProtocolEnum',
    :'host' => :'String',
    :'settings' => :'Hash<String, Object>',
    :'property_mappings' => :'Array<String>',
    :'auth_mode' => :'EndpointAuthModeEnum',
    :'maximum_connections' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      provider == o.provider &&
      protocol == o.protocol &&
      host == o.host &&
      settings == o.settings &&
      property_mappings == o.property_mappings &&
      auth_mode == o.auth_mode &&
      maximum_connections == o.maximum_connections
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 252

def hash
  [name, provider, protocol, host, settings, property_mappings, auth_mode, maximum_connections].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@host.nil? && @host.to_s.length < 1
    invalid_properties.push('invalid value for "host", the character length must be greater than or equal to 1.')
  end

  if !@maximum_connections.nil? && @maximum_connections > 2147483647
    invalid_properties.push('invalid value for "maximum_connections", must be smaller than or equal to 2147483647.')
  end

  if !@maximum_connections.nil? && @maximum_connections < -2147483648
    invalid_properties.push('invalid value for "maximum_connections", must be greater than or equal to -2147483648.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 281

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
# File 'lib/authentik/api/models/patched_endpoint_request.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@host.nil? && @host.to_s.length < 1
  return false if !@maximum_connections.nil? && @maximum_connections > 2147483647
  return false if !@maximum_connections.nil? && @maximum_connections < -2147483648
  true
end