Class: Authentik::Api::PatchedEnrollmentTokenRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedEnrollmentTokenRequest
- Defined in:
- lib/authentik/api/models/patched_enrollment_token_request.rb
Instance Attribute Summary collapse
-
#connector ⇒ Object
Returns the value of attribute connector.
-
#device_group ⇒ Object
Returns the value of attribute device_group.
-
#expires ⇒ Object
Returns the value of attribute expires.
-
#expiring ⇒ Object
Returns the value of attribute expiring.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedEnrollmentTokenRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedEnrollmentTokenRequest
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedEnrollmentTokenRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedEnrollmentTokenRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'device_group') self.device_group = attributes[:'device_group'] end if attributes.key?(:'connector') self.connector = attributes[:'connector'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'expiring') self.expiring = attributes[:'expiring'] end if attributes.key?(:'expires') self.expires = attributes[:'expires'] end end |
Instance Attribute Details
#connector ⇒ Object
Returns the value of attribute connector.
14 15 16 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 14 def connector @connector end |
#device_group ⇒ Object
Returns the value of attribute device_group.
12 13 14 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 12 def device_group @device_group end |
#expires ⇒ Object
Returns the value of attribute expires.
20 21 22 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 20 def expires @expires end |
#expiring ⇒ Object
Returns the value of attribute expiring.
18 19 20 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 18 def expiring @expiring end |
#name ⇒ Object
Returns the value of attribute name.
16 17 18 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 16 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 31 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 23 def self.attribute_map { :'device_group' => :'device_group', :'connector' => :'connector', :'name' => :'name', :'expiring' => :'expiring', :'expires' => :'expires' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 59 60 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 55 def self.openapi_nullable Set.new([ :'device_group', :'expires' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 44 def self.openapi_types { :'device_group' => :'String', :'connector' => :'String', :'name' => :'String', :'expiring' => :'Boolean', :'expires' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 135 def ==(o) return true if self.equal?(o) self.class == o.class && device_group == o.device_group && connector == o.connector && name == o.name && expiring == o.expiring && expires == o.expires end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 153 def hash [device_group, connector, name, expiring, expires].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
101 102 103 104 105 106 107 108 109 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 101 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 116 117 |
# File 'lib/authentik/api/models/patched_enrollment_token_request.rb', line 113 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 true end |