Class: Authentik::Api::PatchedEventMatcherPolicyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedEventMatcherPolicyRequest
- Defined in:
- lib/authentik/api/models/patched_event_matcher_policy_request.rb
Overview
Event Matcher Policy Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Match created events with this action type.
-
#app ⇒ Object
Match events created by selected application.
-
#client_ip ⇒ Object
Matches Event’s Client IP (strict matching, for network matching use an Expression Policy).
-
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged.
-
#model ⇒ Object
Match events created by selected model.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedEventMatcherPolicyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedEventMatcherPolicyRequest
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedEventMatcherPolicyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedEventMatcherPolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'execution_logging') self.execution_logging = attributes[:'execution_logging'] end if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'client_ip') self.client_ip = attributes[:'client_ip'] end if attributes.key?(:'app') self.app = attributes[:'app'] end if attributes.key?(:'model') self.model = attributes[:'model'] end end |
Instance Attribute Details
#action ⇒ Object
Match created events with this action type. When left empty, all action types will be matched.
19 20 21 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 19 def action @action end |
#app ⇒ Object
Match events created by selected application. When left empty, all applications are matched.
25 26 27 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 25 def app @app end |
#client_ip ⇒ Object
Matches Event’s Client IP (strict matching, for network matching use an Expression Policy)
22 23 24 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 22 def client_ip @client_ip end |
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.
16 17 18 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 16 def execution_logging @execution_logging end |
#model ⇒ Object
Match events created by selected model. When left empty, all models are matched. When an app is selected, all the application’s models are matched.
28 29 30 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 28 def model @model end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 13 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 53 def self.attribute_map { :'name' => :'name', :'execution_logging' => :'execution_logging', :'action' => :'action', :'client_ip' => :'client_ip', :'app' => :'app', :'model' => :'model' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 91 92 93 94 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 87 def self.openapi_nullable Set.new([ :'action', :'client_ip', :'app', :'model' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 75 def self.openapi_types { :'name' => :'String', :'execution_logging' => :'Boolean', :'action' => :'EventActions', :'client_ip' => :'String', :'app' => :'AppEnum', :'model' => :'ModelEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && execution_logging == o.execution_logging && action == o.action && client_ip == o.client_ip && app == o.app && model == o.model end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 207 def hash [name, execution_logging, action, client_ip, app, model].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@client_ip.nil? && @client_ip.to_s.length < 1 invalid_properties.push('invalid value for "client_ip", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 159 160 |
# File 'lib/authentik/api/models/patched_event_matcher_policy_request.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@client_ip.nil? && @client_ip.to_s.length < 1 true end |