Class: Authentik::Api::PatchedExpressionPolicyRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_expression_policy_request.rb

Overview

Group Membership Policy Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedExpressionPolicyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 56

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedExpressionPolicyRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedExpressionPolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'execution_logging')
    self.execution_logging = attributes[:'execution_logging']
  end

  if attributes.key?(:'expression')
    self.expression = attributes[:'expression']
  end
end

Instance Attribute Details

#execution_loggingObject

When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.



16
17
18
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 16

def execution_logging
  @execution_logging
end

#expressionObject

Returns the value of attribute expression.



18
19
20
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 18

def expression
  @expression
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 13

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



30
31
32
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 30

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



35
36
37
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 35

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 21

def self.attribute_map
  {
    :'name' => :'name',
    :'execution_logging' => :'execution_logging',
    :'expression' => :'expression'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



49
50
51
52
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 49

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



40
41
42
43
44
45
46
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 40

def self.openapi_types
  {
    :'name' => :'String',
    :'execution_logging' => :'Boolean',
    :'expression' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



138
139
140
141
142
143
144
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 138

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      execution_logging == o.execution_logging &&
      expression == o.expression
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 148

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 154

def hash
  [name, execution_logging, expression].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 85

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@expression.nil? && @expression.to_s.length < 1
    invalid_properties.push('invalid value for "expression", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



101
102
103
104
105
106
# File 'lib/authentik/api/models/patched_expression_policy_request.rb', line 101

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@expression.nil? && @expression.to_s.length < 1
  true
end