Class: Authentik::Api::PatchedFleetConnectorRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedFleetConnectorRequest
- Defined in:
- lib/authentik/api/models/patched_fleet_connector_request.rb
Overview
FleetConnector Serializer
Instance Attribute Summary collapse
-
#connector_uuid ⇒ Object
Returns the value of attribute connector_uuid.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#headers_mapping ⇒ Object
Configure additional headers to be sent.
-
#map_teams_access_group ⇒ Object
Returns the value of attribute map_teams_access_group.
-
#map_users ⇒ Object
Returns the value of attribute map_users.
-
#name ⇒ Object
Returns the value of attribute name.
-
#token ⇒ Object
Returns the value of attribute token.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedFleetConnectorRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedFleetConnectorRequest
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 77 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedFleetConnectorRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedFleetConnectorRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'connector_uuid') self.connector_uuid = attributes[:'connector_uuid'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'headers_mapping') self.headers_mapping = attributes[:'headers_mapping'] end if attributes.key?(:'map_users') self.map_users = attributes[:'map_users'] end if attributes.key?(:'map_teams_access_group') self.map_teams_access_group = attributes[:'map_teams_access_group'] end end |
Instance Attribute Details
#connector_uuid ⇒ Object
Returns the value of attribute connector_uuid.
13 14 15 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 13 def connector_uuid @connector_uuid end |
#enabled ⇒ Object
Returns the value of attribute enabled.
17 18 19 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 17 def enabled @enabled end |
#headers_mapping ⇒ Object
Configure additional headers to be sent. Mapping should return a dictionary of key-value pairs
24 25 26 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 24 def headers_mapping @headers_mapping end |
#map_teams_access_group ⇒ Object
Returns the value of attribute map_teams_access_group.
28 29 30 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 28 def map_teams_access_group @map_teams_access_group end |
#map_users ⇒ Object
Returns the value of attribute map_users.
26 27 28 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 26 def map_users @map_users end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 15 def name @name end |
#token ⇒ Object
Returns the value of attribute token.
21 22 23 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 21 def token @token end |
#url ⇒ Object
Returns the value of attribute url.
19 20 21 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 19 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 31 def self.attribute_map { :'connector_uuid' => :'connector_uuid', :'name' => :'name', :'enabled' => :'enabled', :'url' => :'url', :'token' => :'token', :'headers_mapping' => :'headers_mapping', :'map_users' => :'map_users', :'map_teams_access_group' => :'map_teams_access_group' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 235 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 73 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 69 def self.openapi_nullable Set.new([ :'headers_mapping', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 55 def self.openapi_types { :'connector_uuid' => :'String', :'name' => :'String', :'enabled' => :'Boolean', :'url' => :'String', :'token' => :'String', :'headers_mapping' => :'String', :'map_users' => :'Boolean', :'map_teams_access_group' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && connector_uuid == o.connector_uuid && name == o.name && enabled == o.enabled && url == o.url && token == o.token && headers_mapping == o.headers_mapping && map_users == o.map_users && map_teams_access_group == o.map_teams_access_group end |
#eql?(o) ⇒ Boolean
222 223 224 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 222 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 228 def hash [connector_uuid, name, enabled, url, token, headers_mapping, map_users, map_teams_access_group].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@url.nil? && @url.to_s.length > 200 invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 200.') end if !@url.nil? && @url.to_s.length < 1 invalid_properties.push('invalid value for "url", the character length must be greater than or equal to 1.') end if !@token.nil? && @token.to_s.length < 1 invalid_properties.push('invalid value for "token", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 257 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/patched_fleet_connector_request.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@url.nil? && @url.to_s.length > 200 return false if !@url.nil? && @url.to_s.length < 1 return false if !@token.nil? && @token.to_s.length < 1 true end |