Class: Authentik::Api::PatchedFlowStageBindingRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_flow_stage_binding_request.rb

Overview

FlowStageBinding Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedFlowStageBindingRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedFlowStageBindingRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedFlowStageBindingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'stage')
    self.stage = attributes[:'stage']
  end

  if attributes.key?(:'evaluate_on_plan')
    self.evaluate_on_plan = attributes[:'evaluate_on_plan']
  end

  if attributes.key?(:'re_evaluate_policies')
    self.re_evaluate_policies = attributes[:'re_evaluate_policies']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'invalid_response_action')
    self.invalid_response_action = attributes[:'invalid_response_action']
  end
end

Instance Attribute Details

#evaluate_on_planObject

Evaluate policies during the Flow planning process.



18
19
20
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 18

def evaluate_on_plan
  @evaluate_on_plan
end

#invalid_response_actionObject

Configure how the flow executor should handle an invalid response to a challenge. RETRY returns the error message and a similar challenge to the executor. RESTART restarts the flow from the beginning, and RESTART_WITH_CONTEXT restarts the flow while keeping the current context.



28
29
30
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 28

def invalid_response_action
  @invalid_response_action
end

#orderObject

Returns the value of attribute order.



23
24
25
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 23

def order
  @order
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



25
26
27
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 25

def policy_engine_mode
  @policy_engine_mode
end

#re_evaluate_policiesObject

Evaluate policies when the Stage is presented to the user.



21
22
23
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 21

def re_evaluate_policies
  @re_evaluate_policies
end

#stageObject

Returns the value of attribute stage.



15
16
17
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 15

def stage
  @stage
end

#targetObject

Returns the value of attribute target.



13
14
15
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 13

def target
  @target
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 53

def self.attribute_map
  {
    :'target' => :'target',
    :'stage' => :'stage',
    :'evaluate_on_plan' => :'evaluate_on_plan',
    :'re_evaluate_policies' => :'re_evaluate_policies',
    :'order' => :'order',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'invalid_response_action' => :'invalid_response_action'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 211

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 76

def self.openapi_types
  {
    :'target' => :'String',
    :'stage' => :'String',
    :'evaluate_on_plan' => :'Boolean',
    :'re_evaluate_policies' => :'Boolean',
    :'order' => :'Integer',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'invalid_response_action' => :'InvalidResponseActionEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
192
193
194
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      target == o.target &&
      stage == o.stage &&
      evaluate_on_plan == o.evaluate_on_plan &&
      re_evaluate_policies == o.re_evaluate_policies &&
      order == o.order &&
      policy_engine_mode == o.policy_engine_mode &&
      invalid_response_action == o.invalid_response_action
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 204

def hash
  [target, stage, evaluate_on_plan, re_evaluate_policies, order, policy_engine_mode, invalid_response_action].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@order.nil? && @order > 2147483647
    invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.')
  end

  if !@order.nil? && @order < -2147483648
    invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



157
158
159
160
161
162
# File 'lib/authentik/api/models/patched_flow_stage_binding_request.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@order.nil? && @order > 2147483647
  return false if !@order.nil? && @order < -2147483648
  true
end