Class: Authentik::Api::PatchedGroupRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/patched_group_request.rb

Overview

Group Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedGroupRequest

Initializes the object



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/authentik/api/models/patched_group_request.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedGroupRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedGroupRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'is_superuser')
    self.is_superuser = attributes[:'is_superuser']
  end

  if attributes.key?(:'parents')
    if (value = attributes[:'parents']).is_a?(Array)
      self.parents = value
    end
  end

  if attributes.key?(:'users')
    if (value = attributes[:'users']).is_a?(Array)
      self.users = value
    end
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end

  if attributes.key?(:'roles')
    if (value = attributes[:'roles']).is_a?(Array)
      self.roles = value
    end
  end
end

Instance Attribute Details

#attributes ⇒ Object

Returns the value of attribute attributes.



22
23
24
# File 'lib/authentik/api/models/patched_group_request.rb', line 22

def attributes
  @attributes
end

#is_superuser ⇒ Object

Users added to this group will be superusers.



16
17
18
# File 'lib/authentik/api/models/patched_group_request.rb', line 16

def is_superuser
  @is_superuser
end

#name ⇒ Object

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_group_request.rb', line 13

def name
  @name
end

#parents ⇒ Object

Returns the value of attribute parents.



18
19
20
# File 'lib/authentik/api/models/patched_group_request.rb', line 18

def parents
  @parents
end

#roles ⇒ Object

Returns the value of attribute roles.



24
25
26
# File 'lib/authentik/api/models/patched_group_request.rb', line 24

def roles
  @roles
end

#users ⇒ Object

Returns the value of attribute users.



20
21
22
# File 'lib/authentik/api/models/patched_group_request.rb', line 20

def users
  @users
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



39
40
41
# File 'lib/authentik/api/models/patched_group_request.rb', line 39

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/authentik/api/models/patched_group_request.rb', line 44

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
# File 'lib/authentik/api/models/patched_group_request.rb', line 27

def self.attribute_map
  {
    :'name' => :'name',
    :'is_superuser' => :'is_superuser',
    :'parents' => :'parents',
    :'users' => :'users',
    :'attributes' => :'attributes',
    :'roles' => :'roles'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/authentik/api/models/patched_group_request.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



61
62
63
64
# File 'lib/authentik/api/models/patched_group_request.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
# File 'lib/authentik/api/models/patched_group_request.rb', line 49

def self.openapi_types
  {
    :'name' => :'String',
    :'is_superuser' => :'Boolean',
    :'parents' => :'Array<String>',
    :'users' => :'Array<Integer>',
    :'attributes' => :'Hash<String, Object>',
    :'roles' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



151
152
153
154
155
156
157
158
159
160
# File 'lib/authentik/api/models/patched_group_request.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      is_superuser == o.is_superuser &&
      parents == o.parents &&
      users == o.users &&
      attributes == o.attributes &&
      roles == o.roles
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


164
165
166
# File 'lib/authentik/api/models/patched_group_request.rb', line 164

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



170
171
172
# File 'lib/authentik/api/models/patched_group_request.rb', line 170

def hash
  [name, is_superuser, parents, users, attributes, roles].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



117
118
119
120
121
122
123
124
125
# File 'lib/authentik/api/models/patched_group_request.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/authentik/api/models/patched_group_request.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



129
130
131
132
133
# File 'lib/authentik/api/models/patched_group_request.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  true
end