Class: Authentik::Api::PatchedInitialPermissionsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedInitialPermissionsRequest
- Defined in:
- lib/authentik/api/models/patched_initial_permissions_request.rb
Overview
InitialPermissions serializer
Instance Attribute Summary collapse
-
#name ⇒ Object
Returns the value of attribute name.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
-
#role ⇒ Object
Returns the value of attribute role.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedInitialPermissionsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedInitialPermissionsRequest
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 55 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedInitialPermissionsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedInitialPermissionsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'role') self.role = attributes[:'role'] end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 13 def name @name end |
#permissions ⇒ Object
Returns the value of attribute permissions.
17 18 19 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 17 def @permissions end |
#role ⇒ Object
Returns the value of attribute role.
15 16 17 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 15 def role @role end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
29 30 31 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 29 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
34 35 36 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 34 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 20 def self.attribute_map { :'name' => :'name', :'role' => :'role', :'permissions' => :'permissions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 152 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 51 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 48 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 39 def self.openapi_types { :'name' => :'String', :'role' => :'String', :'permissions' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 129 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && role == o.role && == o. end |
#eql?(o) ⇒ Boolean
139 140 141 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 139 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
145 146 147 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 145 def hash [name, role, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 150 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 150.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 174 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 105 106 107 |
# File 'lib/authentik/api/models/patched_initial_permissions_request.rb', line 102 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 150 return false if !@name.nil? && @name.to_s.length < 1 true end |