Class: Authentik::Api::PatchedKerberosSourceRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_kerberos_source_request.rb

Overview

Kerberos Source Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedKerberosSourceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 196

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedKerberosSourceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedKerberosSourceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'promoted')
    self.promoted = attributes[:'promoted']
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'enrollment_flow')
    self.enrollment_flow = attributes[:'enrollment_flow']
  end

  if attributes.key?(:'user_property_mappings')
    if (value = attributes[:'user_property_mappings']).is_a?(Array)
      self.user_property_mappings = value
    end
  end

  if attributes.key?(:'group_property_mappings')
    if (value = attributes[:'group_property_mappings']).is_a?(Array)
      self.group_property_mappings = value
    end
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'user_matching_mode')
    self.user_matching_mode = attributes[:'user_matching_mode']
  end

  if attributes.key?(:'user_path_template')
    self.user_path_template = attributes[:'user_path_template']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'group_matching_mode')
    self.group_matching_mode = attributes[:'group_matching_mode']
  end

  if attributes.key?(:'realm')
    self.realm = attributes[:'realm']
  end

  if attributes.key?(:'krb5_conf')
    self.krb5_conf = attributes[:'krb5_conf']
  end

  if attributes.key?(:'kadmin_type')
    self.kadmin_type = attributes[:'kadmin_type']
  end

  if attributes.key?(:'sync_users')
    self.sync_users = attributes[:'sync_users']
  end

  if attributes.key?(:'sync_users_password')
    self.sync_users_password = attributes[:'sync_users_password']
  end

  if attributes.key?(:'sync_principal')
    self.sync_principal = attributes[:'sync_principal']
  end

  if attributes.key?(:'sync_password')
    self.sync_password = attributes[:'sync_password']
  end

  if attributes.key?(:'sync_keytab')
    self.sync_keytab = attributes[:'sync_keytab']
  end

  if attributes.key?(:'sync_ccache')
    self.sync_ccache = attributes[:'sync_ccache']
  end

  if attributes.key?(:'spnego_server_name')
    self.spnego_server_name = attributes[:'spnego_server_name']
  end

  if attributes.key?(:'spnego_keytab')
    self.spnego_keytab = attributes[:'spnego_keytab']
  end

  if attributes.key?(:'spnego_ccache')
    self.spnego_ccache = attributes[:'spnego_ccache']
  end

  if attributes.key?(:'password_login_update_internal_password')
    self. = attributes[:'password_login_update_internal_password']
  end

  if attributes.key?(:'sync_outgoing_trigger_mode')
    self.sync_outgoing_trigger_mode = attributes[:'sync_outgoing_trigger_mode']
  end
end

Instance Attribute Details

#authentication_flowObject

Flow to use when authenticating existing users.



25
26
27
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 25

def authentication_flow
  @authentication_flow
end

#enabledObject

Returns the value of attribute enabled.



19
20
21
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 19

def enabled
  @enabled
end

#enrollment_flowObject

Flow to use when enrolling new users.



28
29
30
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 28

def enrollment_flow
  @enrollment_flow
end

#group_matching_modeObject

How the source determines if an existing group should be used or a new group created.



44
45
46
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 44

def group_matching_mode
  @group_matching_mode
end

#group_property_mappingsObject

Returns the value of attribute group_property_mappings.



32
33
34
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 32

def group_property_mappings
  @group_property_mappings
end

#iconObject

Returns the value of attribute icon.



41
42
43
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 41

def icon
  @icon
end

#kadmin_typeObject

KAdmin server type



53
54
55
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 53

def kadmin_type
  @kadmin_type
end

#krb5_confObject

Custom krb5.conf to use. Uses the system one by default



50
51
52
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 50

def krb5_conf
  @krb5_conf
end

#nameObject

Source’s display Name.



14
15
16
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 14

def name
  @name
end

#password_login_update_internal_passwordObject

If enabled, the authentik-stored password will be updated upon login with the Kerberos password backend



83
84
85
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 83

def 
  @password_login_update_internal_password
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



34
35
36
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 34

def policy_engine_mode
  @policy_engine_mode
end

When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.



22
23
24
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 22

def promoted
  @promoted
end

#realmObject

Kerberos realm



47
48
49
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 47

def realm
  @realm
end

#slugObject

Internal source name, used in URLs.



17
18
19
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 17

def slug
  @slug
end

#spnego_ccacheObject

Credential cache to use for SPNEGO in form type:residual



80
81
82
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 80

def spnego_ccache
  @spnego_ccache
end

#spnego_keytabObject

SPNEGO keytab base64-encoded or path to keytab in the form FILE:path



77
78
79
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 77

def spnego_keytab
  @spnego_keytab
end

#spnego_server_nameObject

Force the use of a specific server name for SPNEGO. Must be in the form HTTP@hostname



74
75
76
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 74

def spnego_server_name
  @spnego_server_name
end

#sync_ccacheObject

Credentials cache to authenticate to kadmin for sync. Must be in the form TYPE:residual



71
72
73
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 71

def sync_ccache
  @sync_ccache
end

#sync_keytabObject

Keytab to authenticate to kadmin for sync. Must be base64-encoded or in the form TYPE:residual



68
69
70
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 68

def sync_keytab
  @sync_keytab
end

#sync_outgoing_trigger_modeObject

When to trigger sync for outgoing providers



86
87
88
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 86

def sync_outgoing_trigger_mode
  @sync_outgoing_trigger_mode
end

#sync_passwordObject

Password to authenticate to kadmin for sync



65
66
67
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 65

def sync_password
  @sync_password
end

#sync_principalObject

Principal to authenticate to kadmin for sync.



62
63
64
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 62

def sync_principal
  @sync_principal
end

#sync_usersObject

Sync users from Kerberos into authentik



56
57
58
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 56

def sync_users
  @sync_users
end

#sync_users_passwordObject

When a user changes their password, sync it back to Kerberos



59
60
61
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 59

def sync_users_password
  @sync_users_password
end

#user_matching_modeObject

How the source determines if an existing user should be authenticated or a new user enrolled.



37
38
39
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 37

def user_matching_mode
  @user_matching_mode
end

#user_path_templateObject

Returns the value of attribute user_path_template.



39
40
41
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 39

def user_path_template
  @user_path_template
end

#user_property_mappingsObject

Returns the value of attribute user_property_mappings.



30
31
32
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 30

def user_property_mappings
  @user_property_mappings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



144
145
146
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 144

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



149
150
151
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 149

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 111

def self.attribute_map
  {
    :'name' => :'name',
    :'slug' => :'slug',
    :'enabled' => :'enabled',
    :'promoted' => :'promoted',
    :'authentication_flow' => :'authentication_flow',
    :'enrollment_flow' => :'enrollment_flow',
    :'user_property_mappings' => :'user_property_mappings',
    :'group_property_mappings' => :'group_property_mappings',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'user_matching_mode' => :'user_matching_mode',
    :'user_path_template' => :'user_path_template',
    :'icon' => :'icon',
    :'group_matching_mode' => :'group_matching_mode',
    :'realm' => :'realm',
    :'krb5_conf' => :'krb5_conf',
    :'kadmin_type' => :'kadmin_type',
    :'sync_users' => :'sync_users',
    :'sync_users_password' => :'sync_users_password',
    :'sync_principal' => :'sync_principal',
    :'sync_password' => :'sync_password',
    :'sync_keytab' => :'sync_keytab',
    :'sync_ccache' => :'sync_ccache',
    :'spnego_server_name' => :'spnego_server_name',
    :'spnego_keytab' => :'spnego_keytab',
    :'spnego_ccache' => :'spnego_ccache',
    :'password_login_update_internal_password' => :'password_login_update_internal_password',
    :'sync_outgoing_trigger_mode' => :'sync_outgoing_trigger_mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 474

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



187
188
189
190
191
192
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 187

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
    :'enrollment_flow',
  ])
end

.openapi_typesObject

Attribute type mapping.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 154

def self.openapi_types
  {
    :'name' => :'String',
    :'slug' => :'String',
    :'enabled' => :'Boolean',
    :'promoted' => :'Boolean',
    :'authentication_flow' => :'String',
    :'enrollment_flow' => :'String',
    :'user_property_mappings' => :'Array<String>',
    :'group_property_mappings' => :'Array<String>',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'user_matching_mode' => :'UserMatchingModeEnum',
    :'user_path_template' => :'String',
    :'icon' => :'String',
    :'group_matching_mode' => :'GroupMatchingModeEnum',
    :'realm' => :'String',
    :'krb5_conf' => :'String',
    :'kadmin_type' => :'KadminTypeEnum',
    :'sync_users' => :'Boolean',
    :'sync_users_password' => :'Boolean',
    :'sync_principal' => :'String',
    :'sync_password' => :'String',
    :'sync_keytab' => :'String',
    :'sync_ccache' => :'String',
    :'spnego_server_name' => :'String',
    :'spnego_keytab' => :'String',
    :'spnego_ccache' => :'String',
    :'password_login_update_internal_password' => :'Boolean',
    :'sync_outgoing_trigger_mode' => :'SyncOutgoingTriggerModeEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 427

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      slug == o.slug &&
      enabled == o.enabled &&
      promoted == o.promoted &&
      authentication_flow == o.authentication_flow &&
      enrollment_flow == o.enrollment_flow &&
      user_property_mappings == o.user_property_mappings &&
      group_property_mappings == o.group_property_mappings &&
      policy_engine_mode == o.policy_engine_mode &&
      user_matching_mode == o.user_matching_mode &&
      user_path_template == o.user_path_template &&
      icon == o.icon &&
      group_matching_mode == o.group_matching_mode &&
      realm == o.realm &&
      krb5_conf == o.krb5_conf &&
      kadmin_type == o.kadmin_type &&
      sync_users == o.sync_users &&
      sync_users_password == o.sync_users_password &&
      sync_principal == o.sync_principal &&
      sync_password == o.sync_password &&
      sync_keytab == o.sync_keytab &&
      sync_ccache == o.sync_ccache &&
      spnego_server_name == o.spnego_server_name &&
      spnego_keytab == o.spnego_keytab &&
      spnego_ccache == o.spnego_ccache &&
       == o. &&
      sync_outgoing_trigger_mode == o.sync_outgoing_trigger_mode
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


461
462
463
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 461

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



467
468
469
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 467

def hash
  [name, slug, enabled, promoted, authentication_flow, enrollment_flow, user_property_mappings, group_property_mappings, policy_engine_mode, user_matching_mode, user_path_template, icon, group_matching_mode, realm, krb5_conf, kadmin_type, sync_users, sync_users_password, sync_principal, sync_password, sync_keytab, sync_ccache, spnego_server_name, spnego_keytab, spnego_ccache, , sync_outgoing_trigger_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 325

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@slug.nil? && @slug.to_s.length < 1
    invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if !@slug.nil? && @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if !@user_path_template.nil? && @user_path_template.to_s.length < 1
    invalid_properties.push('invalid value for "user_path_template", the character length must be greater than or equal to 1.')
  end

  if !@realm.nil? && @realm.to_s.length < 1
    invalid_properties.push('invalid value for "realm", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 496

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



354
355
356
357
358
359
360
361
362
# File 'lib/authentik/api/models/patched_kerberos_source_request.rb', line 354

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@slug.nil? && @slug.to_s.length < 1
  return false if !@slug.nil? && @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if !@user_path_template.nil? && @user_path_template.to_s.length < 1
  return false if !@realm.nil? && @realm.to_s.length < 1
  true
end