Class: Authentik::Api::PatchedLDAPSourceRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedLDAPSourceRequest
- Defined in:
- lib/authentik/api/models/patched_ldap_source_request.rb
Overview
LDAP Source Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#additional_group_dn ⇒ Object
Prepended to Base DN for Group-queries.
-
#additional_user_dn ⇒ Object
Prepended to Base DN for User-queries.
-
#authentication_flow ⇒ Object
Flow to use when authenticating existing users.
-
#base_dn ⇒ Object
Returns the value of attribute base_dn.
-
#bind_cn ⇒ Object
Returns the value of attribute bind_cn.
-
#bind_password ⇒ Object
Returns the value of attribute bind_password.
-
#client_certificate ⇒ Object
Client certificate to authenticate against the LDAP Server’s Certificate.
-
#delete_not_found_objects ⇒ Object
Delete authentik users and groups which were previously supplied by this source, but are now missing from it.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#enrollment_flow ⇒ Object
Flow to use when enrolling new users.
-
#group_membership_field ⇒ Object
Field which contains members of a group.
-
#group_object_filter ⇒ Object
Consider Objects matching this filter to be Groups.
-
#group_property_mappings ⇒ Object
Returns the value of attribute group_property_mappings.
-
#icon ⇒ Object
Returns the value of attribute icon.
-
#lookup_groups_from_user ⇒ Object
Lookup group membership based on a user attribute instead of a group attribute.
-
#name ⇒ Object
Source’s display Name.
-
#object_uniqueness_field ⇒ Object
Field which contains a unique Identifier.
-
#password_login_update_internal_password ⇒ Object
Update internal authentik password when login succeeds with LDAP.
-
#peer_certificate ⇒ Object
Optionally verify the LDAP Server’s Certificate against the CA Chain in this keypair.
-
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
-
#promoted ⇒ Object
When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
-
#server_uri ⇒ Object
Returns the value of attribute server_uri.
-
#slug ⇒ Object
Internal source name, used in URLs.
-
#sni ⇒ Object
Returns the value of attribute sni.
-
#start_tls ⇒ Object
Returns the value of attribute start_tls.
-
#sync_groups ⇒ Object
Returns the value of attribute sync_groups.
-
#sync_outgoing_trigger_mode ⇒ Object
When to trigger sync for outgoing providers.
-
#sync_parent_group ⇒ Object
Returns the value of attribute sync_parent_group.
-
#sync_users ⇒ Object
Returns the value of attribute sync_users.
-
#sync_users_password ⇒ Object
When a user changes their password, sync it back to LDAP.
-
#user_matching_mode ⇒ Object
How the source determines if an existing user should be authenticated or a new user enrolled.
-
#user_membership_attribute ⇒ Object
Attribute which matches the value of ‘group_membership_field`.
-
#user_object_filter ⇒ Object
Consider Objects matching this filter to be Users.
-
#user_path_template ⇒ Object
Returns the value of attribute user_path_template.
-
#user_property_mappings ⇒ Object
Returns the value of attribute user_property_mappings.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedLDAPSourceRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedLDAPSourceRequest
Initializes the object
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 230 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedLDAPSourceRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedLDAPSourceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'promoted') self.promoted = attributes[:'promoted'] end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'enrollment_flow') self.enrollment_flow = attributes[:'enrollment_flow'] end if attributes.key?(:'user_property_mappings') if (value = attributes[:'user_property_mappings']).is_a?(Array) self.user_property_mappings = value end end if attributes.key?(:'group_property_mappings') if (value = attributes[:'group_property_mappings']).is_a?(Array) self.group_property_mappings = value end end if attributes.key?(:'policy_engine_mode') self.policy_engine_mode = attributes[:'policy_engine_mode'] end if attributes.key?(:'user_matching_mode') self.user_matching_mode = attributes[:'user_matching_mode'] end if attributes.key?(:'user_path_template') self.user_path_template = attributes[:'user_path_template'] end if attributes.key?(:'icon') self.icon = attributes[:'icon'] end if attributes.key?(:'server_uri') self.server_uri = attributes[:'server_uri'] end if attributes.key?(:'peer_certificate') self.peer_certificate = attributes[:'peer_certificate'] end if attributes.key?(:'client_certificate') self.client_certificate = attributes[:'client_certificate'] end if attributes.key?(:'bind_cn') self.bind_cn = attributes[:'bind_cn'] end if attributes.key?(:'bind_password') self.bind_password = attributes[:'bind_password'] end if attributes.key?(:'start_tls') self.start_tls = attributes[:'start_tls'] end if attributes.key?(:'sni') self.sni = attributes[:'sni'] end if attributes.key?(:'base_dn') self.base_dn = attributes[:'base_dn'] end if attributes.key?(:'additional_user_dn') self.additional_user_dn = attributes[:'additional_user_dn'] end if attributes.key?(:'additional_group_dn') self.additional_group_dn = attributes[:'additional_group_dn'] end if attributes.key?(:'user_object_filter') self.user_object_filter = attributes[:'user_object_filter'] end if attributes.key?(:'group_object_filter') self.group_object_filter = attributes[:'group_object_filter'] end if attributes.key?(:'group_membership_field') self.group_membership_field = attributes[:'group_membership_field'] end if attributes.key?(:'user_membership_attribute') self.user_membership_attribute = attributes[:'user_membership_attribute'] end if attributes.key?(:'object_uniqueness_field') self.object_uniqueness_field = attributes[:'object_uniqueness_field'] end if attributes.key?(:'password_login_update_internal_password') self.password_login_update_internal_password = attributes[:'password_login_update_internal_password'] end if attributes.key?(:'sync_users') self.sync_users = attributes[:'sync_users'] end if attributes.key?(:'sync_users_password') self.sync_users_password = attributes[:'sync_users_password'] end if attributes.key?(:'sync_groups') self.sync_groups = attributes[:'sync_groups'] end if attributes.key?(:'sync_parent_group') self.sync_parent_group = attributes[:'sync_parent_group'] end if attributes.key?(:'lookup_groups_from_user') self.lookup_groups_from_user = attributes[:'lookup_groups_from_user'] end if attributes.key?(:'delete_not_found_objects') self.delete_not_found_objects = attributes[:'delete_not_found_objects'] end if attributes.key?(:'sync_outgoing_trigger_mode') self.sync_outgoing_trigger_mode = attributes[:'sync_outgoing_trigger_mode'] end end |
Instance Attribute Details
#additional_group_dn ⇒ Object
Prepended to Base DN for Group-queries.
65 66 67 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 65 def additional_group_dn @additional_group_dn end |
#additional_user_dn ⇒ Object
Prepended to Base DN for User-queries.
62 63 64 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 62 def additional_user_dn @additional_user_dn end |
#authentication_flow ⇒ Object
Flow to use when authenticating existing users.
25 26 27 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 25 def authentication_flow @authentication_flow end |
#base_dn ⇒ Object
Returns the value of attribute base_dn.
59 60 61 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 59 def base_dn @base_dn end |
#bind_cn ⇒ Object
Returns the value of attribute bind_cn.
51 52 53 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 51 def bind_cn @bind_cn end |
#bind_password ⇒ Object
Returns the value of attribute bind_password.
53 54 55 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 53 def bind_password @bind_password end |
#client_certificate ⇒ Object
Client certificate to authenticate against the LDAP Server’s Certificate.
49 50 51 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 49 def client_certificate @client_certificate end |
#delete_not_found_objects ⇒ Object
Delete authentik users and groups which were previously supplied by this source, but are now missing from it.
98 99 100 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 98 def delete_not_found_objects @delete_not_found_objects end |
#enabled ⇒ Object
Returns the value of attribute enabled.
19 20 21 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 19 def enabled @enabled end |
#enrollment_flow ⇒ Object
Flow to use when enrolling new users.
28 29 30 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 28 def enrollment_flow @enrollment_flow end |
#group_membership_field ⇒ Object
Field which contains members of a group.
74 75 76 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 74 def group_membership_field @group_membership_field end |
#group_object_filter ⇒ Object
Consider Objects matching this filter to be Groups.
71 72 73 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 71 def group_object_filter @group_object_filter end |
#group_property_mappings ⇒ Object
Returns the value of attribute group_property_mappings.
32 33 34 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 32 def group_property_mappings @group_property_mappings end |
#icon ⇒ Object
Returns the value of attribute icon.
41 42 43 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 41 def icon @icon end |
#lookup_groups_from_user ⇒ Object
Lookup group membership based on a user attribute instead of a group attribute. This allows nested group resolution on systems like FreeIPA and Active Directory
95 96 97 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 95 def lookup_groups_from_user @lookup_groups_from_user end |
#name ⇒ Object
Source’s display Name.
14 15 16 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 14 def name @name end |
#object_uniqueness_field ⇒ Object
Field which contains a unique Identifier.
80 81 82 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 80 def object_uniqueness_field @object_uniqueness_field end |
#password_login_update_internal_password ⇒ Object
Update internal authentik password when login succeeds with LDAP
83 84 85 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 83 def password_login_update_internal_password @password_login_update_internal_password end |
#peer_certificate ⇒ Object
Optionally verify the LDAP Server’s Certificate against the CA Chain in this keypair.
46 47 48 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 46 def peer_certificate @peer_certificate end |
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
34 35 36 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 34 def policy_engine_mode @policy_engine_mode end |
#promoted ⇒ Object
When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
22 23 24 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 22 def promoted @promoted end |
#server_uri ⇒ Object
Returns the value of attribute server_uri.
43 44 45 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 43 def server_uri @server_uri end |
#slug ⇒ Object
Internal source name, used in URLs.
17 18 19 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 17 def slug @slug end |
#sni ⇒ Object
Returns the value of attribute sni.
57 58 59 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 57 def sni @sni end |
#start_tls ⇒ Object
Returns the value of attribute start_tls.
55 56 57 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 55 def start_tls @start_tls end |
#sync_groups ⇒ Object
Returns the value of attribute sync_groups.
90 91 92 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 90 def sync_groups @sync_groups end |
#sync_outgoing_trigger_mode ⇒ Object
When to trigger sync for outgoing providers
101 102 103 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 101 def sync_outgoing_trigger_mode @sync_outgoing_trigger_mode end |
#sync_parent_group ⇒ Object
Returns the value of attribute sync_parent_group.
92 93 94 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 92 def sync_parent_group @sync_parent_group end |
#sync_users ⇒ Object
Returns the value of attribute sync_users.
85 86 87 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 85 def sync_users @sync_users end |
#sync_users_password ⇒ Object
When a user changes their password, sync it back to LDAP. This can only be enabled on a single LDAP source.
88 89 90 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 88 def sync_users_password @sync_users_password end |
#user_matching_mode ⇒ Object
How the source determines if an existing user should be authenticated or a new user enrolled.
37 38 39 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 37 def user_matching_mode @user_matching_mode end |
#user_membership_attribute ⇒ Object
Attribute which matches the value of ‘group_membership_field`.
77 78 79 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 77 def user_membership_attribute @user_membership_attribute end |
#user_object_filter ⇒ Object
Consider Objects matching this filter to be Users.
68 69 70 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 68 def user_object_filter @user_object_filter end |
#user_path_template ⇒ Object
Returns the value of attribute user_path_template.
39 40 41 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 39 def user_path_template @user_path_template end |
#user_property_mappings ⇒ Object
Returns the value of attribute user_property_mappings.
30 31 32 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 30 def user_property_mappings @user_property_mappings end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
167 168 169 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 167 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
172 173 174 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 172 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 126 def self.attribute_map { :'name' => :'name', :'slug' => :'slug', :'enabled' => :'enabled', :'promoted' => :'promoted', :'authentication_flow' => :'authentication_flow', :'enrollment_flow' => :'enrollment_flow', :'user_property_mappings' => :'user_property_mappings', :'group_property_mappings' => :'group_property_mappings', :'policy_engine_mode' => :'policy_engine_mode', :'user_matching_mode' => :'user_matching_mode', :'user_path_template' => :'user_path_template', :'icon' => :'icon', :'server_uri' => :'server_uri', :'peer_certificate' => :'peer_certificate', :'client_certificate' => :'client_certificate', :'bind_cn' => :'bind_cn', :'bind_password' => :'bind_password', :'start_tls' => :'start_tls', :'sni' => :'sni', :'base_dn' => :'base_dn', :'additional_user_dn' => :'additional_user_dn', :'additional_group_dn' => :'additional_group_dn', :'user_object_filter' => :'user_object_filter', :'group_object_filter' => :'group_object_filter', :'group_membership_field' => :'group_membership_field', :'user_membership_attribute' => :'user_membership_attribute', :'object_uniqueness_field' => :'object_uniqueness_field', :'password_login_update_internal_password' => :'password_login_update_internal_password', :'sync_users' => :'sync_users', :'sync_users_password' => :'sync_users_password', :'sync_groups' => :'sync_groups', :'sync_parent_group' => :'sync_parent_group', :'lookup_groups_from_user' => :'lookup_groups_from_user', :'delete_not_found_objects' => :'delete_not_found_objects', :'sync_outgoing_trigger_mode' => :'sync_outgoing_trigger_mode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 662 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
218 219 220 221 222 223 224 225 226 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 218 def self.openapi_nullable Set.new([ :'authentication_flow', :'enrollment_flow', :'peer_certificate', :'client_certificate', :'sync_parent_group', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 177 def self.openapi_types { :'name' => :'String', :'slug' => :'String', :'enabled' => :'Boolean', :'promoted' => :'Boolean', :'authentication_flow' => :'String', :'enrollment_flow' => :'String', :'user_property_mappings' => :'Array<String>', :'group_property_mappings' => :'Array<String>', :'policy_engine_mode' => :'PolicyEngineMode', :'user_matching_mode' => :'UserMatchingModeEnum', :'user_path_template' => :'String', :'icon' => :'String', :'server_uri' => :'String', :'peer_certificate' => :'String', :'client_certificate' => :'String', :'bind_cn' => :'String', :'bind_password' => :'String', :'start_tls' => :'Boolean', :'sni' => :'Boolean', :'base_dn' => :'String', :'additional_user_dn' => :'String', :'additional_group_dn' => :'String', :'user_object_filter' => :'String', :'group_object_filter' => :'String', :'group_membership_field' => :'String', :'user_membership_attribute' => :'String', :'object_uniqueness_field' => :'String', :'password_login_update_internal_password' => :'Boolean', :'sync_users' => :'Boolean', :'sync_users_password' => :'Boolean', :'sync_groups' => :'Boolean', :'sync_parent_group' => :'String', :'lookup_groups_from_user' => :'Boolean', :'delete_not_found_objects' => :'Boolean', :'sync_outgoing_trigger_mode' => :'SyncOutgoingTriggerModeEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 607 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && slug == o.slug && enabled == o.enabled && promoted == o.promoted && authentication_flow == o.authentication_flow && enrollment_flow == o.enrollment_flow && user_property_mappings == o.user_property_mappings && group_property_mappings == o.group_property_mappings && policy_engine_mode == o.policy_engine_mode && user_matching_mode == o.user_matching_mode && user_path_template == o.user_path_template && icon == o.icon && server_uri == o.server_uri && peer_certificate == o.peer_certificate && client_certificate == o.client_certificate && bind_cn == o.bind_cn && bind_password == o.bind_password && start_tls == o.start_tls && sni == o.sni && base_dn == o.base_dn && additional_user_dn == o.additional_user_dn && additional_group_dn == o.additional_group_dn && user_object_filter == o.user_object_filter && group_object_filter == o.group_object_filter && group_membership_field == o.group_membership_field && user_membership_attribute == o.user_membership_attribute && object_uniqueness_field == o.object_uniqueness_field && password_login_update_internal_password == o.password_login_update_internal_password && sync_users == o.sync_users && sync_users_password == o.sync_users_password && sync_groups == o.sync_groups && sync_parent_group == o.sync_parent_group && lookup_groups_from_user == o.lookup_groups_from_user && delete_not_found_objects == o.delete_not_found_objects && sync_outgoing_trigger_mode == o.sync_outgoing_trigger_mode end |
#eql?(o) ⇒ Boolean
649 650 651 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 649 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
655 656 657 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 655 def hash [name, slug, enabled, promoted, authentication_flow, enrollment_flow, user_property_mappings, group_property_mappings, policy_engine_mode, user_matching_mode, user_path_template, icon, server_uri, peer_certificate, client_certificate, bind_cn, bind_password, start_tls, sni, base_dn, additional_user_dn, additional_group_dn, user_object_filter, group_object_filter, group_membership_field, user_membership_attribute, object_uniqueness_field, password_login_update_internal_password, sync_users, sync_users_password, sync_groups, sync_parent_group, lookup_groups_from_user, delete_not_found_objects, sync_outgoing_trigger_mode].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 391 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@slug.nil? && @slug.to_s.length < 1 invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/) if !@slug.nil? && @slug !~ pattern invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.") end if !@user_path_template.nil? && @user_path_template.to_s.length < 1 invalid_properties.push('invalid value for "user_path_template", the character length must be greater than or equal to 1.') end if !@server_uri.nil? && @server_uri.to_s.length < 1 invalid_properties.push('invalid value for "server_uri", the character length must be greater than or equal to 1.') end if !@base_dn.nil? && @base_dn.to_s.length < 1 invalid_properties.push('invalid value for "base_dn", the character length must be greater than or equal to 1.') end if !@user_object_filter.nil? && @user_object_filter.to_s.length < 1 invalid_properties.push('invalid value for "user_object_filter", the character length must be greater than or equal to 1.') end if !@group_object_filter.nil? && @group_object_filter.to_s.length < 1 invalid_properties.push('invalid value for "group_object_filter", the character length must be greater than or equal to 1.') end if !@group_membership_field.nil? && @group_membership_field.to_s.length < 1 invalid_properties.push('invalid value for "group_membership_field", the character length must be greater than or equal to 1.') end if !@user_membership_attribute.nil? && @user_membership_attribute.to_s.length < 1 invalid_properties.push('invalid value for "user_membership_attribute", the character length must be greater than or equal to 1.') end if !@object_uniqueness_field.nil? && @object_uniqueness_field.to_s.length < 1 invalid_properties.push('invalid value for "object_uniqueness_field", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
684 685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 684 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/authentik/api/models/patched_ldap_source_request.rb', line 444 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@slug.nil? && @slug.to_s.length < 1 return false if !@slug.nil? && @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/) return false if !@user_path_template.nil? && @user_path_template.to_s.length < 1 return false if !@server_uri.nil? && @server_uri.to_s.length < 1 return false if !@base_dn.nil? && @base_dn.to_s.length < 1 return false if !@user_object_filter.nil? && @user_object_filter.to_s.length < 1 return false if !@group_object_filter.nil? && @group_object_filter.to_s.length < 1 return false if !@group_membership_field.nil? && @group_membership_field.to_s.length < 1 return false if !@user_membership_attribute.nil? && @user_membership_attribute.to_s.length < 1 return false if !@object_uniqueness_field.nil? && @object_uniqueness_field.to_s.length < 1 true end |