Class: Authentik::Api::PatchedLifecycleRuleRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedLifecycleRuleRequest
- Defined in:
- lib/authentik/api/models/patched_lifecycle_rule_request.rb
Overview
Mixin to validate that a valid enterprise license exists before allowing to save the object
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#content_type ⇒ Object
Returns the value of attribute content_type.
-
#grace_period ⇒ Object
Returns the value of attribute grace_period.
-
#interval ⇒ Object
Returns the value of attribute interval.
-
#min_reviewers ⇒ Object
Returns the value of attribute min_reviewers.
-
#min_reviewers_is_per_group ⇒ Object
Returns the value of attribute min_reviewers_is_per_group.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notification_transports ⇒ Object
Select which transports should be used to notify the reviewers.
-
#obj_id ⇒ Object
Returns the value of attribute obj_id.
-
#reviewer_groups ⇒ Object
Returns the value of attribute reviewer_groups.
-
#reviewers ⇒ Object
Returns the value of attribute reviewers.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedLifecycleRuleRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedLifecycleRuleRequest
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedLifecycleRuleRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedLifecycleRuleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'content_type') self.content_type = attributes[:'content_type'] end if attributes.key?(:'obj_id') self.obj_id = attributes[:'obj_id'] end if attributes.key?(:'interval') self.interval = attributes[:'interval'] end if attributes.key?(:'grace_period') self.grace_period = attributes[:'grace_period'] end if attributes.key?(:'reviewer_groups') if (value = attributes[:'reviewer_groups']).is_a?(Array) self.reviewer_groups = value end end if attributes.key?(:'min_reviewers') self.min_reviewers = attributes[:'min_reviewers'] end if attributes.key?(:'min_reviewers_is_per_group') self.min_reviewers_is_per_group = attributes[:'min_reviewers_is_per_group'] end if attributes.key?(:'reviewers') if (value = attributes[:'reviewers']).is_a?(Array) self.reviewers = value end end if attributes.key?(:'notification_transports') if (value = attributes[:'notification_transports']).is_a?(Array) self.notification_transports = value end end end |
Instance Attribute Details
#content_type ⇒ Object
Returns the value of attribute content_type.
15 16 17 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 15 def content_type @content_type end |
#grace_period ⇒ Object
Returns the value of attribute grace_period.
21 22 23 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 21 def grace_period @grace_period end |
#interval ⇒ Object
Returns the value of attribute interval.
19 20 21 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 19 def interval @interval end |
#min_reviewers ⇒ Object
Returns the value of attribute min_reviewers.
25 26 27 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 25 def min_reviewers @min_reviewers end |
#min_reviewers_is_per_group ⇒ Object
Returns the value of attribute min_reviewers_is_per_group.
27 28 29 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 27 def min_reviewers_is_per_group @min_reviewers_is_per_group end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 13 def name @name end |
#notification_transports ⇒ Object
Select which transports should be used to notify the reviewers. If none are selected, the notification will only be shown in the authentik UI.
32 33 34 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 32 def notification_transports @notification_transports end |
#obj_id ⇒ Object
Returns the value of attribute obj_id.
17 18 19 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 17 def obj_id @obj_id end |
#reviewer_groups ⇒ Object
Returns the value of attribute reviewer_groups.
23 24 25 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 23 def reviewer_groups @reviewer_groups end |
#reviewers ⇒ Object
Returns the value of attribute reviewers.
29 30 31 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 29 def reviewers @reviewers end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 57 def self.attribute_map { :'name' => :'name', :'content_type' => :'content_type', :'obj_id' => :'object_id', :'interval' => :'interval', :'grace_period' => :'grace_period', :'reviewer_groups' => :'reviewer_groups', :'min_reviewers' => :'min_reviewers', :'min_reviewers_is_per_group' => :'min_reviewers_is_per_group', :'reviewers' => :'reviewers', :'notification_transports' => :'notification_transports' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 315 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 99 def self.openapi_nullable Set.new([ :'obj_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 83 def self.openapi_types { :'name' => :'String', :'content_type' => :'ContentTypeEnum', :'obj_id' => :'String', :'interval' => :'String', :'grace_period' => :'String', :'reviewer_groups' => :'Array<String>', :'min_reviewers' => :'Integer', :'min_reviewers_is_per_group' => :'Boolean', :'reviewers' => :'Array<String>', :'notification_transports' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && content_type == o.content_type && obj_id == o.obj_id && interval == o.interval && grace_period == o.grace_period && reviewer_groups == o.reviewer_groups && min_reviewers == o.min_reviewers && min_reviewers_is_per_group == o.min_reviewers_is_per_group && reviewers == o.reviewers && notification_transports == o.notification_transports end |
#eql?(o) ⇒ Boolean
302 303 304 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 302 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
308 309 310 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 308 def hash [name, content_type, obj_id, interval, grace_period, reviewer_groups, min_reviewers, min_reviewers_is_per_group, reviewers, notification_transports].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 170 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@obj_id.nil? && @obj_id.to_s.length < 1 invalid_properties.push('invalid value for "obj_id", the character length must be greater than or equal to 1.') end if !@interval.nil? && @interval.to_s.length < 1 invalid_properties.push('invalid value for "interval", the character length must be greater than or equal to 1.') end if !@grace_period.nil? && @grace_period.to_s.length < 1 invalid_properties.push('invalid value for "grace_period", the character length must be greater than or equal to 1.') end if !@min_reviewers.nil? && @min_reviewers > 32767 invalid_properties.push('invalid value for "min_reviewers", must be smaller than or equal to 32767.') end if !@min_reviewers.nil? && @min_reviewers < 0 invalid_properties.push('invalid value for "min_reviewers", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/authentik/api/models/patched_lifecycle_rule_request.rb', line 202 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@obj_id.nil? && @obj_id.to_s.length < 1 return false if !@interval.nil? && @interval.to_s.length < 1 return false if !@grace_period.nil? && @grace_period.to_s.length < 1 return false if !@min_reviewers.nil? && @min_reviewers > 32767 return false if !@min_reviewers.nil? && @min_reviewers < 0 true end |