Class: Authentik::Api::PatchedMutualTLSStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedMutualTLSStageRequest
- Defined in:
- lib/authentik/api/models/patched_mutual_tls_stage_request.rb
Overview
MutualTLSStage Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cert_attribute ⇒ Object
Returns the value of attribute cert_attribute.
-
#certificate_authorities ⇒ Object
Configure certificate authorities to validate the certificate against.
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#name ⇒ Object
Returns the value of attribute name.
-
#user_attribute ⇒ Object
Returns the value of attribute user_attribute.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedMutualTLSStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedMutualTLSStageRequest
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedMutualTLSStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedMutualTLSStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'certificate_authorities') if (value = attributes[:'certificate_authorities']).is_a?(Array) self. = value end end if attributes.key?(:'cert_attribute') self.cert_attribute = attributes[:'cert_attribute'] end if attributes.key?(:'user_attribute') self.user_attribute = attributes[:'user_attribute'] end end |
Instance Attribute Details
#cert_attribute ⇒ Object
Returns the value of attribute cert_attribute.
20 21 22 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 20 def cert_attribute @cert_attribute end |
#certificate_authorities ⇒ Object
Configure certificate authorities to validate the certificate against. This option has a higher priority than the ‘client_certificate` option on `Brand`.
18 19 20 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 18 def @certificate_authorities end |
#mode ⇒ Object
Returns the value of attribute mode.
15 16 17 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 15 def mode @mode end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 13 def name @name end |
#user_attribute ⇒ Object
Returns the value of attribute user_attribute.
22 23 24 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 22 def user_attribute @user_attribute end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 47 def self.attribute_map { :'name' => :'name', :'mode' => :'mode', :'certificate_authorities' => :'certificate_authorities', :'cert_attribute' => :'cert_attribute', :'user_attribute' => :'user_attribute' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 68 def self.openapi_types { :'name' => :'String', :'mode' => :'StageModeEnum', :'certificate_authorities' => :'Array<String>', :'cert_attribute' => :'CertAttributeEnum', :'user_attribute' => :'UserAttributeEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 159 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && mode == o.mode && == o. && cert_attribute == o.cert_attribute && user_attribute == o.user_attribute end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 177 def hash [name, mode, , cert_attribute, user_attribute].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 |
# File 'lib/authentik/api/models/patched_mutual_tls_stage_request.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 true end |