Class: Authentik::Api::PatchedNotificationTransportRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedNotificationTransportRequest
- Defined in:
- lib/authentik/api/models/patched_notification_transport_request.rb
Overview
NotificationTransport Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#email_subject_prefix ⇒ Object
Returns the value of attribute email_subject_prefix.
-
#email_template ⇒ Object
Returns the value of attribute email_template.
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#name ⇒ Object
Returns the value of attribute name.
-
#send_once ⇒ Object
Only send notification once, for example when sending a webhook into a chat channel.
-
#webhook_ca ⇒ Object
When set, the selected ceritifcate is used to validate the certificate of the webhook server.
-
#webhook_mapping_body ⇒ Object
Customize the body of the request.
-
#webhook_mapping_headers ⇒ Object
Configure additional headers to be sent.
-
#webhook_url ⇒ Object
Returns the value of attribute webhook_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedNotificationTransportRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedNotificationTransportRequest
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedNotificationTransportRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedNotificationTransportRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'webhook_url') self.webhook_url = attributes[:'webhook_url'] end if attributes.key?(:'webhook_ca') self.webhook_ca = attributes[:'webhook_ca'] end if attributes.key?(:'webhook_mapping_body') self.webhook_mapping_body = attributes[:'webhook_mapping_body'] end if attributes.key?(:'webhook_mapping_headers') self.webhook_mapping_headers = attributes[:'webhook_mapping_headers'] end if attributes.key?(:'email_subject_prefix') self.email_subject_prefix = attributes[:'email_subject_prefix'] end if attributes.key?(:'email_template') self.email_template = attributes[:'email_template'] end if attributes.key?(:'send_once') self.send_once = attributes[:'send_once'] end end |
Instance Attribute Details
#email_subject_prefix ⇒ Object
Returns the value of attribute email_subject_prefix.
28 29 30 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 28 def email_subject_prefix @email_subject_prefix end |
#email_template ⇒ Object
Returns the value of attribute email_template.
30 31 32 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 30 def email_template @email_template end |
#mode ⇒ Object
Returns the value of attribute mode.
15 16 17 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 15 def mode @mode end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 13 def name @name end |
#send_once ⇒ Object
Only send notification once, for example when sending a webhook into a chat channel.
33 34 35 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 33 def send_once @send_once end |
#webhook_ca ⇒ Object
When set, the selected ceritifcate is used to validate the certificate of the webhook server.
20 21 22 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 20 def webhook_ca @webhook_ca end |
#webhook_mapping_body ⇒ Object
Customize the body of the request. Mapping should return data that is JSON-serializable.
23 24 25 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 23 def webhook_mapping_body @webhook_mapping_body end |
#webhook_mapping_headers ⇒ Object
Configure additional headers to be sent. Mapping should return a dictionary of key-value pairs
26 27 28 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 26 def webhook_mapping_headers @webhook_mapping_headers end |
#webhook_url ⇒ Object
Returns the value of attribute webhook_url.
17 18 19 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 17 def webhook_url @webhook_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 58 def self.attribute_map { :'name' => :'name', :'mode' => :'mode', :'webhook_url' => :'webhook_url', :'webhook_ca' => :'webhook_ca', :'webhook_mapping_body' => :'webhook_mapping_body', :'webhook_mapping_headers' => :'webhook_mapping_headers', :'email_subject_prefix' => :'email_subject_prefix', :'email_template' => :'email_template', :'send_once' => :'send_once' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 243 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 102 103 104 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 98 def self.openapi_nullable Set.new([ :'webhook_ca', :'webhook_mapping_body', :'webhook_mapping_headers', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 83 def self.openapi_types { :'name' => :'String', :'mode' => :'TransportModeEnum', :'webhook_url' => :'String', :'webhook_ca' => :'String', :'webhook_mapping_body' => :'String', :'webhook_mapping_headers' => :'String', :'email_subject_prefix' => :'String', :'email_template' => :'String', :'send_once' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 214 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && mode == o.mode && webhook_url == o.webhook_url && webhook_ca == o.webhook_ca && webhook_mapping_body == o.webhook_mapping_body && webhook_mapping_headers == o.webhook_mapping_headers && email_subject_prefix == o.email_subject_prefix && email_template == o.email_template && send_once == o.send_once end |
#eql?(o) ⇒ Boolean
230 231 232 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 230 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 236 def hash [name, mode, webhook_url, webhook_ca, webhook_mapping_body, webhook_mapping_headers, email_subject_prefix, email_template, send_once].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@email_template.nil? && @email_template.to_s.length < 1 invalid_properties.push('invalid value for "email_template", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 |
# File 'lib/authentik/api/models/patched_notification_transport_request.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@email_template.nil? && @email_template.to_s.length < 1 true end |