Class: Authentik::Api::PatchedObjectAttributeRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedObjectAttributeRequest
- Defined in:
- lib/authentik/api/models/patched_object_attribute_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#group ⇒ Object
Returns the value of attribute group.
-
#is_required ⇒ Object
Returns the value of attribute is_required.
-
#is_unique ⇒ Object
Returns the value of attribute is_unique.
-
#key ⇒ Object
Returns the value of attribute key.
-
#label ⇒ Object
Returns the value of attribute label.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#object_type ⇒ Object
Returns the value of attribute object_type.
-
#regex ⇒ Object
Returns the value of attribute regex.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedObjectAttributeRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedObjectAttributeRequest
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedObjectAttributeRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedObjectAttributeRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'object_type') self.object_type = attributes[:'object_type'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = true end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'regex') self.regex = attributes[:'regex'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'group') self.group = attributes[:'group'] end if attributes.key?(:'managed') self.managed = attributes[:'managed'] end if attributes.key?(:'is_unique') self.is_unique = attributes[:'is_unique'] end if attributes.key?(:'is_required') self.is_required = attributes[:'is_required'] end end |
Instance Attribute Details
#enabled ⇒ Object
Returns the value of attribute enabled.
14 15 16 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 14 def enabled @enabled end |
#group ⇒ Object
Returns the value of attribute group.
24 25 26 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 24 def group @group end |
#is_required ⇒ Object
Returns the value of attribute is_required.
31 32 33 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 31 def is_required @is_required end |
#is_unique ⇒ Object
Returns the value of attribute is_unique.
29 30 31 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 29 def is_unique @is_unique end |
#key ⇒ Object
Returns the value of attribute key.
16 17 18 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 16 def key @key end |
#label ⇒ Object
Returns the value of attribute label.
18 19 20 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 18 def label @label end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
27 28 29 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 27 def managed @managed end |
#object_type ⇒ Object
Returns the value of attribute object_type.
12 13 14 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 12 def object_type @object_type end |
#regex ⇒ Object
Returns the value of attribute regex.
20 21 22 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 20 def regex @regex end |
#type ⇒ Object
Returns the value of attribute type.
22 23 24 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 22 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 56 def self.attribute_map { :'object_type' => :'object_type', :'enabled' => :'enabled', :'key' => :'key', :'label' => :'label', :'regex' => :'regex', :'type' => :'type', :'group' => :'group', :'managed' => :'managed', :'is_unique' => :'is_unique', :'is_required' => :'is_required' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 282 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 102 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 98 def self.openapi_nullable Set.new([ :'managed', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 82 def self.openapi_types { :'object_type' => :'String', :'enabled' => :'Boolean', :'key' => :'String', :'label' => :'String', :'regex' => :'String', :'type' => :'ObjectAttributeTypeEnum', :'group' => :'String', :'managed' => :'String', :'is_unique' => :'Boolean', :'is_required' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && object_type == o.object_type && enabled == o.enabled && key == o.key && label == o.label && regex == o.regex && type == o.type && group == o.group && managed == o.managed && is_unique == o.is_unique && is_required == o.is_required end |
#eql?(o) ⇒ Boolean
269 270 271 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 269 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 275 def hash [object_type, enabled, key, label, regex, type, group, managed, is_unique, is_required].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@object_type.nil? && @object_type.to_s.length < 1 invalid_properties.push('invalid value for "object_type", the character length must be greater than or equal to 1.') end if !@key.nil? && @key.to_s.length < 1 invalid_properties.push('invalid value for "key", the character length must be greater than or equal to 1.') end if !@label.nil? && @label.to_s.length < 1 invalid_properties.push('invalid value for "label", the character length must be greater than or equal to 1.') end if !@managed.nil? && @managed.to_s.length < 1 invalid_properties.push('invalid value for "managed", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 |
# File 'lib/authentik/api/models/patched_object_attribute_request.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@object_type.nil? && @object_type.to_s.length < 1 return false if !@key.nil? && @key.to_s.length < 1 return false if !@label.nil? && @label.to_s.length < 1 return false if !@managed.nil? && @managed.to_s.length < 1 true end |