Class: Authentik::Api::PatchedOutpostRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedOutpostRequest
- Defined in:
- lib/authentik/api/models/patched_outpost_request.rb
Overview
Outpost Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#name ⇒ Object
Returns the value of attribute name.
-
#providers ⇒ Object
Returns the value of attribute providers.
-
#service_connection ⇒ Object
Select Service-Connection authentik should use to manage this outpost.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedOutpostRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedOutpostRequest
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedOutpostRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedOutpostRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'providers') if (value = attributes[:'providers']).is_a?(Array) self.providers = value end end if attributes.key?(:'service_connection') self.service_connection = attributes[:'service_connection'] end if attributes.key?(:'config') if (value = attributes[:'config']).is_a?(Hash) self.config = value end end if attributes.key?(:'managed') self.managed = attributes[:'managed'] end end |
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config.
22 23 24 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 22 def config @config end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
25 26 27 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 25 def managed @managed end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 13 def name @name end |
#providers ⇒ Object
Returns the value of attribute providers.
17 18 19 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 17 def providers @providers end |
#service_connection ⇒ Object
Select Service-Connection authentik should use to manage this outpost. Leave empty if authentik should not handle the deployment.
20 21 22 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 20 def service_connection @service_connection end |
#type ⇒ Object
Returns the value of attribute type.
15 16 17 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 15 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 50 def self.attribute_map { :'name' => :'name', :'type' => :'type', :'providers' => :'providers', :'service_connection' => :'service_connection', :'config' => :'config', :'managed' => :'managed' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 213 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 88 89 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 84 def self.openapi_nullable Set.new([ :'service_connection', :'managed' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 72 def self.openapi_types { :'name' => :'String', :'type' => :'OutpostTypeEnum', :'providers' => :'Array<Integer>', :'service_connection' => :'String', :'config' => :'Hash<String, Object>', :'managed' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 187 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && type == o.type && providers == o.providers && service_connection == o.service_connection && config == o.config && managed == o.managed end |
#eql?(o) ⇒ Boolean
200 201 202 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 200 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 206 def hash [name, type, providers, service_connection, config, managed].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@managed.nil? && @managed.to_s.length < 1 invalid_properties.push('invalid value for "managed", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 235 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 158 159 |
# File 'lib/authentik/api/models/patched_outpost_request.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@managed.nil? && @managed.to_s.length < 1 true end |