Class: Authentik::Api::PatchedPasswordPolicyRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_password_policy_request.rb

Overview

Password Policy Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedPasswordPolicyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedPasswordPolicyRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedPasswordPolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'execution_logging')
    self.execution_logging = attributes[:'execution_logging']
  end

  if attributes.key?(:'password_field')
    self.password_field = attributes[:'password_field']
  end

  if attributes.key?(:'amount_digits')
    self.amount_digits = attributes[:'amount_digits']
  end

  if attributes.key?(:'amount_uppercase')
    self.amount_uppercase = attributes[:'amount_uppercase']
  end

  if attributes.key?(:'amount_lowercase')
    self.amount_lowercase = attributes[:'amount_lowercase']
  end

  if attributes.key?(:'amount_symbols')
    self.amount_symbols = attributes[:'amount_symbols']
  end

  if attributes.key?(:'length_min')
    self.length_min = attributes[:'length_min']
  end

  if attributes.key?(:'symbol_charset')
    self.symbol_charset = attributes[:'symbol_charset']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'check_static_rules')
    self.check_static_rules = attributes[:'check_static_rules']
  end

  if attributes.key?(:'check_have_i_been_pwned')
    self.check_have_i_been_pwned = attributes[:'check_have_i_been_pwned']
  end

  if attributes.key?(:'check_zxcvbn')
    self.check_zxcvbn = attributes[:'check_zxcvbn']
  end

  if attributes.key?(:'hibp_allowed_count')
    self.hibp_allowed_count = attributes[:'hibp_allowed_count']
  end

  if attributes.key?(:'zxcvbn_score_threshold')
    self.zxcvbn_score_threshold = attributes[:'zxcvbn_score_threshold']
  end
end

Instance Attribute Details

#amount_digitsObject

Returns the value of attribute amount_digits.



21
22
23
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 21

def amount_digits
  @amount_digits
end

#amount_lowercaseObject

Returns the value of attribute amount_lowercase.



25
26
27
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 25

def amount_lowercase
  @amount_lowercase
end

#amount_symbolsObject

Returns the value of attribute amount_symbols.



27
28
29
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 27

def amount_symbols
  @amount_symbols
end

#amount_uppercaseObject

Returns the value of attribute amount_uppercase.



23
24
25
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 23

def amount_uppercase
  @amount_uppercase
end

#check_have_i_been_pwnedObject

Returns the value of attribute check_have_i_been_pwned.



37
38
39
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 37

def check_have_i_been_pwned
  @check_have_i_been_pwned
end

#check_static_rulesObject

Returns the value of attribute check_static_rules.



35
36
37
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 35

def check_static_rules
  @check_static_rules
end

#check_zxcvbnObject

Returns the value of attribute check_zxcvbn.



39
40
41
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 39

def check_zxcvbn
  @check_zxcvbn
end

#error_messageObject

Returns the value of attribute error_message.



33
34
35
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 33

def error_message
  @error_message
end

#execution_loggingObject

When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.



16
17
18
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 16

def execution_logging
  @execution_logging
end

#hibp_allowed_countObject

How many times the password hash is allowed to be on haveibeenpwned



42
43
44
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 42

def hibp_allowed_count
  @hibp_allowed_count
end

#length_minObject

Returns the value of attribute length_min.



29
30
31
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 29

def length_min
  @length_min
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 13

def name
  @name
end

#password_fieldObject

Field key to check, field keys defined in Prompt stages are available.



19
20
21
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 19

def password_field
  @password_field
end

#symbol_charsetObject

Returns the value of attribute symbol_charset.



31
32
33
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 31

def symbol_charset
  @symbol_charset
end

#zxcvbn_score_thresholdObject

If the zxcvbn score is equal or less than this value, the policy will fail.



45
46
47
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 45

def zxcvbn_score_threshold
  @zxcvbn_score_threshold
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 48

def self.attribute_map
  {
    :'name' => :'name',
    :'execution_logging' => :'execution_logging',
    :'password_field' => :'password_field',
    :'amount_digits' => :'amount_digits',
    :'amount_uppercase' => :'amount_uppercase',
    :'amount_lowercase' => :'amount_lowercase',
    :'amount_symbols' => :'amount_symbols',
    :'length_min' => :'length_min',
    :'symbol_charset' => :'symbol_charset',
    :'error_message' => :'error_message',
    :'check_static_rules' => :'check_static_rules',
    :'check_have_i_been_pwned' => :'check_have_i_been_pwned',
    :'check_zxcvbn' => :'check_zxcvbn',
    :'hibp_allowed_count' => :'hibp_allowed_count',
    :'zxcvbn_score_threshold' => :'zxcvbn_score_threshold'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 487

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 79

def self.openapi_types
  {
    :'name' => :'String',
    :'execution_logging' => :'Boolean',
    :'password_field' => :'String',
    :'amount_digits' => :'Integer',
    :'amount_uppercase' => :'Integer',
    :'amount_lowercase' => :'Integer',
    :'amount_symbols' => :'Integer',
    :'length_min' => :'Integer',
    :'symbol_charset' => :'String',
    :'error_message' => :'String',
    :'check_static_rules' => :'Boolean',
    :'check_have_i_been_pwned' => :'Boolean',
    :'check_zxcvbn' => :'Boolean',
    :'hibp_allowed_count' => :'Integer',
    :'zxcvbn_score_threshold' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 452

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      execution_logging == o.execution_logging &&
      password_field == o.password_field &&
      amount_digits == o.amount_digits &&
      amount_uppercase == o.amount_uppercase &&
      amount_lowercase == o.amount_lowercase &&
      amount_symbols == o.amount_symbols &&
      length_min == o.length_min &&
      symbol_charset == o.symbol_charset &&
      error_message == o.error_message &&
      check_static_rules == o.check_static_rules &&
      check_have_i_been_pwned == o.check_have_i_been_pwned &&
      check_zxcvbn == o.check_zxcvbn &&
      hibp_allowed_count == o.hibp_allowed_count &&
      zxcvbn_score_threshold == o.zxcvbn_score_threshold
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


474
475
476
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 474

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



480
481
482
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 480

def hash
  [name, execution_logging, password_field, amount_digits, amount_uppercase, amount_lowercase, amount_symbols, length_min, symbol_charset, error_message, check_static_rules, check_have_i_been_pwned, check_zxcvbn, hibp_allowed_count, zxcvbn_score_threshold].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@password_field.nil? && @password_field.to_s.length < 1
    invalid_properties.push('invalid value for "password_field", the character length must be greater than or equal to 1.')
  end

  if !@amount_digits.nil? && @amount_digits > 2147483647
    invalid_properties.push('invalid value for "amount_digits", must be smaller than or equal to 2147483647.')
  end

  if !@amount_digits.nil? && @amount_digits < 0
    invalid_properties.push('invalid value for "amount_digits", must be greater than or equal to 0.')
  end

  if !@amount_uppercase.nil? && @amount_uppercase > 2147483647
    invalid_properties.push('invalid value for "amount_uppercase", must be smaller than or equal to 2147483647.')
  end

  if !@amount_uppercase.nil? && @amount_uppercase < 0
    invalid_properties.push('invalid value for "amount_uppercase", must be greater than or equal to 0.')
  end

  if !@amount_lowercase.nil? && @amount_lowercase > 2147483647
    invalid_properties.push('invalid value for "amount_lowercase", must be smaller than or equal to 2147483647.')
  end

  if !@amount_lowercase.nil? && @amount_lowercase < 0
    invalid_properties.push('invalid value for "amount_lowercase", must be greater than or equal to 0.')
  end

  if !@amount_symbols.nil? && @amount_symbols > 2147483647
    invalid_properties.push('invalid value for "amount_symbols", must be smaller than or equal to 2147483647.')
  end

  if !@amount_symbols.nil? && @amount_symbols < 0
    invalid_properties.push('invalid value for "amount_symbols", must be greater than or equal to 0.')
  end

  if !@length_min.nil? && @length_min > 2147483647
    invalid_properties.push('invalid value for "length_min", must be smaller than or equal to 2147483647.')
  end

  if !@length_min.nil? && @length_min < 0
    invalid_properties.push('invalid value for "length_min", must be greater than or equal to 0.')
  end

  if !@symbol_charset.nil? && @symbol_charset.to_s.length < 1
    invalid_properties.push('invalid value for "symbol_charset", the character length must be greater than or equal to 1.')
  end

  if !@hibp_allowed_count.nil? && @hibp_allowed_count > 2147483647
    invalid_properties.push('invalid value for "hibp_allowed_count", must be smaller than or equal to 2147483647.')
  end

  if !@hibp_allowed_count.nil? && @hibp_allowed_count < 0
    invalid_properties.push('invalid value for "hibp_allowed_count", must be greater than or equal to 0.')
  end

  if !@zxcvbn_score_threshold.nil? && @zxcvbn_score_threshold > 2147483647
    invalid_properties.push('invalid value for "zxcvbn_score_threshold", must be smaller than or equal to 2147483647.')
  end

  if !@zxcvbn_score_threshold.nil? && @zxcvbn_score_threshold < 0
    invalid_properties.push('invalid value for "zxcvbn_score_threshold", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



509
510
511
512
513
514
515
516
517
518
519
520
521
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 509

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/authentik/api/models/patched_password_policy_request.rb', line 260

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@password_field.nil? && @password_field.to_s.length < 1
  return false if !@amount_digits.nil? && @amount_digits > 2147483647
  return false if !@amount_digits.nil? && @amount_digits < 0
  return false if !@amount_uppercase.nil? && @amount_uppercase > 2147483647
  return false if !@amount_uppercase.nil? && @amount_uppercase < 0
  return false if !@amount_lowercase.nil? && @amount_lowercase > 2147483647
  return false if !@amount_lowercase.nil? && @amount_lowercase < 0
  return false if !@amount_symbols.nil? && @amount_symbols > 2147483647
  return false if !@amount_symbols.nil? && @amount_symbols < 0
  return false if !@length_min.nil? && @length_min > 2147483647
  return false if !@length_min.nil? && @length_min < 0
  return false if !@symbol_charset.nil? && @symbol_charset.to_s.length < 1
  return false if !@hibp_allowed_count.nil? && @hibp_allowed_count > 2147483647
  return false if !@hibp_allowed_count.nil? && @hibp_allowed_count < 0
  return false if !@zxcvbn_score_threshold.nil? && @zxcvbn_score_threshold > 2147483647
  return false if !@zxcvbn_score_threshold.nil? && @zxcvbn_score_threshold < 0
  true
end