Class: Authentik::Api::PatchedPasswordStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedPasswordStageRequest
- Defined in:
- lib/authentik/api/models/patched_password_stage_request.rb
Overview
PasswordStage Serializer
Instance Attribute Summary collapse
-
#allow_show_password ⇒ Object
When enabled, provides a ‘show password’ button with the password input field.
-
#backends ⇒ Object
Selection of backends to test the password against.
-
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage.
-
#failed_attempts_before_cancel ⇒ Object
How many attempts a user has before the flow is canceled.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedPasswordStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedPasswordStageRequest
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedPasswordStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedPasswordStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'backends') if (value = attributes[:'backends']).is_a?(Array) self.backends = value end end if attributes.key?(:'configure_flow') self.configure_flow = attributes[:'configure_flow'] end if attributes.key?(:'failed_attempts_before_cancel') self.failed_attempts_before_cancel = attributes[:'failed_attempts_before_cancel'] end if attributes.key?(:'allow_show_password') self.allow_show_password = attributes[:'allow_show_password'] end end |
Instance Attribute Details
#allow_show_password ⇒ Object
When enabled, provides a ‘show password’ button with the password input field.
25 26 27 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 25 def allow_show_password @allow_show_password end |
#backends ⇒ Object
Selection of backends to test the password against.
16 17 18 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 16 def backends @backends end |
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.
19 20 21 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 19 def configure_flow @configure_flow end |
#failed_attempts_before_cancel ⇒ Object
How many attempts a user has before the flow is canceled. To lock the user out, use a reputation policy and a user_write stage.
22 23 24 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 22 def failed_attempts_before_cancel @failed_attempts_before_cancel end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 13 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 28 def self.attribute_map { :'name' => :'name', :'backends' => :'backends', :'configure_flow' => :'configure_flow', :'failed_attempts_before_cancel' => :'failed_attempts_before_cancel', :'allow_show_password' => :'allow_show_password' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 64 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 60 def self.openapi_nullable Set.new([ :'configure_flow', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 57 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 49 def self.openapi_types { :'name' => :'String', :'backends' => :'Array<BackendsEnum>', :'configure_flow' => :'String', :'failed_attempts_before_cancel' => :'Integer', :'allow_show_password' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && backends == o.backends && configure_flow == o.configure_flow && failed_attempts_before_cancel == o.failed_attempts_before_cancel && allow_show_password == o.allow_show_password end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 187 def hash [name, backends, configure_flow, failed_attempts_before_cancel, allow_show_password].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@failed_attempts_before_cancel.nil? && @failed_attempts_before_cancel > 2147483647 invalid_properties.push('invalid value for "failed_attempts_before_cancel", must be smaller than or equal to 2147483647.') end if !@failed_attempts_before_cancel.nil? && @failed_attempts_before_cancel < -2147483648 invalid_properties.push('invalid value for "failed_attempts_before_cancel", must be greater than or equal to -2147483648.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 133 |
# File 'lib/authentik/api/models/patched_password_stage_request.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@failed_attempts_before_cancel.nil? && @failed_attempts_before_cancel > 2147483647 return false if !@failed_attempts_before_cancel.nil? && @failed_attempts_before_cancel < -2147483648 true end |