Class: Authentik::Api::PatchedPermissionAssignRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedPermissionAssignRequest
- Defined in:
- lib/authentik/api/models/patched_permission_assign_request.rb
Overview
Request to assign a new permission
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#model ⇒ Object
Returns the value of attribute model.
-
#object_pk ⇒ Object
Returns the value of attribute object_pk.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedPermissionAssignRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedPermissionAssignRequest
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 77 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedPermissionAssignRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedPermissionAssignRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'object_pk') self.object_pk = attributes[:'object_pk'] end end |
Instance Attribute Details
#model ⇒ Object
Returns the value of attribute model.
15 16 17 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 15 def model @model end |
#object_pk ⇒ Object
Returns the value of attribute object_pk.
17 18 19 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 17 def object_pk @object_pk end |
#permissions ⇒ Object
Returns the value of attribute permissions.
13 14 15 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 13 def @permissions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 42 def self.attribute_map { :'permissions' => :'permissions', :'model' => :'model', :'object_pk' => :'object_pk' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 165 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 70 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 61 def self.openapi_types { :'permissions' => :'Array<String>', :'model' => :'ModelEnum', :'object_pk' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && model == o.model && object_pk == o.object_pk end |
#eql?(o) ⇒ Boolean
152 153 154 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 152 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 158 def hash [, model, object_pk].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@object_pk.nil? && @object_pk.to_s.length < 1 invalid_properties.push('invalid value for "object_pk", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 124 |
# File 'lib/authentik/api/models/patched_permission_assign_request.rb', line 120 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@object_pk.nil? && @object_pk.to_s.length < 1 true end |