Class: Authentik::Api::PatchedPromptRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/patched_prompt_request.rb

Overview

Prompt Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedPromptRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedPromptRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedPromptRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'field_key')
    self.field_key = attributes[:'field_key']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  end

  if attributes.key?(:'placeholder')
    self.placeholder = attributes[:'placeholder']
  end

  if attributes.key?(:'initial_value')
    self.initial_value = attributes[:'initial_value']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.key?(:'sub_text')
    self.sub_text = attributes[:'sub_text']
  end

  if attributes.key?(:'placeholder_expression')
    self.placeholder_expression = attributes[:'placeholder_expression']
  end

  if attributes.key?(:'initial_value_expression')
    self.initial_value_expression = attributes[:'initial_value_expression']
  end
end

Instance Attribute Details

#field_keyObject

Name of the form field, also used to store the value



16
17
18
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 16

def field_key
  @field_key
end

#initial_valueObject

Optionally pre-fill the input with an initial value. When creating a fixed choice field, enable interpreting as expression and return a list to return multiple default choices.



28
29
30
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 28

def initial_value
  @initial_value
end

#initial_value_expressionObject

Returns the value of attribute initial_value_expression.



36
37
38
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 36

def initial_value_expression
  @initial_value_expression
end

#labelObject

Returns the value of attribute label.



18
19
20
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 18

def label
  @label
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 13

def name
  @name
end

#orderObject

Returns the value of attribute order.



30
31
32
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 30

def order
  @order
end

#placeholderObject

Optionally provide a short hint that describes the expected input value. When creating a fixed choice field, enable interpreting as expression and return a list to return multiple choices.



25
26
27
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 25

def placeholder
  @placeholder
end

#placeholder_expressionObject

Returns the value of attribute placeholder_expression.



34
35
36
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 34

def placeholder_expression
  @placeholder_expression
end

#requiredObject

Returns the value of attribute required.



22
23
24
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 22

def required
  @required
end

#sub_textObject

Returns the value of attribute sub_text.



32
33
34
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 32

def sub_text
  @sub_text
end

#typeObject

Returns the value of attribute type.



20
21
22
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 61

def self.attribute_map
  {
    :'name' => :'name',
    :'field_key' => :'field_key',
    :'label' => :'label',
    :'type' => :'type',
    :'required' => :'required',
    :'placeholder' => :'placeholder',
    :'initial_value' => :'initial_value',
    :'order' => :'order',
    :'sub_text' => :'sub_text',
    :'placeholder_expression' => :'placeholder_expression',
    :'initial_value_expression' => :'initial_value_expression'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 304

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 105

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 88

def self.openapi_types
  {
    :'name' => :'String',
    :'field_key' => :'String',
    :'label' => :'String',
    :'type' => :'PromptTypeEnum',
    :'required' => :'Boolean',
    :'placeholder' => :'String',
    :'initial_value' => :'String',
    :'order' => :'Integer',
    :'sub_text' => :'String',
    :'placeholder_expression' => :'Boolean',
    :'initial_value_expression' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 273

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      field_key == o.field_key &&
      label == o.label &&
      type == o.type &&
      required == o.required &&
      placeholder == o.placeholder &&
      initial_value == o.initial_value &&
      order == o.order &&
      sub_text == o.sub_text &&
      placeholder_expression == o.placeholder_expression &&
      initial_value_expression == o.initial_value_expression
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


291
292
293
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 291

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



297
298
299
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 297

def hash
  [name, field_key, label, type, required, placeholder, initial_value, order, sub_text, placeholder_expression, initial_value_expression].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 173

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@field_key.nil? && @field_key.to_s.length < 1
    invalid_properties.push('invalid value for "field_key", the character length must be greater than or equal to 1.')
  end

  if !@label.nil? && @label.to_s.length < 1
    invalid_properties.push('invalid value for "label", the character length must be greater than or equal to 1.')
  end

  if !@order.nil? && @order > 2147483647
    invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.')
  end

  if !@order.nil? && @order < -2147483648
    invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 326

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
# File 'lib/authentik/api/models/patched_prompt_request.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@field_key.nil? && @field_key.to_s.length < 1
  return false if !@label.nil? && @label.to_s.length < 1
  return false if !@order.nil? && @order > 2147483647
  return false if !@order.nil? && @order < -2147483648
  true
end