Class: Authentik::Api::PatchedRACPropertyMappingRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedRACPropertyMappingRequest
- Defined in:
- lib/authentik/api/models/patched_rac_property_mapping_request.rb
Overview
RACPropertyMapping Serializer
Instance Attribute Summary collapse
-
#expression ⇒ Object
Returns the value of attribute expression.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#name ⇒ Object
Returns the value of attribute name.
-
#static_settings ⇒ Object
Returns the value of attribute static_settings.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedRACPropertyMappingRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedRACPropertyMappingRequest
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedRACPropertyMappingRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedRACPropertyMappingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'managed') self.managed = attributes[:'managed'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'expression') self.expression = attributes[:'expression'] end if attributes.key?(:'static_settings') if (value = attributes[:'static_settings']).is_a?(Hash) self.static_settings = value end end end |
Instance Attribute Details
#expression ⇒ Object
Returns the value of attribute expression.
18 19 20 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 18 def expression @expression end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
14 15 16 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 14 def managed @managed end |
#name ⇒ Object
Returns the value of attribute name.
16 17 18 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 16 def name @name end |
#static_settings ⇒ Object
Returns the value of attribute static_settings.
20 21 22 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 20 def static_settings @static_settings end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 23 def self.attribute_map { :'managed' => :'managed', :'name' => :'name', :'expression' => :'expression', :'static_settings' => :'static_settings' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
53 54 55 56 57 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 53 def self.openapi_nullable Set.new([ :'managed', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 43 def self.openapi_types { :'managed' => :'String', :'name' => :'String', :'expression' => :'String', :'static_settings' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 151 152 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && managed == o.managed && name == o.name && expression == o.expression && static_settings == o.static_settings end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 162 def hash [managed, name, expression, static_settings].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 96 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@managed.nil? && @managed.to_s.length < 1 invalid_properties.push('invalid value for "managed", the character length must be greater than or equal to 1.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 116 117 |
# File 'lib/authentik/api/models/patched_rac_property_mapping_request.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@managed.nil? && @managed.to_s.length < 1 return false if !@name.nil? && @name.to_s.length < 1 true end |