Class: Authentik::Api::PatchedReputationPolicyRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_reputation_policy_request.rb

Overview

Reputation Policy Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedReputationPolicyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedReputationPolicyRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedReputationPolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'execution_logging')
    self.execution_logging = attributes[:'execution_logging']
  end

  if attributes.key?(:'check_ip')
    self.check_ip = attributes[:'check_ip']
  end

  if attributes.key?(:'check_username')
    self.check_username = attributes[:'check_username']
  end

  if attributes.key?(:'threshold')
    self.threshold = attributes[:'threshold']
  end
end

Instance Attribute Details

#check_ipObject

Returns the value of attribute check_ip.



18
19
20
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 18

def check_ip
  @check_ip
end

#check_usernameObject

Returns the value of attribute check_username.



20
21
22
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 20

def check_username
  @check_username
end

#execution_loggingObject

When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.



16
17
18
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 16

def execution_logging
  @execution_logging
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 13

def name
  @name
end

#thresholdObject

Returns the value of attribute threshold.



22
23
24
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 22

def threshold
  @threshold
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



36
37
38
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 36

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 41

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
32
33
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 25

def self.attribute_map
  {
    :'name' => :'name',
    :'execution_logging' => :'execution_logging',
    :'check_ip' => :'check_ip',
    :'check_username' => :'check_username',
    :'threshold' => :'threshold'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 46

def self.openapi_types
  {
    :'name' => :'String',
    :'execution_logging' => :'Boolean',
    :'check_ip' => :'Boolean',
    :'check_username' => :'Boolean',
    :'threshold' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
170
171
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      execution_logging == o.execution_logging &&
      check_ip == o.check_ip &&
      check_username == o.check_username &&
      threshold == o.threshold
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 181

def hash
  [name, execution_logging, check_ip, check_username, threshold].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 101

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@threshold.nil? && @threshold > 2147483647
    invalid_properties.push('invalid value for "threshold", must be smaller than or equal to 2147483647.')
  end

  if !@threshold.nil? && @threshold < -2147483648
    invalid_properties.push('invalid value for "threshold", must be greater than or equal to -2147483648.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



121
122
123
124
125
126
127
# File 'lib/authentik/api/models/patched_reputation_policy_request.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@threshold.nil? && @threshold > 2147483647
  return false if !@threshold.nil? && @threshold < -2147483648
  true
end