Class: Authentik::Api::PatchedRequestRuleBindingRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedRequestRuleBindingRequest
- Defined in:
- lib/authentik/api/models/patched_request_rule_binding_request.rb
Overview
Mixin to validate that a valid enterprise license exists before allowing to save the object
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#expiry_granted_max ⇒ Object
The maximum duration a grant approved against this binding can last.
-
#expiry_pending ⇒ Object
How long a request against this binding stays pending before it automatically lapses if not approved or denied.
-
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
-
#rule ⇒ Object
Returns the value of attribute rule.
-
#target ⇒ Object
Returns the value of attribute target.
-
#uuid ⇒ Object
Returns the value of attribute uuid.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedRequestRuleBindingRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedRequestRuleBindingRequest
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedRequestRuleBindingRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedRequestRuleBindingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'policy_engine_mode') self.policy_engine_mode = attributes[:'policy_engine_mode'] end if attributes.key?(:'rule') self.rule = attributes[:'rule'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'expiry_pending') self.expiry_pending = attributes[:'expiry_pending'] end if attributes.key?(:'expiry_granted_max') self.expiry_granted_max = attributes[:'expiry_granted_max'] end end |
Instance Attribute Details
#expiry_granted_max ⇒ Object
The maximum duration a grant approved against this binding can last.
25 26 27 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 25 def expiry_granted_max @expiry_granted_max end |
#expiry_pending ⇒ Object
How long a request against this binding stays pending before it automatically lapses if not approved or denied.
22 23 24 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 22 def expiry_pending @expiry_pending end |
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
15 16 17 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 15 def policy_engine_mode @policy_engine_mode end |
#rule ⇒ Object
Returns the value of attribute rule.
17 18 19 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 17 def rule @rule end |
#target ⇒ Object
Returns the value of attribute target.
19 20 21 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 19 def target @target end |
#uuid ⇒ Object
Returns the value of attribute uuid.
13 14 15 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 13 def uuid @uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 50 def self.attribute_map { :'uuid' => :'uuid', :'policy_engine_mode' => :'policy_engine_mode', :'rule' => :'rule', :'target' => :'target', :'expiry_pending' => :'expiry_pending', :'expiry_granted_max' => :'expiry_granted_max' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 84 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 72 def self.openapi_types { :'uuid' => :'String', :'policy_engine_mode' => :'PolicyEngineMode', :'rule' => :'String', :'target' => :'String', :'expiry_pending' => :'String', :'expiry_granted_max' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 185 def ==(o) return true if self.equal?(o) self.class == o.class && uuid == o.uuid && policy_engine_mode == o.policy_engine_mode && rule == o.rule && target == o.target && expiry_pending == o.expiry_pending && expiry_granted_max == o.expiry_granted_max end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 204 def hash [uuid, policy_engine_mode, rule, target, expiry_pending, expiry_granted_max].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@expiry_pending.nil? && @expiry_pending.to_s.length < 1 invalid_properties.push('invalid value for "expiry_pending", the character length must be greater than or equal to 1.') end if !@expiry_granted_max.nil? && @expiry_granted_max.to_s.length < 1 invalid_properties.push('invalid value for "expiry_granted_max", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 152 153 |
# File 'lib/authentik/api/models/patched_request_rule_binding_request.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@expiry_pending.nil? && @expiry_pending.to_s.length < 1 return false if !@expiry_granted_max.nil? && @expiry_granted_max.to_s.length < 1 true end |