Class: Authentik::Api::PatchedSAMLPropertyMappingRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedSAMLPropertyMappingRequest
- Defined in:
- lib/authentik/api/models/patched_saml_property_mapping_request.rb
Overview
SAMLPropertyMapping Serializer
Instance Attribute Summary collapse
-
#expression ⇒ Object
Returns the value of attribute expression.
-
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#name ⇒ Object
Returns the value of attribute name.
-
#saml_name ⇒ Object
Returns the value of attribute saml_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedSAMLPropertyMappingRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedSAMLPropertyMappingRequest
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedSAMLPropertyMappingRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedSAMLPropertyMappingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'managed') self.managed = attributes[:'managed'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'expression') self.expression = attributes[:'expression'] end if attributes.key?(:'saml_name') self.saml_name = attributes[:'saml_name'] end if attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] end end |
Instance Attribute Details
#expression ⇒ Object
Returns the value of attribute expression.
18 19 20 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 18 def expression @expression end |
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
22 23 24 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 22 def friendly_name @friendly_name end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
14 15 16 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 14 def managed @managed end |
#name ⇒ Object
Returns the value of attribute name.
16 17 18 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 16 def name @name end |
#saml_name ⇒ Object
Returns the value of attribute saml_name.
20 21 22 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 20 def saml_name @saml_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 25 def self.attribute_map { :'managed' => :'managed', :'name' => :'name', :'expression' => :'expression', :'saml_name' => :'saml_name', :'friendly_name' => :'friendly_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 215 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 61 62 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 57 def self.openapi_nullable Set.new([ :'managed', :'friendly_name' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 54 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 46 def self.openapi_types { :'managed' => :'String', :'name' => :'String', :'expression' => :'String', :'saml_name' => :'String', :'friendly_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && managed == o.managed && name == o.name && expression == o.expression && saml_name == o.saml_name && friendly_name == o.friendly_name end |
#eql?(o) ⇒ Boolean
202 203 204 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 202 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
208 209 210 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 208 def hash [managed, name, expression, saml_name, friendly_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@managed.nil? && @managed.to_s.length < 1 invalid_properties.push('invalid value for "managed", the character length must be greater than or equal to 1.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@expression.nil? && @expression.to_s.length < 1 invalid_properties.push('invalid value for "expression", the character length must be greater than or equal to 1.') end if !@saml_name.nil? && @saml_name.to_s.length < 1 invalid_properties.push('invalid value for "saml_name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 237 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 133 134 |
# File 'lib/authentik/api/models/patched_saml_property_mapping_request.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@managed.nil? && @managed.to_s.length < 1 return false if !@name.nil? && @name.to_s.length < 1 return false if !@expression.nil? && @expression.to_s.length < 1 return false if !@saml_name.nil? && @saml_name.to_s.length < 1 true end |