Class: Authentik::Api::PatchedSettingsRequestFlags
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedSettingsRequestFlags
- Defined in:
- lib/authentik/api/models/patched_settings_request_flags.rb
Instance Attribute Summary collapse
-
#core_default_app_access ⇒ Object
Configure if applications without any policy/group/user bindings should be accessible to any user.
-
#enterprise_audit_include_expanded_diff ⇒ Object
Include additional information in audit logs, may incur a performance penalty.
-
#flows_continuous_login ⇒ Object
Upon successful authentication, re-start authentication in other open tabs.
-
#flows_refresh_others ⇒ Object
Refresh other tabs after successful authentication.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedSettingsRequestFlags
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedSettingsRequestFlags
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedSettingsRequestFlags` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedSettingsRequestFlags`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'core_default_app_access') self.core_default_app_access = attributes[:'core_default_app_access'] else self.core_default_app_access = nil end if attributes.key?(:'enterprise_audit_include_expanded_diff') self. = attributes[:'enterprise_audit_include_expanded_diff'] else self. = nil end if attributes.key?(:'flows_continuous_login') self.flows_continuous_login = attributes[:'flows_continuous_login'] else self.flows_continuous_login = nil end if attributes.key?(:'flows_refresh_others') self.flows_refresh_others = attributes[:'flows_refresh_others'] else self.flows_refresh_others = nil end end |
Instance Attribute Details
#core_default_app_access ⇒ Object
Configure if applications without any policy/group/user bindings should be accessible to any user.
13 14 15 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 13 def core_default_app_access @core_default_app_access end |
#enterprise_audit_include_expanded_diff ⇒ Object
Include additional information in audit logs, may incur a performance penalty.
16 17 18 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 16 def @enterprise_audit_include_expanded_diff end |
#flows_continuous_login ⇒ Object
Upon successful authentication, re-start authentication in other open tabs.
19 20 21 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 19 def flows_continuous_login @flows_continuous_login end |
#flows_refresh_others ⇒ Object
Refresh other tabs after successful authentication.
22 23 24 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 22 def flows_refresh_others @flows_refresh_others end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 25 def self.attribute_map { :'core_default_app_access' => :'core_default_app_access', :'enterprise_audit_include_expanded_diff' => :'enterprise_audit_include_expanded_diff', :'flows_continuous_login' => :'flows_continuous_login', :'flows_refresh_others' => :'flows_refresh_others' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 202 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 45 def self.openapi_types { :'core_default_app_access' => :'Boolean', :'enterprise_audit_include_expanded_diff' => :'Boolean', :'flows_continuous_login' => :'Boolean', :'flows_refresh_others' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && core_default_app_access == o.core_default_app_access && == o. && flows_continuous_login == o.flows_continuous_login && flows_refresh_others == o.flows_refresh_others end |
#eql?(o) ⇒ Boolean
189 190 191 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 189 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
195 196 197 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 195 def hash [core_default_app_access, , flows_continuous_login, flows_refresh_others].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @core_default_app_access.nil? invalid_properties.push('invalid value for "core_default_app_access", core_default_app_access cannot be nil.') end if @enterprise_audit_include_expanded_diff.nil? invalid_properties.push('invalid value for "enterprise_audit_include_expanded_diff", enterprise_audit_include_expanded_diff cannot be nil.') end if @flows_continuous_login.nil? invalid_properties.push('invalid value for "flows_continuous_login", flows_continuous_login cannot be nil.') end if @flows_refresh_others.nil? invalid_properties.push('invalid value for "flows_refresh_others", flows_refresh_others cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 224 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 133 134 |
# File 'lib/authentik/api/models/patched_settings_request_flags.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @core_default_app_access.nil? return false if @enterprise_audit_include_expanded_diff.nil? return false if @flows_continuous_login.nil? return false if @flows_refresh_others.nil? true end |