Class: Authentik::Api::PatchedSourceStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedSourceStageRequest
- Defined in:
- lib/authentik/api/models/patched_source_stage_request.rb
Overview
SourceStage Serializer
Instance Attribute Summary collapse
-
#name ⇒ Object
Returns the value of attribute name.
-
#resume_on_match_failures ⇒ Object
Source matching failure reasons for which the flow should resume.
-
#resume_timeout ⇒ Object
Amount of time a user can take to return from the source to continue the flow (Format: hours=-1;minutes=-2;seconds=-3).
-
#source ⇒ Object
Returns the value of attribute source.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedSourceStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedSourceStageRequest
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedSourceStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedSourceStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'source') self.source = attributes[:'source'] end if attributes.key?(:'resume_timeout') self.resume_timeout = attributes[:'resume_timeout'] end if attributes.key?(:'resume_on_match_failures') if (value = attributes[:'resume_on_match_failures']).is_a?(Array) self.resume_on_match_failures = value end end end |
Instance Attribute Details
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 13 def name @name end |
#resume_on_match_failures ⇒ Object
Source matching failure reasons for which the flow should resume.
21 22 23 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 21 def resume_on_match_failures @resume_on_match_failures end |
#resume_timeout ⇒ Object
Amount of time a user can take to return from the source to continue the flow (Format: hours=-1;minutes=-2;seconds=-3)
18 19 20 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 18 def resume_timeout @resume_timeout end |
#source ⇒ Object
Returns the value of attribute source.
15 16 17 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 15 def source @source end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 24 def self.attribute_map { :'name' => :'name', :'source' => :'source', :'resume_timeout' => :'resume_timeout', :'resume_on_match_failures' => :'resume_on_match_failures' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 54 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 44 def self.openapi_types { :'name' => :'String', :'source' => :'String', :'resume_timeout' => :'String', :'resume_on_match_failures' => :'Array<ResumeOnMatchFailuresEnum>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && source == o.source && resume_timeout == o.resume_timeout && resume_on_match_failures == o.resume_on_match_failures end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 166 def hash [name, source, resume_timeout, resume_on_match_failures].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 96 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@resume_timeout.nil? && @resume_timeout.to_s.length < 1 invalid_properties.push('invalid value for "resume_timeout", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 116 117 |
# File 'lib/authentik/api/models/patched_source_stage_request.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@resume_timeout.nil? && @resume_timeout.to_s.length < 1 true end |