Class: Authentik::Api::PatchedTelegramSourcePropertyMappingRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb

Overview

TelegramSourcePropertyMapping Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedTelegramSourcePropertyMappingRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 57

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedTelegramSourcePropertyMappingRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedTelegramSourcePropertyMappingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'managed')
    self.managed = attributes[:'managed']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'expression')
    self.expression = attributes[:'expression']
  end
end

Instance Attribute Details

#expressionObject

Returns the value of attribute expression.



18
19
20
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 18

def expression
  @expression
end

#managedObject

Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.



14
15
16
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 14

def managed
  @managed
end

#nameObject

Returns the value of attribute name.



16
17
18
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 16

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



30
31
32
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 30

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



35
36
37
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 35

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 21

def self.attribute_map
  {
    :'managed' => :'managed',
    :'name' => :'name',
    :'expression' => :'expression'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



49
50
51
52
53
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 49

def self.openapi_nullable
  Set.new([
    :'managed',
  ])
end

.openapi_typesObject

Attribute type mapping.



40
41
42
43
44
45
46
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 40

def self.openapi_types
  {
    :'managed' => :'String',
    :'name' => :'String',
    :'expression' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



154
155
156
157
158
159
160
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 154

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      managed == o.managed &&
      name == o.name &&
      expression == o.expression
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 170

def hash
  [managed, name, expression].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 86

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@managed.nil? && @managed.to_s.length < 1
    invalid_properties.push('invalid value for "managed", the character length must be greater than or equal to 1.')
  end

  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@expression.nil? && @expression.to_s.length < 1
    invalid_properties.push('invalid value for "expression", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



106
107
108
109
110
111
112
# File 'lib/authentik/api/models/patched_telegram_source_property_mapping_request.rb', line 106

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@managed.nil? && @managed.to_s.length < 1
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@expression.nil? && @expression.to_s.length < 1
  true
end