Class: Authentik::Api::PatchedTelegramSourceRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedTelegramSourceRequest
- Defined in:
- lib/authentik/api/models/patched_telegram_source_request.rb
Overview
Source Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#authentication_flow ⇒ Object
Flow to use when authenticating existing users.
-
#bot_token ⇒ Object
Telegram bot token.
-
#bot_username ⇒ Object
Telegram bot username.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#enrollment_flow ⇒ Object
Flow to use when enrolling new users.
-
#group_property_mappings ⇒ Object
Returns the value of attribute group_property_mappings.
-
#icon ⇒ Object
Returns the value of attribute icon.
-
#name ⇒ Object
Source’s display Name.
-
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
-
#pre_authentication_flow ⇒ Object
Flow used before authentication.
-
#promoted ⇒ Object
When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
-
#request_message_access ⇒ Object
Request access to send messages from your bot.
-
#slug ⇒ Object
Internal source name, used in URLs.
-
#user_matching_mode ⇒ Object
How the source determines if an existing user should be authenticated or a new user enrolled.
-
#user_path_template ⇒ Object
Returns the value of attribute user_path_template.
-
#user_property_mappings ⇒ Object
Returns the value of attribute user_property_mappings.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedTelegramSourceRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedTelegramSourceRequest
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedTelegramSourceRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedTelegramSourceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'promoted') self.promoted = attributes[:'promoted'] end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'enrollment_flow') self.enrollment_flow = attributes[:'enrollment_flow'] end if attributes.key?(:'user_property_mappings') if (value = attributes[:'user_property_mappings']).is_a?(Array) self.user_property_mappings = value end end if attributes.key?(:'group_property_mappings') if (value = attributes[:'group_property_mappings']).is_a?(Array) self.group_property_mappings = value end end if attributes.key?(:'policy_engine_mode') self.policy_engine_mode = attributes[:'policy_engine_mode'] end if attributes.key?(:'user_matching_mode') self.user_matching_mode = attributes[:'user_matching_mode'] end if attributes.key?(:'user_path_template') self.user_path_template = attributes[:'user_path_template'] end if attributes.key?(:'icon') self.icon = attributes[:'icon'] end if attributes.key?(:'bot_username') self.bot_username = attributes[:'bot_username'] end if attributes.key?(:'bot_token') self.bot_token = attributes[:'bot_token'] end if attributes.key?(:'request_message_access') self. = attributes[:'request_message_access'] end if attributes.key?(:'pre_authentication_flow') self.pre_authentication_flow = attributes[:'pre_authentication_flow'] end end |
Instance Attribute Details
#authentication_flow ⇒ Object
Flow to use when authenticating existing users.
25 26 27 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 25 def authentication_flow @authentication_flow end |
#bot_token ⇒ Object
Telegram bot token
47 48 49 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 47 def bot_token @bot_token end |
#bot_username ⇒ Object
Telegram bot username
44 45 46 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 44 def bot_username @bot_username end |
#enabled ⇒ Object
Returns the value of attribute enabled.
19 20 21 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 19 def enabled @enabled end |
#enrollment_flow ⇒ Object
Flow to use when enrolling new users.
28 29 30 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 28 def enrollment_flow @enrollment_flow end |
#group_property_mappings ⇒ Object
Returns the value of attribute group_property_mappings.
32 33 34 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 32 def group_property_mappings @group_property_mappings end |
#icon ⇒ Object
Returns the value of attribute icon.
41 42 43 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 41 def icon @icon end |
#name ⇒ Object
Source’s display Name.
14 15 16 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 14 def name @name end |
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
34 35 36 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 34 def policy_engine_mode @policy_engine_mode end |
#pre_authentication_flow ⇒ Object
Flow used before authentication.
53 54 55 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 53 def pre_authentication_flow @pre_authentication_flow end |
#promoted ⇒ Object
When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
22 23 24 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 22 def promoted @promoted end |
#request_message_access ⇒ Object
Request access to send messages from your bot.
50 51 52 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 50 def @request_message_access end |
#slug ⇒ Object
Internal source name, used in URLs.
17 18 19 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 17 def slug @slug end |
#user_matching_mode ⇒ Object
How the source determines if an existing user should be authenticated or a new user enrolled.
37 38 39 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 37 def user_matching_mode @user_matching_mode end |
#user_path_template ⇒ Object
Returns the value of attribute user_path_template.
39 40 41 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 39 def user_path_template @user_path_template end |
#user_property_mappings ⇒ Object
Returns the value of attribute user_property_mappings.
30 31 32 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 30 def user_property_mappings @user_property_mappings end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
100 101 102 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 100 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
105 106 107 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 105 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 78 def self.attribute_map { :'name' => :'name', :'slug' => :'slug', :'enabled' => :'enabled', :'promoted' => :'promoted', :'authentication_flow' => :'authentication_flow', :'enrollment_flow' => :'enrollment_flow', :'user_property_mappings' => :'user_property_mappings', :'group_property_mappings' => :'group_property_mappings', :'policy_engine_mode' => :'policy_engine_mode', :'user_matching_mode' => :'user_matching_mode', :'user_path_template' => :'user_path_template', :'icon' => :'icon', :'bot_username' => :'bot_username', :'bot_token' => :'bot_token', :'request_message_access' => :'request_message_access', :'pre_authentication_flow' => :'pre_authentication_flow' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 383 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
132 133 134 135 136 137 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 132 def self.openapi_nullable Set.new([ :'authentication_flow', :'enrollment_flow', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 110 def self.openapi_types { :'name' => :'String', :'slug' => :'String', :'enabled' => :'Boolean', :'promoted' => :'Boolean', :'authentication_flow' => :'String', :'enrollment_flow' => :'String', :'user_property_mappings' => :'Array<String>', :'group_property_mappings' => :'Array<String>', :'policy_engine_mode' => :'PolicyEngineMode', :'user_matching_mode' => :'UserMatchingModeEnum', :'user_path_template' => :'String', :'icon' => :'String', :'bot_username' => :'String', :'bot_token' => :'String', :'request_message_access' => :'Boolean', :'pre_authentication_flow' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 347 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && slug == o.slug && enabled == o.enabled && promoted == o.promoted && authentication_flow == o.authentication_flow && enrollment_flow == o.enrollment_flow && user_property_mappings == o.user_property_mappings && group_property_mappings == o.group_property_mappings && policy_engine_mode == o.policy_engine_mode && user_matching_mode == o.user_matching_mode && user_path_template == o.user_path_template && icon == o.icon && bot_username == o.bot_username && bot_token == o.bot_token && == o. && pre_authentication_flow == o.pre_authentication_flow end |
#eql?(o) ⇒ Boolean
370 371 372 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 370 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
376 377 378 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 376 def hash [name, slug, enabled, promoted, authentication_flow, enrollment_flow, user_property_mappings, group_property_mappings, policy_engine_mode, user_matching_mode, user_path_template, icon, bot_username, bot_token, , pre_authentication_flow].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 226 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@slug.nil? && @slug.to_s.length < 1 invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/) if !@slug.nil? && @slug !~ pattern invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.") end if !@user_path_template.nil? && @user_path_template.to_s.length < 1 invalid_properties.push('invalid value for "user_path_template", the character length must be greater than or equal to 1.') end if !@bot_username.nil? && @bot_username.to_s.length < 1 invalid_properties.push('invalid value for "bot_username", the character length must be greater than or equal to 1.') end if !@bot_token.nil? && @bot_token.to_s.length < 1 invalid_properties.push('invalid value for "bot_token", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 405 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
259 260 261 262 263 264 265 266 267 268 |
# File 'lib/authentik/api/models/patched_telegram_source_request.rb', line 259 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@slug.nil? && @slug.to_s.length < 1 return false if !@slug.nil? && @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/) return false if !@user_path_template.nil? && @user_path_template.to_s.length < 1 return false if !@bot_username.nil? && @bot_username.to_s.length < 1 return false if !@bot_token.nil? && @bot_token.to_s.length < 1 true end |