Class: Authentik::Api::PatchedTenantRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedTenantRequest
- Defined in:
- lib/authentik/api/models/patched_tenant_request.rb
Overview
Tenant Serializer
Instance Attribute Summary collapse
-
#name ⇒ Object
Returns the value of attribute name.
-
#ready ⇒ Object
Returns the value of attribute ready.
-
#schema_name ⇒ Object
Returns the value of attribute schema_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedTenantRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedTenantRequest
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 55 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedTenantRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedTenantRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'schema_name') self.schema_name = attributes[:'schema_name'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'ready') self.ready = attributes[:'ready'] end end |
Instance Attribute Details
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 15 def name @name end |
#ready ⇒ Object
Returns the value of attribute ready.
17 18 19 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 17 def ready @ready end |
#schema_name ⇒ Object
Returns the value of attribute schema_name.
13 14 15 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 13 def schema_name @schema_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
29 30 31 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 29 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
34 35 36 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 34 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 20 def self.attribute_map { :'schema_name' => :'schema_name', :'name' => :'name', :'ready' => :'ready' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 169 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 51 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 48 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 39 def self.openapi_types { :'schema_name' => :'String', :'name' => :'String', :'ready' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 146 def ==(o) return true if self.equal?(o) self.class == o.class && schema_name == o.schema_name && name == o.name && ready == o.ready end |
#eql?(o) ⇒ Boolean
156 157 158 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 156 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
162 163 164 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 162 def hash [schema_name, name, ready].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 84 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@schema_name.nil? && @schema_name.to_s.length > 63 invalid_properties.push('invalid value for "schema_name", the character length must be smaller than or equal to 63.') end if !@schema_name.nil? && @schema_name.to_s.length < 1 invalid_properties.push('invalid value for "schema_name", the character length must be greater than or equal to 1.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
104 105 106 107 108 109 110 |
# File 'lib/authentik/api/models/patched_tenant_request.rb', line 104 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@schema_name.nil? && @schema_name.to_s.length > 63 return false if !@schema_name.nil? && @schema_name.to_s.length < 1 return false if !@name.nil? && @name.to_s.length < 1 true end |