Class: Authentik::Api::PatchedUserOAuthSourceConnectionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedUserOAuthSourceConnectionRequest
- Defined in:
- lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb
Overview
User source connection
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Returns the value of attribute access_token.
-
#expires ⇒ Object
Returns the value of attribute expires.
-
#identifier ⇒ Object
Returns the value of attribute identifier.
-
#source ⇒ Object
Returns the value of attribute source.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedUserOAuthSourceConnectionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedUserOAuthSourceConnectionRequest
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedUserOAuthSourceConnectionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedUserOAuthSourceConnectionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'source') self.source = attributes[:'source'] end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] end if attributes.key?(:'access_token') self.access_token = attributes[:'access_token'] end if attributes.key?(:'expires') self.expires = attributes[:'expires'] end end |
Instance Attribute Details
#access_token ⇒ Object
Returns the value of attribute access_token.
17 18 19 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 17 def access_token @access_token end |
#expires ⇒ Object
Returns the value of attribute expires.
19 20 21 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 19 def expires @expires end |
#identifier ⇒ Object
Returns the value of attribute identifier.
15 16 17 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 15 def identifier @identifier end |
#source ⇒ Object
Returns the value of attribute source.
13 14 15 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 13 def source @source end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 22 def self.attribute_map { :'source' => :'source', :'identifier' => :'identifier', :'access_token' => :'access_token', :'expires' => :'expires' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 56 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 52 def self.openapi_nullable Set.new([ :'access_token', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 42 def self.openapi_types { :'source' => :'String', :'identifier' => :'String', :'access_token' => :'String', :'expires' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 134 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 127 def ==(o) return true if self.equal?(o) self.class == o.class && source == o.source && identifier == o.identifier && access_token == o.access_token && expires == o.expires end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 144 def hash [source, identifier, access_token, expires].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@identifier.nil? && @identifier.to_s.length < 1 invalid_properties.push('invalid value for "identifier", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
105 106 107 108 109 |
# File 'lib/authentik/api/models/patched_user_o_auth_source_connection_request.rb', line 105 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@identifier.nil? && @identifier.to_s.length < 1 true end |