Class: Authentik::Api::PatchedUserWriteStageRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_user_write_stage_request.rb

Overview

UserWriteStage Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedUserWriteStageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedUserWriteStageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedUserWriteStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'user_creation_mode')
    self.user_creation_mode = attributes[:'user_creation_mode']
  end

  if attributes.key?(:'create_users_as_inactive')
    self.create_users_as_inactive = attributes[:'create_users_as_inactive']
  end

  if attributes.key?(:'create_users_group')
    self.create_users_group = attributes[:'create_users_group']
  end

  if attributes.key?(:'user_type')
    self.user_type = attributes[:'user_type']
  end

  if attributes.key?(:'user_path_template')
    self.user_path_template = attributes[:'user_path_template']
  end
end

Instance Attribute Details

#create_users_as_inactiveObject

When set, newly created users are inactive and cannot login.



18
19
20
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 18

def create_users_as_inactive
  @create_users_as_inactive
end

#create_users_groupObject

Optionally add newly created users to this group.



21
22
23
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 21

def create_users_group
  @create_users_group
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 13

def name
  @name
end

#user_creation_modeObject

Returns the value of attribute user_creation_mode.



15
16
17
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 15

def user_creation_mode
  @user_creation_mode
end

#user_path_templateObject

Returns the value of attribute user_path_template.



25
26
27
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 25

def user_path_template
  @user_path_template
end

#user_typeObject

Returns the value of attribute user_type.



23
24
25
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 23

def user_type
  @user_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 50

def self.attribute_map
  {
    :'name' => :'name',
    :'user_creation_mode' => :'user_creation_mode',
    :'create_users_as_inactive' => :'create_users_as_inactive',
    :'create_users_group' => :'create_users_group',
    :'user_type' => :'user_type',
    :'user_path_template' => :'user_path_template'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
88
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 84

def self.openapi_nullable
  Set.new([
    :'create_users_group',
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 72

def self.openapi_types
  {
    :'name' => :'String',
    :'user_creation_mode' => :'UserCreationModeEnum',
    :'create_users_as_inactive' => :'Boolean',
    :'create_users_group' => :'String',
    :'user_type' => :'UserTypeEnum',
    :'user_path_template' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



167
168
169
170
171
172
173
174
175
176
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 167

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      user_creation_mode == o.user_creation_mode &&
      create_users_as_inactive == o.create_users_as_inactive &&
      create_users_group == o.create_users_group &&
      user_type == o.user_type &&
      user_path_template == o.user_path_template
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 186

def hash
  [name, user_creation_mode, create_users_as_inactive, create_users_group, user_type, user_path_template].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
138
139
140
141
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
# File 'lib/authentik/api/models/patched_user_write_stage_request.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  true
end