Class: Authentik::Api::PlexSourceRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/plex_source_request.rb

Overview

Plex Source Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PlexSourceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/authentik/api/models/plex_source_request.rb', line 146

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PlexSourceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PlexSourceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'promoted')
    self.promoted = attributes[:'promoted']
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'enrollment_flow')
    self.enrollment_flow = attributes[:'enrollment_flow']
  end

  if attributes.key?(:'user_property_mappings')
    if (value = attributes[:'user_property_mappings']).is_a?(Array)
      self.user_property_mappings = value
    end
  end

  if attributes.key?(:'group_property_mappings')
    if (value = attributes[:'group_property_mappings']).is_a?(Array)
      self.group_property_mappings = value
    end
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'user_matching_mode')
    self.user_matching_mode = attributes[:'user_matching_mode']
  end

  if attributes.key?(:'user_path_template')
    self.user_path_template = attributes[:'user_path_template']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'group_matching_mode')
    self.group_matching_mode = attributes[:'group_matching_mode']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'allowed_servers')
    if (value = attributes[:'allowed_servers']).is_a?(Array)
      self.allowed_servers = value
    end
  end

  if attributes.key?(:'allow_friends')
    self.allow_friends = attributes[:'allow_friends']
  end

  if attributes.key?(:'plex_token')
    self.plex_token = attributes[:'plex_token']
  else
    self.plex_token = nil
  end
end

Instance Attribute Details

#allow_friendsObject

Allow friends to authenticate, even if you don’t share a server.



53
54
55
# File 'lib/authentik/api/models/plex_source_request.rb', line 53

def allow_friends
  @allow_friends
end

#allowed_serversObject

Which servers a user has to be a member of to be granted access. Empty list allows every server.



50
51
52
# File 'lib/authentik/api/models/plex_source_request.rb', line 50

def allowed_servers
  @allowed_servers
end

#authentication_flowObject

Flow to use when authenticating existing users.



25
26
27
# File 'lib/authentik/api/models/plex_source_request.rb', line 25

def authentication_flow
  @authentication_flow
end

#client_idObject

Client identifier used to talk to Plex.



47
48
49
# File 'lib/authentik/api/models/plex_source_request.rb', line 47

def client_id
  @client_id
end

#enabledObject

Returns the value of attribute enabled.



19
20
21
# File 'lib/authentik/api/models/plex_source_request.rb', line 19

def enabled
  @enabled
end

#enrollment_flowObject

Flow to use when enrolling new users.



28
29
30
# File 'lib/authentik/api/models/plex_source_request.rb', line 28

def enrollment_flow
  @enrollment_flow
end

#group_matching_modeObject

How the source determines if an existing group should be used or a new group created.



44
45
46
# File 'lib/authentik/api/models/plex_source_request.rb', line 44

def group_matching_mode
  @group_matching_mode
end

#group_property_mappingsObject

Returns the value of attribute group_property_mappings.



32
33
34
# File 'lib/authentik/api/models/plex_source_request.rb', line 32

def group_property_mappings
  @group_property_mappings
end

#iconObject

Returns the value of attribute icon.



41
42
43
# File 'lib/authentik/api/models/plex_source_request.rb', line 41

def icon
  @icon
end

#nameObject

Source’s display Name.



14
15
16
# File 'lib/authentik/api/models/plex_source_request.rb', line 14

def name
  @name
end

#plex_tokenObject

Plex token used to check friends



56
57
58
# File 'lib/authentik/api/models/plex_source_request.rb', line 56

def plex_token
  @plex_token
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



34
35
36
# File 'lib/authentik/api/models/plex_source_request.rb', line 34

def policy_engine_mode
  @policy_engine_mode
end

When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.



22
23
24
# File 'lib/authentik/api/models/plex_source_request.rb', line 22

def promoted
  @promoted
end

#slugObject

Internal source name, used in URLs.



17
18
19
# File 'lib/authentik/api/models/plex_source_request.rb', line 17

def slug
  @slug
end

#user_matching_modeObject

How the source determines if an existing user should be authenticated or a new user enrolled.



37
38
39
# File 'lib/authentik/api/models/plex_source_request.rb', line 37

def user_matching_mode
  @user_matching_mode
end

#user_path_templateObject

Returns the value of attribute user_path_template.



39
40
41
# File 'lib/authentik/api/models/plex_source_request.rb', line 39

def user_path_template
  @user_path_template
end

#user_property_mappingsObject

Returns the value of attribute user_property_mappings.



30
31
32
# File 'lib/authentik/api/models/plex_source_request.rb', line 30

def user_property_mappings
  @user_property_mappings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



104
105
106
# File 'lib/authentik/api/models/plex_source_request.rb', line 104

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/authentik/api/models/plex_source_request.rb', line 109

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/authentik/api/models/plex_source_request.rb', line 81

def self.attribute_map
  {
    :'name' => :'name',
    :'slug' => :'slug',
    :'enabled' => :'enabled',
    :'promoted' => :'promoted',
    :'authentication_flow' => :'authentication_flow',
    :'enrollment_flow' => :'enrollment_flow',
    :'user_property_mappings' => :'user_property_mappings',
    :'group_property_mappings' => :'group_property_mappings',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'user_matching_mode' => :'user_matching_mode',
    :'user_path_template' => :'user_path_template',
    :'icon' => :'icon',
    :'group_matching_mode' => :'group_matching_mode',
    :'client_id' => :'client_id',
    :'allowed_servers' => :'allowed_servers',
    :'allow_friends' => :'allow_friends',
    :'plex_token' => :'plex_token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/authentik/api/models/plex_source_request.rb', line 416

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



137
138
139
140
141
142
# File 'lib/authentik/api/models/plex_source_request.rb', line 137

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
    :'enrollment_flow',
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/authentik/api/models/plex_source_request.rb', line 114

def self.openapi_types
  {
    :'name' => :'String',
    :'slug' => :'String',
    :'enabled' => :'Boolean',
    :'promoted' => :'Boolean',
    :'authentication_flow' => :'String',
    :'enrollment_flow' => :'String',
    :'user_property_mappings' => :'Array<String>',
    :'group_property_mappings' => :'Array<String>',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'user_matching_mode' => :'UserMatchingModeEnum',
    :'user_path_template' => :'String',
    :'icon' => :'String',
    :'group_matching_mode' => :'GroupMatchingModeEnum',
    :'client_id' => :'String',
    :'allowed_servers' => :'Array<String>',
    :'allow_friends' => :'Boolean',
    :'plex_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/authentik/api/models/plex_source_request.rb', line 379

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      slug == o.slug &&
      enabled == o.enabled &&
      promoted == o.promoted &&
      authentication_flow == o.authentication_flow &&
      enrollment_flow == o.enrollment_flow &&
      user_property_mappings == o.user_property_mappings &&
      group_property_mappings == o.group_property_mappings &&
      policy_engine_mode == o.policy_engine_mode &&
      user_matching_mode == o.user_matching_mode &&
      user_path_template == o.user_path_template &&
      icon == o.icon &&
      group_matching_mode == o.group_matching_mode &&
      client_id == o.client_id &&
      allowed_servers == o.allowed_servers &&
      allow_friends == o.allow_friends &&
      plex_token == o.plex_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


403
404
405
# File 'lib/authentik/api/models/plex_source_request.rb', line 403

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



409
410
411
# File 'lib/authentik/api/models/plex_source_request.rb', line 409

def hash
  [name, slug, enabled, promoted, authentication_flow, enrollment_flow, user_property_mappings, group_property_mappings, policy_engine_mode, user_matching_mode, user_path_template, icon, group_matching_mode, client_id, allowed_servers, allow_friends, plex_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/authentik/api/models/plex_source_request.rb', line 243

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  if @slug.to_s.length < 1
    invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if !@user_path_template.nil? && @user_path_template.to_s.length < 1
    invalid_properties.push('invalid value for "user_path_template", the character length must be greater than or equal to 1.')
  end

  if !@client_id.nil? && @client_id.to_s.length < 1
    invalid_properties.push('invalid value for "client_id", the character length must be greater than or equal to 1.')
  end

  if @plex_token.nil?
    invalid_properties.push('invalid value for "plex_token", plex_token cannot be nil.')
  end

  if @plex_token.to_s.length < 1
    invalid_properties.push('invalid value for "plex_token", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/authentik/api/models/plex_source_request.rb', line 438

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/authentik/api/models/plex_source_request.rb', line 288

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @slug.nil?
  return false if @slug.to_s.length < 1
  return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if !@user_path_template.nil? && @user_path_template.to_s.length < 1
  return false if !@client_id.nil? && @client_id.to_s.length < 1
  return false if @plex_token.nil?
  return false if @plex_token.to_s.length < 1
  true
end