Class: Authentik::Api::PolicyBinding

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/policy_binding.rb

Overview

PolicyBinding Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PolicyBinding

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/authentik/api/models/policy_binding.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PolicyBinding` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PolicyBinding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'policy')
    self.policy = attributes[:'policy']
  end

  if attributes.key?(:'group')
    self.group = attributes[:'group']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'policy_obj')
    self.policy_obj = attributes[:'policy_obj']
  else
    self.policy_obj = nil
  end

  if attributes.key?(:'group_obj')
    self.group_obj = attributes[:'group_obj']
  else
    self.group_obj = nil
  end

  if attributes.key?(:'user_obj')
    self.user_obj = attributes[:'user_obj']
  else
    self.user_obj = nil
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  else
    self.target = nil
  end

  if attributes.key?(:'negate')
    self.negate = attributes[:'negate']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  else
    self.order = nil
  end

  if attributes.key?(:'timeout')
    self.timeout = attributes[:'timeout']
  end

  if attributes.key?(:'failure_result')
    self.failure_result = attributes[:'failure_result']
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  else
    self.expires = nil
  end

  if attributes.key?(:'expiring')
    self.expiring = attributes[:'expiring']
  else
    self.expiring = nil
  end
end

Instance Attribute Details

#enabledObject

Returns the value of attribute enabled.



32
33
34
# File 'lib/authentik/api/models/policy_binding.rb', line 32

def enabled
  @enabled
end

#expiresObject

Returns the value of attribute expires.



42
43
44
# File 'lib/authentik/api/models/policy_binding.rb', line 42

def expires
  @expires
end

#expiringObject

Returns the value of attribute expiring.



44
45
46
# File 'lib/authentik/api/models/policy_binding.rb', line 44

def expiring
  @expiring
end

#failure_resultObject

Result if the Policy execution fails.



40
41
42
# File 'lib/authentik/api/models/policy_binding.rb', line 40

def failure_result
  @failure_result
end

#groupObject

Returns the value of attribute group.



17
18
19
# File 'lib/authentik/api/models/policy_binding.rb', line 17

def group
  @group
end

#group_objObject

Returns the value of attribute group_obj.



23
24
25
# File 'lib/authentik/api/models/policy_binding.rb', line 23

def group_obj
  @group_obj
end

#negateObject

Negates the outcome of the policy. Messages are unaffected.



30
31
32
# File 'lib/authentik/api/models/policy_binding.rb', line 30

def negate
  @negate
end

#orderObject

Returns the value of attribute order.



34
35
36
# File 'lib/authentik/api/models/policy_binding.rb', line 34

def order
  @order
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/policy_binding.rb', line 13

def pk
  @pk
end

#policyObject

Returns the value of attribute policy.



15
16
17
# File 'lib/authentik/api/models/policy_binding.rb', line 15

def policy
  @policy
end

#policy_objObject

Returns the value of attribute policy_obj.



21
22
23
# File 'lib/authentik/api/models/policy_binding.rb', line 21

def policy_obj
  @policy_obj
end

#targetObject

Returns the value of attribute target.



27
28
29
# File 'lib/authentik/api/models/policy_binding.rb', line 27

def target
  @target
end

#timeoutObject

Timeout after which Policy execution is terminated.



37
38
39
# File 'lib/authentik/api/models/policy_binding.rb', line 37

def timeout
  @timeout
end

#userObject

Returns the value of attribute user.



19
20
21
# File 'lib/authentik/api/models/policy_binding.rb', line 19

def user
  @user
end

#user_objObject

Returns the value of attribute user_obj.



25
26
27
# File 'lib/authentik/api/models/policy_binding.rb', line 25

def user_obj
  @user_obj
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/authentik/api/models/policy_binding.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/authentik/api/models/policy_binding.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/authentik/api/models/policy_binding.rb', line 47

def self.attribute_map
  {
    :'pk' => :'pk',
    :'policy' => :'policy',
    :'group' => :'group',
    :'user' => :'user',
    :'policy_obj' => :'policy_obj',
    :'group_obj' => :'group_obj',
    :'user_obj' => :'user_obj',
    :'target' => :'target',
    :'negate' => :'negate',
    :'enabled' => :'enabled',
    :'order' => :'order',
    :'timeout' => :'timeout',
    :'failure_result' => :'failure_result',
    :'expires' => :'expires',
    :'expiring' => :'expiring'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/authentik/api/models/policy_binding.rb', line 362

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
103
104
105
106
107
108
109
# File 'lib/authentik/api/models/policy_binding.rb', line 99

def self.openapi_nullable
  Set.new([
    :'policy',
    :'group',
    :'user',
    :'policy_obj',
    :'group_obj',
    :'user_obj',
    :'expires',
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/authentik/api/models/policy_binding.rb', line 78

def self.openapi_types
  {
    :'pk' => :'String',
    :'policy' => :'String',
    :'group' => :'String',
    :'user' => :'Integer',
    :'policy_obj' => :'Policy',
    :'group_obj' => :'PartialGroup',
    :'user_obj' => :'PartialUser',
    :'target' => :'String',
    :'negate' => :'Boolean',
    :'enabled' => :'Boolean',
    :'order' => :'Integer',
    :'timeout' => :'Integer',
    :'failure_result' => :'Boolean',
    :'expires' => :'Time',
    :'expiring' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/authentik/api/models/policy_binding.rb', line 327

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      policy == o.policy &&
      group == o.group &&
      user == o.user &&
      policy_obj == o.policy_obj &&
      group_obj == o.group_obj &&
      user_obj == o.user_obj &&
      target == o.target &&
      negate == o.negate &&
      enabled == o.enabled &&
      order == o.order &&
      timeout == o.timeout &&
      failure_result == o.failure_result &&
      expires == o.expires &&
      expiring == o.expiring
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


349
350
351
# File 'lib/authentik/api/models/policy_binding.rb', line 349

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



355
356
357
# File 'lib/authentik/api/models/policy_binding.rb', line 355

def hash
  [pk, policy, group, user, policy_obj, group_obj, user_obj, target, negate, enabled, order, timeout, failure_result, expires, expiring].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/authentik/api/models/policy_binding.rb', line 206

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @target.nil?
    invalid_properties.push('invalid value for "target", target cannot be nil.')
  end

  if @order.nil?
    invalid_properties.push('invalid value for "order", order cannot be nil.')
  end

  if @order > 2147483647
    invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.')
  end

  if @order < -2147483648
    invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.')
  end

  if !@timeout.nil? && @timeout > 2147483647
    invalid_properties.push('invalid value for "timeout", must be smaller than or equal to 2147483647.')
  end

  if !@timeout.nil? && @timeout < 0
    invalid_properties.push('invalid value for "timeout", must be greater than or equal to 0.')
  end

  if @expiring.nil?
    invalid_properties.push('invalid value for "expiring", expiring cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/authentik/api/models/policy_binding.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/authentik/api/models/policy_binding.rb', line 246

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @target.nil?
  return false if @order.nil?
  return false if @order > 2147483647
  return false if @order < -2147483648
  return false if !@timeout.nil? && @timeout > 2147483647
  return false if !@timeout.nil? && @timeout < 0
  return false if @expiring.nil?
  true
end