Class: Authentik::Api::Prompt

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/prompt.rb

Overview

Prompt Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Prompt

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/authentik/api/models/prompt.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Prompt` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Prompt`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'field_key')
    self.field_key = attributes[:'field_key']
  else
    self.field_key = nil
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  else
    self.label = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  end

  if attributes.key?(:'placeholder')
    self.placeholder = attributes[:'placeholder']
  end

  if attributes.key?(:'initial_value')
    self.initial_value = attributes[:'initial_value']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.key?(:'prompt_stages_obj')
    if (value = attributes[:'prompt_stages_obj']).is_a?(Array)
      self.prompt_stages_obj = value
    end
  else
    self.prompt_stages_obj = nil
  end

  if attributes.key?(:'sub_text')
    self.sub_text = attributes[:'sub_text']
  end

  if attributes.key?(:'placeholder_expression')
    self.placeholder_expression = attributes[:'placeholder_expression']
  end

  if attributes.key?(:'initial_value_expression')
    self.initial_value_expression = attributes[:'initial_value_expression']
  end
end

Instance Attribute Details

#field_keyObject

Name of the form field, also used to store the value



18
19
20
# File 'lib/authentik/api/models/prompt.rb', line 18

def field_key
  @field_key
end

#initial_valueObject

Optionally pre-fill the input with an initial value. When creating a fixed choice field, enable interpreting as expression and return a list to return multiple default choices.



30
31
32
# File 'lib/authentik/api/models/prompt.rb', line 30

def initial_value
  @initial_value
end

#initial_value_expressionObject

Returns the value of attribute initial_value_expression.



40
41
42
# File 'lib/authentik/api/models/prompt.rb', line 40

def initial_value_expression
  @initial_value_expression
end

#labelObject

Returns the value of attribute label.



20
21
22
# File 'lib/authentik/api/models/prompt.rb', line 20

def label
  @label
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/prompt.rb', line 15

def name
  @name
end

#orderObject

Returns the value of attribute order.



32
33
34
# File 'lib/authentik/api/models/prompt.rb', line 32

def order
  @order
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/prompt.rb', line 13

def pk
  @pk
end

#placeholderObject

Optionally provide a short hint that describes the expected input value. When creating a fixed choice field, enable interpreting as expression and return a list to return multiple choices.



27
28
29
# File 'lib/authentik/api/models/prompt.rb', line 27

def placeholder
  @placeholder
end

#placeholder_expressionObject

Returns the value of attribute placeholder_expression.



38
39
40
# File 'lib/authentik/api/models/prompt.rb', line 38

def placeholder_expression
  @placeholder_expression
end

#prompt_stages_objObject

Returns the value of attribute prompt_stages_obj.



34
35
36
# File 'lib/authentik/api/models/prompt.rb', line 34

def prompt_stages_obj
  @prompt_stages_obj
end

#requiredObject

Returns the value of attribute required.



24
25
26
# File 'lib/authentik/api/models/prompt.rb', line 24

def required
  @required
end

#sub_textObject

Returns the value of attribute sub_text.



36
37
38
# File 'lib/authentik/api/models/prompt.rb', line 36

def sub_text
  @sub_text
end

#typeObject

Returns the value of attribute type.



22
23
24
# File 'lib/authentik/api/models/prompt.rb', line 22

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



84
85
86
# File 'lib/authentik/api/models/prompt.rb', line 84

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/authentik/api/models/prompt.rb', line 89

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/authentik/api/models/prompt.rb', line 65

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'field_key' => :'field_key',
    :'label' => :'label',
    :'type' => :'type',
    :'required' => :'required',
    :'placeholder' => :'placeholder',
    :'initial_value' => :'initial_value',
    :'order' => :'order',
    :'prompt_stages_obj' => :'prompt_stages_obj',
    :'sub_text' => :'sub_text',
    :'placeholder_expression' => :'placeholder_expression',
    :'initial_value_expression' => :'initial_value_expression'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/authentik/api/models/prompt.rb', line 369

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
# File 'lib/authentik/api/models/prompt.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/authentik/api/models/prompt.rb', line 94

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'field_key' => :'String',
    :'label' => :'String',
    :'type' => :'PromptTypeEnum',
    :'required' => :'Boolean',
    :'placeholder' => :'String',
    :'initial_value' => :'String',
    :'order' => :'Integer',
    :'prompt_stages_obj' => :'Array<PromptStage>',
    :'sub_text' => :'String',
    :'placeholder_expression' => :'Boolean',
    :'initial_value_expression' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/authentik/api/models/prompt.rb', line 336

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      field_key == o.field_key &&
      label == o.label &&
      type == o.type &&
      required == o.required &&
      placeholder == o.placeholder &&
      initial_value == o.initial_value &&
      order == o.order &&
      prompt_stages_obj == o.prompt_stages_obj &&
      sub_text == o.sub_text &&
      placeholder_expression == o.placeholder_expression &&
      initial_value_expression == o.initial_value_expression
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


356
357
358
# File 'lib/authentik/api/models/prompt.rb', line 356

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



362
363
364
# File 'lib/authentik/api/models/prompt.rb', line 362

def hash
  [pk, name, field_key, label, type, required, placeholder, initial_value, order, prompt_stages_obj, sub_text, placeholder_expression, initial_value_expression].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/authentik/api/models/prompt.rb', line 203

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @field_key.nil?
    invalid_properties.push('invalid value for "field_key", field_key cannot be nil.')
  end

  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@order.nil? && @order > 2147483647
    invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.')
  end

  if !@order.nil? && @order < -2147483648
    invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.')
  end

  if @prompt_stages_obj.nil?
    invalid_properties.push('invalid value for "prompt_stages_obj", prompt_stages_obj cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/authentik/api/models/prompt.rb', line 391

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/authentik/api/models/prompt.rb', line 243

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @field_key.nil?
  return false if @label.nil?
  return false if @type.nil?
  return false if !@order.nil? && @order > 2147483647
  return false if !@order.nil? && @order < -2147483648
  return false if @prompt_stages_obj.nil?
  true
end