Class: Authentik::Api::PromptChallenge

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/prompt_challenge.rb

Overview

Initial challenge being sent, define fields

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PromptChallenge

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/authentik/api/models/prompt_challenge.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PromptChallenge` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PromptChallenge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flow_info')
    self.flow_info = attributes[:'flow_info']
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = 'ak-stage-prompt'
  end

  if attributes.key?(:'response_errors')
    if (value = attributes[:'response_errors']).is_a?(Hash)
      self.response_errors = value
    end
  end

  if attributes.key?(:'fields')
    if (value = attributes[:'fields']).is_a?(Array)
      self.fields = value
    end
  else
    self.fields = nil
  end
end

Instance Attribute Details

#componentObject

Returns the value of attribute component.



15
16
17
# File 'lib/authentik/api/models/prompt_challenge.rb', line 15

def component
  @component
end

#fieldsObject

Returns the value of attribute fields.



19
20
21
# File 'lib/authentik/api/models/prompt_challenge.rb', line 19

def fields
  @fields
end

#flow_infoObject

Returns the value of attribute flow_info.



13
14
15
# File 'lib/authentik/api/models/prompt_challenge.rb', line 13

def flow_info
  @flow_info
end

#response_errorsObject

Returns the value of attribute response_errors.



17
18
19
# File 'lib/authentik/api/models/prompt_challenge.rb', line 17

def response_errors
  @response_errors
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



32
33
34
# File 'lib/authentik/api/models/prompt_challenge.rb', line 32

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



37
38
39
# File 'lib/authentik/api/models/prompt_challenge.rb', line 37

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



22
23
24
25
26
27
28
29
# File 'lib/authentik/api/models/prompt_challenge.rb', line 22

def self.attribute_map
  {
    :'flow_info' => :'flow_info',
    :'component' => :'component',
    :'response_errors' => :'response_errors',
    :'fields' => :'fields'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/authentik/api/models/prompt_challenge.rb', line 154

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
# File 'lib/authentik/api/models/prompt_challenge.rb', line 52

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



42
43
44
45
46
47
48
49
# File 'lib/authentik/api/models/prompt_challenge.rb', line 42

def self.openapi_types
  {
    :'flow_info' => :'ContextualFlowInfo',
    :'component' => :'String',
    :'response_errors' => :'Hash<String, Array<ErrorDetail>>',
    :'fields' => :'Array<StagePrompt>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



130
131
132
133
134
135
136
137
# File 'lib/authentik/api/models/prompt_challenge.rb', line 130

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flow_info == o.flow_info &&
      component == o.component &&
      response_errors == o.response_errors &&
      fields == o.fields
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


141
142
143
# File 'lib/authentik/api/models/prompt_challenge.rb', line 141

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



147
148
149
# File 'lib/authentik/api/models/prompt_challenge.rb', line 147

def hash
  [flow_info, component, response_errors, fields].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



100
101
102
103
104
105
106
107
108
# File 'lib/authentik/api/models/prompt_challenge.rb', line 100

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @fields.nil?
    invalid_properties.push('invalid value for "fields", fields cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/authentik/api/models/prompt_challenge.rb', line 176

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



112
113
114
115
116
# File 'lib/authentik/api/models/prompt_challenge.rb', line 112

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @fields.nil?
  true
end