Class: Authentik::Api::PromptRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PromptRequest
- Defined in:
- lib/authentik/api/models/prompt_request.rb
Overview
Prompt Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#field_key ⇒ Object
Name of the form field, also used to store the value.
-
#initial_value ⇒ Object
Optionally pre-fill the input with an initial value.
-
#initial_value_expression ⇒ Object
Returns the value of attribute initial_value_expression.
-
#label ⇒ Object
Returns the value of attribute label.
-
#name ⇒ Object
Returns the value of attribute name.
-
#order ⇒ Object
Returns the value of attribute order.
-
#placeholder ⇒ Object
Optionally provide a short hint that describes the expected input value.
-
#placeholder_expression ⇒ Object
Returns the value of attribute placeholder_expression.
-
#required ⇒ Object
Returns the value of attribute required.
-
#sub_text ⇒ Object
Returns the value of attribute sub_text.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PromptRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PromptRequest
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/authentik/api/models/prompt_request.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PromptRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PromptRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'field_key') self.field_key = attributes[:'field_key'] else self.field_key = nil end if attributes.key?(:'label') self.label = attributes[:'label'] else self.label = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'required') self.required = attributes[:'required'] end if attributes.key?(:'placeholder') self.placeholder = attributes[:'placeholder'] end if attributes.key?(:'initial_value') self.initial_value = attributes[:'initial_value'] end if attributes.key?(:'order') self.order = attributes[:'order'] end if attributes.key?(:'sub_text') self.sub_text = attributes[:'sub_text'] end if attributes.key?(:'placeholder_expression') self.placeholder_expression = attributes[:'placeholder_expression'] end if attributes.key?(:'initial_value_expression') self.initial_value_expression = attributes[:'initial_value_expression'] end end |
Instance Attribute Details
#field_key ⇒ Object
Name of the form field, also used to store the value
16 17 18 |
# File 'lib/authentik/api/models/prompt_request.rb', line 16 def field_key @field_key end |
#initial_value ⇒ Object
Optionally pre-fill the input with an initial value. When creating a fixed choice field, enable interpreting as expression and return a list to return multiple default choices.
28 29 30 |
# File 'lib/authentik/api/models/prompt_request.rb', line 28 def initial_value @initial_value end |
#initial_value_expression ⇒ Object
Returns the value of attribute initial_value_expression.
36 37 38 |
# File 'lib/authentik/api/models/prompt_request.rb', line 36 def initial_value_expression @initial_value_expression end |
#label ⇒ Object
Returns the value of attribute label.
18 19 20 |
# File 'lib/authentik/api/models/prompt_request.rb', line 18 def label @label end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/prompt_request.rb', line 13 def name @name end |
#order ⇒ Object
Returns the value of attribute order.
30 31 32 |
# File 'lib/authentik/api/models/prompt_request.rb', line 30 def order @order end |
#placeholder ⇒ Object
Optionally provide a short hint that describes the expected input value. When creating a fixed choice field, enable interpreting as expression and return a list to return multiple choices.
25 26 27 |
# File 'lib/authentik/api/models/prompt_request.rb', line 25 def placeholder @placeholder end |
#placeholder_expression ⇒ Object
Returns the value of attribute placeholder_expression.
34 35 36 |
# File 'lib/authentik/api/models/prompt_request.rb', line 34 def placeholder_expression @placeholder_expression end |
#required ⇒ Object
Returns the value of attribute required.
22 23 24 |
# File 'lib/authentik/api/models/prompt_request.rb', line 22 def required @required end |
#sub_text ⇒ Object
Returns the value of attribute sub_text.
32 33 34 |
# File 'lib/authentik/api/models/prompt_request.rb', line 32 def sub_text @sub_text end |
#type ⇒ Object
Returns the value of attribute type.
20 21 22 |
# File 'lib/authentik/api/models/prompt_request.rb', line 20 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/authentik/api/models/prompt_request.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/authentik/api/models/prompt_request.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/authentik/api/models/prompt_request.rb', line 61 def self.attribute_map { :'name' => :'name', :'field_key' => :'field_key', :'label' => :'label', :'type' => :'type', :'required' => :'required', :'placeholder' => :'placeholder', :'initial_value' => :'initial_value', :'order' => :'order', :'sub_text' => :'sub_text', :'placeholder_expression' => :'placeholder_expression', :'initial_value_expression' => :'initial_value_expression' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/authentik/api/models/prompt_request.rb', line 342 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/authentik/api/models/prompt_request.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/authentik/api/models/prompt_request.rb', line 88 def self.openapi_types { :'name' => :'String', :'field_key' => :'String', :'label' => :'String', :'type' => :'PromptTypeEnum', :'required' => :'Boolean', :'placeholder' => :'String', :'initial_value' => :'String', :'order' => :'Integer', :'sub_text' => :'String', :'placeholder_expression' => :'Boolean', :'initial_value_expression' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/authentik/api/models/prompt_request.rb', line 311 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && field_key == o.field_key && label == o.label && type == o.type && required == o.required && placeholder == o.placeholder && initial_value == o.initial_value && order == o.order && sub_text == o.sub_text && placeholder_expression == o.placeholder_expression && initial_value_expression == o.initial_value_expression end |
#eql?(o) ⇒ Boolean
329 330 331 |
# File 'lib/authentik/api/models/prompt_request.rb', line 329 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
335 336 337 |
# File 'lib/authentik/api/models/prompt_request.rb', line 335 def hash [name, field_key, label, type, required, placeholder, initial_value, order, sub_text, placeholder_expression, initial_value_expression].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/authentik/api/models/prompt_request.rb', line 181 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @field_key.nil? invalid_properties.push('invalid value for "field_key", field_key cannot be nil.') end if @field_key.to_s.length < 1 invalid_properties.push('invalid value for "field_key", the character length must be greater than or equal to 1.') end if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end if @label.to_s.length < 1 invalid_properties.push('invalid value for "label", the character length must be greater than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if !@order.nil? && @order > 2147483647 invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.') end if !@order.nil? && @order < -2147483648 invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/authentik/api/models/prompt_request.rb', line 364 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/authentik/api/models/prompt_request.rb', line 225 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @field_key.nil? return false if @field_key.to_s.length < 1 return false if @label.nil? return false if @label.to_s.length < 1 return false if @type.nil? return false if !@order.nil? && @order > 2147483647 return false if !@order.nil? && @order < -2147483648 true end |