Class: Authentik::Api::RACProvider
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::RACProvider
- Defined in:
- lib/authentik/api/models/rac_provider.rb
Overview
RACProvider Serializer
Instance Attribute Summary collapse
-
#assigned_application_name ⇒ Object
Application’s display Name.
-
#assigned_application_slug ⇒ Object
Internal application name, used in URLs.
-
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
-
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
-
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
-
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#connection_expiry ⇒ Object
Determines how long a session lasts.
-
#delete_token_on_disconnect ⇒ Object
When set to true, connection tokens will be deleted upon disconnect.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#outpost_set ⇒ Object
Returns the value of attribute outpost_set.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#settings ⇒ Object
Returns the value of attribute settings.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RACProvider
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RACProvider
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/authentik/api/models/rac_provider.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::RACProvider` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::RACProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'authorization_flow') self. = attributes[:'authorization_flow'] else self. = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'assigned_application_slug') self.assigned_application_slug = attributes[:'assigned_application_slug'] else self.assigned_application_slug = nil end if attributes.key?(:'assigned_application_name') self.assigned_application_name = attributes[:'assigned_application_name'] else self.assigned_application_name = nil end if attributes.key?(:'assigned_backchannel_application_slug') self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug'] else self.assigned_backchannel_application_slug = nil end if attributes.key?(:'assigned_backchannel_application_name') self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name'] else self.assigned_backchannel_application_name = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'settings') if (value = attributes[:'settings']).is_a?(Hash) self.settings = value end end if attributes.key?(:'outpost_set') if (value = attributes[:'outpost_set']).is_a?(Array) self.outpost_set = value end else self.outpost_set = nil end if attributes.key?(:'connection_expiry') self.connection_expiry = attributes[:'connection_expiry'] end if attributes.key?(:'delete_token_on_disconnect') self.delete_token_on_disconnect = attributes[:'delete_token_on_disconnect'] end end |
Instance Attribute Details
#assigned_application_name ⇒ Object
Application’s display Name.
32 33 34 |
# File 'lib/authentik/api/models/rac_provider.rb', line 32 def assigned_application_name @assigned_application_name end |
#assigned_application_slug ⇒ Object
Internal application name, used in URLs.
29 30 31 |
# File 'lib/authentik/api/models/rac_provider.rb', line 29 def assigned_application_slug @assigned_application_slug end |
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
38 39 40 |
# File 'lib/authentik/api/models/rac_provider.rb', line 38 def assigned_backchannel_application_name @assigned_backchannel_application_name end |
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
35 36 37 |
# File 'lib/authentik/api/models/rac_provider.rb', line 35 def assigned_backchannel_application_slug @assigned_backchannel_application_slug end |
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
18 19 20 |
# File 'lib/authentik/api/models/rac_provider.rb', line 18 def authentication_flow @authentication_flow end |
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
21 22 23 |
# File 'lib/authentik/api/models/rac_provider.rb', line 21 def @authorization_flow end |
#component ⇒ Object
Get object component so that we know how to edit the object
26 27 28 |
# File 'lib/authentik/api/models/rac_provider.rb', line 26 def component @component end |
#connection_expiry ⇒ Object
Determines how long a session lasts. Default of 0 means that the sessions lasts until the browser is closed. (Format: hours=-1;minutes=-2;seconds=-3)
54 55 56 |
# File 'lib/authentik/api/models/rac_provider.rb', line 54 def connection_expiry @connection_expiry end |
#delete_token_on_disconnect ⇒ Object
When set to true, connection tokens will be deleted upon disconnect.
57 58 59 |
# File 'lib/authentik/api/models/rac_provider.rb', line 57 def delete_token_on_disconnect @delete_token_on_disconnect end |
#meta_model_name ⇒ Object
Return internal model name
47 48 49 |
# File 'lib/authentik/api/models/rac_provider.rb', line 47 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/rac_provider.rb', line 15 def name @name end |
#outpost_set ⇒ Object
Returns the value of attribute outpost_set.
51 52 53 |
# File 'lib/authentik/api/models/rac_provider.rb', line 51 def outpost_set @outpost_set end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/rac_provider.rb', line 13 def pk @pk end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
23 24 25 |
# File 'lib/authentik/api/models/rac_provider.rb', line 23 def property_mappings @property_mappings end |
#settings ⇒ Object
Returns the value of attribute settings.
49 50 51 |
# File 'lib/authentik/api/models/rac_provider.rb', line 49 def settings @settings end |
#verbose_name ⇒ Object
Return object’s verbose_name
41 42 43 |
# File 'lib/authentik/api/models/rac_provider.rb', line 41 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
44 45 46 |
# File 'lib/authentik/api/models/rac_provider.rb', line 44 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/authentik/api/models/rac_provider.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/authentik/api/models/rac_provider.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/authentik/api/models/rac_provider.rb', line 60 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'authentication_flow' => :'authentication_flow', :'authorization_flow' => :'authorization_flow', :'property_mappings' => :'property_mappings', :'component' => :'component', :'assigned_application_slug' => :'assigned_application_slug', :'assigned_application_name' => :'assigned_application_name', :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'settings' => :'settings', :'outpost_set' => :'outpost_set', :'connection_expiry' => :'connection_expiry', :'delete_token_on_disconnect' => :'delete_token_on_disconnect' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/authentik/api/models/rac_provider.rb', line 415 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 120 121 122 123 124 |
# File 'lib/authentik/api/models/rac_provider.rb', line 116 def self.openapi_nullable Set.new([ :'authentication_flow', :'assigned_application_slug', :'assigned_application_name', :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/authentik/api/models/rac_provider.rb', line 93 def self.openapi_types { :'pk' => :'Integer', :'name' => :'String', :'authentication_flow' => :'String', :'authorization_flow' => :'String', :'property_mappings' => :'Array<String>', :'component' => :'String', :'assigned_application_slug' => :'String', :'assigned_application_name' => :'String', :'assigned_backchannel_application_slug' => :'String', :'assigned_backchannel_application_name' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'settings' => :'Hash<String, Object>', :'outpost_set' => :'Array<String>', :'connection_expiry' => :'String', :'delete_token_on_disconnect' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/authentik/api/models/rac_provider.rb', line 378 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && authentication_flow == o.authentication_flow && == o. && property_mappings == o.property_mappings && component == o.component && assigned_application_slug == o.assigned_application_slug && assigned_application_name == o.assigned_application_name && assigned_backchannel_application_slug == o.assigned_backchannel_application_slug && assigned_backchannel_application_name == o.assigned_backchannel_application_name && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && settings == o.settings && outpost_set == o.outpost_set && connection_expiry == o.connection_expiry && delete_token_on_disconnect == o.delete_token_on_disconnect end |
#eql?(o) ⇒ Boolean
402 403 404 |
# File 'lib/authentik/api/models/rac_provider.rb', line 402 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
408 409 410 |
# File 'lib/authentik/api/models/rac_provider.rb', line 408 def hash [pk, name, authentication_flow, , property_mappings, component, assigned_application_slug, assigned_application_name, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, , settings, outpost_set, connection_expiry, delete_token_on_disconnect].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/authentik/api/models/rac_provider.rb', line 243 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @authorization_flow.nil? invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @outpost_set.nil? invalid_properties.push('invalid value for "outpost_set", outpost_set cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/authentik/api/models/rac_provider.rb', line 437 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/authentik/api/models/rac_provider.rb', line 283 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @authorization_flow.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @outpost_set.nil? true end |