Class: Authentik::Api::RACProviderRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/rac_provider_request.rb

Overview

RACProvider Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RACProviderRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/authentik/api/models/rac_provider_request.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::RACProviderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::RACProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'authorization_flow')
    self.authorization_flow = attributes[:'authorization_flow']
  else
    self.authorization_flow = nil
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'settings')
    if (value = attributes[:'settings']).is_a?(Hash)
      self.settings = value
    end
  end

  if attributes.key?(:'connection_expiry')
    self.connection_expiry = attributes[:'connection_expiry']
  end

  if attributes.key?(:'delete_token_on_disconnect')
    self.delete_token_on_disconnect = attributes[:'delete_token_on_disconnect']
  end
end

Instance Attribute Details

#authentication_flowObject

Flow used for authentication when the associated application is accessed by an un-authenticated user.



16
17
18
# File 'lib/authentik/api/models/rac_provider_request.rb', line 16

def authentication_flow
  @authentication_flow
end

#authorization_flowObject

Flow used when authorizing this provider.



19
20
21
# File 'lib/authentik/api/models/rac_provider_request.rb', line 19

def authorization_flow
  @authorization_flow
end

#connection_expiryObject

Determines how long a session lasts. Default of 0 means that the sessions lasts until the browser is closed. (Format: hours=-1;minutes=-2;seconds=-3)



26
27
28
# File 'lib/authentik/api/models/rac_provider_request.rb', line 26

def connection_expiry
  @connection_expiry
end

#delete_token_on_disconnectObject

When set to true, connection tokens will be deleted upon disconnect.



29
30
31
# File 'lib/authentik/api/models/rac_provider_request.rb', line 29

def delete_token_on_disconnect
  @delete_token_on_disconnect
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/rac_provider_request.rb', line 13

def name
  @name
end

#property_mappingsObject

Returns the value of attribute property_mappings.



21
22
23
# File 'lib/authentik/api/models/rac_provider_request.rb', line 21

def property_mappings
  @property_mappings
end

#settingsObject

Returns the value of attribute settings.



23
24
25
# File 'lib/authentik/api/models/rac_provider_request.rb', line 23

def settings
  @settings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/authentik/api/models/rac_provider_request.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/authentik/api/models/rac_provider_request.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
42
# File 'lib/authentik/api/models/rac_provider_request.rb', line 32

def self.attribute_map
  {
    :'name' => :'name',
    :'authentication_flow' => :'authentication_flow',
    :'authorization_flow' => :'authorization_flow',
    :'property_mappings' => :'property_mappings',
    :'settings' => :'settings',
    :'connection_expiry' => :'connection_expiry',
    :'delete_token_on_disconnect' => :'delete_token_on_disconnect'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/authentik/api/models/rac_provider_request.rb', line 229

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
72
# File 'lib/authentik/api/models/rac_provider_request.rb', line 68

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/authentik/api/models/rac_provider_request.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'authentication_flow' => :'String',
    :'authorization_flow' => :'String',
    :'property_mappings' => :'Array<String>',
    :'settings' => :'Hash<String, Object>',
    :'connection_expiry' => :'String',
    :'delete_token_on_disconnect' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
211
212
# File 'lib/authentik/api/models/rac_provider_request.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      authentication_flow == o.authentication_flow &&
      authorization_flow == o.authorization_flow &&
      property_mappings == o.property_mappings &&
      settings == o.settings &&
      connection_expiry == o.connection_expiry &&
      delete_token_on_disconnect == o.delete_token_on_disconnect
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


216
217
218
# File 'lib/authentik/api/models/rac_provider_request.rb', line 216

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



222
223
224
# File 'lib/authentik/api/models/rac_provider_request.rb', line 222

def hash
  [name, authentication_flow, authorization_flow, property_mappings, settings, connection_expiry, delete_token_on_disconnect].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/authentik/api/models/rac_provider_request.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @authorization_flow.nil?
    invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.')
  end

  if !@connection_expiry.nil? && @connection_expiry.to_s.length < 1
    invalid_properties.push('invalid value for "connection_expiry", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/authentik/api/models/rac_provider_request.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
160
# File 'lib/authentik/api/models/rac_provider_request.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @authorization_flow.nil?
  return false if !@connection_expiry.nil? && @connection_expiry.to_s.length < 1
  true
end