Class: Authentik::Api::RadiusOutpostConfig

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/radius_outpost_config.rb

Overview

RadiusProvider Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RadiusOutpostConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::RadiusOutpostConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::RadiusOutpostConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'application_slug')
    self.application_slug = attributes[:'application_slug']
  else
    self.application_slug = nil
  end

  if attributes.key?(:'auth_flow_slug')
    self.auth_flow_slug = attributes[:'auth_flow_slug']
  else
    self.auth_flow_slug = nil
  end

  if attributes.key?(:'client_networks')
    self.client_networks = attributes[:'client_networks']
  end

  if attributes.key?(:'shared_secret')
    self.shared_secret = attributes[:'shared_secret']
  end

  if attributes.key?(:'mfa_support')
    self.mfa_support = attributes[:'mfa_support']
  end

  if attributes.key?(:'certificate')
    self.certificate = attributes[:'certificate']
  end
end

Instance Attribute Details

#application_slugObject

Returns the value of attribute application_slug.



17
18
19
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 17

def application_slug
  @application_slug
end

#auth_flow_slugObject

Returns the value of attribute auth_flow_slug.



19
20
21
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 19

def auth_flow_slug
  @auth_flow_slug
end

#certificateObject

Returns the value of attribute certificate.



30
31
32
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 30

def certificate
  @certificate
end

#client_networksObject

List of CIDRs (comma-separated) that clients can connect from. A more specific CIDR will match before a looser one. Clients connecting from a non-specified CIDR will be dropped.



22
23
24
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 22

def client_networks
  @client_networks
end

#mfa_supportObject

When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon.



28
29
30
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 28

def mfa_support
  @mfa_support
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 15

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 13

def pk
  @pk
end

#shared_secretObject

Shared secret between clients and server to hash packets.



25
26
27
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 25

def shared_secret
  @shared_secret
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 33

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'application_slug' => :'application_slug',
    :'auth_flow_slug' => :'auth_flow_slug',
    :'client_networks' => :'client_networks',
    :'shared_secret' => :'shared_secret',
    :'mfa_support' => :'mfa_support',
    :'certificate' => :'certificate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 239

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
75
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 71

def self.openapi_nullable
  Set.new([
    :'certificate'
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 57

def self.openapi_types
  {
    :'pk' => :'Integer',
    :'name' => :'String',
    :'application_slug' => :'String',
    :'auth_flow_slug' => :'String',
    :'client_networks' => :'String',
    :'shared_secret' => :'String',
    :'mfa_support' => :'Boolean',
    :'certificate' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      application_slug == o.application_slug &&
      auth_flow_slug == o.auth_flow_slug &&
      client_networks == o.client_networks &&
      shared_secret == o.shared_secret &&
      mfa_support == o.mfa_support &&
      certificate == o.certificate
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 232

def hash
  [pk, name, application_slug, auth_flow_slug, client_networks, shared_secret, mfa_support, certificate].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @application_slug.nil?
    invalid_properties.push('invalid value for "application_slug", application_slug cannot be nil.')
  end

  if @auth_flow_slug.nil?
    invalid_properties.push('invalid value for "auth_flow_slug", auth_flow_slug cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
# File 'lib/authentik/api/models/radius_outpost_config.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @application_slug.nil?
  return false if @auth_flow_slug.nil?
  true
end