Class: Authentik::Api::Reputation

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/reputation.rb

Overview

Reputation Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Reputation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/authentik/api/models/reputation.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Reputation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Reputation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  end

  if attributes.key?(:'identifier')
    self.identifier = attributes[:'identifier']
  else
    self.identifier = nil
  end

  if attributes.key?(:'ip')
    self.ip = attributes[:'ip']
  else
    self.ip = nil
  end

  if attributes.key?(:'ip_geo_data')
    if (value = attributes[:'ip_geo_data']).is_a?(Hash)
      self.ip_geo_data = value
    end
  end

  if attributes.key?(:'ip_asn_data')
    if (value = attributes[:'ip_asn_data']).is_a?(Hash)
      self.ip_asn_data = value
    end
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  else
    self.updated = nil
  end
end

Instance Attribute Details

#identifierObject

Returns the value of attribute identifier.



15
16
17
# File 'lib/authentik/api/models/reputation.rb', line 15

def identifier
  @identifier
end

#ipObject

Returns the value of attribute ip.



17
18
19
# File 'lib/authentik/api/models/reputation.rb', line 17

def ip
  @ip
end

#ip_asn_dataObject

Returns the value of attribute ip_asn_data.



21
22
23
# File 'lib/authentik/api/models/reputation.rb', line 21

def ip_asn_data
  @ip_asn_data
end

#ip_geo_dataObject

Returns the value of attribute ip_geo_data.



19
20
21
# File 'lib/authentik/api/models/reputation.rb', line 19

def ip_geo_data
  @ip_geo_data
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/reputation.rb', line 13

def pk
  @pk
end

#scoreObject

Returns the value of attribute score.



23
24
25
# File 'lib/authentik/api/models/reputation.rb', line 23

def score
  @score
end

#updatedObject

Returns the value of attribute updated.



25
26
27
# File 'lib/authentik/api/models/reputation.rb', line 25

def updated
  @updated
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/authentik/api/models/reputation.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/authentik/api/models/reputation.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
37
38
# File 'lib/authentik/api/models/reputation.rb', line 28

def self.attribute_map
  {
    :'pk' => :'pk',
    :'identifier' => :'identifier',
    :'ip' => :'ip',
    :'ip_geo_data' => :'ip_geo_data',
    :'ip_asn_data' => :'ip_asn_data',
    :'score' => :'score',
    :'updated' => :'updated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/authentik/api/models/reputation.rb', line 241

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



64
65
66
67
# File 'lib/authentik/api/models/reputation.rb', line 64

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/authentik/api/models/reputation.rb', line 51

def self.openapi_types
  {
    :'pk' => :'String',
    :'identifier' => :'String',
    :'ip' => :'String',
    :'ip_geo_data' => :'Hash<String, Object>',
    :'ip_asn_data' => :'Hash<String, Object>',
    :'score' => :'Integer',
    :'updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



214
215
216
217
218
219
220
221
222
223
224
# File 'lib/authentik/api/models/reputation.rb', line 214

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      identifier == o.identifier &&
      ip == o.ip &&
      ip_geo_data == o.ip_geo_data &&
      ip_asn_data == o.ip_asn_data &&
      score == o.score &&
      updated == o.updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


228
229
230
# File 'lib/authentik/api/models/reputation.rb', line 228

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



234
235
236
# File 'lib/authentik/api/models/reputation.rb', line 234

def hash
  [pk, identifier, ip, ip_geo_data, ip_asn_data, score, updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/authentik/api/models/reputation.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @identifier.nil?
    invalid_properties.push('invalid value for "identifier", identifier cannot be nil.')
  end

  if @ip.nil?
    invalid_properties.push('invalid value for "ip", ip cannot be nil.')
  end

  if !@score.nil? && @score > 9223372036854775807
    invalid_properties.push('invalid value for "score", must be smaller than or equal to 9223372036854775807.')
  end

  if !@score.nil? && @score < -9223372036854775808
    invalid_properties.push('invalid value for "score", must be greater than or equal to -9223372036854775808.')
  end

  if @updated.nil?
    invalid_properties.push('invalid value for "updated", updated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/authentik/api/models/reputation.rb', line 263

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
161
162
# File 'lib/authentik/api/models/reputation.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @identifier.nil?
  return false if @ip.nil?
  return false if !@score.nil? && @score > 9223372036854775807
  return false if !@score.nil? && @score < -9223372036854775808
  return false if @updated.nil?
  true
end