Class: Authentik::Api::RequestRule

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/request_rule.rb

Overview

Mixin to validate that a valid enterprise license exists before allowing to save the object

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RequestRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/authentik/api/models/request_rule.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::RequestRule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::RequestRule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end

  if attributes.key?(:'pbm_uuid')
    self.pbm_uuid = attributes[:'pbm_uuid']
  else
    self.pbm_uuid = nil
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'targets')
    if (value = attributes[:'targets']).is_a?(Array)
      self.targets = value
    end
  else
    self.targets = nil
  end

  if attributes.key?(:'notification_transports')
    if (value = attributes[:'notification_transports']).is_a?(Array)
      self.notification_transports = value
    end
  end

  if attributes.key?(:'notification_mode')
    self.notification_mode = attributes[:'notification_mode']
  end

  if attributes.key?(:'min_reviewers')
    self.min_reviewers = attributes[:'min_reviewers']
  end

  if attributes.key?(:'min_reviewers_is_per_group')
    self.min_reviewers_is_per_group = attributes[:'min_reviewers_is_per_group']
  end

  if attributes.key?(:'request_flow')
    self.request_flow = attributes[:'request_flow']
  end
end

Instance Attribute Details

#min_reviewersObject

Returns the value of attribute min_reviewers.



27
28
29
# File 'lib/authentik/api/models/request_rule.rb', line 27

def min_reviewers
  @min_reviewers
end

#min_reviewers_is_per_groupObject

Returns the value of attribute min_reviewers_is_per_group.



29
30
31
# File 'lib/authentik/api/models/request_rule.rb', line 29

def min_reviewers_is_per_group
  @min_reviewers_is_per_group
end

#nameObject

Returns the value of attribute name.



19
20
21
# File 'lib/authentik/api/models/request_rule.rb', line 19

def name
  @name
end

#notification_modeObject

Returns the value of attribute notification_mode.



25
26
27
# File 'lib/authentik/api/models/request_rule.rb', line 25

def notification_mode
  @notification_mode
end

#notification_transportsObject

Returns the value of attribute notification_transports.



23
24
25
# File 'lib/authentik/api/models/request_rule.rb', line 23

def notification_transports
  @notification_transports
end

#pbm_uuidObject

Returns the value of attribute pbm_uuid.



15
16
17
# File 'lib/authentik/api/models/request_rule.rb', line 15

def pbm_uuid
  @pbm_uuid
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



17
18
19
# File 'lib/authentik/api/models/request_rule.rb', line 17

def policy_engine_mode
  @policy_engine_mode
end

#request_flowObject

Returns the value of attribute request_flow.



31
32
33
# File 'lib/authentik/api/models/request_rule.rb', line 31

def request_flow
  @request_flow
end

#targetsObject

Returns the value of attribute targets.



21
22
23
# File 'lib/authentik/api/models/request_rule.rb', line 21

def targets
  @targets
end

#uuidObject

Returns the value of attribute uuid.



13
14
15
# File 'lib/authentik/api/models/request_rule.rb', line 13

def uuid
  @uuid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/authentik/api/models/request_rule.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/authentik/api/models/request_rule.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/authentik/api/models/request_rule.rb', line 56

def self.attribute_map
  {
    :'uuid' => :'uuid',
    :'pbm_uuid' => :'pbm_uuid',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'name' => :'name',
    :'targets' => :'targets',
    :'notification_transports' => :'notification_transports',
    :'notification_mode' => :'notification_mode',
    :'min_reviewers' => :'min_reviewers',
    :'min_reviewers_is_per_group' => :'min_reviewers_is_per_group',
    :'request_flow' => :'request_flow'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/authentik/api/models/request_rule.rb', line 291

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
# File 'lib/authentik/api/models/request_rule.rb', line 98

def self.openapi_nullable
  Set.new([
    :'request_flow'
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/authentik/api/models/request_rule.rb', line 82

def self.openapi_types
  {
    :'uuid' => :'String',
    :'pbm_uuid' => :'String',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'name' => :'String',
    :'targets' => :'Array<String>',
    :'notification_transports' => :'Array<String>',
    :'notification_mode' => :'NotificationModeEnum',
    :'min_reviewers' => :'Integer',
    :'min_reviewers_is_per_group' => :'Boolean',
    :'request_flow' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/authentik/api/models/request_rule.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      uuid == o.uuid &&
      pbm_uuid == o.pbm_uuid &&
      policy_engine_mode == o.policy_engine_mode &&
      name == o.name &&
      targets == o.targets &&
      notification_transports == o.notification_transports &&
      notification_mode == o.notification_mode &&
      min_reviewers == o.min_reviewers &&
      min_reviewers_is_per_group == o.min_reviewers_is_per_group &&
      request_flow == o.request_flow
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


278
279
280
# File 'lib/authentik/api/models/request_rule.rb', line 278

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



284
285
286
# File 'lib/authentik/api/models/request_rule.rb', line 284

def hash
  [uuid, pbm_uuid, policy_engine_mode, name, targets, notification_transports, notification_mode, min_reviewers, min_reviewers_is_per_group, request_flow].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/authentik/api/models/request_rule.rb', line 173

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pbm_uuid.nil?
    invalid_properties.push('invalid value for "pbm_uuid", pbm_uuid cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @targets.nil?
    invalid_properties.push('invalid value for "targets", targets cannot be nil.')
  end

  if !@min_reviewers.nil? && @min_reviewers > 32767
    invalid_properties.push('invalid value for "min_reviewers", must be smaller than or equal to 32767.')
  end

  if !@min_reviewers.nil? && @min_reviewers < 0
    invalid_properties.push('invalid value for "min_reviewers", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/authentik/api/models/request_rule.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
# File 'lib/authentik/api/models/request_rule.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pbm_uuid.nil?
  return false if @name.nil?
  return false if @targets.nil?
  return false if !@min_reviewers.nil? && @min_reviewers > 32767
  return false if !@min_reviewers.nil? && @min_reviewers < 0
  true
end