Class: Authentik::Api::Review

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/review.rb

Overview

Mixin to validate that a valid enterprise license exists before allowing to save the object

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Review

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/authentik/api/models/review.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Review` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Review`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'iteration')
    self.iteration = attributes[:'iteration']
  else
    self.iteration = nil
  end

  if attributes.key?(:'reviewer')
    self.reviewer = attributes[:'reviewer']
  else
    self.reviewer = nil
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end
end

Instance Attribute Details

#idObject

Returns the value of attribute id.



13
14
15
# File 'lib/authentik/api/models/review.rb', line 13

def id
  @id
end

#iterationObject

Returns the value of attribute iteration.



15
16
17
# File 'lib/authentik/api/models/review.rb', line 15

def iteration
  @iteration
end

#noteObject

Returns the value of attribute note.



21
22
23
# File 'lib/authentik/api/models/review.rb', line 21

def note
  @note
end

#reviewerObject

Returns the value of attribute reviewer.



17
18
19
# File 'lib/authentik/api/models/review.rb', line 17

def reviewer
  @reviewer
end

#timestampObject

Returns the value of attribute timestamp.



19
20
21
# File 'lib/authentik/api/models/review.rb', line 19

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



35
36
37
# File 'lib/authentik/api/models/review.rb', line 35

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



40
41
42
# File 'lib/authentik/api/models/review.rb', line 40

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
30
31
32
# File 'lib/authentik/api/models/review.rb', line 24

def self.attribute_map
  {
    :'id' => :'id',
    :'iteration' => :'iteration',
    :'reviewer' => :'reviewer',
    :'timestamp' => :'timestamp',
    :'note' => :'note'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/authentik/api/models/review.rb', line 209

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
60
# File 'lib/authentik/api/models/review.rb', line 56

def self.openapi_nullable
  Set.new([
    :'note'
  ])
end

.openapi_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
52
53
# File 'lib/authentik/api/models/review.rb', line 45

def self.openapi_types
  {
    :'id' => :'String',
    :'iteration' => :'String',
    :'reviewer' => :'ReviewerUser',
    :'timestamp' => :'Time',
    :'note' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
192
# File 'lib/authentik/api/models/review.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      iteration == o.iteration &&
      reviewer == o.reviewer &&
      timestamp == o.timestamp &&
      note == o.note
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


196
197
198
# File 'lib/authentik/api/models/review.rb', line 196

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



202
203
204
# File 'lib/authentik/api/models/review.rb', line 202

def hash
  [id, iteration, reviewer, timestamp, note].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/authentik/api/models/review.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @iteration.nil?
    invalid_properties.push('invalid value for "iteration", iteration cannot be nil.')
  end

  if @reviewer.nil?
    invalid_properties.push('invalid value for "reviewer", reviewer cannot be nil.')
  end

  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/authentik/api/models/review.rb', line 231

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
139
140
# File 'lib/authentik/api/models/review.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @iteration.nil?
  return false if @reviewer.nil?
  return false if @timestamp.nil?
  true
end