Class: Authentik::Api::ReviewerUser
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ReviewerUser
- Defined in:
- lib/authentik/api/models/reviewer_user.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
User’s display name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#username ⇒ Object
Required.
-
#uuid ⇒ Object
Returns the value of attribute uuid.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReviewerUser
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReviewerUser
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ReviewerUser` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ReviewerUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] else self.uuid = nil end if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end end |
Instance Attribute Details
#name ⇒ Object
User’s display name.
20 21 22 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 20 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
12 13 14 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 12 def pk @pk end |
#username ⇒ Object
Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.
17 18 19 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 17 def username @username end |
#uuid ⇒ Object
Returns the value of attribute uuid.
14 15 16 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 14 def uuid @uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 23 def self.attribute_map { :'pk' => :'pk', :'uuid' => :'uuid', :'username' => :'username', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 220 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
53 54 55 56 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 53 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 43 def self.openapi_types { :'pk' => :'Integer', :'uuid' => :'String', :'username' => :'String', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && uuid == o.uuid && username == o.username && name == o.name end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 213 def hash [pk, uuid, username, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 101 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @uuid.nil? invalid_properties.push('invalid value for "uuid", uuid cannot be nil.') end if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end if @username.to_s.length > 150 invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 150.') end pattern = Regexp.new(/^[\w.@+-]+$/) if @username !~ pattern invalid_properties.push("invalid value for \"username\", must conform to the pattern #{pattern}.") end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 242 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/authentik/api/models/reviewer_user.rb', line 134 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @uuid.nil? return false if @username.nil? return false if @username.to_s.length > 150 return false if @username !~ Regexp.new(/^[\w.@+-]+$/) return false if @name.nil? true end |