Class: Authentik::Api::SAMLPropertyMapping

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/saml_property_mapping.rb

Overview

SAMLPropertyMapping Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SAMLPropertyMapping

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SAMLPropertyMapping` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SAMLPropertyMapping`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'managed')
    self.managed = attributes[:'managed']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'expression')
    self.expression = attributes[:'expression']
  else
    self.expression = nil
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'saml_name')
    self.saml_name = attributes[:'saml_name']
  else
    self.saml_name = nil
  end

  if attributes.key?(:'friendly_name')
    self.friendly_name = attributes[:'friendly_name']
  end
end

Instance Attribute Details

#componentObject

Get object’s component so that we know how to edit the object



23
24
25
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 23

def component
  @component
end

#expressionObject

Returns the value of attribute expression.



20
21
22
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 20

def expression
  @expression
end

#friendly_nameObject

Returns the value of attribute friendly_name.



36
37
38
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 36

def friendly_name
  @friendly_name
end

#managedObject

Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.



16
17
18
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 16

def managed
  @managed
end

#meta_model_nameObject

Return internal model name



32
33
34
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 32

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 18

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 13

def pk
  @pk
end

#saml_nameObject

Returns the value of attribute saml_name.



34
35
36
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 34

def saml_name
  @saml_name
end

#verbose_nameObject

Return object’s verbose_name



26
27
28
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 26

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



29
30
31
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 29

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 39

def self.attribute_map
  {
    :'pk' => :'pk',
    :'managed' => :'managed',
    :'name' => :'name',
    :'expression' => :'expression',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'saml_name' => :'saml_name',
    :'friendly_name' => :'friendly_name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 328

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
86
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 81

def self.openapi_nullable
  Set.new([
    :'managed',
    :'friendly_name'
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 65

def self.openapi_types
  {
    :'pk' => :'String',
    :'managed' => :'String',
    :'name' => :'String',
    :'expression' => :'String',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'saml_name' => :'String',
    :'friendly_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      managed == o.managed &&
      name == o.name &&
      expression == o.expression &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      saml_name == o.saml_name &&
      friendly_name == o.friendly_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 315

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



321
322
323
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 321

def hash
  [pk, managed, name, expression, component, verbose_name, verbose_name_plural, meta_model_name, saml_name, friendly_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @expression.nil?
    invalid_properties.push('invalid value for "expression", expression cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @saml_name.nil?
    invalid_properties.push('invalid value for "saml_name", saml_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/authentik/api/models/saml_property_mapping.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @expression.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @saml_name.nil?
  true
end