Class: Authentik::Api::SAMLProvider
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::SAMLProvider
- Defined in:
- lib/authentik/api/models/saml_provider.rb
Overview
SAMLProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#acs_url ⇒ Object
Returns the value of attribute acs_url.
-
#assertion_valid_not_before ⇒ Object
Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).
-
#assertion_valid_not_on_or_after ⇒ Object
Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#assigned_application_name ⇒ Object
Application’s display Name.
-
#assigned_application_slug ⇒ Object
Internal application name, used in URLs.
-
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
-
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
-
#audience ⇒ Object
Value of the audience restriction field of the assertion.
-
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
-
#authn_context_class_ref_mapping ⇒ Object
Configure how the AuthnContextClassRef value will be created.
-
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#default_name_id_policy ⇒ Object
Returns the value of attribute default_name_id_policy.
-
#default_relay_state ⇒ Object
Default relay_state value for IDP-initiated logins.
-
#digest_algorithm ⇒ Object
Returns the value of attribute digest_algorithm.
-
#encryption_kp ⇒ Object
When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair.
-
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
-
#issuer_override ⇒ Object
Also known as EntityID.
-
#logout_method ⇒ Object
Method to use for logout.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#name_id_mapping ⇒ Object
Configure how the NameID value will be created.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#session_valid_not_on_or_after ⇒ Object
Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#sign_assertion ⇒ Object
Returns the value of attribute sign_assertion.
-
#sign_logout_request ⇒ Object
Returns the value of attribute sign_logout_request.
-
#sign_logout_response ⇒ Object
Returns the value of attribute sign_logout_response.
-
#sign_response ⇒ Object
Returns the value of attribute sign_response.
-
#signature_algorithm ⇒ Object
Returns the value of attribute signature_algorithm.
-
#signing_kp ⇒ Object
Keypair used to sign outgoing Responses going to the Service Provider.
-
#sls_binding ⇒ Object
This determines how authentik sends the logout response back to the Service Provider.
-
#sls_url ⇒ Object
Single Logout Service URL where the logout response should be sent.
-
#sp_binding ⇒ Object
This determines how authentik sends the response back to the Service Provider.
-
#url_download_metadata ⇒ Object
Get metadata download URL.
-
#url_issuer ⇒ Object
Get Issuer/EntityID URL.
-
#url_slo_post ⇒ Object
Get SLO POST URL.
-
#url_slo_redirect ⇒ Object
Get SLO redirect URL.
-
#url_sso_init ⇒ Object
Get SSO IDP-Initiated URL.
-
#url_sso_post ⇒ Object
Get SSO Post URL.
-
#url_sso_redirect ⇒ Object
Get SSO Redirect URL.
-
#url_unified ⇒ Object
Get unified SAML endpoint URL (handles SSO and SLO).
-
#url_unified_init ⇒ Object
Get IdP-initiated SAML URL.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
-
#verification_kp ⇒ Object
When selected, incoming assertion’s Signatures will be validated against this certificate.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SAMLProvider
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SAMLProvider
Initializes the object
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/authentik/api/models/saml_provider.rb', line 294 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SAMLProvider` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SAMLProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'authorization_flow') self. = attributes[:'authorization_flow'] else self. = nil end if attributes.key?(:'invalidation_flow') self.invalidation_flow = attributes[:'invalidation_flow'] else self.invalidation_flow = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'assigned_application_slug') self.assigned_application_slug = attributes[:'assigned_application_slug'] else self.assigned_application_slug = nil end if attributes.key?(:'assigned_application_name') self.assigned_application_name = attributes[:'assigned_application_name'] else self.assigned_application_name = nil end if attributes.key?(:'assigned_backchannel_application_slug') self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug'] else self.assigned_backchannel_application_slug = nil end if attributes.key?(:'assigned_backchannel_application_name') self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name'] else self.assigned_backchannel_application_name = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'acs_url') self.acs_url = attributes[:'acs_url'] else self.acs_url = nil end if attributes.key?(:'sls_url') self.sls_url = attributes[:'sls_url'] end if attributes.key?(:'audience') self.audience = attributes[:'audience'] end if attributes.key?(:'issuer_override') self.issuer_override = attributes[:'issuer_override'] end if attributes.key?(:'assertion_valid_not_before') self.assertion_valid_not_before = attributes[:'assertion_valid_not_before'] end if attributes.key?(:'assertion_valid_not_on_or_after') self.assertion_valid_not_on_or_after = attributes[:'assertion_valid_not_on_or_after'] end if attributes.key?(:'session_valid_not_on_or_after') self.session_valid_not_on_or_after = attributes[:'session_valid_not_on_or_after'] end if attributes.key?(:'name_id_mapping') self.name_id_mapping = attributes[:'name_id_mapping'] end if attributes.key?(:'authn_context_class_ref_mapping') self.authn_context_class_ref_mapping = attributes[:'authn_context_class_ref_mapping'] end if attributes.key?(:'digest_algorithm') self.digest_algorithm = attributes[:'digest_algorithm'] end if attributes.key?(:'signature_algorithm') self.signature_algorithm = attributes[:'signature_algorithm'] end if attributes.key?(:'signing_kp') self.signing_kp = attributes[:'signing_kp'] end if attributes.key?(:'verification_kp') self.verification_kp = attributes[:'verification_kp'] end if attributes.key?(:'encryption_kp') self.encryption_kp = attributes[:'encryption_kp'] end if attributes.key?(:'sign_assertion') self.sign_assertion = attributes[:'sign_assertion'] end if attributes.key?(:'sign_response') self.sign_response = attributes[:'sign_response'] end if attributes.key?(:'sign_logout_request') self.sign_logout_request = attributes[:'sign_logout_request'] end if attributes.key?(:'sign_logout_response') self.sign_logout_response = attributes[:'sign_logout_response'] end if attributes.key?(:'sp_binding') self.sp_binding = attributes[:'sp_binding'] end if attributes.key?(:'sls_binding') self.sls_binding = attributes[:'sls_binding'] end if attributes.key?(:'logout_method') self.logout_method = attributes[:'logout_method'] end if attributes.key?(:'default_relay_state') self.default_relay_state = attributes[:'default_relay_state'] end if attributes.key?(:'default_name_id_policy') self.default_name_id_policy = attributes[:'default_name_id_policy'] end if attributes.key?(:'url_download_metadata') self. = attributes[:'url_download_metadata'] else self. = nil end if attributes.key?(:'url_issuer') self.url_issuer = attributes[:'url_issuer'] else self.url_issuer = nil end if attributes.key?(:'url_unified') self.url_unified = attributes[:'url_unified'] else self.url_unified = nil end if attributes.key?(:'url_unified_init') self.url_unified_init = attributes[:'url_unified_init'] else self.url_unified_init = nil end if attributes.key?(:'url_sso_post') self.url_sso_post = attributes[:'url_sso_post'] else self.url_sso_post = nil end if attributes.key?(:'url_sso_redirect') self.url_sso_redirect = attributes[:'url_sso_redirect'] else self.url_sso_redirect = nil end if attributes.key?(:'url_sso_init') self.url_sso_init = attributes[:'url_sso_init'] else self.url_sso_init = nil end if attributes.key?(:'url_slo_post') self.url_slo_post = attributes[:'url_slo_post'] else self.url_slo_post = nil end if attributes.key?(:'url_slo_redirect') self.url_slo_redirect = attributes[:'url_slo_redirect'] else self.url_slo_redirect = nil end end |
Instance Attribute Details
#acs_url ⇒ Object
Returns the value of attribute acs_url.
52 53 54 |
# File 'lib/authentik/api/models/saml_provider.rb', line 52 def acs_url @acs_url end |
#assertion_valid_not_before ⇒ Object
Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).
64 65 66 |
# File 'lib/authentik/api/models/saml_provider.rb', line 64 def assertion_valid_not_before @assertion_valid_not_before end |
#assertion_valid_not_on_or_after ⇒ Object
Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
67 68 69 |
# File 'lib/authentik/api/models/saml_provider.rb', line 67 def assertion_valid_not_on_or_after @assertion_valid_not_on_or_after end |
#assigned_application_name ⇒ Object
Application’s display Name.
35 36 37 |
# File 'lib/authentik/api/models/saml_provider.rb', line 35 def assigned_application_name @assigned_application_name end |
#assigned_application_slug ⇒ Object
Internal application name, used in URLs.
32 33 34 |
# File 'lib/authentik/api/models/saml_provider.rb', line 32 def assigned_application_slug @assigned_application_slug end |
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
41 42 43 |
# File 'lib/authentik/api/models/saml_provider.rb', line 41 def assigned_backchannel_application_name @assigned_backchannel_application_name end |
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
38 39 40 |
# File 'lib/authentik/api/models/saml_provider.rb', line 38 def assigned_backchannel_application_slug @assigned_backchannel_application_slug end |
#audience ⇒ Object
Value of the audience restriction field of the assertion. When left empty, no audience restriction will be added.
58 59 60 |
# File 'lib/authentik/api/models/saml_provider.rb', line 58 def audience @audience end |
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
18 19 20 |
# File 'lib/authentik/api/models/saml_provider.rb', line 18 def authentication_flow @authentication_flow end |
#authn_context_class_ref_mapping ⇒ Object
Configure how the AuthnContextClassRef value will be created. When left empty, the AuthnContextClassRef will be set based on which authentication methods the user used to authenticate.
76 77 78 |
# File 'lib/authentik/api/models/saml_provider.rb', line 76 def authn_context_class_ref_mapping @authn_context_class_ref_mapping end |
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
21 22 23 |
# File 'lib/authentik/api/models/saml_provider.rb', line 21 def @authorization_flow end |
#component ⇒ Object
Get object component so that we know how to edit the object
29 30 31 |
# File 'lib/authentik/api/models/saml_provider.rb', line 29 def component @component end |
#default_name_id_policy ⇒ Object
Returns the value of attribute default_name_id_policy.
111 112 113 |
# File 'lib/authentik/api/models/saml_provider.rb', line 111 def default_name_id_policy @default_name_id_policy end |
#default_relay_state ⇒ Object
Default relay_state value for IDP-initiated logins
109 110 111 |
# File 'lib/authentik/api/models/saml_provider.rb', line 109 def default_relay_state @default_relay_state end |
#digest_algorithm ⇒ Object
Returns the value of attribute digest_algorithm.
78 79 80 |
# File 'lib/authentik/api/models/saml_provider.rb', line 78 def digest_algorithm @digest_algorithm end |
#encryption_kp ⇒ Object
When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.
89 90 91 |
# File 'lib/authentik/api/models/saml_provider.rb', line 89 def encryption_kp @encryption_kp end |
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
24 25 26 |
# File 'lib/authentik/api/models/saml_provider.rb', line 24 def invalidation_flow @invalidation_flow end |
#issuer_override ⇒ Object
Also known as EntityID. Providing a value overrides the default issuer generated by authentik.
61 62 63 |
# File 'lib/authentik/api/models/saml_provider.rb', line 61 def issuer_override @issuer_override end |
#logout_method ⇒ Object
Method to use for logout. Front-channel iframe loads all logout URLs simultaneously in hidden iframes. Front-channel native uses your active browser tab to send post requests and redirect to providers. Back-channel sends logout requests directly from the server without user interaction (requires POST SLS binding).
106 107 108 |
# File 'lib/authentik/api/models/saml_provider.rb', line 106 def logout_method @logout_method end |
#meta_model_name ⇒ Object
Return internal model name
50 51 52 |
# File 'lib/authentik/api/models/saml_provider.rb', line 50 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/saml_provider.rb', line 15 def name @name end |
#name_id_mapping ⇒ Object
Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be considered
73 74 75 |
# File 'lib/authentik/api/models/saml_provider.rb', line 73 def name_id_mapping @name_id_mapping end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/saml_provider.rb', line 13 def pk @pk end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
26 27 28 |
# File 'lib/authentik/api/models/saml_provider.rb', line 26 def property_mappings @property_mappings end |
#session_valid_not_on_or_after ⇒ Object
Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
70 71 72 |
# File 'lib/authentik/api/models/saml_provider.rb', line 70 def session_valid_not_on_or_after @session_valid_not_on_or_after end |
#sign_assertion ⇒ Object
Returns the value of attribute sign_assertion.
91 92 93 |
# File 'lib/authentik/api/models/saml_provider.rb', line 91 def sign_assertion @sign_assertion end |
#sign_logout_request ⇒ Object
Returns the value of attribute sign_logout_request.
95 96 97 |
# File 'lib/authentik/api/models/saml_provider.rb', line 95 def sign_logout_request @sign_logout_request end |
#sign_logout_response ⇒ Object
Returns the value of attribute sign_logout_response.
97 98 99 |
# File 'lib/authentik/api/models/saml_provider.rb', line 97 def sign_logout_response @sign_logout_response end |
#sign_response ⇒ Object
Returns the value of attribute sign_response.
93 94 95 |
# File 'lib/authentik/api/models/saml_provider.rb', line 93 def sign_response @sign_response end |
#signature_algorithm ⇒ Object
Returns the value of attribute signature_algorithm.
80 81 82 |
# File 'lib/authentik/api/models/saml_provider.rb', line 80 def signature_algorithm @signature_algorithm end |
#signing_kp ⇒ Object
Keypair used to sign outgoing Responses going to the Service Provider.
83 84 85 |
# File 'lib/authentik/api/models/saml_provider.rb', line 83 def signing_kp @signing_kp end |
#sls_binding ⇒ Object
This determines how authentik sends the logout response back to the Service Provider.
103 104 105 |
# File 'lib/authentik/api/models/saml_provider.rb', line 103 def sls_binding @sls_binding end |
#sls_url ⇒ Object
Single Logout Service URL where the logout response should be sent.
55 56 57 |
# File 'lib/authentik/api/models/saml_provider.rb', line 55 def sls_url @sls_url end |
#sp_binding ⇒ Object
This determines how authentik sends the response back to the Service Provider.
100 101 102 |
# File 'lib/authentik/api/models/saml_provider.rb', line 100 def sp_binding @sp_binding end |
#url_download_metadata ⇒ Object
Get metadata download URL
114 115 116 |
# File 'lib/authentik/api/models/saml_provider.rb', line 114 def @url_download_metadata end |
#url_issuer ⇒ Object
Get Issuer/EntityID URL
117 118 119 |
# File 'lib/authentik/api/models/saml_provider.rb', line 117 def url_issuer @url_issuer end |
#url_slo_post ⇒ Object
Get SLO POST URL
135 136 137 |
# File 'lib/authentik/api/models/saml_provider.rb', line 135 def url_slo_post @url_slo_post end |
#url_slo_redirect ⇒ Object
Get SLO redirect URL
138 139 140 |
# File 'lib/authentik/api/models/saml_provider.rb', line 138 def url_slo_redirect @url_slo_redirect end |
#url_sso_init ⇒ Object
Get SSO IDP-Initiated URL
132 133 134 |
# File 'lib/authentik/api/models/saml_provider.rb', line 132 def url_sso_init @url_sso_init end |
#url_sso_post ⇒ Object
Get SSO Post URL
126 127 128 |
# File 'lib/authentik/api/models/saml_provider.rb', line 126 def url_sso_post @url_sso_post end |
#url_sso_redirect ⇒ Object
Get SSO Redirect URL
129 130 131 |
# File 'lib/authentik/api/models/saml_provider.rb', line 129 def url_sso_redirect @url_sso_redirect end |
#url_unified ⇒ Object
Get unified SAML endpoint URL (handles SSO and SLO)
120 121 122 |
# File 'lib/authentik/api/models/saml_provider.rb', line 120 def url_unified @url_unified end |
#url_unified_init ⇒ Object
Get IdP-initiated SAML URL
123 124 125 |
# File 'lib/authentik/api/models/saml_provider.rb', line 123 def url_unified_init @url_unified_init end |
#verbose_name ⇒ Object
Return object’s verbose_name
44 45 46 |
# File 'lib/authentik/api/models/saml_provider.rb', line 44 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
47 48 49 |
# File 'lib/authentik/api/models/saml_provider.rb', line 47 def verbose_name_plural @verbose_name_plural end |
#verification_kp ⇒ Object
When selected, incoming assertion’s Signatures will be validated against this certificate. To allow unsigned Requests, leave on default.
86 87 88 |
# File 'lib/authentik/api/models/saml_provider.rb', line 86 def verification_kp @verification_kp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
215 216 217 |
# File 'lib/authentik/api/models/saml_provider.rb', line 215 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
220 221 222 |
# File 'lib/authentik/api/models/saml_provider.rb', line 220 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/authentik/api/models/saml_provider.rb', line 163 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'authentication_flow' => :'authentication_flow', :'authorization_flow' => :'authorization_flow', :'invalidation_flow' => :'invalidation_flow', :'property_mappings' => :'property_mappings', :'component' => :'component', :'assigned_application_slug' => :'assigned_application_slug', :'assigned_application_name' => :'assigned_application_name', :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'acs_url' => :'acs_url', :'sls_url' => :'sls_url', :'audience' => :'audience', :'issuer_override' => :'issuer_override', :'assertion_valid_not_before' => :'assertion_valid_not_before', :'assertion_valid_not_on_or_after' => :'assertion_valid_not_on_or_after', :'session_valid_not_on_or_after' => :'session_valid_not_on_or_after', :'name_id_mapping' => :'name_id_mapping', :'authn_context_class_ref_mapping' => :'authn_context_class_ref_mapping', :'digest_algorithm' => :'digest_algorithm', :'signature_algorithm' => :'signature_algorithm', :'signing_kp' => :'signing_kp', :'verification_kp' => :'verification_kp', :'encryption_kp' => :'encryption_kp', :'sign_assertion' => :'sign_assertion', :'sign_response' => :'sign_response', :'sign_logout_request' => :'sign_logout_request', :'sign_logout_response' => :'sign_logout_response', :'sp_binding' => :'sp_binding', :'sls_binding' => :'sls_binding', :'logout_method' => :'logout_method', :'default_relay_state' => :'default_relay_state', :'default_name_id_policy' => :'default_name_id_policy', :'url_download_metadata' => :'url_download_metadata', :'url_issuer' => :'url_issuer', :'url_unified' => :'url_unified', :'url_unified_init' => :'url_unified_init', :'url_sso_post' => :'url_sso_post', :'url_sso_redirect' => :'url_sso_redirect', :'url_sso_init' => :'url_sso_init', :'url_slo_post' => :'url_slo_post', :'url_slo_redirect' => :'url_slo_redirect' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 |
# File 'lib/authentik/api/models/saml_provider.rb', line 892 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/authentik/api/models/saml_provider.rb', line 277 def self.openapi_nullable Set.new([ :'authentication_flow', :'assigned_application_slug', :'assigned_application_name', :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name', :'name_id_mapping', :'authn_context_class_ref_mapping', :'signing_kp', :'verification_kp', :'encryption_kp', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/authentik/api/models/saml_provider.rb', line 225 def self.openapi_types { :'pk' => :'Integer', :'name' => :'String', :'authentication_flow' => :'String', :'authorization_flow' => :'String', :'invalidation_flow' => :'String', :'property_mappings' => :'Array<String>', :'component' => :'String', :'assigned_application_slug' => :'String', :'assigned_application_name' => :'String', :'assigned_backchannel_application_slug' => :'String', :'assigned_backchannel_application_name' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'acs_url' => :'String', :'sls_url' => :'String', :'audience' => :'String', :'issuer_override' => :'String', :'assertion_valid_not_before' => :'String', :'assertion_valid_not_on_or_after' => :'String', :'session_valid_not_on_or_after' => :'String', :'name_id_mapping' => :'String', :'authn_context_class_ref_mapping' => :'String', :'digest_algorithm' => :'DigestAlgorithmEnum', :'signature_algorithm' => :'SignatureAlgorithmEnum', :'signing_kp' => :'String', :'verification_kp' => :'String', :'encryption_kp' => :'String', :'sign_assertion' => :'Boolean', :'sign_response' => :'Boolean', :'sign_logout_request' => :'Boolean', :'sign_logout_response' => :'Boolean', :'sp_binding' => :'SAMLBindingsEnum', :'sls_binding' => :'SAMLBindingsEnum', :'logout_method' => :'SAMLLogoutMethods', :'default_relay_state' => :'String', :'default_name_id_policy' => :'SAMLNameIDPolicyEnum', :'url_download_metadata' => :'String', :'url_issuer' => :'String', :'url_unified' => :'String', :'url_unified_init' => :'String', :'url_sso_post' => :'String', :'url_sso_redirect' => :'String', :'url_sso_init' => :'String', :'url_slo_post' => :'String', :'url_slo_redirect' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 |
# File 'lib/authentik/api/models/saml_provider.rb', line 826 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && authentication_flow == o.authentication_flow && == o. && invalidation_flow == o.invalidation_flow && property_mappings == o.property_mappings && component == o.component && assigned_application_slug == o.assigned_application_slug && assigned_application_name == o.assigned_application_name && assigned_backchannel_application_slug == o.assigned_backchannel_application_slug && assigned_backchannel_application_name == o.assigned_backchannel_application_name && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && acs_url == o.acs_url && sls_url == o.sls_url && audience == o.audience && issuer_override == o.issuer_override && assertion_valid_not_before == o.assertion_valid_not_before && assertion_valid_not_on_or_after == o.assertion_valid_not_on_or_after && session_valid_not_on_or_after == o.session_valid_not_on_or_after && name_id_mapping == o.name_id_mapping && authn_context_class_ref_mapping == o.authn_context_class_ref_mapping && digest_algorithm == o.digest_algorithm && signature_algorithm == o.signature_algorithm && signing_kp == o.signing_kp && verification_kp == o.verification_kp && encryption_kp == o.encryption_kp && sign_assertion == o.sign_assertion && sign_response == o.sign_response && sign_logout_request == o.sign_logout_request && sign_logout_response == o.sign_logout_response && sp_binding == o.sp_binding && sls_binding == o.sls_binding && logout_method == o.logout_method && default_relay_state == o.default_relay_state && default_name_id_policy == o.default_name_id_policy && == o. && url_issuer == o.url_issuer && url_unified == o.url_unified && url_unified_init == o.url_unified_init && url_sso_post == o.url_sso_post && url_sso_redirect == o.url_sso_redirect && url_sso_init == o.url_sso_init && url_slo_post == o.url_slo_post && url_slo_redirect == o.url_slo_redirect end |
#eql?(o) ⇒ Boolean
879 880 881 |
# File 'lib/authentik/api/models/saml_provider.rb', line 879 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
885 886 887 |
# File 'lib/authentik/api/models/saml_provider.rb', line 885 def hash [pk, name, authentication_flow, , invalidation_flow, property_mappings, component, assigned_application_slug, assigned_application_name, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, , acs_url, sls_url, audience, issuer_override, assertion_valid_not_before, assertion_valid_not_on_or_after, session_valid_not_on_or_after, name_id_mapping, authn_context_class_ref_mapping, digest_algorithm, signature_algorithm, signing_kp, verification_kp, encryption_kp, sign_assertion, sign_response, sign_logout_request, sign_logout_response, sp_binding, sls_binding, logout_method, default_relay_state, default_name_id_policy, , url_issuer, url_unified, url_unified_init, url_sso_post, url_sso_redirect, url_sso_init, url_slo_post, url_slo_redirect].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/authentik/api/models/saml_provider.rb', line 541 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @authorization_flow.nil? invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.') end if @invalidation_flow.nil? invalid_properties.push('invalid value for "invalidation_flow", invalidation_flow cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @acs_url.nil? invalid_properties.push('invalid value for "acs_url", acs_url cannot be nil.') end if @url_download_metadata.nil? invalid_properties.push('invalid value for "url_download_metadata", url_download_metadata cannot be nil.') end if @url_issuer.nil? invalid_properties.push('invalid value for "url_issuer", url_issuer cannot be nil.') end if @url_unified.nil? invalid_properties.push('invalid value for "url_unified", url_unified cannot be nil.') end if @url_unified_init.nil? invalid_properties.push('invalid value for "url_unified_init", url_unified_init cannot be nil.') end if @url_sso_post.nil? invalid_properties.push('invalid value for "url_sso_post", url_sso_post cannot be nil.') end if @url_sso_redirect.nil? invalid_properties.push('invalid value for "url_sso_redirect", url_sso_redirect cannot be nil.') end if @url_sso_init.nil? invalid_properties.push('invalid value for "url_sso_init", url_sso_init cannot be nil.') end if @url_slo_post.nil? invalid_properties.push('invalid value for "url_slo_post", url_slo_post cannot be nil.') end if @url_slo_redirect.nil? invalid_properties.push('invalid value for "url_slo_redirect", url_slo_redirect cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
914 915 916 917 918 919 920 921 922 923 924 925 926 |
# File 'lib/authentik/api/models/saml_provider.rb', line 914 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/authentik/api/models/saml_provider.rb', line 621 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @authorization_flow.nil? return false if @invalidation_flow.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @acs_url.nil? return false if @url_download_metadata.nil? return false if @url_issuer.nil? return false if @url_unified.nil? return false if @url_unified_init.nil? return false if @url_sso_post.nil? return false if @url_sso_redirect.nil? return false if @url_sso_init.nil? return false if @url_slo_post.nil? return false if @url_slo_redirect.nil? true end |