Class: Authentik::Api::SCIMProviderGroup

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/scim_provider_group.rb

Overview

SCIMProviderGroup Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SCIMProviderGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/authentik/api/models/scim_provider_group.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SCIMProviderGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SCIMProviderGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'scim_id')
    self.scim_id = attributes[:'scim_id']
  else
    self.scim_id = nil
  end

  if attributes.key?(:'group')
    self.group = attributes[:'group']
  else
    self.group = nil
  end

  if attributes.key?(:'group_obj')
    self.group_obj = attributes[:'group_obj']
  else
    self.group_obj = nil
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  else
    self.attributes = nil
  end
end

Instance Attribute Details

#attributesObject

Returns the value of attribute attributes.



23
24
25
# File 'lib/authentik/api/models/scim_provider_group.rb', line 23

def attributes
  @attributes
end

#groupObject

Returns the value of attribute group.



17
18
19
# File 'lib/authentik/api/models/scim_provider_group.rb', line 17

def group
  @group
end

#group_objObject

Returns the value of attribute group_obj.



19
20
21
# File 'lib/authentik/api/models/scim_provider_group.rb', line 19

def group_obj
  @group_obj
end

#idObject

Returns the value of attribute id.



13
14
15
# File 'lib/authentik/api/models/scim_provider_group.rb', line 13

def id
  @id
end

#providerObject

Returns the value of attribute provider.



21
22
23
# File 'lib/authentik/api/models/scim_provider_group.rb', line 21

def provider
  @provider
end

#scim_idObject

Returns the value of attribute scim_id.



15
16
17
# File 'lib/authentik/api/models/scim_provider_group.rb', line 15

def scim_id
  @scim_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/authentik/api/models/scim_provider_group.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/authentik/api/models/scim_provider_group.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
35
# File 'lib/authentik/api/models/scim_provider_group.rb', line 26

def self.attribute_map
  {
    :'id' => :'id',
    :'scim_id' => :'scim_id',
    :'group' => :'group',
    :'group_obj' => :'group_obj',
    :'provider' => :'provider',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/authentik/api/models/scim_provider_group.rb', line 253

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/authentik/api/models/scim_provider_group.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
# File 'lib/authentik/api/models/scim_provider_group.rb', line 48

def self.openapi_types
  {
    :'id' => :'String',
    :'scim_id' => :'String',
    :'group' => :'String',
    :'group_obj' => :'PartialGroup',
    :'provider' => :'Integer',
    :'attributes' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



227
228
229
230
231
232
233
234
235
236
# File 'lib/authentik/api/models/scim_provider_group.rb', line 227

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      scim_id == o.scim_id &&
      group == o.group &&
      group_obj == o.group_obj &&
      provider == o.provider &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/authentik/api/models/scim_provider_group.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/authentik/api/models/scim_provider_group.rb', line 246

def hash
  [id, scim_id, group, group_obj, provider, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/authentik/api/models/scim_provider_group.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @scim_id.nil?
    invalid_properties.push('invalid value for "scim_id", scim_id cannot be nil.')
  end

  if @group.nil?
    invalid_properties.push('invalid value for "group", group cannot be nil.')
  end

  if @group_obj.nil?
    invalid_properties.push('invalid value for "group_obj", group_obj cannot be nil.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @attributes.nil?
    invalid_properties.push('invalid value for "attributes", attributes cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/authentik/api/models/scim_provider_group.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
161
162
163
# File 'lib/authentik/api/models/scim_provider_group.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @scim_id.nil?
  return false if @group.nil?
  return false if @group_obj.nil?
  return false if @provider.nil?
  return false if @attributes.nil?
  true
end