Class: Authentik::Api::SCIMProviderRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/scim_provider_request.rb

Overview

SCIMProvider Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SCIMProviderRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/authentik/api/models/scim_provider_request.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SCIMProviderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SCIMProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'property_mappings_group')
    if (value = attributes[:'property_mappings_group']).is_a?(Array)
      self.property_mappings_group = value
    end
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'verify_certificates')
    self.verify_certificates = attributes[:'verify_certificates']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'auth_mode')
    self.auth_mode = attributes[:'auth_mode']
  end

  if attributes.key?(:'auth_oauth')
    self.auth_oauth = attributes[:'auth_oauth']
  end

  if attributes.key?(:'auth_oauth_params')
    if (value = attributes[:'auth_oauth_params']).is_a?(Hash)
      self.auth_oauth_params = value
    end
  end

  if attributes.key?(:'compatibility_mode')
    self.compatibility_mode = attributes[:'compatibility_mode']
  end

  if attributes.key?(:'service_provider_config_cache_timeout')
    self.service_provider_config_cache_timeout = attributes[:'service_provider_config_cache_timeout']
  end

  if attributes.key?(:'exclude_users_service_account')
    self. = attributes[:'exclude_users_service_account']
  end

  if attributes.key?(:'sync_page_size')
    self.sync_page_size = attributes[:'sync_page_size']
  end

  if attributes.key?(:'sync_page_timeout')
    self.sync_page_timeout = attributes[:'sync_page_timeout']
  end

  if attributes.key?(:'group_filters')
    if (value = attributes[:'group_filters']).is_a?(Array)
      self.group_filters = value
    end
  end

  if attributes.key?(:'dry_run')
    self.dry_run = attributes[:'dry_run']
  end
end

Instance Attribute Details

#auth_modeObject

Returns the value of attribute auth_mode.



28
29
30
# File 'lib/authentik/api/models/scim_provider_request.rb', line 28

def auth_mode
  @auth_mode
end

#auth_oauthObject

OAuth Source used for authentication



31
32
33
# File 'lib/authentik/api/models/scim_provider_request.rb', line 31

def auth_oauth
  @auth_oauth
end

#auth_oauth_paramsObject

Additional OAuth parameters, such as grant_type



34
35
36
# File 'lib/authentik/api/models/scim_provider_request.rb', line 34

def auth_oauth_params
  @auth_oauth_params
end

#compatibility_modeObject

Alter authentik behavior for vendor-specific SCIM implementations.



37
38
39
# File 'lib/authentik/api/models/scim_provider_request.rb', line 37

def compatibility_mode
  @compatibility_mode
end

#dry_runObject

When enabled, provider will not modify or create objects in the remote system.



54
55
56
# File 'lib/authentik/api/models/scim_provider_request.rb', line 54

def dry_run
  @dry_run
end

#exclude_users_service_accountObject

Returns the value of attribute exclude_users_service_account.



42
43
44
# File 'lib/authentik/api/models/scim_provider_request.rb', line 42

def 
  @exclude_users_service_account
end

#group_filtersObject

Group filters used to define sync-scope for groups.



51
52
53
# File 'lib/authentik/api/models/scim_provider_request.rb', line 51

def group_filters
  @group_filters
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/scim_provider_request.rb', line 13

def name
  @name
end

#property_mappingsObject

Returns the value of attribute property_mappings.



15
16
17
# File 'lib/authentik/api/models/scim_provider_request.rb', line 15

def property_mappings
  @property_mappings
end

#property_mappings_groupObject

Property mappings used for group creation/updating.



18
19
20
# File 'lib/authentik/api/models/scim_provider_request.rb', line 18

def property_mappings_group
  @property_mappings_group
end

#service_provider_config_cache_timeoutObject

Cache duration for ServiceProviderConfig responses. Set minutes=0 to disable.



40
41
42
# File 'lib/authentik/api/models/scim_provider_request.rb', line 40

def service_provider_config_cache_timeout
  @service_provider_config_cache_timeout
end

#sync_page_sizeObject

Controls the number of objects synced in a single task



45
46
47
# File 'lib/authentik/api/models/scim_provider_request.rb', line 45

def sync_page_size
  @sync_page_size
end

#sync_page_timeoutObject

Timeout for synchronization of a single page



48
49
50
# File 'lib/authentik/api/models/scim_provider_request.rb', line 48

def sync_page_timeout
  @sync_page_timeout
end

#tokenObject

Authentication token



26
27
28
# File 'lib/authentik/api/models/scim_provider_request.rb', line 26

def token
  @token
end

#urlObject

Base URL to SCIM requests, usually ends in /v2



21
22
23
# File 'lib/authentik/api/models/scim_provider_request.rb', line 21

def url
  @url
end

#verify_certificatesObject

Returns the value of attribute verify_certificates.



23
24
25
# File 'lib/authentik/api/models/scim_provider_request.rb', line 23

def verify_certificates
  @verify_certificates
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



101
102
103
# File 'lib/authentik/api/models/scim_provider_request.rb', line 101

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



106
107
108
# File 'lib/authentik/api/models/scim_provider_request.rb', line 106

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/authentik/api/models/scim_provider_request.rb', line 79

def self.attribute_map
  {
    :'name' => :'name',
    :'property_mappings' => :'property_mappings',
    :'property_mappings_group' => :'property_mappings_group',
    :'url' => :'url',
    :'verify_certificates' => :'verify_certificates',
    :'token' => :'token',
    :'auth_mode' => :'auth_mode',
    :'auth_oauth' => :'auth_oauth',
    :'auth_oauth_params' => :'auth_oauth_params',
    :'compatibility_mode' => :'compatibility_mode',
    :'service_provider_config_cache_timeout' => :'service_provider_config_cache_timeout',
    :'exclude_users_service_account' => :'exclude_users_service_account',
    :'sync_page_size' => :'sync_page_size',
    :'sync_page_timeout' => :'sync_page_timeout',
    :'group_filters' => :'group_filters',
    :'dry_run' => :'dry_run'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/authentik/api/models/scim_provider_request.rb', line 399

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



133
134
135
136
137
# File 'lib/authentik/api/models/scim_provider_request.rb', line 133

def self.openapi_nullable
  Set.new([
    :'auth_oauth',
  ])
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/authentik/api/models/scim_provider_request.rb', line 111

def self.openapi_types
  {
    :'name' => :'String',
    :'property_mappings' => :'Array<String>',
    :'property_mappings_group' => :'Array<String>',
    :'url' => :'String',
    :'verify_certificates' => :'Boolean',
    :'token' => :'String',
    :'auth_mode' => :'SCIMAuthenticationModeEnum',
    :'auth_oauth' => :'String',
    :'auth_oauth_params' => :'Hash<String, Object>',
    :'compatibility_mode' => :'CompatibilityModeEnum',
    :'service_provider_config_cache_timeout' => :'String',
    :'exclude_users_service_account' => :'Boolean',
    :'sync_page_size' => :'Integer',
    :'sync_page_timeout' => :'String',
    :'group_filters' => :'Array<String>',
    :'dry_run' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/authentik/api/models/scim_provider_request.rb', line 363

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      property_mappings == o.property_mappings &&
      property_mappings_group == o.property_mappings_group &&
      url == o.url &&
      verify_certificates == o.verify_certificates &&
      token == o.token &&
      auth_mode == o.auth_mode &&
      auth_oauth == o.auth_oauth &&
      auth_oauth_params == o.auth_oauth_params &&
      compatibility_mode == o.compatibility_mode &&
      service_provider_config_cache_timeout == o.service_provider_config_cache_timeout &&
       == o. &&
      sync_page_size == o.sync_page_size &&
      sync_page_timeout == o.sync_page_timeout &&
      group_filters == o.group_filters &&
      dry_run == o.dry_run
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


386
387
388
# File 'lib/authentik/api/models/scim_provider_request.rb', line 386

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



392
393
394
# File 'lib/authentik/api/models/scim_provider_request.rb', line 392

def hash
  [name, property_mappings, property_mappings_group, url, verify_certificates, token, auth_mode, auth_oauth, auth_oauth_params, compatibility_mode, service_provider_config_cache_timeout, , sync_page_size, sync_page_timeout, group_filters, dry_run].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/authentik/api/models/scim_provider_request.rb', line 234

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length < 1
    invalid_properties.push('invalid value for "url", the character length must be greater than or equal to 1.')
  end

  if !@service_provider_config_cache_timeout.nil? && @service_provider_config_cache_timeout.to_s.length < 1
    invalid_properties.push('invalid value for "service_provider_config_cache_timeout", the character length must be greater than or equal to 1.')
  end

  if !@sync_page_size.nil? && @sync_page_size > 2147483647
    invalid_properties.push('invalid value for "sync_page_size", must be smaller than or equal to 2147483647.')
  end

  if !@sync_page_size.nil? && @sync_page_size < 1
    invalid_properties.push('invalid value for "sync_page_size", must be greater than or equal to 1.')
  end

  if !@sync_page_timeout.nil? && @sync_page_timeout.to_s.length < 1
    invalid_properties.push('invalid value for "sync_page_timeout", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/authentik/api/models/scim_provider_request.rb', line 421

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/authentik/api/models/scim_provider_request.rb', line 274

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @url.nil?
  return false if @url.to_s.length < 1
  return false if !@service_provider_config_cache_timeout.nil? && @service_provider_config_cache_timeout.to_s.length < 1
  return false if !@sync_page_size.nil? && @sync_page_size > 2147483647
  return false if !@sync_page_size.nil? && @sync_page_size < 1
  return false if !@sync_page_timeout.nil? && @sync_page_timeout.to_s.length < 1
  true
end