Class: Authentik::Api::SCIMSource
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::SCIMSource
- Defined in:
- lib/authentik/api/models/scim_source.rb
Overview
SCIMSource Serializer
Instance Attribute Summary collapse
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#group_property_mappings ⇒ Object
Returns the value of attribute group_property_mappings.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Source’s display Name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#root_url ⇒ Object
Get Root URL.
-
#slug ⇒ Object
Internal source name, used in URLs.
-
#token_obj ⇒ Object
Returns the value of attribute token_obj.
-
#user_path_template ⇒ Object
Returns the value of attribute user_path_template.
-
#user_property_mappings ⇒ Object
Returns the value of attribute user_property_mappings.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SCIMSource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SCIMSource
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/authentik/api/models/scim_source.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SCIMSource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SCIMSource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'user_property_mappings') if (value = attributes[:'user_property_mappings']).is_a?(Array) self.user_property_mappings = value end end if attributes.key?(:'group_property_mappings') if (value = attributes[:'group_property_mappings']).is_a?(Array) self.group_property_mappings = value end end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'managed') self.managed = attributes[:'managed'] else self.managed = nil end if attributes.key?(:'user_path_template') self.user_path_template = attributes[:'user_path_template'] end if attributes.key?(:'root_url') self.root_url = attributes[:'root_url'] else self.root_url = nil end if attributes.key?(:'token_obj') self.token_obj = attributes[:'token_obj'] else self.token_obj = nil end end |
Instance Attribute Details
#component ⇒ Object
Get object component so that we know how to edit the object
28 29 30 |
# File 'lib/authentik/api/models/scim_source.rb', line 28 def component @component end |
#enabled ⇒ Object
Returns the value of attribute enabled.
21 22 23 |
# File 'lib/authentik/api/models/scim_source.rb', line 21 def enabled @enabled end |
#group_property_mappings ⇒ Object
Returns the value of attribute group_property_mappings.
25 26 27 |
# File 'lib/authentik/api/models/scim_source.rb', line 25 def group_property_mappings @group_property_mappings end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
40 41 42 |
# File 'lib/authentik/api/models/scim_source.rb', line 40 def managed @managed end |
#meta_model_name ⇒ Object
Return internal model name
37 38 39 |
# File 'lib/authentik/api/models/scim_source.rb', line 37 def @meta_model_name end |
#name ⇒ Object
Source’s display Name.
16 17 18 |
# File 'lib/authentik/api/models/scim_source.rb', line 16 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/scim_source.rb', line 13 def pk @pk end |
#root_url ⇒ Object
Get Root URL
45 46 47 |
# File 'lib/authentik/api/models/scim_source.rb', line 45 def root_url @root_url end |
#slug ⇒ Object
Internal source name, used in URLs.
19 20 21 |
# File 'lib/authentik/api/models/scim_source.rb', line 19 def slug @slug end |
#token_obj ⇒ Object
Returns the value of attribute token_obj.
47 48 49 |
# File 'lib/authentik/api/models/scim_source.rb', line 47 def token_obj @token_obj end |
#user_path_template ⇒ Object
Returns the value of attribute user_path_template.
42 43 44 |
# File 'lib/authentik/api/models/scim_source.rb', line 42 def user_path_template @user_path_template end |
#user_property_mappings ⇒ Object
Returns the value of attribute user_property_mappings.
23 24 25 |
# File 'lib/authentik/api/models/scim_source.rb', line 23 def user_property_mappings @user_property_mappings end |
#verbose_name ⇒ Object
Return object’s verbose_name
31 32 33 |
# File 'lib/authentik/api/models/scim_source.rb', line 31 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
34 35 36 |
# File 'lib/authentik/api/models/scim_source.rb', line 34 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/authentik/api/models/scim_source.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/authentik/api/models/scim_source.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/authentik/api/models/scim_source.rb', line 50 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'slug' => :'slug', :'enabled' => :'enabled', :'user_property_mappings' => :'user_property_mappings', :'group_property_mappings' => :'group_property_mappings', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'managed' => :'managed', :'user_path_template' => :'user_path_template', :'root_url' => :'root_url', :'token_obj' => :'token_obj' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/authentik/api/models/scim_source.rb', line 400 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 104 |
# File 'lib/authentik/api/models/scim_source.rb', line 100 def self.openapi_nullable Set.new([ :'managed', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/authentik/api/models/scim_source.rb', line 80 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'slug' => :'String', :'enabled' => :'Boolean', :'user_property_mappings' => :'Array<String>', :'group_property_mappings' => :'Array<String>', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'managed' => :'String', :'user_path_template' => :'String', :'root_url' => :'String', :'token_obj' => :'Token' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/authentik/api/models/scim_source.rb', line 366 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && slug == o.slug && enabled == o.enabled && user_property_mappings == o.user_property_mappings && group_property_mappings == o.group_property_mappings && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && managed == o.managed && user_path_template == o.user_path_template && root_url == o.root_url && token_obj == o.token_obj end |
#eql?(o) ⇒ Boolean
387 388 389 |
# File 'lib/authentik/api/models/scim_source.rb', line 387 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
393 394 395 |
# File 'lib/authentik/api/models/scim_source.rb', line 393 def hash [pk, name, slug, enabled, user_property_mappings, group_property_mappings, component, verbose_name, verbose_name_plural, , managed, user_path_template, root_url, token_obj].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/authentik/api/models/scim_source.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/) if @slug !~ pattern invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.") end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @root_url.nil? invalid_properties.push('invalid value for "root_url", root_url cannot be nil.') end if @token_obj.nil? invalid_properties.push('invalid value for "token_obj", token_obj cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/authentik/api/models/scim_source.rb', line 422 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/authentik/api/models/scim_source.rb', line 254 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @slug.nil? return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/) return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @root_url.nil? return false if @token_obj.nil? true end |