Class: Authentik::Api::SCIMSourceRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/scim_source_request.rb

Overview

SCIMSource Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SCIMSourceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/authentik/api/models/scim_source_request.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SCIMSourceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SCIMSourceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'user_property_mappings')
    if (value = attributes[:'user_property_mappings']).is_a?(Array)
      self.user_property_mappings = value
    end
  end

  if attributes.key?(:'group_property_mappings')
    if (value = attributes[:'group_property_mappings']).is_a?(Array)
      self.group_property_mappings = value
    end
  end

  if attributes.key?(:'user_path_template')
    self.user_path_template = attributes[:'user_path_template']
  end
end

Instance Attribute Details

#enabledObject

Returns the value of attribute enabled.



19
20
21
# File 'lib/authentik/api/models/scim_source_request.rb', line 19

def enabled
  @enabled
end

#group_property_mappingsObject

Returns the value of attribute group_property_mappings.



23
24
25
# File 'lib/authentik/api/models/scim_source_request.rb', line 23

def group_property_mappings
  @group_property_mappings
end

#nameObject

Source’s display Name.



14
15
16
# File 'lib/authentik/api/models/scim_source_request.rb', line 14

def name
  @name
end

#slugObject

Internal source name, used in URLs.



17
18
19
# File 'lib/authentik/api/models/scim_source_request.rb', line 17

def slug
  @slug
end

#user_path_templateObject

Returns the value of attribute user_path_template.



25
26
27
# File 'lib/authentik/api/models/scim_source_request.rb', line 25

def user_path_template
  @user_path_template
end

#user_property_mappingsObject

Returns the value of attribute user_property_mappings.



21
22
23
# File 'lib/authentik/api/models/scim_source_request.rb', line 21

def user_property_mappings
  @user_property_mappings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/authentik/api/models/scim_source_request.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/authentik/api/models/scim_source_request.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
37
# File 'lib/authentik/api/models/scim_source_request.rb', line 28

def self.attribute_map
  {
    :'name' => :'name',
    :'slug' => :'slug',
    :'enabled' => :'enabled',
    :'user_property_mappings' => :'user_property_mappings',
    :'group_property_mappings' => :'group_property_mappings',
    :'user_path_template' => :'user_path_template'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/authentik/api/models/scim_source_request.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/authentik/api/models/scim_source_request.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
59
# File 'lib/authentik/api/models/scim_source_request.rb', line 50

def self.openapi_types
  {
    :'name' => :'String',
    :'slug' => :'String',
    :'enabled' => :'Boolean',
    :'user_property_mappings' => :'Array<String>',
    :'group_property_mappings' => :'Array<String>',
    :'user_path_template' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
# File 'lib/authentik/api/models/scim_source_request.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      slug == o.slug &&
      enabled == o.enabled &&
      user_property_mappings == o.user_property_mappings &&
      group_property_mappings == o.group_property_mappings &&
      user_path_template == o.user_path_template
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/authentik/api/models/scim_source_request.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/authentik/api/models/scim_source_request.rb', line 230

def hash
  [name, slug, enabled, user_property_mappings, group_property_mappings, user_path_template].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/authentik/api/models/scim_source_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  if @slug.to_s.length < 1
    invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if !@user_path_template.nil? && @user_path_template.to_s.length < 1
    invalid_properties.push('invalid value for "user_path_template", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/authentik/api/models/scim_source_request.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



151
152
153
154
155
156
157
158
159
160
# File 'lib/authentik/api/models/scim_source_request.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @slug.nil?
  return false if @slug.to_s.length < 1
  return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if !@user_path_template.nil? && @user_path_template.to_s.length < 1
  true
end