Class: Authentik::Api::SCIMSourceUser
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::SCIMSourceUser
- Defined in:
- lib/authentik/api/models/scim_source_user.rb
Overview
SCIMSourceUser Serializer
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#source ⇒ Object
Returns the value of attribute source.
-
#user ⇒ Object
Returns the value of attribute user.
-
#user_obj ⇒ Object
Returns the value of attribute user_obj.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SCIMSourceUser
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SCIMSourceUser
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SCIMSourceUser` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SCIMSourceUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] else self.external_id = nil end if attributes.key?(:'user') self.user = attributes[:'user'] else self.user = nil end if attributes.key?(:'user_obj') self.user_obj = attributes[:'user_obj'] else self.user_obj = nil end if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
23 24 25 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 23 def attributes @attributes end |
#external_id ⇒ Object
Returns the value of attribute external_id.
15 16 17 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 15 def external_id @external_id end |
#id ⇒ Object
Returns the value of attribute id.
13 14 15 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 13 def id @id end |
#source ⇒ Object
Returns the value of attribute source.
21 22 23 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 21 def source @source end |
#user ⇒ Object
Returns the value of attribute user.
17 18 19 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 17 def user @user end |
#user_obj ⇒ Object
Returns the value of attribute user_obj.
19 20 21 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 19 def user_obj @user_obj end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 26 def self.attribute_map { :'id' => :'id', :'external_id' => :'external_id', :'user' => :'user', :'user_obj' => :'user_obj', :'source' => :'source', :'attributes' => :'attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 219 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 48 def self.openapi_types { :'id' => :'String', :'external_id' => :'String', :'user' => :'Integer', :'user_obj' => :'PartialUser', :'source' => :'String', :'attributes' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 193 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && external_id == o.external_id && user == o.user && user_obj == o.user_obj && source == o.source && attributes == o.attributes end |
#eql?(o) ⇒ Boolean
206 207 208 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 206 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 212 def hash [id, external_id, user, user_obj, source, attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @external_id.nil? invalid_properties.push('invalid value for "external_id", external_id cannot be nil.') end if @user.nil? invalid_properties.push('invalid value for "user", user cannot be nil.') end if @user_obj.nil? invalid_properties.push('invalid value for "user_obj", user_obj cannot be nil.') end if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
142 143 144 145 146 147 148 149 |
# File 'lib/authentik/api/models/scim_source_user.rb', line 142 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @external_id.nil? return false if @user.nil? return false if @user_obj.nil? return false if @source.nil? true end |