Class: Authentik::Api::SSFProviderRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::SSFProviderRequest
- Defined in:
- lib/authentik/api/models/ssf_provider_request.rb
Overview
SSFProvider Serializer
Instance Attribute Summary collapse
-
#event_retention ⇒ Object
Returns the value of attribute event_retention.
-
#name ⇒ Object
Returns the value of attribute name.
-
#oidc_auth_providers ⇒ Object
Returns the value of attribute oidc_auth_providers.
-
#signing_key ⇒ Object
Key used to sign the SSF Events.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SSFProviderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SSFProviderRequest
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SSFProviderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SSFProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'signing_key') self.signing_key = attributes[:'signing_key'] else self.signing_key = nil end if attributes.key?(:'oidc_auth_providers') if (value = attributes[:'oidc_auth_providers']).is_a?(Array) self.oidc_auth_providers = value end end if attributes.key?(:'event_retention') self.event_retention = attributes[:'event_retention'] end end |
Instance Attribute Details
#event_retention ⇒ Object
Returns the value of attribute event_retention.
20 21 22 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 20 def event_retention @event_retention end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 13 def name @name end |
#oidc_auth_providers ⇒ Object
Returns the value of attribute oidc_auth_providers.
18 19 20 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 18 def oidc_auth_providers @oidc_auth_providers end |
#signing_key ⇒ Object
Key used to sign the SSF Events.
16 17 18 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 16 def signing_key @signing_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 23 def self.attribute_map { :'name' => :'name', :'signing_key' => :'signing_key', :'oidc_auth_providers' => :'oidc_auth_providers', :'event_retention' => :'event_retention' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 196 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
53 54 55 56 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 53 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 43 def self.openapi_types { :'name' => :'String', :'signing_key' => :'String', :'oidc_auth_providers' => :'Array<Integer>', :'event_retention' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && signing_key == o.signing_key && oidc_auth_providers == o.oidc_auth_providers && event_retention == o.event_retention end |
#eql?(o) ⇒ Boolean
183 184 185 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 183 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
189 190 191 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 189 def hash [name, signing_key, oidc_auth_providers, event_retention].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 99 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @signing_key.nil? invalid_properties.push('invalid value for "signing_key", signing_key cannot be nil.') end if !@event_retention.nil? && @event_retention.to_s.length < 1 invalid_properties.push('invalid value for "event_retention", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 127 128 129 130 |
# File 'lib/authentik/api/models/ssf_provider_request.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @signing_key.nil? return false if !@event_retention.nil? && @event_retention.to_s.length < 1 true end |