Class: Authentik::Api::SSFStream

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/ssf_stream.rb

Overview

SSFStream Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SSFStream

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/authentik/api/models/ssf_stream.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SSFStream` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SSFStream`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'provider_obj')
    self.provider_obj = attributes[:'provider_obj']
  else
    self.provider_obj = nil
  end

  if attributes.key?(:'delivery_method')
    self.delivery_method = attributes[:'delivery_method']
  else
    self.delivery_method = nil
  end

  if attributes.key?(:'endpoint_url')
    self.endpoint_url = attributes[:'endpoint_url']
  end

  if attributes.key?(:'events_requested')
    if (value = attributes[:'events_requested']).is_a?(Array)
      self.events_requested = value
    end
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  else
    self.format = nil
  end

  if attributes.key?(:'aud')
    if (value = attributes[:'aud']).is_a?(Array)
      self.aud = value
    end
  end

  if attributes.key?(:'iss')
    self.iss = attributes[:'iss']
  else
    self.iss = nil
  end
end

Instance Attribute Details

#audObject

Returns the value of attribute aud.



29
30
31
# File 'lib/authentik/api/models/ssf_stream.rb', line 29

def aud
  @aud
end

#delivery_methodObject

Returns the value of attribute delivery_method.



21
22
23
# File 'lib/authentik/api/models/ssf_stream.rb', line 21

def delivery_method
  @delivery_method
end

#endpoint_urlObject

Returns the value of attribute endpoint_url.



23
24
25
# File 'lib/authentik/api/models/ssf_stream.rb', line 23

def endpoint_url
  @endpoint_url
end

#events_requestedObject

Returns the value of attribute events_requested.



25
26
27
# File 'lib/authentik/api/models/ssf_stream.rb', line 25

def events_requested
  @events_requested
end

#formatObject

Returns the value of attribute format.



27
28
29
# File 'lib/authentik/api/models/ssf_stream.rb', line 27

def format
  @format
end

#issObject

Returns the value of attribute iss.



31
32
33
# File 'lib/authentik/api/models/ssf_stream.rb', line 31

def iss
  @iss
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/ssf_stream.rb', line 13

def pk
  @pk
end

#providerObject

Returns the value of attribute provider.



17
18
19
# File 'lib/authentik/api/models/ssf_stream.rb', line 17

def provider
  @provider
end

#provider_objObject

Returns the value of attribute provider_obj.



19
20
21
# File 'lib/authentik/api/models/ssf_stream.rb', line 19

def provider_obj
  @provider_obj
end

#statusObject

Returns the value of attribute status.



15
16
17
# File 'lib/authentik/api/models/ssf_stream.rb', line 15

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/authentik/api/models/ssf_stream.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/authentik/api/models/ssf_stream.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/authentik/api/models/ssf_stream.rb', line 56

def self.attribute_map
  {
    :'pk' => :'pk',
    :'status' => :'status',
    :'provider' => :'provider',
    :'provider_obj' => :'provider_obj',
    :'delivery_method' => :'delivery_method',
    :'endpoint_url' => :'endpoint_url',
    :'events_requested' => :'events_requested',
    :'format' => :'format',
    :'aud' => :'aud',
    :'iss' => :'iss'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/authentik/api/models/ssf_stream.rb', line 314

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
# File 'lib/authentik/api/models/ssf_stream.rb', line 98

def self.openapi_nullable
  Set.new([
    :'endpoint_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/authentik/api/models/ssf_stream.rb', line 82

def self.openapi_types
  {
    :'pk' => :'String',
    :'status' => :'SSFStreamStatusEnum',
    :'provider' => :'Integer',
    :'provider_obj' => :'SSFProvider',
    :'delivery_method' => :'DeliveryMethodEnum',
    :'endpoint_url' => :'String',
    :'events_requested' => :'Array<EventsRequestedEnum>',
    :'format' => :'String',
    :'aud' => :'Array<String>',
    :'iss' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/authentik/api/models/ssf_stream.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      status == o.status &&
      provider == o.provider &&
      provider_obj == o.provider_obj &&
      delivery_method == o.delivery_method &&
      endpoint_url == o.endpoint_url &&
      events_requested == o.events_requested &&
      format == o.format &&
      aud == o.aud &&
      iss == o.iss
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/authentik/api/models/ssf_stream.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



307
308
309
# File 'lib/authentik/api/models/ssf_stream.rb', line 307

def hash
  [pk, status, provider, provider_obj, delivery_method, endpoint_url, events_requested, format, aud, iss].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/authentik/api/models/ssf_stream.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @provider_obj.nil?
    invalid_properties.push('invalid value for "provider_obj", provider_obj cannot be nil.')
  end

  if @delivery_method.nil?
    invalid_properties.push('invalid value for "delivery_method", delivery_method cannot be nil.')
  end

  if @format.nil?
    invalid_properties.push('invalid value for "format", format cannot be nil.')
  end

  if @iss.nil?
    invalid_properties.push('invalid value for "iss", iss cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/authentik/api/models/ssf_stream.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
214
215
216
217
218
219
220
# File 'lib/authentik/api/models/ssf_stream.rb', line 211

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @provider.nil?
  return false if @provider_obj.nil?
  return false if @delivery_method.nil?
  return false if @format.nil?
  return false if @iss.nil?
  true
end