Class: Authentik::Api::Schedule

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/schedule.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Schedule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/authentik/api/models/schedule.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Schedule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Schedule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'identifier')
    self.identifier = attributes[:'identifier']
  else
    self.identifier = nil
  end

  if attributes.key?(:'uid')
    self.uid = attributes[:'uid']
  else
    self.uid = nil
  end

  if attributes.key?(:'actor_name')
    self.actor_name = attributes[:'actor_name']
  else
    self.actor_name = nil
  end

  if attributes.key?(:'rel_obj_app_label')
    self.rel_obj_app_label = attributes[:'rel_obj_app_label']
  else
    self.rel_obj_app_label = nil
  end

  if attributes.key?(:'rel_obj_model')
    self.rel_obj_model = attributes[:'rel_obj_model']
  else
    self.rel_obj_model = nil
  end

  if attributes.key?(:'rel_obj_id')
    self.rel_obj_id = attributes[:'rel_obj_id']
  end

  if attributes.key?(:'crontab')
    self.crontab = attributes[:'crontab']
  else
    self.crontab = nil
  end

  if attributes.key?(:'paused')
    self.paused = attributes[:'paused']
  end

  if attributes.key?(:'next_run')
    self.next_run = attributes[:'next_run']
  else
    self.next_run = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'last_task_status')
    self.last_task_status = attributes[:'last_task_status']
  else
    self.last_task_status = nil
  end
end

Instance Attribute Details

#actor_nameObject

Dramatiq actor to call



20
21
22
# File 'lib/authentik/api/models/schedule.rb', line 20

def actor_name
  @actor_name
end

#crontabObject

When to schedule tasks



29
30
31
# File 'lib/authentik/api/models/schedule.rb', line 29

def crontab
  @crontab
end

#descriptionObject

Returns the value of attribute description.



36
37
38
# File 'lib/authentik/api/models/schedule.rb', line 36

def description
  @description
end

#idObject

Returns the value of attribute id.



12
13
14
# File 'lib/authentik/api/models/schedule.rb', line 12

def id
  @id
end

#identifierObject

Unique schedule identifier



15
16
17
# File 'lib/authentik/api/models/schedule.rb', line 15

def identifier
  @identifier
end

#last_task_statusObject

Returns the value of attribute last_task_status.



38
39
40
# File 'lib/authentik/api/models/schedule.rb', line 38

def last_task_status
  @last_task_status
end

#next_runObject

Returns the value of attribute next_run.



34
35
36
# File 'lib/authentik/api/models/schedule.rb', line 34

def next_run
  @next_run
end

#pausedObject

Pause this schedule



32
33
34
# File 'lib/authentik/api/models/schedule.rb', line 32

def paused
  @paused
end

#rel_obj_app_labelObject

Returns the value of attribute rel_obj_app_label.



22
23
24
# File 'lib/authentik/api/models/schedule.rb', line 22

def rel_obj_app_label
  @rel_obj_app_label
end

#rel_obj_idObject

Returns the value of attribute rel_obj_id.



26
27
28
# File 'lib/authentik/api/models/schedule.rb', line 26

def rel_obj_id
  @rel_obj_id
end

#rel_obj_modelObject

Returns the value of attribute rel_obj_model.



24
25
26
# File 'lib/authentik/api/models/schedule.rb', line 24

def rel_obj_model
  @rel_obj_model
end

#uidObject

Returns the value of attribute uid.



17
18
19
# File 'lib/authentik/api/models/schedule.rb', line 17

def uid
  @uid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/authentik/api/models/schedule.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/authentik/api/models/schedule.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/authentik/api/models/schedule.rb', line 63

def self.attribute_map
  {
    :'id' => :'id',
    :'identifier' => :'identifier',
    :'uid' => :'uid',
    :'actor_name' => :'actor_name',
    :'rel_obj_app_label' => :'rel_obj_app_label',
    :'rel_obj_model' => :'rel_obj_model',
    :'rel_obj_id' => :'rel_obj_id',
    :'crontab' => :'crontab',
    :'paused' => :'paused',
    :'next_run' => :'next_run',
    :'description' => :'description',
    :'last_task_status' => :'last_task_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/authentik/api/models/schedule.rb', line 357

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
113
114
115
116
# File 'lib/authentik/api/models/schedule.rb', line 109

def self.openapi_nullable
  Set.new([
    :'identifier',
    :'rel_obj_id',
    :'description',
    :'last_task_status'
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/authentik/api/models/schedule.rb', line 91

def self.openapi_types
  {
    :'id' => :'String',
    :'identifier' => :'String',
    :'uid' => :'String',
    :'actor_name' => :'String',
    :'rel_obj_app_label' => :'String',
    :'rel_obj_model' => :'String',
    :'rel_obj_id' => :'String',
    :'crontab' => :'String',
    :'paused' => :'Boolean',
    :'next_run' => :'Time',
    :'description' => :'String',
    :'last_task_status' => :'LastTaskStatusEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/authentik/api/models/schedule.rb', line 325

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      identifier == o.identifier &&
      uid == o.uid &&
      actor_name == o.actor_name &&
      rel_obj_app_label == o.rel_obj_app_label &&
      rel_obj_model == o.rel_obj_model &&
      rel_obj_id == o.rel_obj_id &&
      crontab == o.crontab &&
      paused == o.paused &&
      next_run == o.next_run &&
      description == o.description &&
      last_task_status == o.last_task_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


344
345
346
# File 'lib/authentik/api/models/schedule.rb', line 344

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



350
351
352
# File 'lib/authentik/api/models/schedule.rb', line 350

def hash
  [id, identifier, uid, actor_name, rel_obj_app_label, rel_obj_model, rel_obj_id, crontab, paused, next_run, description, last_task_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/authentik/api/models/schedule.rb', line 205

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @uid.nil?
    invalid_properties.push('invalid value for "uid", uid cannot be nil.')
  end

  if @actor_name.nil?
    invalid_properties.push('invalid value for "actor_name", actor_name cannot be nil.')
  end

  if @rel_obj_app_label.nil?
    invalid_properties.push('invalid value for "rel_obj_app_label", rel_obj_app_label cannot be nil.')
  end

  if @rel_obj_model.nil?
    invalid_properties.push('invalid value for "rel_obj_model", rel_obj_model cannot be nil.')
  end

  if @crontab.nil?
    invalid_properties.push('invalid value for "crontab", crontab cannot be nil.')
  end

  if @next_run.nil?
    invalid_properties.push('invalid value for "next_run", next_run cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/authentik/api/models/schedule.rb', line 379

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



241
242
243
244
245
246
247
248
249
250
251
# File 'lib/authentik/api/models/schedule.rb', line 241

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @uid.nil?
  return false if @actor_name.nil?
  return false if @rel_obj_app_label.nil?
  return false if @rel_obj_model.nil?
  return false if @crontab.nil?
  return false if @next_run.nil?
  true
end