Class: Authentik::Api::ScheduleRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ScheduleRequest
- Defined in:
- lib/authentik/api/models/schedule_request.rb
Instance Attribute Summary collapse
-
#crontab ⇒ Object
When to schedule tasks.
-
#paused ⇒ Object
Pause this schedule.
-
#rel_obj_id ⇒ Object
Returns the value of attribute rel_obj_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScheduleRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScheduleRequest
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/authentik/api/models/schedule_request.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ScheduleRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ScheduleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'rel_obj_id') self.rel_obj_id = attributes[:'rel_obj_id'] end if attributes.key?(:'crontab') self.crontab = attributes[:'crontab'] else self.crontab = nil end if attributes.key?(:'paused') self.paused = attributes[:'paused'] end end |
Instance Attribute Details
#crontab ⇒ Object
When to schedule tasks
15 16 17 |
# File 'lib/authentik/api/models/schedule_request.rb', line 15 def crontab @crontab end |
#paused ⇒ Object
Pause this schedule
18 19 20 |
# File 'lib/authentik/api/models/schedule_request.rb', line 18 def paused @paused end |
#rel_obj_id ⇒ Object
Returns the value of attribute rel_obj_id.
12 13 14 |
# File 'lib/authentik/api/models/schedule_request.rb', line 12 def rel_obj_id @rel_obj_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
30 31 32 |
# File 'lib/authentik/api/models/schedule_request.rb', line 30 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
35 36 37 |
# File 'lib/authentik/api/models/schedule_request.rb', line 35 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 |
# File 'lib/authentik/api/models/schedule_request.rb', line 21 def self.attribute_map { :'rel_obj_id' => :'rel_obj_id', :'crontab' => :'crontab', :'paused' => :'paused' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/authentik/api/models/schedule_request.rb', line 165 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
49 50 51 52 53 |
# File 'lib/authentik/api/models/schedule_request.rb', line 49 def self.openapi_nullable Set.new([ :'rel_obj_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 |
# File 'lib/authentik/api/models/schedule_request.rb', line 40 def self.openapi_types { :'rel_obj_id' => :'String', :'crontab' => :'String', :'paused' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 |
# File 'lib/authentik/api/models/schedule_request.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && rel_obj_id == o.rel_obj_id && crontab == o.crontab && paused == o.paused end |
#eql?(o) ⇒ Boolean
152 153 154 |
# File 'lib/authentik/api/models/schedule_request.rb', line 152 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/authentik/api/models/schedule_request.rb', line 158 def hash [rel_obj_id, crontab, paused].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/authentik/api/models/schedule_request.rb', line 88 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@rel_obj_id.nil? && @rel_obj_id.to_s.length < 1 invalid_properties.push('invalid value for "rel_obj_id", the character length must be greater than or equal to 1.') end if @crontab.nil? invalid_properties.push('invalid value for "crontab", crontab cannot be nil.') end if @crontab.to_s.length < 1 invalid_properties.push('invalid value for "crontab", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/authentik/api/models/schedule_request.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
108 109 110 111 112 113 114 |
# File 'lib/authentik/api/models/schedule_request.rb', line 108 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@rel_obj_id.nil? && @rel_obj_id.to_s.length < 1 return false if @crontab.nil? return false if @crontab.to_s.length < 1 true end |