Class: Authentik::Api::ScopeMappingRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ScopeMappingRequest
- Defined in:
- lib/authentik/api/models/scope_mapping_request.rb
Overview
ScopeMapping Serializer
Instance Attribute Summary collapse
-
#description ⇒ Object
Description shown to the user when consenting.
-
#expression ⇒ Object
Returns the value of attribute expression.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#name ⇒ Object
Returns the value of attribute name.
-
#scope_name ⇒ Object
Scope name requested by the client.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScopeMappingRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScopeMappingRequest
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ScopeMappingRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ScopeMappingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'managed') self.managed = attributes[:'managed'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'expression') self.expression = attributes[:'expression'] else self.expression = nil end if attributes.key?(:'scope_name') self.scope_name = attributes[:'scope_name'] else self.scope_name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end end |
Instance Attribute Details
#description ⇒ Object
Description shown to the user when consenting. If left empty, the user won’t be informed.
24 25 26 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 24 def description @description end |
#expression ⇒ Object
Returns the value of attribute expression.
18 19 20 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 18 def expression @expression end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
14 15 16 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 14 def managed @managed end |
#name ⇒ Object
Returns the value of attribute name.
16 17 18 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 16 def name @name end |
#scope_name ⇒ Object
Scope name requested by the client
21 22 23 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 21 def scope_name @scope_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 27 def self.attribute_map { :'managed' => :'managed', :'name' => :'name', :'expression' => :'expression', :'scope_name' => :'scope_name', :'description' => :'description' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 237 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 63 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 59 def self.openapi_nullable Set.new([ :'managed', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 48 def self.openapi_types { :'managed' => :'String', :'name' => :'String', :'expression' => :'String', :'scope_name' => :'String', :'description' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && managed == o.managed && name == o.name && expression == o.expression && scope_name == o.scope_name && description == o.description end |
#eql?(o) ⇒ Boolean
224 225 226 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 224 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
230 231 232 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 230 def hash [managed, name, expression, scope_name, description].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@managed.nil? && @managed.to_s.length < 1 invalid_properties.push('invalid value for "managed", the character length must be greater than or equal to 1.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @expression.nil? invalid_properties.push('invalid value for "expression", expression cannot be nil.') end if @expression.to_s.length < 1 invalid_properties.push('invalid value for "expression", the character length must be greater than or equal to 1.') end if @scope_name.nil? invalid_properties.push('invalid value for "scope_name", scope_name cannot be nil.') end if @scope_name.to_s.length < 1 invalid_properties.push('invalid value for "scope_name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 259 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/authentik/api/models/scope_mapping_request.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@managed.nil? && @managed.to_s.length < 1 return false if @name.nil? return false if @name.to_s.length < 1 return false if @expression.nil? return false if @expression.to_s.length < 1 return false if @scope_name.nil? return false if @scope_name.to_s.length < 1 true end |