Class: Authentik::Api::Source

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/source.rb

Overview

Source Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Source

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/authentik/api/models/source.rb', line 162

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Source` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Source`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'promoted')
    self.promoted = attributes[:'promoted']
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'enrollment_flow')
    self.enrollment_flow = attributes[:'enrollment_flow']
  end

  if attributes.key?(:'user_property_mappings')
    if (value = attributes[:'user_property_mappings']).is_a?(Array)
      self.user_property_mappings = value
    end
  end

  if attributes.key?(:'group_property_mappings')
    if (value = attributes[:'group_property_mappings']).is_a?(Array)
      self.group_property_mappings = value
    end
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'user_matching_mode')
    self.user_matching_mode = attributes[:'user_matching_mode']
  end

  if attributes.key?(:'managed')
    self.managed = attributes[:'managed']
  else
    self.managed = nil
  end

  if attributes.key?(:'user_path_template')
    self.user_path_template = attributes[:'user_path_template']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'icon_url')
    self.icon_url = attributes[:'icon_url']
  else
    self.icon_url = nil
  end

  if attributes.key?(:'icon_themed_urls')
    self.icon_themed_urls = attributes[:'icon_themed_urls']
  else
    self.icon_themed_urls = nil
  end
end

Instance Attribute Details

#authentication_flowObject

Flow to use when authenticating existing users.



27
28
29
# File 'lib/authentik/api/models/source.rb', line 27

def authentication_flow
  @authentication_flow
end

#componentObject

Get object component so that we know how to edit the object



37
38
39
# File 'lib/authentik/api/models/source.rb', line 37

def component
  @component
end

#enabledObject

Returns the value of attribute enabled.



21
22
23
# File 'lib/authentik/api/models/source.rb', line 21

def enabled
  @enabled
end

#enrollment_flowObject

Flow to use when enrolling new users.



30
31
32
# File 'lib/authentik/api/models/source.rb', line 30

def enrollment_flow
  @enrollment_flow
end

#group_property_mappingsObject

Returns the value of attribute group_property_mappings.



34
35
36
# File 'lib/authentik/api/models/source.rb', line 34

def group_property_mappings
  @group_property_mappings
end

#iconObject

Returns the value of attribute icon.



58
59
60
# File 'lib/authentik/api/models/source.rb', line 58

def icon
  @icon
end

#icon_themed_urlsObject

Returns the value of attribute icon_themed_urls.



63
64
65
# File 'lib/authentik/api/models/source.rb', line 63

def icon_themed_urls
  @icon_themed_urls
end

#icon_urlObject

Get the URL to the source icon



61
62
63
# File 'lib/authentik/api/models/source.rb', line 61

def icon_url
  @icon_url
end

#managedObject

Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.



54
55
56
# File 'lib/authentik/api/models/source.rb', line 54

def managed
  @managed
end

#meta_model_nameObject

Return internal model name



46
47
48
# File 'lib/authentik/api/models/source.rb', line 46

def meta_model_name
  @meta_model_name
end

#nameObject

Source’s display Name.



16
17
18
# File 'lib/authentik/api/models/source.rb', line 16

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/source.rb', line 13

def pk
  @pk
end

#policy_engine_modeObject

Returns the value of attribute policy_engine_mode.



48
49
50
# File 'lib/authentik/api/models/source.rb', line 48

def policy_engine_mode
  @policy_engine_mode
end

When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.



24
25
26
# File 'lib/authentik/api/models/source.rb', line 24

def promoted
  @promoted
end

#slugObject

Internal source name, used in URLs.



19
20
21
# File 'lib/authentik/api/models/source.rb', line 19

def slug
  @slug
end

#user_matching_modeObject

How the source determines if an existing user should be authenticated or a new user enrolled.



51
52
53
# File 'lib/authentik/api/models/source.rb', line 51

def user_matching_mode
  @user_matching_mode
end

#user_path_templateObject

Returns the value of attribute user_path_template.



56
57
58
# File 'lib/authentik/api/models/source.rb', line 56

def user_path_template
  @user_path_template
end

#user_property_mappingsObject

Returns the value of attribute user_property_mappings.



32
33
34
# File 'lib/authentik/api/models/source.rb', line 32

def user_property_mappings
  @user_property_mappings
end

#verbose_nameObject

Return object’s verbose_name



40
41
42
# File 'lib/authentik/api/models/source.rb', line 40

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



43
44
45
# File 'lib/authentik/api/models/source.rb', line 43

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



114
115
116
# File 'lib/authentik/api/models/source.rb', line 114

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/authentik/api/models/source.rb', line 119

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/authentik/api/models/source.rb', line 88

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'slug' => :'slug',
    :'enabled' => :'enabled',
    :'promoted' => :'promoted',
    :'authentication_flow' => :'authentication_flow',
    :'enrollment_flow' => :'enrollment_flow',
    :'user_property_mappings' => :'user_property_mappings',
    :'group_property_mappings' => :'group_property_mappings',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'user_matching_mode' => :'user_matching_mode',
    :'managed' => :'managed',
    :'user_path_template' => :'user_path_template',
    :'icon' => :'icon',
    :'icon_url' => :'icon_url',
    :'icon_themed_urls' => :'icon_themed_urls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/authentik/api/models/source.rb', line 454

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



150
151
152
153
154
155
156
157
158
# File 'lib/authentik/api/models/source.rb', line 150

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
    :'enrollment_flow',
    :'managed',
    :'icon_url',
    :'icon_themed_urls'
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/authentik/api/models/source.rb', line 124

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'slug' => :'String',
    :'enabled' => :'Boolean',
    :'promoted' => :'Boolean',
    :'authentication_flow' => :'String',
    :'enrollment_flow' => :'String',
    :'user_property_mappings' => :'Array<String>',
    :'group_property_mappings' => :'Array<String>',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'user_matching_mode' => :'UserMatchingModeEnum',
    :'managed' => :'String',
    :'user_path_template' => :'String',
    :'icon' => :'String',
    :'icon_url' => :'String',
    :'icon_themed_urls' => :'ThemedUrls'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/authentik/api/models/source.rb', line 414

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      slug == o.slug &&
      enabled == o.enabled &&
      promoted == o.promoted &&
      authentication_flow == o.authentication_flow &&
      enrollment_flow == o.enrollment_flow &&
      user_property_mappings == o.user_property_mappings &&
      group_property_mappings == o.group_property_mappings &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      policy_engine_mode == o.policy_engine_mode &&
      user_matching_mode == o.user_matching_mode &&
      managed == o.managed &&
      user_path_template == o.user_path_template &&
      icon == o.icon &&
      icon_url == o.icon_url &&
      icon_themed_urls == o.icon_themed_urls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


441
442
443
# File 'lib/authentik/api/models/source.rb', line 441

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



447
448
449
# File 'lib/authentik/api/models/source.rb', line 447

def hash
  [pk, name, slug, enabled, promoted, authentication_flow, enrollment_flow, user_property_mappings, group_property_mappings, component, verbose_name, verbose_name_plural, meta_model_name, policy_engine_mode, user_matching_mode, managed, user_path_template, icon, icon_url, icon_themed_urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/authentik/api/models/source.rb', line 283

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/authentik/api/models/source.rb', line 476

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/authentik/api/models/source.rb', line 324

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @slug.nil?
  return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  true
end