Class: Authentik::Api::SourceStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::SourceStageRequest
- Defined in:
- lib/authentik/api/models/source_stage_request.rb
Overview
SourceStage Serializer
Instance Attribute Summary collapse
-
#name ⇒ Object
Returns the value of attribute name.
-
#resume_timeout ⇒ Object
Amount of time a user can take to return from the source to continue the flow (Format: hours=-1;minutes=-2;seconds=-3).
-
#source ⇒ Object
Returns the value of attribute source.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SourceStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SourceStageRequest
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 56 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SourceStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SourceStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'resume_timeout') self.resume_timeout = attributes[:'resume_timeout'] end end |
Instance Attribute Details
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 13 def name @name end |
#resume_timeout ⇒ Object
Amount of time a user can take to return from the source to continue the flow (Format: hours=-1;minutes=-2;seconds=-3)
18 19 20 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 18 def resume_timeout @resume_timeout end |
#source ⇒ Object
Returns the value of attribute source.
15 16 17 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 15 def source @source end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
30 31 32 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 30 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
35 36 37 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 35 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 21 def self.attribute_map { :'name' => :'name', :'source' => :'source', :'resume_timeout' => :'resume_timeout' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 185 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
49 50 51 52 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 49 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
40 41 42 43 44 45 46 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 40 def self.openapi_types { :'name' => :'String', :'source' => :'String', :'resume_timeout' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && source == o.source && resume_timeout == o.resume_timeout end |
#eql?(o) ⇒ Boolean
172 173 174 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 172 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 178 def hash [name, source, resume_timeout].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 89 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end if !@resume_timeout.nil? && @resume_timeout.to_s.length < 1 invalid_properties.push('invalid value for "resume_timeout", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 207 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 116 117 118 119 120 |
# File 'lib/authentik/api/models/source_stage_request.rb', line 113 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @source.nil? return false if !@resume_timeout.nil? && @resume_timeout.to_s.length < 1 true end |