Class: Authentik::Api::SourceType

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/source_type.rb

Overview

Serializer for SourceType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SourceType

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/authentik/api/models/source_type.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SourceType` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SourceType`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'urls_customizable')
    self.urls_customizable = attributes[:'urls_customizable']
  else
    self.urls_customizable = nil
  end

  if attributes.key?(:'request_token_url')
    self.request_token_url = attributes[:'request_token_url']
  else
    self.request_token_url = nil
  end

  if attributes.key?(:'authorization_url')
    self.authorization_url = attributes[:'authorization_url']
  else
    self.authorization_url = nil
  end

  if attributes.key?(:'access_token_url')
    self.access_token_url = attributes[:'access_token_url']
  else
    self.access_token_url = nil
  end

  if attributes.key?(:'profile_url')
    self.profile_url = attributes[:'profile_url']
  else
    self.profile_url = nil
  end

  if attributes.key?(:'oidc_well_known_url')
    self.oidc_well_known_url = attributes[:'oidc_well_known_url']
  else
    self.oidc_well_known_url = nil
  end

  if attributes.key?(:'oidc_jwks_url')
    self.oidc_jwks_url = attributes[:'oidc_jwks_url']
  else
    self.oidc_jwks_url = nil
  end
end

Instance Attribute Details

#access_token_urlObject

Returns the value of attribute access_token_url.



23
24
25
# File 'lib/authentik/api/models/source_type.rb', line 23

def access_token_url
  @access_token_url
end

#authorization_urlObject

Returns the value of attribute authorization_url.



21
22
23
# File 'lib/authentik/api/models/source_type.rb', line 21

def authorization_url
  @authorization_url
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/source_type.rb', line 13

def name
  @name
end

#oidc_jwks_urlObject

Returns the value of attribute oidc_jwks_url.



29
30
31
# File 'lib/authentik/api/models/source_type.rb', line 29

def oidc_jwks_url
  @oidc_jwks_url
end

#oidc_well_known_urlObject

Returns the value of attribute oidc_well_known_url.



27
28
29
# File 'lib/authentik/api/models/source_type.rb', line 27

def oidc_well_known_url
  @oidc_well_known_url
end

#profile_urlObject

Returns the value of attribute profile_url.



25
26
27
# File 'lib/authentik/api/models/source_type.rb', line 25

def profile_url
  @profile_url
end

#request_token_urlObject

Returns the value of attribute request_token_url.



19
20
21
# File 'lib/authentik/api/models/source_type.rb', line 19

def request_token_url
  @request_token_url
end

#urls_customizableObject

Returns the value of attribute urls_customizable.



17
18
19
# File 'lib/authentik/api/models/source_type.rb', line 17

def urls_customizable
  @urls_customizable
end

#verbose_nameObject

Returns the value of attribute verbose_name.



15
16
17
# File 'lib/authentik/api/models/source_type.rb', line 15

def verbose_name
  @verbose_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/authentik/api/models/source_type.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/authentik/api/models/source_type.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/authentik/api/models/source_type.rb', line 32

def self.attribute_map
  {
    :'name' => :'name',
    :'verbose_name' => :'verbose_name',
    :'urls_customizable' => :'urls_customizable',
    :'request_token_url' => :'request_token_url',
    :'authorization_url' => :'authorization_url',
    :'access_token_url' => :'access_token_url',
    :'profile_url' => :'profile_url',
    :'oidc_well_known_url' => :'oidc_well_known_url',
    :'oidc_jwks_url' => :'oidc_jwks_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/authentik/api/models/source_type.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
77
78
79
80
81
# File 'lib/authentik/api/models/source_type.rb', line 72

def self.openapi_nullable
  Set.new([
    :'request_token_url',
    :'authorization_url',
    :'access_token_url',
    :'profile_url',
    :'oidc_well_known_url',
    :'oidc_jwks_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/authentik/api/models/source_type.rb', line 57

def self.openapi_types
  {
    :'name' => :'String',
    :'verbose_name' => :'String',
    :'urls_customizable' => :'Boolean',
    :'request_token_url' => :'String',
    :'authorization_url' => :'String',
    :'access_token_url' => :'String',
    :'profile_url' => :'String',
    :'oidc_well_known_url' => :'String',
    :'oidc_jwks_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/authentik/api/models/source_type.rb', line 216

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      verbose_name == o.verbose_name &&
      urls_customizable == o.urls_customizable &&
      request_token_url == o.request_token_url &&
      authorization_url == o.authorization_url &&
      access_token_url == o.access_token_url &&
      profile_url == o.profile_url &&
      oidc_well_known_url == o.oidc_well_known_url &&
      oidc_jwks_url == o.oidc_jwks_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/authentik/api/models/source_type.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/authentik/api/models/source_type.rb', line 238

def hash
  [name, verbose_name, urls_customizable, request_token_url, authorization_url, access_token_url, profile_url, oidc_well_known_url, oidc_jwks_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/authentik/api/models/source_type.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @urls_customizable.nil?
    invalid_properties.push('invalid value for "urls_customizable", urls_customizable cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/authentik/api/models/source_type.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
# File 'lib/authentik/api/models/source_type.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @verbose_name.nil?
  return false if @urls_customizable.nil?
  true
end