Class: Authentik::Api::StagePrompt

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/stage_prompt.rb

Overview

Serializer for a single Prompt field

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StagePrompt

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/authentik/api/models/stage_prompt.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::StagePrompt` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::StagePrompt`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'field_key')
    self.field_key = attributes[:'field_key']
  else
    self.field_key = nil
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  else
    self.label = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  else
    self.required = nil
  end

  if attributes.key?(:'placeholder')
    self.placeholder = attributes[:'placeholder']
  else
    self.placeholder = nil
  end

  if attributes.key?(:'initial_value')
    self.initial_value = attributes[:'initial_value']
  else
    self.initial_value = nil
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  else
    self.order = nil
  end

  if attributes.key?(:'sub_text')
    self.sub_text = attributes[:'sub_text']
  else
    self.sub_text = nil
  end

  if attributes.key?(:'choices')
    if (value = attributes[:'choices']).is_a?(Array)
      self.choices = value
    end
  else
    self.choices = nil
  end
end

Instance Attribute Details

#choicesObject

Returns the value of attribute choices.



29
30
31
# File 'lib/authentik/api/models/stage_prompt.rb', line 29

def choices
  @choices
end

#field_keyObject

Returns the value of attribute field_key.



13
14
15
# File 'lib/authentik/api/models/stage_prompt.rb', line 13

def field_key
  @field_key
end

#initial_valueObject

Returns the value of attribute initial_value.



23
24
25
# File 'lib/authentik/api/models/stage_prompt.rb', line 23

def initial_value
  @initial_value
end

#labelObject

Returns the value of attribute label.



15
16
17
# File 'lib/authentik/api/models/stage_prompt.rb', line 15

def label
  @label
end

#orderObject

Returns the value of attribute order.



25
26
27
# File 'lib/authentik/api/models/stage_prompt.rb', line 25

def order
  @order
end

#placeholderObject

Returns the value of attribute placeholder.



21
22
23
# File 'lib/authentik/api/models/stage_prompt.rb', line 21

def placeholder
  @placeholder
end

#requiredObject

Returns the value of attribute required.



19
20
21
# File 'lib/authentik/api/models/stage_prompt.rb', line 19

def required
  @required
end

#sub_textObject

Returns the value of attribute sub_text.



27
28
29
# File 'lib/authentik/api/models/stage_prompt.rb', line 27

def sub_text
  @sub_text
end

#typeObject

Returns the value of attribute type.



17
18
19
# File 'lib/authentik/api/models/stage_prompt.rb', line 17

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/authentik/api/models/stage_prompt.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/authentik/api/models/stage_prompt.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/authentik/api/models/stage_prompt.rb', line 54

def self.attribute_map
  {
    :'field_key' => :'field_key',
    :'label' => :'label',
    :'type' => :'type',
    :'required' => :'required',
    :'placeholder' => :'placeholder',
    :'initial_value' => :'initial_value',
    :'order' => :'order',
    :'sub_text' => :'sub_text',
    :'choices' => :'choices'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/authentik/api/models/stage_prompt.rb', line 339

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
# File 'lib/authentik/api/models/stage_prompt.rb', line 94

def self.openapi_nullable
  Set.new([
    :'choices'
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/authentik/api/models/stage_prompt.rb', line 79

def self.openapi_types
  {
    :'field_key' => :'String',
    :'label' => :'String',
    :'type' => :'PromptTypeEnum',
    :'required' => :'Boolean',
    :'placeholder' => :'String',
    :'initial_value' => :'String',
    :'order' => :'Integer',
    :'sub_text' => :'String',
    :'choices' => :'Array<PromptChoice>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/authentik/api/models/stage_prompt.rb', line 310

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      field_key == o.field_key &&
      label == o.label &&
      type == o.type &&
      required == o.required &&
      placeholder == o.placeholder &&
      initial_value == o.initial_value &&
      order == o.order &&
      sub_text == o.sub_text &&
      choices == o.choices
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


326
327
328
# File 'lib/authentik/api/models/stage_prompt.rb', line 326

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



332
333
334
# File 'lib/authentik/api/models/stage_prompt.rb', line 332

def hash
  [field_key, label, type, required, placeholder, initial_value, order, sub_text, choices].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/authentik/api/models/stage_prompt.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @field_key.nil?
    invalid_properties.push('invalid value for "field_key", field_key cannot be nil.')
  end

  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @required.nil?
    invalid_properties.push('invalid value for "required", required cannot be nil.')
  end

  if @placeholder.nil?
    invalid_properties.push('invalid value for "placeholder", placeholder cannot be nil.')
  end

  if @initial_value.nil?
    invalid_properties.push('invalid value for "initial_value", initial_value cannot be nil.')
  end

  if @order.nil?
    invalid_properties.push('invalid value for "order", order cannot be nil.')
  end

  if @sub_text.nil?
    invalid_properties.push('invalid value for "sub_text", sub_text cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/authentik/api/models/stage_prompt.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/authentik/api/models/stage_prompt.rb', line 215

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @field_key.nil?
  return false if @label.nil?
  return false if @type.nil?
  return false if @required.nil?
  return false if @placeholder.nil?
  return false if @initial_value.nil?
  return false if @order.nil?
  return false if @sub_text.nil?
  true
end