Class: Authentik::Api::SyncObjectResult
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::SyncObjectResult
- Defined in:
- lib/authentik/api/models/sync_object_result.rb
Overview
Result of a single object sync
Instance Attribute Summary collapse
-
#messages ⇒ Object
Returns the value of attribute messages.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SyncObjectResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SyncObjectResult
Initializes the object
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 47 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SyncObjectResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SyncObjectResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'messages') if (value = attributes[:'messages']).is_a?(Array) self. = value end else self. = nil end end |
Instance Attribute Details
#messages ⇒ Object
Returns the value of attribute messages.
13 14 15 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 13 def @messages end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
23 24 25 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 23 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
28 29 30 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 28 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
16 17 18 19 20 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 16 def self.attribute_map { :'messages' => :'messages' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 123 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
40 41 42 43 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 40 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
33 34 35 36 37 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 33 def self.openapi_types { :'messages' => :'Array<LogEvent>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
102 103 104 105 106 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 102 def ==(o) return true if self.equal?(o) self.class == o.class && == o. end |
#eql?(o) ⇒ Boolean
110 111 112 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 110 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 116 def hash [].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
72 73 74 75 76 77 78 79 80 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 72 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @messages.nil? invalid_properties.push('invalid value for "messages", messages cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 145 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
84 85 86 87 88 |
# File 'lib/authentik/api/models/sync_object_result.rb', line 84 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @messages.nil? true end |