Class: Authentik::Api::SyncStatus

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/sync_status.rb

Overview

Provider/source sync status

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SyncStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/authentik/api/models/sync_status.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SyncStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SyncStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'is_running')
    self.is_running = attributes[:'is_running']
  else
    self.is_running = nil
  end

  if attributes.key?(:'last_successful_sync')
    self.last_successful_sync = attributes[:'last_successful_sync']
  end

  if attributes.key?(:'last_sync_status')
    self.last_sync_status = attributes[:'last_sync_status']
  end
end

Instance Attribute Details

#is_runningObject

Returns the value of attribute is_running.



13
14
15
# File 'lib/authentik/api/models/sync_status.rb', line 13

def is_running
  @is_running
end

#last_successful_syncObject

Returns the value of attribute last_successful_sync.



15
16
17
# File 'lib/authentik/api/models/sync_status.rb', line 15

def last_successful_sync
  @last_successful_sync
end

#last_sync_statusObject

Returns the value of attribute last_sync_status.



17
18
19
# File 'lib/authentik/api/models/sync_status.rb', line 17

def last_sync_status
  @last_sync_status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/authentik/api/models/sync_status.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/authentik/api/models/sync_status.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
# File 'lib/authentik/api/models/sync_status.rb', line 42

def self.attribute_map
  {
    :'is_running' => :'is_running',
    :'last_successful_sync' => :'last_successful_sync',
    :'last_sync_status' => :'last_sync_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/authentik/api/models/sync_status.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/authentik/api/models/sync_status.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
# File 'lib/authentik/api/models/sync_status.rb', line 61

def self.openapi_types
  {
    :'is_running' => :'Boolean',
    :'last_successful_sync' => :'Time',
    :'last_sync_status' => :'TaskAggregatedStatusEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



138
139
140
141
142
143
144
# File 'lib/authentik/api/models/sync_status.rb', line 138

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      is_running == o.is_running &&
      last_successful_sync == o.last_successful_sync &&
      last_sync_status == o.last_sync_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/authentik/api/models/sync_status.rb', line 148

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/authentik/api/models/sync_status.rb', line 154

def hash
  [is_running, last_successful_sync, last_sync_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
# File 'lib/authentik/api/models/sync_status.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @is_running.nil?
    invalid_properties.push('invalid value for "is_running", is_running cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/authentik/api/models/sync_status.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



120
121
122
123
124
# File 'lib/authentik/api/models/sync_status.rb', line 120

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @is_running.nil?
  true
end