Class: Authentik::Api::SystemInfo

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/system_info.rb

Overview

Get system information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SystemInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/authentik/api/models/system_info.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SystemInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SystemInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'http_headers')
    if (value = attributes[:'http_headers']).is_a?(Hash)
      self.http_headers = value
    end
  else
    self.http_headers = nil
  end

  if attributes.key?(:'http_host')
    self.http_host = attributes[:'http_host']
  else
    self.http_host = nil
  end

  if attributes.key?(:'http_is_secure')
    self.http_is_secure = attributes[:'http_is_secure']
  else
    self.http_is_secure = nil
  end

  if attributes.key?(:'runtime')
    self.runtime = attributes[:'runtime']
  else
    self.runtime = nil
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  else
    self.brand = nil
  end

  if attributes.key?(:'server_time')
    self.server_time = attributes[:'server_time']
  else
    self.server_time = nil
  end

  if attributes.key?(:'embedded_outpost_disabled')
    self.embedded_outpost_disabled = attributes[:'embedded_outpost_disabled']
  else
    self.embedded_outpost_disabled = nil
  end

  if attributes.key?(:'embedded_outpost_host')
    self.embedded_outpost_host = attributes[:'embedded_outpost_host']
  else
    self.embedded_outpost_host = nil
  end
end

Instance Attribute Details

#brandObject

Currently active brand



25
26
27
# File 'lib/authentik/api/models/system_info.rb', line 25

def brand
  @brand
end

#embedded_outpost_disabledObject

Whether the embedded outpost is disabled



31
32
33
# File 'lib/authentik/api/models/system_info.rb', line 31

def embedded_outpost_disabled
  @embedded_outpost_disabled
end

#embedded_outpost_hostObject

Get the FQDN configured on the embedded outpost



34
35
36
# File 'lib/authentik/api/models/system_info.rb', line 34

def embedded_outpost_host
  @embedded_outpost_host
end

#http_headersObject

Get HTTP Request headers



14
15
16
# File 'lib/authentik/api/models/system_info.rb', line 14

def http_headers
  @http_headers
end

#http_hostObject

Get HTTP host



17
18
19
# File 'lib/authentik/api/models/system_info.rb', line 17

def http_host
  @http_host
end

#http_is_secureObject

Get HTTP Secure flag



20
21
22
# File 'lib/authentik/api/models/system_info.rb', line 20

def http_is_secure
  @http_is_secure
end

#runtimeObject

Returns the value of attribute runtime.



22
23
24
# File 'lib/authentik/api/models/system_info.rb', line 22

def runtime
  @runtime
end

#server_timeObject

Current server time



28
29
30
# File 'lib/authentik/api/models/system_info.rb', line 28

def server_time
  @server_time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/authentik/api/models/system_info.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/authentik/api/models/system_info.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/authentik/api/models/system_info.rb', line 37

def self.attribute_map
  {
    :'http_headers' => :'http_headers',
    :'http_host' => :'http_host',
    :'http_is_secure' => :'http_is_secure',
    :'runtime' => :'runtime',
    :'brand' => :'brand',
    :'server_time' => :'server_time',
    :'embedded_outpost_disabled' => :'embedded_outpost_disabled',
    :'embedded_outpost_host' => :'embedded_outpost_host'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/authentik/api/models/system_info.rb', line 312

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
# File 'lib/authentik/api/models/system_info.rb', line 75

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/authentik/api/models/system_info.rb', line 61

def self.openapi_types
  {
    :'http_headers' => :'Hash<String, String>',
    :'http_host' => :'String',
    :'http_is_secure' => :'Boolean',
    :'runtime' => :'SystemInfoRuntime',
    :'brand' => :'String',
    :'server_time' => :'Time',
    :'embedded_outpost_disabled' => :'Boolean',
    :'embedded_outpost_host' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/authentik/api/models/system_info.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      http_headers == o.http_headers &&
      http_host == o.http_host &&
      http_is_secure == o.http_is_secure &&
      runtime == o.runtime &&
      brand == o.brand &&
      server_time == o.server_time &&
      embedded_outpost_disabled == o.embedded_outpost_disabled &&
      embedded_outpost_host == o.embedded_outpost_host
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


299
300
301
# File 'lib/authentik/api/models/system_info.rb', line 299

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



305
306
307
# File 'lib/authentik/api/models/system_info.rb', line 305

def hash
  [http_headers, http_host, http_is_secure, runtime, brand, server_time, embedded_outpost_disabled, embedded_outpost_host].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/authentik/api/models/system_info.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @http_headers.nil?
    invalid_properties.push('invalid value for "http_headers", http_headers cannot be nil.')
  end

  if @http_host.nil?
    invalid_properties.push('invalid value for "http_host", http_host cannot be nil.')
  end

  if @http_is_secure.nil?
    invalid_properties.push('invalid value for "http_is_secure", http_is_secure cannot be nil.')
  end

  if @runtime.nil?
    invalid_properties.push('invalid value for "runtime", runtime cannot be nil.')
  end

  if @brand.nil?
    invalid_properties.push('invalid value for "brand", brand cannot be nil.')
  end

  if @server_time.nil?
    invalid_properties.push('invalid value for "server_time", server_time cannot be nil.')
  end

  if @embedded_outpost_disabled.nil?
    invalid_properties.push('invalid value for "embedded_outpost_disabled", embedded_outpost_disabled cannot be nil.')
  end

  if @embedded_outpost_host.nil?
    invalid_properties.push('invalid value for "embedded_outpost_host", embedded_outpost_host cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/authentik/api/models/system_info.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/authentik/api/models/system_info.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @http_headers.nil?
  return false if @http_host.nil?
  return false if @http_is_secure.nil?
  return false if @runtime.nil?
  return false if @brand.nil?
  return false if @server_time.nil?
  return false if @embedded_outpost_disabled.nil?
  return false if @embedded_outpost_host.nil?
  true
end