Class: Authentik::Api::TasksApi

Inherits:
Object
  • Object
show all
Defined in:
lib/authentik/api/api/tasks_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TasksApi

Returns a new instance of TasksApi.



13
14
15
# File 'lib/authentik/api/api/tasks_api.rb', line 13

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



11
12
13
# File 'lib/authentik/api/api/tasks_api.rb', line 11

def api_client
  @api_client
end

Instance Method Details

#tasks_schedules_list(opts = {}) ⇒ PaginatedScheduleList

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :actor_name (String)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :paused (Boolean)
  • :rel_obj_content_type__app_label (String)
  • :rel_obj_content_type__model (String)
  • :rel_obj_id (String)
  • :rel_obj_id__isnull (Boolean)
  • :search (String)

    A search term.

Returns:



28
29
30
31
# File 'lib/authentik/api/api/tasks_api.rb', line 28

def tasks_schedules_list(opts = {})
  data, _status_code, _headers = tasks_schedules_list_with_http_info(opts)
  data
end

#tasks_schedules_list_with_http_info(opts = {}) ⇒ Array<(PaginatedScheduleList, Integer, Hash)>

Returns PaginatedScheduleList data, response status code and response headers.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :actor_name (String)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :paused (Boolean)
  • :rel_obj_content_type__app_label (String)
  • :rel_obj_content_type__model (String)
  • :rel_obj_id (String)
  • :rel_obj_id__isnull (Boolean)
  • :search (String)

    A search term.

Returns:

  • (Array<(PaginatedScheduleList, Integer, Hash)>)

    PaginatedScheduleList data, response status code and response headers



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/authentik/api/api/tasks_api.rb', line 45

def tasks_schedules_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_schedules_list ...'
  end
  # resource path
  local_var_path = '/tasks/schedules/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'actor_name'] = opts[:'actor_name'] if !opts[:'actor_name'].nil?
  query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'paused'] = opts[:'paused'] if !opts[:'paused'].nil?
  query_params[:'rel_obj_content_type__app_label'] = opts[:'rel_obj_content_type__app_label'] if !opts[:'rel_obj_content_type__app_label'].nil?
  query_params[:'rel_obj_content_type__model'] = opts[:'rel_obj_content_type__model'] if !opts[:'rel_obj_content_type__model'].nil?
  query_params[:'rel_obj_id'] = opts[:'rel_obj_id'] if !opts[:'rel_obj_id'].nil?
  query_params[:'rel_obj_id__isnull'] = opts[:'rel_obj_id__isnull'] if !opts[:'rel_obj_id__isnull'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedScheduleList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_schedules_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_schedules_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_schedules_partial_update(id, opts = {}) ⇒ Schedule

Parameters:

  • id (String)

    A UUID string identifying this Schedule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



103
104
105
106
# File 'lib/authentik/api/api/tasks_api.rb', line 103

def tasks_schedules_partial_update(id, opts = {})
  data, _status_code, _headers = tasks_schedules_partial_update_with_http_info(id, opts)
  data
end

#tasks_schedules_partial_update_with_http_info(id, opts = {}) ⇒ Array<(Schedule, Integer, Hash)>

Returns Schedule data, response status code and response headers.

Parameters:

  • id (String)

    A UUID string identifying this Schedule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(Schedule, Integer, Hash)>)

    Schedule data, response status code and response headers



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/authentik/api/api/tasks_api.rb', line 112

def tasks_schedules_partial_update_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_schedules_partial_update ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling TasksApi.tasks_schedules_partial_update"
  end
  # resource path
  local_var_path = '/tasks/schedules/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_schedule_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'Schedule'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_schedules_partial_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_schedules_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_schedules_retrieve(id, opts = {}) ⇒ Schedule

Parameters:

  • id (String)

    A UUID string identifying this Schedule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



168
169
170
171
# File 'lib/authentik/api/api/tasks_api.rb', line 168

def tasks_schedules_retrieve(id, opts = {})
  data, _status_code, _headers = tasks_schedules_retrieve_with_http_info(id, opts)
  data
end

#tasks_schedules_retrieve_with_http_info(id, opts = {}) ⇒ Array<(Schedule, Integer, Hash)>

Returns Schedule data, response status code and response headers.

Parameters:

  • id (String)

    A UUID string identifying this Schedule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Schedule, Integer, Hash)>)

    Schedule data, response status code and response headers



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/authentik/api/api/tasks_api.rb', line 176

def tasks_schedules_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_schedules_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling TasksApi.tasks_schedules_retrieve"
  end
  # resource path
  local_var_path = '/tasks/schedules/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Schedule'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_schedules_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_schedules_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_schedules_send_create(id, opts = {}) ⇒ nil

Trigger this schedule now

Parameters:

  • id (String)

    A UUID string identifying this Schedule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


228
229
230
231
# File 'lib/authentik/api/api/tasks_api.rb', line 228

def tasks_schedules_send_create(id, opts = {})
  tasks_schedules_send_create_with_http_info(id, opts)
  nil
end

#tasks_schedules_send_create_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Trigger this schedule now

Parameters:

  • id (String)

    A UUID string identifying this Schedule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/authentik/api/api/tasks_api.rb', line 237

def tasks_schedules_send_create_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_schedules_send_create ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling TasksApi.tasks_schedules_send_create"
  end
  # resource path
  local_var_path = '/tasks/schedules/{id}/send/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_schedules_send_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_schedules_send_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_schedules_update(id, schedule_request, opts = {}) ⇒ Schedule

Parameters:

  • id (String)

    A UUID string identifying this Schedule.

  • schedule_request (ScheduleRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



289
290
291
292
# File 'lib/authentik/api/api/tasks_api.rb', line 289

def tasks_schedules_update(id, schedule_request, opts = {})
  data, _status_code, _headers = tasks_schedules_update_with_http_info(id, schedule_request, opts)
  data
end

#tasks_schedules_update_with_http_info(id, schedule_request, opts = {}) ⇒ Array<(Schedule, Integer, Hash)>

Returns Schedule data, response status code and response headers.

Parameters:

  • id (String)

    A UUID string identifying this Schedule.

  • schedule_request (ScheduleRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Schedule, Integer, Hash)>)

    Schedule data, response status code and response headers



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/authentik/api/api/tasks_api.rb', line 298

def tasks_schedules_update_with_http_info(id, schedule_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_schedules_update ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling TasksApi.tasks_schedules_update"
  end
  # verify the required parameter 'schedule_request' is set
  if @api_client.config.client_side_validation && schedule_request.nil?
    fail ArgumentError, "Missing the required parameter 'schedule_request' when calling TasksApi.tasks_schedules_update"
  end
  # resource path
  local_var_path = '/tasks/schedules/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(schedule_request)

  # return_type
  return_type = opts[:debug_return_type] || 'Schedule'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_schedules_update",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_schedules_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_tasks_list(opts = {}) ⇒ PaginatedTaskList

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :actor_name (String)
  • :aggregated_status (Array<TaskAggregatedStatusEnum>)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :queue_name (String)
  • :rel_obj_content_type__app_label (String)
  • :rel_obj_content_type__model (String)
  • :rel_obj_id (String)
  • :rel_obj_id__isnull (Boolean)
  • :search (String)

    A search term.

  • :state (TaskStatusEnum)

Returns:



369
370
371
372
# File 'lib/authentik/api/api/tasks_api.rb', line 369

def tasks_tasks_list(opts = {})
  data, _status_code, _headers = tasks_tasks_list_with_http_info(opts)
  data
end

#tasks_tasks_list_with_http_info(opts = {}) ⇒ Array<(PaginatedTaskList, Integer, Hash)>

Returns PaginatedTaskList data, response status code and response headers.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :actor_name (String)
  • :aggregated_status (Array<TaskAggregatedStatusEnum>)
  • :ordering (String)

    Which field to use when ordering the results.

  • :page (Integer)

    A page number within the paginated result set.

  • :page_size (Integer)

    Number of results to return per page.

  • :queue_name (String)
  • :rel_obj_content_type__app_label (String)
  • :rel_obj_content_type__model (String)
  • :rel_obj_id (String)
  • :rel_obj_id__isnull (Boolean)
  • :search (String)

    A search term.

  • :state (TaskStatusEnum)

Returns:

  • (Array<(PaginatedTaskList, Integer, Hash)>)

    PaginatedTaskList data, response status code and response headers



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/authentik/api/api/tasks_api.rb', line 388

def tasks_tasks_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_tasks_list ...'
  end
  # resource path
  local_var_path = '/tasks/tasks/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'actor_name'] = opts[:'actor_name'] if !opts[:'actor_name'].nil?
  query_params[:'aggregated_status'] = @api_client.build_collection_param(opts[:'aggregated_status'], :multi) if !opts[:'aggregated_status'].nil?
  query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'queue_name'] = opts[:'queue_name'] if !opts[:'queue_name'].nil?
  query_params[:'rel_obj_content_type__app_label'] = opts[:'rel_obj_content_type__app_label'] if !opts[:'rel_obj_content_type__app_label'].nil?
  query_params[:'rel_obj_content_type__model'] = opts[:'rel_obj_content_type__model'] if !opts[:'rel_obj_content_type__model'].nil?
  query_params[:'rel_obj_id'] = opts[:'rel_obj_id'] if !opts[:'rel_obj_id'].nil?
  query_params[:'rel_obj_id__isnull'] = opts[:'rel_obj_id__isnull'] if !opts[:'rel_obj_id__isnull'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?
  query_params[:'state'] = opts[:'state'] if !opts[:'state'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedTaskList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_tasks_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_tasks_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_tasks_retrieve(message_id, opts = {}) ⇒ Task

Parameters:

  • message_id (String)

    A UUID string identifying this Task.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



447
448
449
450
# File 'lib/authentik/api/api/tasks_api.rb', line 447

def tasks_tasks_retrieve(message_id, opts = {})
  data, _status_code, _headers = tasks_tasks_retrieve_with_http_info(message_id, opts)
  data
end

#tasks_tasks_retrieve_with_http_info(message_id, opts = {}) ⇒ Array<(Task, Integer, Hash)>

Returns Task data, response status code and response headers.

Parameters:

  • message_id (String)

    A UUID string identifying this Task.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Task, Integer, Hash)>)

    Task data, response status code and response headers



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/authentik/api/api/tasks_api.rb', line 455

def tasks_tasks_retrieve_with_http_info(message_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_tasks_retrieve ...'
  end
  # verify the required parameter 'message_id' is set
  if @api_client.config.client_side_validation && message_id.nil?
    fail ArgumentError, "Missing the required parameter 'message_id' when calling TasksApi.tasks_tasks_retrieve"
  end
  # resource path
  local_var_path = '/tasks/tasks/{message_id}/'.sub('{message_id}', CGI.escape(message_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Task'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_tasks_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_tasks_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_tasks_retry_create(message_id, opts = {}) ⇒ nil

Retry task

Parameters:

  • message_id (String)

    A UUID string identifying this Task.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


507
508
509
510
# File 'lib/authentik/api/api/tasks_api.rb', line 507

def tasks_tasks_retry_create(message_id, opts = {})
  tasks_tasks_retry_create_with_http_info(message_id, opts)
  nil
end

#tasks_tasks_retry_create_with_http_info(message_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Retry task

Parameters:

  • message_id (String)

    A UUID string identifying this Task.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'lib/authentik/api/api/tasks_api.rb', line 516

def tasks_tasks_retry_create_with_http_info(message_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_tasks_retry_create ...'
  end
  # verify the required parameter 'message_id' is set
  if @api_client.config.client_side_validation && message_id.nil?
    fail ArgumentError, "Missing the required parameter 'message_id' when calling TasksApi.tasks_tasks_retry_create"
  end
  # resource path
  local_var_path = '/tasks/tasks/{message_id}/retry/'.sub('{message_id}', CGI.escape(message_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_tasks_retry_create",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_tasks_retry_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_tasks_status_retrieve(opts = {}) ⇒ GlobalTaskStatus

Global status summary for all tasks

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



567
568
569
570
# File 'lib/authentik/api/api/tasks_api.rb', line 567

def tasks_tasks_status_retrieve(opts = {})
  data, _status_code, _headers = tasks_tasks_status_retrieve_with_http_info(opts)
  data
end

#tasks_tasks_status_retrieve_with_http_info(opts = {}) ⇒ Array<(GlobalTaskStatus, Integer, Hash)>

Global status summary for all tasks

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GlobalTaskStatus, Integer, Hash)>)

    GlobalTaskStatus data, response status code and response headers



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/authentik/api/api/tasks_api.rb', line 575

def tasks_tasks_status_retrieve_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_tasks_status_retrieve ...'
  end
  # resource path
  local_var_path = '/tasks/tasks/status/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GlobalTaskStatus'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_tasks_status_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_tasks_status_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#tasks_workers_list(opts = {}) ⇒ Array<Worker>

Get currently connected worker count.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



622
623
624
625
# File 'lib/authentik/api/api/tasks_api.rb', line 622

def tasks_workers_list(opts = {})
  data, _status_code, _headers = tasks_workers_list_with_http_info(opts)
  data
end

#tasks_workers_list_with_http_info(opts = {}) ⇒ Array<(Array<Worker>, Integer, Hash)>

Get currently connected worker count.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<Worker>, Integer, Hash)>)

    Array<Worker> data, response status code and response headers



630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
# File 'lib/authentik/api/api/tasks_api.rb', line 630

def tasks_workers_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TasksApi.tasks_workers_list ...'
  end
  # resource path
  local_var_path = '/tasks/workers/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<Worker>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['authentik']

  new_options = opts.merge(
    :operation => :"TasksApi.tasks_workers_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TasksApi#tasks_workers_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end