Class: Authentik::Api::TenantRecoveryKeyRequestRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::TenantRecoveryKeyRequestRequest
- Defined in:
- lib/authentik/api/models/tenant_recovery_key_request_request.rb
Overview
Tenant recovery key creation request serializer
Instance Attribute Summary collapse
-
#duration_days ⇒ Object
Returns the value of attribute duration_days.
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TenantRecoveryKeyRequestRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TenantRecoveryKeyRequestRequest
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 51 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::TenantRecoveryKeyRequestRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::TenantRecoveryKeyRequestRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user') self.user = attributes[:'user'] else self.user = nil end if attributes.key?(:'duration_days') self.duration_days = attributes[:'duration_days'] else self.duration_days = nil end end |
Instance Attribute Details
#duration_days ⇒ Object
Returns the value of attribute duration_days.
15 16 17 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 15 def duration_days @duration_days end |
#user ⇒ Object
Returns the value of attribute user.
13 14 15 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 13 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
26 27 28 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 26 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
31 32 33 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 31 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 18 def self.attribute_map { :'user' => :'user', :'duration_days' => :'duration_days' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
44 45 46 47 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 44 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 36 def self.openapi_types { :'user' => :'String', :'duration_days' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && user == o.user && duration_days == o.duration_days end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 149 def hash [user, duration_days].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 80 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @user.nil? invalid_properties.push('invalid value for "user", user cannot be nil.') end if @user.to_s.length < 1 invalid_properties.push('invalid value for "user", the character length must be greater than or equal to 1.') end if @duration_days.nil? invalid_properties.push('invalid value for "duration_days", duration_days cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
100 101 102 103 104 105 106 |
# File 'lib/authentik/api/models/tenant_recovery_key_request_request.rb', line 100 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @user.nil? return false if @user.to_s.length < 1 return false if @duration_days.nil? true end |