Class: Authentik::Api::ThemedUrls
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ThemedUrls
- Defined in:
- lib/authentik/api/models/themed_urls.rb
Overview
Themed URLs - maps theme names to URLs for light and dark themes
Instance Attribute Summary collapse
-
#dark ⇒ Object
Returns the value of attribute dark.
-
#light ⇒ Object
Returns the value of attribute light.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ThemedUrls
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ThemedUrls
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/authentik/api/models/themed_urls.rb', line 53 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ThemedUrls` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ThemedUrls`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'light') self.light = attributes[:'light'] end if attributes.key?(:'dark') self.dark = attributes[:'dark'] end end |
Instance Attribute Details
#dark ⇒ Object
Returns the value of attribute dark.
15 16 17 |
# File 'lib/authentik/api/models/themed_urls.rb', line 15 def dark @dark end |
#light ⇒ Object
Returns the value of attribute light.
13 14 15 |
# File 'lib/authentik/api/models/themed_urls.rb', line 13 def light @light end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
26 27 28 |
# File 'lib/authentik/api/models/themed_urls.rb', line 26 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
31 32 33 |
# File 'lib/authentik/api/models/themed_urls.rb', line 31 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 |
# File 'lib/authentik/api/models/themed_urls.rb', line 18 def self.attribute_map { :'light' => :'light', :'dark' => :'dark' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/authentik/api/models/themed_urls.rb', line 115 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
44 45 46 47 48 49 |
# File 'lib/authentik/api/models/themed_urls.rb', line 44 def self.openapi_nullable Set.new([ :'light', :'dark' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 |
# File 'lib/authentik/api/models/themed_urls.rb', line 36 def self.openapi_types { :'light' => :'String', :'dark' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
93 94 95 96 97 98 |
# File 'lib/authentik/api/models/themed_urls.rb', line 93 def ==(o) return true if self.equal?(o) self.class == o.class && light == o.light && dark == o.dark end |
#eql?(o) ⇒ Boolean
102 103 104 |
# File 'lib/authentik/api/models/themed_urls.rb', line 102 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
108 109 110 |
# File 'lib/authentik/api/models/themed_urls.rb', line 108 def hash [light, dark].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
78 79 80 81 82 |
# File 'lib/authentik/api/models/themed_urls.rb', line 78 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/authentik/api/models/themed_urls.rb', line 137 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
86 87 88 89 |
# File 'lib/authentik/api/models/themed_urls.rb', line 86 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |