Class: Authentik::Api::TokenModel

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/token_model.rb

Overview

Serializer for BaseGrantModel and RefreshToken

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TokenModel

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/authentik/api/models/token_model.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::TokenModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::TokenModel`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end

  if attributes.key?(:'is_expired')
    self.is_expired = attributes[:'is_expired']
  else
    self.is_expired = nil
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  end

  if attributes.key?(:'scope')
    if (value = attributes[:'scope']).is_a?(Array)
      self.scope = value
    end
  else
    self.scope = nil
  end

  if attributes.key?(:'id_token')
    self.id_token = attributes[:'id_token']
  else
    self.id_token = nil
  end

  if attributes.key?(:'revoked')
    self.revoked = attributes[:'revoked']
  end
end

Instance Attribute Details

#expiresObject

Returns the value of attribute expires.



22
23
24
# File 'lib/authentik/api/models/token_model.rb', line 22

def expires
  @expires
end

#id_tokenObject

Get the token’s id_token as JSON String



27
28
29
# File 'lib/authentik/api/models/token_model.rb', line 27

def id_token
  @id_token
end

#is_expiredObject

Check if token is expired yet.



20
21
22
# File 'lib/authentik/api/models/token_model.rb', line 20

def is_expired
  @is_expired
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/token_model.rb', line 13

def pk
  @pk
end

#providerObject

Returns the value of attribute provider.



15
16
17
# File 'lib/authentik/api/models/token_model.rb', line 15

def provider
  @provider
end

#revokedObject

Returns the value of attribute revoked.



29
30
31
# File 'lib/authentik/api/models/token_model.rb', line 29

def revoked
  @revoked
end

#scopeObject

Returns the value of attribute scope.



24
25
26
# File 'lib/authentik/api/models/token_model.rb', line 24

def scope
  @scope
end

#userObject

Returns the value of attribute user.



17
18
19
# File 'lib/authentik/api/models/token_model.rb', line 17

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/authentik/api/models/token_model.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/authentik/api/models/token_model.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/authentik/api/models/token_model.rb', line 32

def self.attribute_map
  {
    :'pk' => :'pk',
    :'provider' => :'provider',
    :'user' => :'user',
    :'is_expired' => :'is_expired',
    :'expires' => :'expires',
    :'scope' => :'scope',
    :'id_token' => :'id_token',
    :'revoked' => :'revoked'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/authentik/api/models/token_model.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
74
# File 'lib/authentik/api/models/token_model.rb', line 70

def self.openapi_nullable
  Set.new([
    :'expires',
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/authentik/api/models/token_model.rb', line 56

def self.openapi_types
  {
    :'pk' => :'Integer',
    :'provider' => :'Provider',
    :'user' => :'User',
    :'is_expired' => :'Boolean',
    :'expires' => :'Time',
    :'scope' => :'Array<String>',
    :'id_token' => :'String',
    :'revoked' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/authentik/api/models/token_model.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      provider == o.provider &&
      user == o.user &&
      is_expired == o.is_expired &&
      expires == o.expires &&
      scope == o.scope &&
      id_token == o.id_token &&
      revoked == o.revoked
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/authentik/api/models/token_model.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



267
268
269
# File 'lib/authentik/api/models/token_model.rb', line 267

def hash
  [pk, provider, user, is_expired, expires, scope, id_token, revoked].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/authentik/api/models/token_model.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @is_expired.nil?
    invalid_properties.push('invalid value for "is_expired", is_expired cannot be nil.')
  end

  if @scope.nil?
    invalid_properties.push('invalid value for "scope", scope cannot be nil.')
  end

  if @id_token.nil?
    invalid_properties.push('invalid value for "id_token", id_token cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/authentik/api/models/token_model.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
180
181
182
# File 'lib/authentik/api/models/token_model.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @provider.nil?
  return false if @user.nil?
  return false if @is_expired.nil?
  return false if @scope.nil?
  return false if @id_token.nil?
  true
end