Class: Authentik::Api::UniquePasswordPolicyRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/unique_password_policy_request.rb

Overview

Password Uniqueness Policy Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UniquePasswordPolicyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UniquePasswordPolicyRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UniquePasswordPolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'execution_logging')
    self.execution_logging = attributes[:'execution_logging']
  end

  if attributes.key?(:'password_field')
    self.password_field = attributes[:'password_field']
  end

  if attributes.key?(:'num_historical_passwords')
    self.num_historical_passwords = attributes[:'num_historical_passwords']
  end
end

Instance Attribute Details

#execution_loggingObject

When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.



16
17
18
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 16

def execution_logging
  @execution_logging
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 13

def name
  @name
end

#num_historical_passwordsObject

Number of passwords to check against.



22
23
24
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 22

def num_historical_passwords
  @num_historical_passwords
end

#password_fieldObject

Field key to check, field keys defined in Prompt stages are available.



19
20
21
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 19

def password_field
  @password_field
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



35
36
37
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 35

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



40
41
42
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 40

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
32
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 25

def self.attribute_map
  {
    :'name' => :'name',
    :'execution_logging' => :'execution_logging',
    :'password_field' => :'password_field',
    :'num_historical_passwords' => :'num_historical_passwords'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 207

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



55
56
57
58
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
52
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 45

def self.openapi_types
  {
    :'name' => :'String',
    :'execution_logging' => :'Boolean',
    :'password_field' => :'String',
    :'num_historical_passwords' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



183
184
185
186
187
188
189
190
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      execution_logging == o.execution_logging &&
      password_field == o.password_field &&
      num_historical_passwords == o.num_historical_passwords
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 194

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



200
201
202
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 200

def hash
  [name, execution_logging, password_field, num_historical_passwords].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@password_field.nil? && @password_field.to_s.length < 1
    invalid_properties.push('invalid value for "password_field", the character length must be greater than or equal to 1.')
  end

  if !@num_historical_passwords.nil? && @num_historical_passwords > 2147483647
    invalid_properties.push('invalid value for "num_historical_passwords", must be smaller than or equal to 2147483647.')
  end

  if !@num_historical_passwords.nil? && @num_historical_passwords < 0
    invalid_properties.push('invalid value for "num_historical_passwords", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
129
130
131
132
133
# File 'lib/authentik/api/models/unique_password_policy_request.rb', line 125

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if !@password_field.nil? && @password_field.to_s.length < 1
  return false if !@num_historical_passwords.nil? && @num_historical_passwords > 2147483647
  return false if !@num_historical_passwords.nil? && @num_historical_passwords < 0
  true
end