Class: Authentik::Api::UserOffboardingRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/user_offboarding_request.rb

Overview

Mixin to validate that a valid enterprise license exists before allowing to save the object

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserOffboardingRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UserOffboardingRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UserOffboardingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end

  if attributes.key?(:'scheduled_at')
    self.scheduled_at = attributes[:'scheduled_at']
  else
    self.scheduled_at = nil
  end

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'revoke_sessions')
    self.revoke_sessions = attributes[:'revoke_sessions']
  end

  if attributes.key?(:'revoke_tokens')
    self.revoke_tokens = attributes[:'revoke_tokens']
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



18
19
20
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 18

def action
  @action
end

#revoke_sessionsObject

Revoke all of the user's sessions when offboarding.



21
22
23
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 21

def revoke_sessions
  @revoke_sessions
end

#revoke_tokensObject

Revoke all of the user's tokens when offboarding.



24
25
26
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 24

def revoke_tokens
  @revoke_tokens
end

#scheduled_atObject

Absolute time at which the offboarding action is executed.



16
17
18
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 16

def scheduled_at
  @scheduled_at
end

#userObject

Returns the value of attribute user.



13
14
15
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 13

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 49

def self.attribute_map
  {
    :'user' => :'user',
    :'scheduled_at' => :'scheduled_at',
    :'action' => :'action',
    :'revoke_sessions' => :'revoke_sessions',
    :'revoke_tokens' => :'revoke_tokens'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 199

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 70

def self.openapi_types
  {
    :'user' => :'Integer',
    :'scheduled_at' => :'Time',
    :'action' => :'OffboardingActionEnum',
    :'revoke_sessions' => :'Boolean',
    :'revoke_tokens' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
181
182
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      user == o.user &&
      scheduled_at == o.scheduled_at &&
      action == o.action &&
      revoke_sessions == o.revoke_sessions &&
      revoke_tokens == o.revoke_tokens
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 186

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



192
193
194
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 192

def hash
  [user, scheduled_at, action, revoke_sessions, revoke_tokens].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @scheduled_at.nil?
    invalid_properties.push('invalid value for "scheduled_at", scheduled_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
# File 'lib/authentik/api/models/user_offboarding_request.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @user.nil?
  return false if @scheduled_at.nil?
  true
end