Class: Authentik::Api::UserPlexSourceConnectionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::UserPlexSourceConnectionRequest
- Defined in:
- lib/authentik/api/models/user_plex_source_connection_request.rb
Overview
User source connection
Instance Attribute Summary collapse
-
#identifier ⇒ Object
Returns the value of attribute identifier.
-
#plex_token ⇒ Object
Returns the value of attribute plex_token.
-
#source ⇒ Object
Returns the value of attribute source.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserPlexSourceConnectionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserPlexSourceConnectionRequest
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 55 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UserPlexSourceConnectionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UserPlexSourceConnectionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] else self.identifier = nil end if attributes.key?(:'plex_token') self.plex_token = attributes[:'plex_token'] else self.plex_token = nil end end |
Instance Attribute Details
#identifier ⇒ Object
Returns the value of attribute identifier.
15 16 17 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 15 def identifier @identifier end |
#plex_token ⇒ Object
Returns the value of attribute plex_token.
17 18 19 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 17 def plex_token @plex_token end |
#source ⇒ Object
Returns the value of attribute source.
13 14 15 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 13 def source @source end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
29 30 31 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 29 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
34 35 36 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 34 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 20 def self.attribute_map { :'source' => :'source', :'identifier' => :'identifier', :'plex_token' => :'plex_token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 51 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 48 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 39 def self.openapi_types { :'source' => :'String', :'identifier' => :'String', :'plex_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && source == o.source && identifier == o.identifier && plex_token == o.plex_token end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 184 def hash [source, identifier, plex_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 90 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end if @identifier.nil? invalid_properties.push('invalid value for "identifier", identifier cannot be nil.') end if @identifier.to_s.length < 1 invalid_properties.push('invalid value for "identifier", the character length must be greater than or equal to 1.') end if @plex_token.nil? invalid_properties.push('invalid value for "plex_token", plex_token cannot be nil.') end if @plex_token.to_s.length < 1 invalid_properties.push('invalid value for "plex_token", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
118 119 120 121 122 123 124 125 126 |
# File 'lib/authentik/api/models/user_plex_source_connection_request.rb', line 118 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @source.nil? return false if @identifier.nil? return false if @identifier.to_s.length < 1 return false if @plex_token.nil? return false if @plex_token.to_s.length < 1 true end |