Class: Authentik::Api::UserRecoveryEmailRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::UserRecoveryEmailRequest
- Defined in:
- lib/authentik/api/models/user_recovery_email_request.rb
Overview
Payload to create and email a recovery link
Instance Attribute Summary collapse
-
#email_stage ⇒ Object
Returns the value of attribute email_stage.
-
#token_duration ⇒ Object
Returns the value of attribute token_duration.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserRecoveryEmailRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserRecoveryEmailRequest
Initializes the object
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 51 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UserRecoveryEmailRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UserRecoveryEmailRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'token_duration') self.token_duration = attributes[:'token_duration'] end if attributes.key?(:'email_stage') self.email_stage = attributes[:'email_stage'] else self.email_stage = nil end end |
Instance Attribute Details
#email_stage ⇒ Object
Returns the value of attribute email_stage.
15 16 17 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 15 def email_stage @email_stage end |
#token_duration ⇒ Object
Returns the value of attribute token_duration.
13 14 15 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 13 def token_duration @token_duration end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
26 27 28 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 26 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
31 32 33 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 31 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 18 def self.attribute_map { :'token_duration' => :'token_duration', :'email_stage' => :'email_stage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 149 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
44 45 46 47 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 44 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
36 37 38 39 40 41 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 36 def self.openapi_types { :'token_duration' => :'String', :'email_stage' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 127 def ==(o) return true if self.equal?(o) self.class == o.class && token_duration == o.token_duration && email_stage == o.email_stage end |
#eql?(o) ⇒ Boolean
136 137 138 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 136 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 142 def hash [token_duration, email_stage].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 78 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@token_duration.nil? && @token_duration.to_s.length < 1 invalid_properties.push('invalid value for "token_duration", the character length must be greater than or equal to 1.') end if @email_stage.nil? invalid_properties.push('invalid value for "email_stage", email_stage cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
94 95 96 97 98 99 |
# File 'lib/authentik/api/models/user_recovery_email_request.rb', line 94 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@token_duration.nil? && @token_duration.to_s.length < 1 return false if @email_stage.nil? true end |