Class: Authentik::Api::UserSelf

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/user_self.rb

Overview

User Serializer for information a user can retrieve about themselves

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserSelf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/authentik/api/models/user_self.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UserSelf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UserSelf`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  else
    self.username = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  else
    self.is_active = nil
  end

  if attributes.key?(:'is_superuser')
    self.is_superuser = attributes[:'is_superuser']
  else
    self.is_superuser = nil
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  else
    self.groups = nil
  end

  if attributes.key?(:'roles')
    if (value = attributes[:'roles']).is_a?(Array)
      self.roles = value
    end
  else
    self.roles = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'avatar')
    self.avatar = attributes[:'avatar']
  else
    self.avatar = nil
  end

  if attributes.key?(:'uid')
    self.uid = attributes[:'uid']
  else
    self.uid = nil
  end

  if attributes.key?(:'settings')
    if (value = attributes[:'settings']).is_a?(Hash)
      self.settings = value
    end
  else
    self.settings = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'system_permissions')
    if (value = attributes[:'system_permissions']).is_a?(Array)
      self.system_permissions = value
    end
  else
    self.system_permissions = nil
  end
end

Instance Attribute Details

#avatarObject

User’s avatar, either a http/https URL or a data URI



33
34
35
# File 'lib/authentik/api/models/user_self.rb', line 33

def avatar
  @avatar
end

#emailObject

Returns the value of attribute email.



30
31
32
# File 'lib/authentik/api/models/user_self.rb', line 30

def email
  @email
end

#groupsObject

Returns the value of attribute groups.



26
27
28
# File 'lib/authentik/api/models/user_self.rb', line 26

def groups
  @groups
end

#is_activeObject

Designates whether this user should be treated as active. Unselect this instead of deleting accounts.



22
23
24
# File 'lib/authentik/api/models/user_self.rb', line 22

def is_active
  @is_active
end

#is_superuserObject

Returns the value of attribute is_superuser.



24
25
26
# File 'lib/authentik/api/models/user_self.rb', line 24

def is_superuser
  @is_superuser
end

#nameObject

User’s display name.



19
20
21
# File 'lib/authentik/api/models/user_self.rb', line 19

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/user_self.rb', line 13

def pk
  @pk
end

#rolesObject

Returns the value of attribute roles.



28
29
30
# File 'lib/authentik/api/models/user_self.rb', line 28

def roles
  @roles
end

#settingsObject

Get user settings with brand and group settings applied



38
39
40
# File 'lib/authentik/api/models/user_self.rb', line 38

def settings
  @settings
end

#system_permissionsObject

Get all system permissions assigned to the user



43
44
45
# File 'lib/authentik/api/models/user_self.rb', line 43

def system_permissions
  @system_permissions
end

#typeObject

Returns the value of attribute type.



40
41
42
# File 'lib/authentik/api/models/user_self.rb', line 40

def type
  @type
end

#uidObject

Returns the value of attribute uid.



35
36
37
# File 'lib/authentik/api/models/user_self.rb', line 35

def uid
  @uid
end

#usernameObject

Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.



16
17
18
# File 'lib/authentik/api/models/user_self.rb', line 16

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/authentik/api/models/user_self.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/authentik/api/models/user_self.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/authentik/api/models/user_self.rb', line 68

def self.attribute_map
  {
    :'pk' => :'pk',
    :'username' => :'username',
    :'name' => :'name',
    :'is_active' => :'is_active',
    :'is_superuser' => :'is_superuser',
    :'groups' => :'groups',
    :'roles' => :'roles',
    :'email' => :'email',
    :'avatar' => :'avatar',
    :'uid' => :'uid',
    :'settings' => :'settings',
    :'type' => :'type',
    :'system_permissions' => :'system_permissions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/authentik/api/models/user_self.rb', line 474

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/authentik/api/models/user_self.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/authentik/api/models/user_self.rb', line 97

def self.openapi_types
  {
    :'pk' => :'Integer',
    :'username' => :'String',
    :'name' => :'String',
    :'is_active' => :'Boolean',
    :'is_superuser' => :'Boolean',
    :'groups' => :'Array<UserSelfGroups>',
    :'roles' => :'Array<UserSelfRoles>',
    :'email' => :'String',
    :'avatar' => :'String',
    :'uid' => :'String',
    :'settings' => :'Hash<String, Object>',
    :'type' => :'UserTypeEnum',
    :'system_permissions' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/authentik/api/models/user_self.rb', line 441

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      username == o.username &&
      name == o.name &&
      is_active == o.is_active &&
      is_superuser == o.is_superuser &&
      groups == o.groups &&
      roles == o.roles &&
      email == o.email &&
      avatar == o.avatar &&
      uid == o.uid &&
      settings == o.settings &&
      type == o.type &&
      system_permissions == o.system_permissions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


461
462
463
# File 'lib/authentik/api/models/user_self.rb', line 461

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



467
468
469
# File 'lib/authentik/api/models/user_self.rb', line 467

def hash
  [pk, username, name, is_active, is_superuser, groups, roles, email, avatar, uid, settings, type, system_permissions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/authentik/api/models/user_self.rb', line 222

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  if @username.to_s.length > 150
    invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 150.')
  end

  pattern = Regexp.new(/^[\w.@+-]+$/)
  if @username !~ pattern
    invalid_properties.push("invalid value for \"username\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @is_active.nil?
    invalid_properties.push('invalid value for "is_active", is_active cannot be nil.')
  end

  if @is_superuser.nil?
    invalid_properties.push('invalid value for "is_superuser", is_superuser cannot be nil.')
  end

  if @groups.nil?
    invalid_properties.push('invalid value for "groups", groups cannot be nil.')
  end

  if @roles.nil?
    invalid_properties.push('invalid value for "roles", roles cannot be nil.')
  end

  if !@email.nil? && @email.to_s.length > 254
    invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 254.')
  end

  if @avatar.nil?
    invalid_properties.push('invalid value for "avatar", avatar cannot be nil.')
  end

  if @uid.nil?
    invalid_properties.push('invalid value for "uid", uid cannot be nil.')
  end

  if @settings.nil?
    invalid_properties.push('invalid value for "settings", settings cannot be nil.')
  end

  if @system_permissions.nil?
    invalid_properties.push('invalid value for "system_permissions", system_permissions cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/authentik/api/models/user_self.rb', line 496

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/authentik/api/models/user_self.rb', line 287

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @username.nil?
  return false if @username.to_s.length > 150
  return false if @username !~ Regexp.new(/^[\w.@+-]+$/)
  return false if @name.nil?
  return false if @is_active.nil?
  return false if @is_superuser.nil?
  return false if @groups.nil?
  return false if @roles.nil?
  return false if !@email.nil? && @email.to_s.length > 254
  return false if @avatar.nil?
  return false if @uid.nil?
  return false if @settings.nil?
  return false if @system_permissions.nil?
  true
end