Class: Authentik::Api::UserServiceAccountRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::UserServiceAccountRequest
- Defined in:
- lib/authentik/api/models/user_service_account_request.rb
Overview
Payload to create a service account
Instance Attribute Summary collapse
-
#create_group ⇒ Object
Returns the value of attribute create_group.
-
#expires ⇒ Object
If not provided, valid for 360 days.
-
#expiring ⇒ Object
Returns the value of attribute expiring.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserServiceAccountRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserServiceAccountRequest
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UserServiceAccountRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UserServiceAccountRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'create_group') self.create_group = attributes[:'create_group'] else self.create_group = false end if attributes.key?(:'expiring') self.expiring = attributes[:'expiring'] else self.expiring = true end if attributes.key?(:'expires') self.expires = attributes[:'expires'] end end |
Instance Attribute Details
#create_group ⇒ Object
Returns the value of attribute create_group.
15 16 17 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 15 def create_group @create_group end |
#expires ⇒ Object
If not provided, valid for 360 days
20 21 22 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 20 def expires @expires end |
#expiring ⇒ Object
Returns the value of attribute expiring.
17 18 19 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 17 def expiring @expiring end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 13 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 23 def self.attribute_map { :'name' => :'name', :'create_group' => :'create_group', :'expiring' => :'expiring', :'expires' => :'expires' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 162 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
53 54 55 56 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 53 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 49 50 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 43 def self.openapi_types { :'name' => :'String', :'create_group' => :'Boolean', :'expiring' => :'Boolean', :'expires' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && create_group == o.create_group && expiring == o.expiring && expires == o.expires end |
#eql?(o) ⇒ Boolean
149 150 151 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 149 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 155 def hash [name, create_group, expiring, expires].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 99 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 184 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
115 116 117 118 119 120 |
# File 'lib/authentik/api/models/user_service_account_request.rb', line 115 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 true end |