Class: Authentik::Api::UserSetting

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/user_setting.rb

Overview

Serializer for User settings for stages and sources

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserSetting

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/authentik/api/models/user_setting.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UserSetting` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UserSetting`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'object_uid')
    self.object_uid = attributes[:'object_uid']
  else
    self.object_uid = nil
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'configure_url')
    self.configure_url = attributes[:'configure_url']
  end

  if attributes.key?(:'icon_url')
    self.icon_url = attributes[:'icon_url']
  end
end

Instance Attribute Details

#componentObject

Returns the value of attribute component.



15
16
17
# File 'lib/authentik/api/models/user_setting.rb', line 15

def component
  @component
end

#configure_urlObject

Returns the value of attribute configure_url.



19
20
21
# File 'lib/authentik/api/models/user_setting.rb', line 19

def configure_url
  @configure_url
end

#icon_urlObject

Returns the value of attribute icon_url.



21
22
23
# File 'lib/authentik/api/models/user_setting.rb', line 21

def icon_url
  @icon_url
end

#object_uidObject

Returns the value of attribute object_uid.



13
14
15
# File 'lib/authentik/api/models/user_setting.rb', line 13

def object_uid
  @object_uid
end

#titleObject

Returns the value of attribute title.



17
18
19
# File 'lib/authentik/api/models/user_setting.rb', line 17

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



35
36
37
# File 'lib/authentik/api/models/user_setting.rb', line 35

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



40
41
42
# File 'lib/authentik/api/models/user_setting.rb', line 40

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
30
31
32
# File 'lib/authentik/api/models/user_setting.rb', line 24

def self.attribute_map
  {
    :'object_uid' => :'object_uid',
    :'component' => :'component',
    :'title' => :'title',
    :'configure_url' => :'configure_url',
    :'icon_url' => :'icon_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/authentik/api/models/user_setting.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/authentik/api/models/user_setting.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
52
53
# File 'lib/authentik/api/models/user_setting.rb', line 45

def self.openapi_types
  {
    :'object_uid' => :'String',
    :'component' => :'String',
    :'title' => :'String',
    :'configure_url' => :'String',
    :'icon_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
173
174
# File 'lib/authentik/api/models/user_setting.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      object_uid == o.object_uid &&
      component == o.component &&
      title == o.title &&
      configure_url == o.configure_url &&
      icon_url == o.icon_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/authentik/api/models/user_setting.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/authentik/api/models/user_setting.rb', line 184

def hash
  [object_uid, component, title, configure_url, icon_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/authentik/api/models/user_setting.rb', line 106

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @object_uid.nil?
    invalid_properties.push('invalid value for "object_uid", object_uid cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/authentik/api/models/user_setting.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



126
127
128
129
130
131
132
# File 'lib/authentik/api/models/user_setting.rb', line 126

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @object_uid.nil?
  return false if @component.nil?
  return false if @title.nil?
  true
end