Class: Authentik::Api::Version

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/version.rb

Overview

Get running and latest version.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Version

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/authentik/api/models/version.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Version` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Version`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version_current')
    self.version_current = attributes[:'version_current']
  else
    self.version_current = nil
  end

  if attributes.key?(:'version_latest')
    self.version_latest = attributes[:'version_latest']
  else
    self.version_latest = nil
  end

  if attributes.key?(:'version_latest_valid')
    self.version_latest_valid = attributes[:'version_latest_valid']
  else
    self.version_latest_valid = nil
  end

  if attributes.key?(:'build_hash')
    self.build_hash = attributes[:'build_hash']
  else
    self.build_hash = nil
  end

  if attributes.key?(:'outdated')
    self.outdated = attributes[:'outdated']
  else
    self.outdated = nil
  end

  if attributes.key?(:'outpost_outdated')
    self.outpost_outdated = attributes[:'outpost_outdated']
  else
    self.outpost_outdated = nil
  end
end

Instance Attribute Details

#build_hashObject

Get build hash, if version is not latest or released



23
24
25
# File 'lib/authentik/api/models/version.rb', line 23

def build_hash
  @build_hash
end

#outdatedObject

Check if we’re running the latest version



26
27
28
# File 'lib/authentik/api/models/version.rb', line 26

def outdated
  @outdated
end

#outpost_outdatedObject

Check if any outpost is outdated/has a version mismatch



29
30
31
# File 'lib/authentik/api/models/version.rb', line 29

def outpost_outdated
  @outpost_outdated
end

#version_currentObject

Get current version



14
15
16
# File 'lib/authentik/api/models/version.rb', line 14

def version_current
  @version_current
end

#version_latestObject

Get latest version from cache



17
18
19
# File 'lib/authentik/api/models/version.rb', line 17

def version_latest
  @version_latest
end

#version_latest_validObject

Check if latest version is valid



20
21
22
# File 'lib/authentik/api/models/version.rb', line 20

def version_latest_valid
  @version_latest_valid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/authentik/api/models/version.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/authentik/api/models/version.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/authentik/api/models/version.rb', line 32

def self.attribute_map
  {
    :'version_current' => :'version_current',
    :'version_latest' => :'version_latest',
    :'version_latest_valid' => :'version_latest_valid',
    :'build_hash' => :'build_hash',
    :'outdated' => :'outdated',
    :'outpost_outdated' => :'outpost_outdated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/authentik/api/models/version.rb', line 257

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/authentik/api/models/version.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/authentik/api/models/version.rb', line 54

def self.openapi_types
  {
    :'version_current' => :'String',
    :'version_latest' => :'String',
    :'version_latest_valid' => :'Boolean',
    :'build_hash' => :'String',
    :'outdated' => :'Boolean',
    :'outpost_outdated' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
# File 'lib/authentik/api/models/version.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version_current == o.version_current &&
      version_latest == o.version_latest &&
      version_latest_valid == o.version_latest_valid &&
      build_hash == o.build_hash &&
      outdated == o.outdated &&
      outpost_outdated == o.outpost_outdated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


244
245
246
# File 'lib/authentik/api/models/version.rb', line 244

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



250
251
252
# File 'lib/authentik/api/models/version.rb', line 250

def hash
  [version_current, version_latest, version_latest_valid, build_hash, outdated, outpost_outdated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/authentik/api/models/version.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @version_current.nil?
    invalid_properties.push('invalid value for "version_current", version_current cannot be nil.')
  end

  if @version_latest.nil?
    invalid_properties.push('invalid value for "version_latest", version_latest cannot be nil.')
  end

  if @version_latest_valid.nil?
    invalid_properties.push('invalid value for "version_latest_valid", version_latest_valid cannot be nil.')
  end

  if @build_hash.nil?
    invalid_properties.push('invalid value for "build_hash", build_hash cannot be nil.')
  end

  if @outdated.nil?
    invalid_properties.push('invalid value for "outdated", outdated cannot be nil.')
  end

  if @outpost_outdated.nil?
    invalid_properties.push('invalid value for "outpost_outdated", outpost_outdated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/authentik/api/models/version.rb', line 279

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
164
165
166
167
# File 'lib/authentik/api/models/version.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @version_current.nil?
  return false if @version_latest.nil?
  return false if @version_latest_valid.nil?
  return false if @build_hash.nil?
  return false if @outdated.nil?
  return false if @outpost_outdated.nil?
  true
end