Class: Authentik::Api::WSFederationProviderRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::WSFederationProviderRequest
- Defined in:
- lib/authentik/api/models/ws_federation_provider_request.rb
Overview
WSFederationProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#assertion_valid_not_before ⇒ Object
Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).
-
#assertion_valid_not_on_or_after ⇒ Object
Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
-
#authn_context_class_ref_mapping ⇒ Object
Configure how the AuthnContextClassRef value will be created.
-
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
-
#default_name_id_policy ⇒ Object
Returns the value of attribute default_name_id_policy.
-
#digest_algorithm ⇒ Object
Returns the value of attribute digest_algorithm.
-
#encryption_kp ⇒ Object
When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair.
-
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
-
#name ⇒ Object
Returns the value of attribute name.
-
#name_id_mapping ⇒ Object
Configure how the NameID value will be created.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#reply_url ⇒ Object
Returns the value of attribute reply_url.
-
#saml_version ⇒ Object
SAML assertion version to issue in the security token.
-
#session_valid_not_on_or_after ⇒ Object
Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#sign_assertion ⇒ Object
Returns the value of attribute sign_assertion.
-
#sign_logout_request ⇒ Object
Returns the value of attribute sign_logout_request.
-
#signature_algorithm ⇒ Object
Returns the value of attribute signature_algorithm.
-
#signing_kp ⇒ Object
Keypair used to sign outgoing Responses going to the Service Provider.
-
#wtrealm ⇒ Object
Returns the value of attribute wtrealm.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WSFederationProviderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WSFederationProviderRequest
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 161 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::WSFederationProviderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::WSFederationProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'authorization_flow') self. = attributes[:'authorization_flow'] else self. = nil end if attributes.key?(:'invalidation_flow') self.invalidation_flow = attributes[:'invalidation_flow'] else self.invalidation_flow = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'reply_url') self.reply_url = attributes[:'reply_url'] else self.reply_url = nil end if attributes.key?(:'wtrealm') self.wtrealm = attributes[:'wtrealm'] else self.wtrealm = nil end if attributes.key?(:'assertion_valid_not_before') self.assertion_valid_not_before = attributes[:'assertion_valid_not_before'] end if attributes.key?(:'assertion_valid_not_on_or_after') self.assertion_valid_not_on_or_after = attributes[:'assertion_valid_not_on_or_after'] end if attributes.key?(:'session_valid_not_on_or_after') self.session_valid_not_on_or_after = attributes[:'session_valid_not_on_or_after'] end if attributes.key?(:'name_id_mapping') self.name_id_mapping = attributes[:'name_id_mapping'] end if attributes.key?(:'authn_context_class_ref_mapping') self.authn_context_class_ref_mapping = attributes[:'authn_context_class_ref_mapping'] end if attributes.key?(:'saml_version') self.saml_version = attributes[:'saml_version'] end if attributes.key?(:'digest_algorithm') self.digest_algorithm = attributes[:'digest_algorithm'] end if attributes.key?(:'signature_algorithm') self.signature_algorithm = attributes[:'signature_algorithm'] end if attributes.key?(:'signing_kp') self.signing_kp = attributes[:'signing_kp'] end if attributes.key?(:'encryption_kp') self.encryption_kp = attributes[:'encryption_kp'] end if attributes.key?(:'sign_assertion') self.sign_assertion = attributes[:'sign_assertion'] end if attributes.key?(:'sign_logout_request') self.sign_logout_request = attributes[:'sign_logout_request'] end if attributes.key?(:'default_name_id_policy') self.default_name_id_policy = attributes[:'default_name_id_policy'] end end |
Instance Attribute Details
#assertion_valid_not_before ⇒ Object
Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).
31 32 33 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 31 def assertion_valid_not_before @assertion_valid_not_before end |
#assertion_valid_not_on_or_after ⇒ Object
Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
34 35 36 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 34 def assertion_valid_not_on_or_after @assertion_valid_not_on_or_after end |
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
16 17 18 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 16 def authentication_flow @authentication_flow end |
#authn_context_class_ref_mapping ⇒ Object
Configure how the AuthnContextClassRef value will be created. When left empty, the AuthnContextClassRef will be set based on which authentication methods the user used to authenticate.
43 44 45 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 43 def authn_context_class_ref_mapping @authn_context_class_ref_mapping end |
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
19 20 21 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 19 def @authorization_flow end |
#default_name_id_policy ⇒ Object
Returns the value of attribute default_name_id_policy.
62 63 64 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 62 def default_name_id_policy @default_name_id_policy end |
#digest_algorithm ⇒ Object
Returns the value of attribute digest_algorithm.
48 49 50 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 48 def digest_algorithm @digest_algorithm end |
#encryption_kp ⇒ Object
When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.
56 57 58 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 56 def encryption_kp @encryption_kp end |
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
22 23 24 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 22 def invalidation_flow @invalidation_flow end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 13 def name @name end |
#name_id_mapping ⇒ Object
Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be considered
40 41 42 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 40 def name_id_mapping @name_id_mapping end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
24 25 26 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 24 def property_mappings @property_mappings end |
#reply_url ⇒ Object
Returns the value of attribute reply_url.
26 27 28 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 26 def reply_url @reply_url end |
#saml_version ⇒ Object
SAML assertion version to issue in the security token. Microsoft Entra ID and classic ADFS-style relying parties typically require SAML 1.1.
46 47 48 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 46 def saml_version @saml_version end |
#session_valid_not_on_or_after ⇒ Object
Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
37 38 39 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 37 def session_valid_not_on_or_after @session_valid_not_on_or_after end |
#sign_assertion ⇒ Object
Returns the value of attribute sign_assertion.
58 59 60 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 58 def sign_assertion @sign_assertion end |
#sign_logout_request ⇒ Object
Returns the value of attribute sign_logout_request.
60 61 62 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 60 def sign_logout_request @sign_logout_request end |
#signature_algorithm ⇒ Object
Returns the value of attribute signature_algorithm.
50 51 52 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 50 def signature_algorithm @signature_algorithm end |
#signing_kp ⇒ Object
Keypair used to sign outgoing Responses going to the Service Provider.
53 54 55 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 53 def signing_kp @signing_kp end |
#wtrealm ⇒ Object
Returns the value of attribute wtrealm.
28 29 30 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 28 def wtrealm @wtrealm end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
113 114 115 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 113 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
118 119 120 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 118 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 87 def self.attribute_map { :'name' => :'name', :'authentication_flow' => :'authentication_flow', :'authorization_flow' => :'authorization_flow', :'invalidation_flow' => :'invalidation_flow', :'property_mappings' => :'property_mappings', :'reply_url' => :'reply_url', :'wtrealm' => :'wtrealm', :'assertion_valid_not_before' => :'assertion_valid_not_before', :'assertion_valid_not_on_or_after' => :'assertion_valid_not_on_or_after', :'session_valid_not_on_or_after' => :'session_valid_not_on_or_after', :'name_id_mapping' => :'name_id_mapping', :'authn_context_class_ref_mapping' => :'authn_context_class_ref_mapping', :'saml_version' => :'saml_version', :'digest_algorithm' => :'digest_algorithm', :'signature_algorithm' => :'signature_algorithm', :'signing_kp' => :'signing_kp', :'encryption_kp' => :'encryption_kp', :'sign_assertion' => :'sign_assertion', :'sign_logout_request' => :'sign_logout_request', :'default_name_id_policy' => :'default_name_id_policy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 484 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
149 150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 149 def self.openapi_nullable Set.new([ :'authentication_flow', :'name_id_mapping', :'authn_context_class_ref_mapping', :'signing_kp', :'encryption_kp', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 123 def self.openapi_types { :'name' => :'String', :'authentication_flow' => :'String', :'authorization_flow' => :'String', :'invalidation_flow' => :'String', :'property_mappings' => :'Array<String>', :'reply_url' => :'String', :'wtrealm' => :'String', :'assertion_valid_not_before' => :'String', :'assertion_valid_not_on_or_after' => :'String', :'session_valid_not_on_or_after' => :'String', :'name_id_mapping' => :'String', :'authn_context_class_ref_mapping' => :'String', :'saml_version' => :'SamlVersionEnum', :'digest_algorithm' => :'DigestAlgorithmEnum', :'signature_algorithm' => :'SignatureAlgorithmEnum', :'signing_kp' => :'String', :'encryption_kp' => :'String', :'sign_assertion' => :'Boolean', :'sign_logout_request' => :'Boolean', :'default_name_id_policy' => :'SAMLNameIDPolicyEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 444 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && authentication_flow == o.authentication_flow && == o. && invalidation_flow == o.invalidation_flow && property_mappings == o.property_mappings && reply_url == o.reply_url && wtrealm == o.wtrealm && assertion_valid_not_before == o.assertion_valid_not_before && assertion_valid_not_on_or_after == o.assertion_valid_not_on_or_after && session_valid_not_on_or_after == o.session_valid_not_on_or_after && name_id_mapping == o.name_id_mapping && authn_context_class_ref_mapping == o.authn_context_class_ref_mapping && saml_version == o.saml_version && digest_algorithm == o.digest_algorithm && signature_algorithm == o.signature_algorithm && signing_kp == o.signing_kp && encryption_kp == o.encryption_kp && sign_assertion == o.sign_assertion && sign_logout_request == o.sign_logout_request && default_name_id_policy == o.default_name_id_policy end |
#eql?(o) ⇒ Boolean
471 472 473 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 471 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
477 478 479 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 477 def hash [name, authentication_flow, , invalidation_flow, property_mappings, reply_url, wtrealm, assertion_valid_not_before, assertion_valid_not_on_or_after, session_valid_not_on_or_after, name_id_mapping, authn_context_class_ref_mapping, saml_version, digest_algorithm, signature_algorithm, signing_kp, encryption_kp, sign_assertion, sign_logout_request, default_name_id_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 270 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @authorization_flow.nil? invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.') end if @invalidation_flow.nil? invalid_properties.push('invalid value for "invalidation_flow", invalidation_flow cannot be nil.') end if @reply_url.nil? invalid_properties.push('invalid value for "reply_url", reply_url cannot be nil.') end if @reply_url.to_s.length < 1 invalid_properties.push('invalid value for "reply_url", the character length must be greater than or equal to 1.') end if @wtrealm.nil? invalid_properties.push('invalid value for "wtrealm", wtrealm cannot be nil.') end if @wtrealm.to_s.length < 1 invalid_properties.push('invalid value for "wtrealm", the character length must be greater than or equal to 1.') end if !@assertion_valid_not_before.nil? && @assertion_valid_not_before.to_s.length < 1 invalid_properties.push('invalid value for "assertion_valid_not_before", the character length must be greater than or equal to 1.') end if !@assertion_valid_not_on_or_after.nil? && @assertion_valid_not_on_or_after.to_s.length < 1 invalid_properties.push('invalid value for "assertion_valid_not_on_or_after", the character length must be greater than or equal to 1.') end if !@session_valid_not_on_or_after.nil? && @session_valid_not_on_or_after.to_s.length < 1 invalid_properties.push('invalid value for "session_valid_not_on_or_after", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 506 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/authentik/api/models/ws_federation_provider_request.rb', line 322 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @authorization_flow.nil? return false if @invalidation_flow.nil? return false if @reply_url.nil? return false if @reply_url.to_s.length < 1 return false if @wtrealm.nil? return false if @wtrealm.to_s.length < 1 return false if !@assertion_valid_not_before.nil? && @assertion_valid_not_before.to_s.length < 1 return false if !@assertion_valid_not_on_or_after.nil? && @assertion_valid_not_on_or_after.to_s.length < 1 return false if !@session_valid_not_on_or_after.nil? && @session_valid_not_on_or_after.to_s.length < 1 true end |