Class: Authentik::Api::WebAuthnDevice
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::WebAuthnDevice
- Defined in:
- lib/authentik/api/models/web_authn_device.rb
Overview
Serializer for WebAuthn authenticator devices
Instance Attribute Summary collapse
-
#aaguid ⇒ Object
Returns the value of attribute aaguid.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#device_type ⇒ Object
Returns the value of attribute device_type.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebAuthnDevice
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebAuthnDevice
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::WebAuthnDevice` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::WebAuthnDevice`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] else self.created_on = nil end if attributes.key?(:'device_type') self.device_type = attributes[:'device_type'] else self.device_type = nil end if attributes.key?(:'aaguid') self.aaguid = attributes[:'aaguid'] else self.aaguid = nil end if attributes.key?(:'user') self.user = attributes[:'user'] else self.user = nil end end |
Instance Attribute Details
#aaguid ⇒ Object
Returns the value of attribute aaguid.
21 22 23 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 21 def aaguid @aaguid end |
#created_on ⇒ Object
Returns the value of attribute created_on.
17 18 19 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 17 def created_on @created_on end |
#device_type ⇒ Object
Returns the value of attribute device_type.
19 20 21 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 19 def device_type @device_type end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 13 def pk @pk end |
#user ⇒ Object
Returns the value of attribute user.
23 24 25 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 23 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 26 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'created_on' => :'created_on', :'device_type' => :'device_type', :'aaguid' => :'aaguid', :'user' => :'user' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 64 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 60 def self.openapi_nullable Set.new([ :'device_type', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 57 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 48 def self.openapi_types { :'pk' => :'Integer', :'name' => :'String', :'created_on' => :'Time', :'device_type' => :'WebAuthnDeviceType', :'aaguid' => :'String', :'user' => :'PartialUser' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && created_on == o.created_on && device_type == o.device_type && aaguid == o.aaguid && user == o.user end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 239 def hash [pk, name, created_on, device_type, aaguid, user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 200 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 200.') end if @created_on.nil? invalid_properties.push('invalid value for "created_on", created_on cannot be nil.') end if @aaguid.nil? invalid_properties.push('invalid value for "aaguid", aaguid cannot be nil.') end if @user.nil? invalid_properties.push('invalid value for "user", user cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 159 160 161 162 |
# File 'lib/authentik/api/models/web_authn_device.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @name.to_s.length > 200 return false if @created_on.nil? return false if @aaguid.nil? return false if @user.nil? true end |