Class: Authentik::Api::AgentsApi
- Inherits:
-
Object
- Object
- Authentik::Api::AgentsApi
- Defined in:
- lib/authentik/api/api/agents_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#agents_agents_create(opts = {}) ⇒ AgentCreated
Admin-provisioned delegate identities.
-
#agents_agents_create_with_http_info(opts = {}) ⇒ Array<(AgentCreated, Integer, Hash)>
Admin-provisioned delegate identities.
-
#agents_agents_destroy(id, opts = {}) ⇒ nil
Admin-provisioned delegate identities.
-
#agents_agents_destroy_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Admin-provisioned delegate identities.
-
#agents_agents_list(opts = {}) ⇒ PaginatedAgentList
Admin-provisioned delegate identities.
-
#agents_agents_list_with_http_info(opts = {}) ⇒ Array<(PaginatedAgentList, Integer, Hash)>
Admin-provisioned delegate identities.
-
#agents_agents_partial_update(id, opts = {}) ⇒ Agent
Admin-provisioned delegate identities.
-
#agents_agents_partial_update_with_http_info(id, opts = {}) ⇒ Array<(Agent, Integer, Hash)>
Admin-provisioned delegate identities.
-
#agents_agents_retrieve(id, opts = {}) ⇒ Agent
Admin-provisioned delegate identities.
-
#agents_agents_retrieve_with_http_info(id, opts = {}) ⇒ Array<(Agent, Integer, Hash)>
Admin-provisioned delegate identities.
-
#agents_agents_update(id, agent_request, opts = {}) ⇒ Agent
Admin-provisioned delegate identities.
-
#agents_agents_update_with_http_info(id, agent_request, opts = {}) ⇒ Array<(Agent, Integer, Hash)>
Admin-provisioned delegate identities.
-
#initialize(api_client = ApiClient.default) ⇒ AgentsApi
constructor
A new instance of AgentsApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
11 12 13 |
# File 'lib/authentik/api/api/agents_api.rb', line 11 def api_client @api_client end |
Instance Method Details
#agents_agents_create(opts = {}) ⇒ AgentCreated
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
20 21 22 23 |
# File 'lib/authentik/api/api/agents_api.rb', line 20 def agents_agents_create(opts = {}) data, _status_code, _headers = agents_agents_create_with_http_info(opts) data end |
#agents_agents_create_with_http_info(opts = {}) ⇒ Array<(AgentCreated, Integer, Hash)>
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/authentik/api/api/agents_api.rb', line 29 def agents_agents_create_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AgentsApi.agents_agents_create ...' end # resource path local_var_path = '/agents/agents/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'agent_create_request']) # return_type return_type = opts[:debug_return_type] || 'AgentCreated' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AgentsApi.agents_agents_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AgentsApi#agents_agents_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#agents_agents_destroy(id, opts = {}) ⇒ nil
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
82 83 84 85 |
# File 'lib/authentik/api/api/agents_api.rb', line 82 def agents_agents_destroy(id, opts = {}) agents_agents_destroy_with_http_info(id, opts) nil end |
#agents_agents_destroy_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/authentik/api/api/agents_api.rb', line 91 def agents_agents_destroy_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AgentsApi.agents_agents_destroy ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AgentsApi.agents_agents_destroy" end # resource path local_var_path = '/agents/agents/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AgentsApi.agents_agents_destroy", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AgentsApi#agents_agents_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#agents_agents_list(opts = {}) ⇒ PaginatedAgentList
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
147 148 149 150 |
# File 'lib/authentik/api/api/agents_api.rb', line 147 def agents_agents_list(opts = {}) data, _status_code, _headers = agents_agents_list_with_http_info(opts) data end |
#agents_agents_list_with_http_info(opts = {}) ⇒ Array<(PaginatedAgentList, Integer, Hash)>
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/authentik/api/api/agents_api.rb', line 160 def agents_agents_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AgentsApi.agents_agents_list ...' end # resource path local_var_path = '/agents/agents/' # query parameters query_params = opts[:query_params] || {} query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'parent'] = opts[:'parent'] if !opts[:'parent'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedAgentList' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AgentsApi.agents_agents_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AgentsApi#agents_agents_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#agents_agents_partial_update(id, opts = {}) ⇒ Agent
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
214 215 216 217 |
# File 'lib/authentik/api/api/agents_api.rb', line 214 def agents_agents_partial_update(id, opts = {}) data, _status_code, _headers = agents_agents_partial_update_with_http_info(id, opts) data end |
#agents_agents_partial_update_with_http_info(id, opts = {}) ⇒ Array<(Agent, Integer, Hash)>
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/authentik/api/api/agents_api.rb', line 224 def agents_agents_partial_update_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AgentsApi.agents_agents_partial_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AgentsApi.agents_agents_partial_update" end # resource path local_var_path = '/agents/agents/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_agent_request']) # return_type return_type = opts[:debug_return_type] || 'Agent' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AgentsApi.agents_agents_partial_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AgentsApi#agents_agents_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#agents_agents_retrieve(id, opts = {}) ⇒ Agent
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
281 282 283 284 |
# File 'lib/authentik/api/api/agents_api.rb', line 281 def agents_agents_retrieve(id, opts = {}) data, _status_code, _headers = agents_agents_retrieve_with_http_info(id, opts) data end |
#agents_agents_retrieve_with_http_info(id, opts = {}) ⇒ Array<(Agent, Integer, Hash)>
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/authentik/api/api/agents_api.rb', line 290 def agents_agents_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AgentsApi.agents_agents_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AgentsApi.agents_agents_retrieve" end # resource path local_var_path = '/agents/agents/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Agent' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AgentsApi.agents_agents_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AgentsApi#agents_agents_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#agents_agents_update(id, agent_request, opts = {}) ⇒ Agent
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
343 344 345 346 |
# File 'lib/authentik/api/api/agents_api.rb', line 343 def agents_agents_update(id, agent_request, opts = {}) data, _status_code, _headers = agents_agents_update_with_http_info(id, agent_request, opts) data end |
#agents_agents_update_with_http_info(id, agent_request, opts = {}) ⇒ Array<(Agent, Integer, Hash)>
Admin-provisioned delegate identities. An admin creates a Agent for a given parent user, then grants it access the same way as any other User -- ordinary PolicyBindings pointed at whatever it needs.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/authentik/api/api/agents_api.rb', line 353 def agents_agents_update_with_http_info(id, agent_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AgentsApi.agents_agents_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AgentsApi.agents_agents_update" end # verify the required parameter 'agent_request' is set if @api_client.config.client_side_validation && agent_request.nil? fail ArgumentError, "Missing the required parameter 'agent_request' when calling AgentsApi.agents_agents_update" end # resource path local_var_path = '/agents/agents/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(agent_request) # return_type return_type = opts[:debug_return_type] || 'Agent' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"AgentsApi.agents_agents_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AgentsApi#agents_agents_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |