Class: Authentik::Api::Application
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::Application
- Defined in:
- lib/authentik/api/models/application.rb
Overview
Application Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#backchannel_providers ⇒ Object
Returns the value of attribute backchannel_providers.
-
#backchannel_providers_obj ⇒ Object
Returns the value of attribute backchannel_providers_obj.
-
#group ⇒ Object
Returns the value of attribute group.
-
#launch_url ⇒ Object
Allow formatting of launch URL.
-
#meta_description ⇒ Object
Returns the value of attribute meta_description.
-
#meta_hide ⇒ Object
Hide this application from the user’s My applications page.
-
#meta_icon ⇒ Object
Returns the value of attribute meta_icon.
-
#meta_icon_themed_urls ⇒ Object
Returns the value of attribute meta_icon_themed_urls.
-
#meta_icon_url ⇒ Object
Get the URL to the App Icon image.
-
#meta_launch_url ⇒ Object
Returns the value of attribute meta_launch_url.
-
#meta_publisher ⇒ Object
Returns the value of attribute meta_publisher.
-
#name ⇒ Object
Application’s display Name.
-
#open_in_new_tab ⇒ Object
Open launch URL in a new browser tab or window.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#provider_obj ⇒ Object
Returns the value of attribute provider_obj.
-
#slug ⇒ Object
Internal application name, used in URLs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Application
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Application
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/authentik/api/models/application.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Application` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Application`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'provider_obj') self.provider_obj = attributes[:'provider_obj'] else self.provider_obj = nil end if attributes.key?(:'backchannel_providers') if (value = attributes[:'backchannel_providers']).is_a?(Array) self.backchannel_providers = value end end if attributes.key?(:'backchannel_providers_obj') if (value = attributes[:'backchannel_providers_obj']).is_a?(Array) self.backchannel_providers_obj = value end else self.backchannel_providers_obj = nil end if attributes.key?(:'launch_url') self.launch_url = attributes[:'launch_url'] else self.launch_url = nil end if attributes.key?(:'open_in_new_tab') self.open_in_new_tab = attributes[:'open_in_new_tab'] end if attributes.key?(:'meta_launch_url') self. = attributes[:'meta_launch_url'] end if attributes.key?(:'meta_icon') self. = attributes[:'meta_icon'] end if attributes.key?(:'meta_icon_url') self. = attributes[:'meta_icon_url'] else self. = nil end if attributes.key?(:'meta_icon_themed_urls') self. = attributes[:'meta_icon_themed_urls'] else self. = nil end if attributes.key?(:'meta_description') self. = attributes[:'meta_description'] end if attributes.key?(:'meta_publisher') self. = attributes[:'meta_publisher'] end if attributes.key?(:'policy_engine_mode') self.policy_engine_mode = attributes[:'policy_engine_mode'] end if attributes.key?(:'group') self.group = attributes[:'group'] end if attributes.key?(:'meta_hide') self. = attributes[:'meta_hide'] end end |
Instance Attribute Details
#backchannel_providers ⇒ Object
Returns the value of attribute backchannel_providers.
25 26 27 |
# File 'lib/authentik/api/models/application.rb', line 25 def backchannel_providers @backchannel_providers end |
#backchannel_providers_obj ⇒ Object
Returns the value of attribute backchannel_providers_obj.
27 28 29 |
# File 'lib/authentik/api/models/application.rb', line 27 def backchannel_providers_obj @backchannel_providers_obj end |
#group ⇒ Object
Returns the value of attribute group.
50 51 52 |
# File 'lib/authentik/api/models/application.rb', line 50 def group @group end |
#launch_url ⇒ Object
Allow formatting of launch URL
30 31 32 |
# File 'lib/authentik/api/models/application.rb', line 30 def launch_url @launch_url end |
#meta_description ⇒ Object
Returns the value of attribute meta_description.
44 45 46 |
# File 'lib/authentik/api/models/application.rb', line 44 def @meta_description end |
#meta_hide ⇒ Object
Hide this application from the user’s My applications page.
53 54 55 |
# File 'lib/authentik/api/models/application.rb', line 53 def @meta_hide end |
#meta_icon ⇒ Object
Returns the value of attribute meta_icon.
37 38 39 |
# File 'lib/authentik/api/models/application.rb', line 37 def @meta_icon end |
#meta_icon_themed_urls ⇒ Object
Returns the value of attribute meta_icon_themed_urls.
42 43 44 |
# File 'lib/authentik/api/models/application.rb', line 42 def @meta_icon_themed_urls end |
#meta_icon_url ⇒ Object
Get the URL to the App Icon image
40 41 42 |
# File 'lib/authentik/api/models/application.rb', line 40 def @meta_icon_url end |
#meta_launch_url ⇒ Object
Returns the value of attribute meta_launch_url.
35 36 37 |
# File 'lib/authentik/api/models/application.rb', line 35 def @meta_launch_url end |
#meta_publisher ⇒ Object
Returns the value of attribute meta_publisher.
46 47 48 |
# File 'lib/authentik/api/models/application.rb', line 46 def @meta_publisher end |
#name ⇒ Object
Application’s display Name.
16 17 18 |
# File 'lib/authentik/api/models/application.rb', line 16 def name @name end |
#open_in_new_tab ⇒ Object
Open launch URL in a new browser tab or window.
33 34 35 |
# File 'lib/authentik/api/models/application.rb', line 33 def open_in_new_tab @open_in_new_tab end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/application.rb', line 13 def pk @pk end |
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
48 49 50 |
# File 'lib/authentik/api/models/application.rb', line 48 def policy_engine_mode @policy_engine_mode end |
#provider ⇒ Object
Returns the value of attribute provider.
21 22 23 |
# File 'lib/authentik/api/models/application.rb', line 21 def provider @provider end |
#provider_obj ⇒ Object
Returns the value of attribute provider_obj.
23 24 25 |
# File 'lib/authentik/api/models/application.rb', line 23 def provider_obj @provider_obj end |
#slug ⇒ Object
Internal application name, used in URLs.
19 20 21 |
# File 'lib/authentik/api/models/application.rb', line 19 def slug @slug end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
102 103 104 |
# File 'lib/authentik/api/models/application.rb', line 102 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
107 108 109 |
# File 'lib/authentik/api/models/application.rb', line 107 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/authentik/api/models/application.rb', line 78 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'slug' => :'slug', :'provider' => :'provider', :'provider_obj' => :'provider_obj', :'backchannel_providers' => :'backchannel_providers', :'backchannel_providers_obj' => :'backchannel_providers_obj', :'launch_url' => :'launch_url', :'open_in_new_tab' => :'open_in_new_tab', :'meta_launch_url' => :'meta_launch_url', :'meta_icon' => :'meta_icon', :'meta_icon_url' => :'meta_icon_url', :'meta_icon_themed_urls' => :'meta_icon_themed_urls', :'meta_description' => :'meta_description', :'meta_publisher' => :'meta_publisher', :'policy_engine_mode' => :'policy_engine_mode', :'group' => :'group', :'meta_hide' => :'meta_hide' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/authentik/api/models/application.rb', line 381 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
136 137 138 139 140 141 142 143 144 |
# File 'lib/authentik/api/models/application.rb', line 136 def self.openapi_nullable Set.new([ :'provider', :'provider_obj', :'launch_url', :'meta_icon_url', :'meta_icon_themed_urls', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/authentik/api/models/application.rb', line 112 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'slug' => :'String', :'provider' => :'Integer', :'provider_obj' => :'Provider', :'backchannel_providers' => :'Array<Integer>', :'backchannel_providers_obj' => :'Array<Provider>', :'launch_url' => :'String', :'open_in_new_tab' => :'Boolean', :'meta_launch_url' => :'String', :'meta_icon' => :'String', :'meta_icon_url' => :'String', :'meta_icon_themed_urls' => :'ThemedUrls', :'meta_description' => :'String', :'meta_publisher' => :'String', :'policy_engine_mode' => :'PolicyEngineMode', :'group' => :'String', :'meta_hide' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/authentik/api/models/application.rb', line 343 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && slug == o.slug && provider == o.provider && provider_obj == o.provider_obj && backchannel_providers == o.backchannel_providers && backchannel_providers_obj == o.backchannel_providers_obj && launch_url == o.launch_url && open_in_new_tab == o.open_in_new_tab && == o. && == o. && == o. && == o. && == o. && == o. && policy_engine_mode == o.policy_engine_mode && group == o.group && == o. end |
#eql?(o) ⇒ Boolean
368 369 370 |
# File 'lib/authentik/api/models/application.rb', line 368 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
374 375 376 |
# File 'lib/authentik/api/models/application.rb', line 374 def hash [pk, name, slug, provider, provider_obj, backchannel_providers, backchannel_providers_obj, launch_url, open_in_new_tab, , , , , , , policy_engine_mode, group, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/authentik/api/models/application.rb', line 257 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/) if @slug !~ pattern invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.") end if @backchannel_providers_obj.nil? invalid_properties.push('invalid value for "backchannel_providers_obj", backchannel_providers_obj cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/authentik/api/models/application.rb', line 403 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
286 287 288 289 290 291 292 293 294 |
# File 'lib/authentik/api/models/application.rb', line 286 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @slug.nil? return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/) return false if @backchannel_providers_obj.nil? true end |