Class: Authentik::Api::AuthenticatorSMSStage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::AuthenticatorSMSStage
- Defined in:
- lib/authentik/api/models/authenticator_sms_stage.rb
Overview
AuthenticatorSMSStage Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_sid ⇒ Object
Returns the value of attribute account_sid.
-
#auth ⇒ Object
Returns the value of attribute auth.
-
#auth_password ⇒ Object
Returns the value of attribute auth_password.
-
#auth_type ⇒ Object
Returns the value of attribute auth_type.
-
#component ⇒ Object
Get object type so that we know how to edit the object.
-
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage.
-
#flow_set ⇒ Object
Returns the value of attribute flow_set.
-
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
-
#from_number ⇒ Object
Returns the value of attribute from_number.
-
#mapping ⇒ Object
Optionally modify the payload being sent to custom providers.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#provider ⇒ Object
Returns the value of attribute provider.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
-
#verify_only ⇒ Object
When enabled, the Phone number is only used during enrollment to verify the users authenticity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthenticatorSMSStage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AuthenticatorSMSStage
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 142 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorSMSStage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorSMSStage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'flow_set') if (value = attributes[:'flow_set']).is_a?(Array) self.flow_set = value end else self.flow_set = nil end if attributes.key?(:'configure_flow') self.configure_flow = attributes[:'configure_flow'] end if attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'from_number') self.from_number = attributes[:'from_number'] else self.from_number = nil end if attributes.key?(:'account_sid') self.account_sid = attributes[:'account_sid'] else self.account_sid = nil end if attributes.key?(:'auth') self.auth = attributes[:'auth'] else self.auth = nil end if attributes.key?(:'auth_password') self.auth_password = attributes[:'auth_password'] end if attributes.key?(:'auth_type') self.auth_type = attributes[:'auth_type'] end if attributes.key?(:'verify_only') self.verify_only = attributes[:'verify_only'] end if attributes.key?(:'mapping') self.mapping = attributes[:'mapping'] end end |
Instance Attribute Details
#account_sid ⇒ Object
Returns the value of attribute account_sid.
40 41 42 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 40 def account_sid @account_sid end |
#auth ⇒ Object
Returns the value of attribute auth.
42 43 44 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 42 def auth @auth end |
#auth_password ⇒ Object
Returns the value of attribute auth_password.
44 45 46 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 44 def auth_password @auth_password end |
#auth_type ⇒ Object
Returns the value of attribute auth_type.
46 47 48 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 46 def auth_type @auth_type end |
#component ⇒ Object
Get object type so that we know how to edit the object
18 19 20 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 18 def component @component end |
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.
32 33 34 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 32 def configure_flow @configure_flow end |
#flow_set ⇒ Object
Returns the value of attribute flow_set.
29 30 31 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 29 def flow_set @flow_set end |
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
34 35 36 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 34 def friendly_name @friendly_name end |
#from_number ⇒ Object
Returns the value of attribute from_number.
38 39 40 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 38 def from_number @from_number end |
#mapping ⇒ Object
Optionally modify the payload being sent to custom providers.
52 53 54 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 52 def mapping @mapping end |
#meta_model_name ⇒ Object
Return internal model name
27 28 29 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 27 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 13 def pk @pk end |
#provider ⇒ Object
Returns the value of attribute provider.
36 37 38 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 36 def provider @provider end |
#verbose_name ⇒ Object
Return object’s verbose_name
21 22 23 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 21 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
24 25 26 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 24 def verbose_name_plural @verbose_name_plural end |
#verify_only ⇒ Object
When enabled, the Phone number is only used during enrollment to verify the users authenticity. Only a hash of the phone number is saved to ensure it is not reused in the future.
49 50 51 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 49 def verify_only @verify_only end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
100 101 102 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 100 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
105 106 107 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 105 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 77 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'flow_set' => :'flow_set', :'configure_flow' => :'configure_flow', :'friendly_name' => :'friendly_name', :'provider' => :'provider', :'from_number' => :'from_number', :'account_sid' => :'account_sid', :'auth' => :'auth', :'auth_password' => :'auth_password', :'auth_type' => :'auth_type', :'verify_only' => :'verify_only', :'mapping' => :'mapping' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 468 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
133 134 135 136 137 138 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 133 def self.openapi_nullable Set.new([ :'configure_flow', :'mapping' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 110 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'flow_set' => :'Array<FlowSet>', :'configure_flow' => :'String', :'friendly_name' => :'String', :'provider' => :'ProviderEnum', :'from_number' => :'String', :'account_sid' => :'String', :'auth' => :'String', :'auth_password' => :'String', :'auth_type' => :'AuthTypeEnum', :'verify_only' => :'Boolean', :'mapping' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 431 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && flow_set == o.flow_set && configure_flow == o.configure_flow && friendly_name == o.friendly_name && provider == o.provider && from_number == o.from_number && account_sid == o.account_sid && auth == o.auth && auth_password == o.auth_password && auth_type == o.auth_type && verify_only == o.verify_only && mapping == o.mapping end |
#eql?(o) ⇒ Boolean
455 456 457 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 455 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
461 462 463 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 461 def hash [pk, name, component, verbose_name, verbose_name_plural, , flow_set, configure_flow, friendly_name, provider, from_number, account_sid, auth, auth_password, auth_type, verify_only, mapping].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 251 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @flow_set.nil? invalid_properties.push('invalid value for "flow_set", flow_set cannot be nil.') end if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if @from_number.nil? invalid_properties.push('invalid value for "from_number", from_number cannot be nil.') end if @account_sid.nil? invalid_properties.push('invalid value for "account_sid", account_sid cannot be nil.') end if @auth.nil? invalid_properties.push('invalid value for "auth", auth cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 490 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/authentik/api/models/authenticator_sms_stage.rb', line 303 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @flow_set.nil? return false if @provider.nil? return false if @from_number.nil? return false if @account_sid.nil? return false if @auth.nil? true end |