Class: Authentik::Api::AuthenticatorWebAuthnStage

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/authenticator_web_authn_stage.rb

Overview

AuthenticatorWebAuthnStage Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthenticatorWebAuthnStage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::AuthenticatorWebAuthnStage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::AuthenticatorWebAuthnStage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'flow_set')
    if (value = attributes[:'flow_set']).is_a?(Array)
      self.flow_set = value
    end
  else
    self.flow_set = nil
  end

  if attributes.key?(:'configure_flow')
    self.configure_flow = attributes[:'configure_flow']
  end

  if attributes.key?(:'friendly_name')
    self.friendly_name = attributes[:'friendly_name']
  end

  if attributes.key?(:'user_verification')
    self.user_verification = attributes[:'user_verification']
  end

  if attributes.key?(:'authenticator_attachment')
    self.authenticator_attachment = attributes[:'authenticator_attachment']
  end

  if attributes.key?(:'resident_key_requirement')
    self.resident_key_requirement = attributes[:'resident_key_requirement']
  end

  if attributes.key?(:'hints')
    if (value = attributes[:'hints']).is_a?(Array)
      self.hints = value
    end
  end

  if attributes.key?(:'device_type_restrictions')
    if (value = attributes[:'device_type_restrictions']).is_a?(Array)
      self.device_type_restrictions = value
    end
  end

  if attributes.key?(:'device_type_restrictions_obj')
    if (value = attributes[:'device_type_restrictions_obj']).is_a?(Array)
      self.device_type_restrictions_obj = value
    end
  else
    self.device_type_restrictions_obj = nil
  end

  if attributes.key?(:'prevent_duplicate_devices')
    self.prevent_duplicate_devices = attributes[:'prevent_duplicate_devices']
  end

  if attributes.key?(:'max_attempts')
    self.max_attempts = attributes[:'max_attempts']
  end
end

Instance Attribute Details

#authenticator_attachmentObject

Returns the value of attribute authenticator_attachment.



38
39
40
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 38

def authenticator_attachment
  @authenticator_attachment
end

#componentObject

Get object type so that we know how to edit the object



18
19
20
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 18

def component
  @component
end

#configure_flowObject

Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.



32
33
34
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 32

def configure_flow
  @configure_flow
end

#device_type_restrictionsObject

Returns the value of attribute device_type_restrictions.



44
45
46
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 44

def device_type_restrictions
  @device_type_restrictions
end

#device_type_restrictions_objObject

Returns the value of attribute device_type_restrictions_obj.



46
47
48
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 46

def device_type_restrictions_obj
  @device_type_restrictions_obj
end

#flow_setObject

Returns the value of attribute flow_set.



29
30
31
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 29

def flow_set
  @flow_set
end

#friendly_nameObject

Returns the value of attribute friendly_name.



34
35
36
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 34

def friendly_name
  @friendly_name
end

#hintsObject

Returns the value of attribute hints.



42
43
44
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 42

def hints
  @hints
end

#max_attemptsObject

Returns the value of attribute max_attempts.



51
52
53
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 51

def max_attempts
  @max_attempts
end

#meta_model_nameObject

Return internal model name



27
28
29
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 27

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 15

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 13

def pk
  @pk
end

#prevent_duplicate_devicesObject

When enabled, a given device can only be registered once.



49
50
51
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 49

def prevent_duplicate_devices
  @prevent_duplicate_devices
end

#resident_key_requirementObject

Returns the value of attribute resident_key_requirement.



40
41
42
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 40

def resident_key_requirement
  @resident_key_requirement
end

#user_verificationObject

Returns the value of attribute user_verification.



36
37
38
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 36

def user_verification
  @user_verification
end

#verbose_nameObject

Return object’s verbose_name



21
22
23
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 21

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



24
25
26
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 24

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



99
100
101
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 99

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 104

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 76

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'flow_set' => :'flow_set',
    :'configure_flow' => :'configure_flow',
    :'friendly_name' => :'friendly_name',
    :'user_verification' => :'user_verification',
    :'authenticator_attachment' => :'authenticator_attachment',
    :'resident_key_requirement' => :'resident_key_requirement',
    :'hints' => :'hints',
    :'device_type_restrictions' => :'device_type_restrictions',
    :'device_type_restrictions_obj' => :'device_type_restrictions_obj',
    :'prevent_duplicate_devices' => :'prevent_duplicate_devices',
    :'max_attempts' => :'max_attempts'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 450

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



132
133
134
135
136
137
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 132

def self.openapi_nullable
  Set.new([
    :'configure_flow',
    :'authenticator_attachment',
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 109

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'flow_set' => :'Array<FlowSet>',
    :'configure_flow' => :'String',
    :'friendly_name' => :'String',
    :'user_verification' => :'UserVerificationEnum',
    :'authenticator_attachment' => :'AuthenticatorAttachmentEnum',
    :'resident_key_requirement' => :'UserVerificationEnum',
    :'hints' => :'Array<WebAuthnHintEnum>',
    :'device_type_restrictions' => :'Array<String>',
    :'device_type_restrictions_obj' => :'Array<WebAuthnDeviceType>',
    :'prevent_duplicate_devices' => :'Boolean',
    :'max_attempts' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 413

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      flow_set == o.flow_set &&
      configure_flow == o.configure_flow &&
      friendly_name == o.friendly_name &&
      user_verification == o.user_verification &&
      authenticator_attachment == o.authenticator_attachment &&
      resident_key_requirement == o.resident_key_requirement &&
      hints == o.hints &&
      device_type_restrictions == o.device_type_restrictions &&
      device_type_restrictions_obj == o.device_type_restrictions_obj &&
      prevent_duplicate_devices == o.prevent_duplicate_devices &&
      max_attempts == o.max_attempts
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


437
438
439
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 437

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



443
444
445
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 443

def hash
  [pk, name, component, verbose_name, verbose_name_plural, meta_model_name, flow_set, configure_flow, friendly_name, user_verification, authenticator_attachment, resident_key_requirement, hints, device_type_restrictions, device_type_restrictions_obj, prevent_duplicate_devices, max_attempts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 250

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @flow_set.nil?
    invalid_properties.push('invalid value for "flow_set", flow_set cannot be nil.')
  end

  if @device_type_restrictions_obj.nil?
    invalid_properties.push('invalid value for "device_type_restrictions_obj", device_type_restrictions_obj cannot be nil.')
  end

  if !@max_attempts.nil? && @max_attempts > 2147483647
    invalid_properties.push('invalid value for "max_attempts", must be smaller than or equal to 2147483647.')
  end

  if !@max_attempts.nil? && @max_attempts < 0
    invalid_properties.push('invalid value for "max_attempts", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 472

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/authentik/api/models/authenticator_web_authn_stage.rb', line 298

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @flow_set.nil?
  return false if @device_type_restrictions_obj.nil?
  return false if !@max_attempts.nil? && @max_attempts > 2147483647
  return false if !@max_attempts.nil? && @max_attempts < 0
  true
end