Class: Authentik::Api::Brand

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/brand.rb

Overview

Brand Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Brand

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/authentik/api/models/brand.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Brand` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Brand`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'brand_uuid')
    self.brand_uuid = attributes[:'brand_uuid']
  else
    self.brand_uuid = nil
  end

  if attributes.key?(:'domain')
    self.domain = attributes[:'domain']
  else
    self.domain = nil
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'branding_title')
    self.branding_title = attributes[:'branding_title']
  end

  if attributes.key?(:'branding_logo')
    self. = attributes[:'branding_logo']
  end

  if attributes.key?(:'branding_favicon')
    self.branding_favicon = attributes[:'branding_favicon']
  end

  if attributes.key?(:'branding_custom_css')
    self.branding_custom_css = attributes[:'branding_custom_css']
  end

  if attributes.key?(:'branding_default_flow_background')
    self.branding_default_flow_background = attributes[:'branding_default_flow_background']
  end

  if attributes.key?(:'flow_authentication')
    self.flow_authentication = attributes[:'flow_authentication']
  end

  if attributes.key?(:'flow_invalidation')
    self.flow_invalidation = attributes[:'flow_invalidation']
  end

  if attributes.key?(:'flow_recovery')
    self.flow_recovery = attributes[:'flow_recovery']
  end

  if attributes.key?(:'flow_unenrollment')
    self.flow_unenrollment = attributes[:'flow_unenrollment']
  end

  if attributes.key?(:'flow_user_settings')
    self. = attributes[:'flow_user_settings']
  end

  if attributes.key?(:'flow_device_code')
    self.flow_device_code = attributes[:'flow_device_code']
  end

  if attributes.key?(:'default_application')
    self.default_application = attributes[:'default_application']
  end

  if attributes.key?(:'web_certificate')
    self.web_certificate = attributes[:'web_certificate']
  end

  if attributes.key?(:'client_certificates')
    if (value = attributes[:'client_certificates']).is_a?(Array)
      self.client_certificates = value
    end
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Hash)
      self.attributes = value
    end
  end
end

Instance Attribute Details

#attributesObject

Returns the value of attribute attributes.



51
52
53
# File 'lib/authentik/api/models/brand.rb', line 51

def attributes
  @attributes
end

#brand_uuidObject

Returns the value of attribute brand_uuid.



13
14
15
# File 'lib/authentik/api/models/brand.rb', line 13

def brand_uuid
  @brand_uuid
end

#branding_custom_cssObject

Returns the value of attribute branding_custom_css.



26
27
28
# File 'lib/authentik/api/models/brand.rb', line 26

def branding_custom_css
  @branding_custom_css
end

#branding_default_flow_backgroundObject

Returns the value of attribute branding_default_flow_background.



28
29
30
# File 'lib/authentik/api/models/brand.rb', line 28

def branding_default_flow_background
  @branding_default_flow_background
end

#branding_faviconObject

Returns the value of attribute branding_favicon.



24
25
26
# File 'lib/authentik/api/models/brand.rb', line 24

def branding_favicon
  @branding_favicon
end

#branding_logoObject

Returns the value of attribute branding_logo.



22
23
24
# File 'lib/authentik/api/models/brand.rb', line 22

def 
  @branding_logo
end

#branding_titleObject

Returns the value of attribute branding_title.



20
21
22
# File 'lib/authentik/api/models/brand.rb', line 20

def branding_title
  @branding_title
end

#client_certificatesObject

Certificates used for client authentication.



49
50
51
# File 'lib/authentik/api/models/brand.rb', line 49

def client_certificates
  @client_certificates
end

#defaultObject

Returns the value of attribute default.



18
19
20
# File 'lib/authentik/api/models/brand.rb', line 18

def default
  @default
end

#default_applicationObject

When set, external users will be redirected to this application after authenticating.



43
44
45
# File 'lib/authentik/api/models/brand.rb', line 43

def default_application
  @default_application
end

#domainObject

Domain that activates this brand. Can be a superset, i.e. ‘a.b` for `aa.b` and `ba.b`



16
17
18
# File 'lib/authentik/api/models/brand.rb', line 16

def domain
  @domain
end

#flow_authenticationObject

Returns the value of attribute flow_authentication.



30
31
32
# File 'lib/authentik/api/models/brand.rb', line 30

def flow_authentication
  @flow_authentication
end

#flow_device_codeObject

Returns the value of attribute flow_device_code.



40
41
42
# File 'lib/authentik/api/models/brand.rb', line 40

def flow_device_code
  @flow_device_code
end

#flow_invalidationObject

Returns the value of attribute flow_invalidation.



32
33
34
# File 'lib/authentik/api/models/brand.rb', line 32

def flow_invalidation
  @flow_invalidation
end

#flow_recoveryObject

Returns the value of attribute flow_recovery.



34
35
36
# File 'lib/authentik/api/models/brand.rb', line 34

def flow_recovery
  @flow_recovery
end

#flow_unenrollmentObject

Returns the value of attribute flow_unenrollment.



36
37
38
# File 'lib/authentik/api/models/brand.rb', line 36

def flow_unenrollment
  @flow_unenrollment
end

#flow_user_settingsObject

Returns the value of attribute flow_user_settings.



38
39
40
# File 'lib/authentik/api/models/brand.rb', line 38

def 
  @flow_user_settings
end

#web_certificateObject

Web Certificate used by the authentik Core webserver.



46
47
48
# File 'lib/authentik/api/models/brand.rb', line 46

def web_certificate
  @web_certificate
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/authentik/api/models/brand.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/authentik/api/models/brand.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/authentik/api/models/brand.rb', line 54

def self.attribute_map
  {
    :'brand_uuid' => :'brand_uuid',
    :'domain' => :'domain',
    :'default' => :'default',
    :'branding_title' => :'branding_title',
    :'branding_logo' => :'branding_logo',
    :'branding_favicon' => :'branding_favicon',
    :'branding_custom_css' => :'branding_custom_css',
    :'branding_default_flow_background' => :'branding_default_flow_background',
    :'flow_authentication' => :'flow_authentication',
    :'flow_invalidation' => :'flow_invalidation',
    :'flow_recovery' => :'flow_recovery',
    :'flow_unenrollment' => :'flow_unenrollment',
    :'flow_user_settings' => :'flow_user_settings',
    :'flow_device_code' => :'flow_device_code',
    :'default_application' => :'default_application',
    :'web_certificate' => :'web_certificate',
    :'client_certificates' => :'client_certificates',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/authentik/api/models/brand.rb', line 307

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/authentik/api/models/brand.rb', line 112

def self.openapi_nullable
  Set.new([
    :'flow_authentication',
    :'flow_invalidation',
    :'flow_recovery',
    :'flow_unenrollment',
    :'flow_user_settings',
    :'flow_device_code',
    :'default_application',
    :'web_certificate',
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/authentik/api/models/brand.rb', line 88

def self.openapi_types
  {
    :'brand_uuid' => :'String',
    :'domain' => :'String',
    :'default' => :'Boolean',
    :'branding_title' => :'String',
    :'branding_logo' => :'String',
    :'branding_favicon' => :'String',
    :'branding_custom_css' => :'String',
    :'branding_default_flow_background' => :'String',
    :'flow_authentication' => :'String',
    :'flow_invalidation' => :'String',
    :'flow_recovery' => :'String',
    :'flow_unenrollment' => :'String',
    :'flow_user_settings' => :'String',
    :'flow_device_code' => :'String',
    :'default_application' => :'String',
    :'web_certificate' => :'String',
    :'client_certificates' => :'Array<String>',
    :'attributes' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/authentik/api/models/brand.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      brand_uuid == o.brand_uuid &&
      domain == o.domain &&
      default == o.default &&
      branding_title == o.branding_title &&
       == o. &&
      branding_favicon == o.branding_favicon &&
      branding_custom_css == o.branding_custom_css &&
      branding_default_flow_background == o.branding_default_flow_background &&
      flow_authentication == o.flow_authentication &&
      flow_invalidation == o.flow_invalidation &&
      flow_recovery == o.flow_recovery &&
      flow_unenrollment == o.flow_unenrollment &&
       == o. &&
      flow_device_code == o.flow_device_code &&
      default_application == o.default_application &&
      web_certificate == o.web_certificate &&
      client_certificates == o.client_certificates &&
      attributes == o.attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


294
295
296
# File 'lib/authentik/api/models/brand.rb', line 294

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



300
301
302
# File 'lib/authentik/api/models/brand.rb', line 300

def hash
  [brand_uuid, domain, default, branding_title, , branding_favicon, branding_custom_css, branding_default_flow_background, flow_authentication, flow_invalidation, flow_recovery, flow_unenrollment, , flow_device_code, default_application, web_certificate, client_certificates, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/authentik/api/models/brand.rb', line 224

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @brand_uuid.nil?
    invalid_properties.push('invalid value for "brand_uuid", brand_uuid cannot be nil.')
  end

  if @domain.nil?
    invalid_properties.push('invalid value for "domain", domain cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/authentik/api/models/brand.rb', line 329

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



240
241
242
243
244
245
# File 'lib/authentik/api/models/brand.rb', line 240

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @brand_uuid.nil?
  return false if @domain.nil?
  true
end