Class: Authentik::Api::CaptchaStage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::CaptchaStage
- Defined in:
- lib/authentik/api/models/captcha_stage.rb
Overview
CaptchaStage Serializer
Instance Attribute Summary collapse
-
#api_url ⇒ Object
Returns the value of attribute api_url.
-
#component ⇒ Object
Get object type so that we know how to edit the object.
-
#error_on_invalid_score ⇒ Object
When enabled and the received captcha score is outside of the given threshold, the stage will show an error message.
-
#flow_set ⇒ Object
Returns the value of attribute flow_set.
-
#interactive ⇒ Object
Returns the value of attribute interactive.
-
#js_url ⇒ Object
Returns the value of attribute js_url.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#public_key ⇒ Object
Public key, acquired your captcha Provider.
-
#score_max_threshold ⇒ Object
Returns the value of attribute score_max_threshold.
-
#score_min_threshold ⇒ Object
Returns the value of attribute score_min_threshold.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CaptchaStage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CaptchaStage
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::CaptchaStage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::CaptchaStage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'flow_set') if (value = attributes[:'flow_set']).is_a?(Array) self.flow_set = value end else self.flow_set = nil end if attributes.key?(:'public_key') self.public_key = attributes[:'public_key'] else self.public_key = nil end if attributes.key?(:'js_url') self.js_url = attributes[:'js_url'] end if attributes.key?(:'api_url') self.api_url = attributes[:'api_url'] end if attributes.key?(:'interactive') self.interactive = attributes[:'interactive'] end if attributes.key?(:'score_min_threshold') self.score_min_threshold = attributes[:'score_min_threshold'] end if attributes.key?(:'score_max_threshold') self.score_max_threshold = attributes[:'score_max_threshold'] end if attributes.key?(:'error_on_invalid_score') self.error_on_invalid_score = attributes[:'error_on_invalid_score'] end end |
Instance Attribute Details
#api_url ⇒ Object
Returns the value of attribute api_url.
36 37 38 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 36 def api_url @api_url end |
#component ⇒ Object
Get object type so that we know how to edit the object
18 19 20 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 18 def component @component end |
#error_on_invalid_score ⇒ Object
When enabled and the received captcha score is outside of the given threshold, the stage will show an error message. When not enabled, the flow will continue, but the data from the captcha will be available in the context for policy decisions
45 46 47 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 45 def error_on_invalid_score @error_on_invalid_score end |
#flow_set ⇒ Object
Returns the value of attribute flow_set.
29 30 31 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 29 def flow_set @flow_set end |
#interactive ⇒ Object
Returns the value of attribute interactive.
38 39 40 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 38 def interactive @interactive end |
#js_url ⇒ Object
Returns the value of attribute js_url.
34 35 36 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 34 def js_url @js_url end |
#meta_model_name ⇒ Object
Return internal model name
27 28 29 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 27 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 13 def pk @pk end |
#public_key ⇒ Object
Public key, acquired your captcha Provider.
32 33 34 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 32 def public_key @public_key end |
#score_max_threshold ⇒ Object
Returns the value of attribute score_max_threshold.
42 43 44 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 42 def score_max_threshold @score_max_threshold end |
#score_min_threshold ⇒ Object
Returns the value of attribute score_min_threshold.
40 41 42 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 40 def score_min_threshold @score_min_threshold end |
#verbose_name ⇒ Object
Return object’s verbose_name
21 22 23 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 21 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
24 25 26 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 24 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 48 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'flow_set' => :'flow_set', :'public_key' => :'public_key', :'js_url' => :'js_url', :'api_url' => :'api_url', :'interactive' => :'interactive', :'score_min_threshold' => :'score_min_threshold', :'score_max_threshold' => :'score_max_threshold', :'error_on_invalid_score' => :'error_on_invalid_score' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 365 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 78 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'flow_set' => :'Array<FlowSet>', :'public_key' => :'String', :'js_url' => :'String', :'api_url' => :'String', :'interactive' => :'Boolean', :'score_min_threshold' => :'Float', :'score_max_threshold' => :'Float', :'error_on_invalid_score' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 331 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && flow_set == o.flow_set && public_key == o.public_key && js_url == o.js_url && api_url == o.api_url && interactive == o.interactive && score_min_threshold == o.score_min_threshold && score_max_threshold == o.score_max_threshold && error_on_invalid_score == o.error_on_invalid_score end |
#eql?(o) ⇒ Boolean
352 353 354 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 352 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
358 359 360 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 358 def hash [pk, name, component, verbose_name, verbose_name_plural, , flow_set, public_key, js_url, api_url, interactive, score_min_threshold, score_max_threshold, error_on_invalid_score].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @flow_set.nil? invalid_properties.push('invalid value for "flow_set", flow_set cannot be nil.') end if @public_key.nil? invalid_properties.push('invalid value for "public_key", public_key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 387 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/authentik/api/models/captcha_stage.rb', line 236 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @flow_set.nil? return false if @public_key.nil? true end |