Class: Authentik::Api::CaptchaStageRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/captcha_stage_request.rb

Overview

CaptchaStage Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CaptchaStageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::CaptchaStageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::CaptchaStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'public_key')
    self.public_key = attributes[:'public_key']
  else
    self.public_key = nil
  end

  if attributes.key?(:'private_key')
    self.private_key = attributes[:'private_key']
  else
    self.private_key = nil
  end

  if attributes.key?(:'js_url')
    self.js_url = attributes[:'js_url']
  end

  if attributes.key?(:'api_url')
    self.api_url = attributes[:'api_url']
  end

  if attributes.key?(:'interactive')
    self.interactive = attributes[:'interactive']
  end

  if attributes.key?(:'score_min_threshold')
    self.score_min_threshold = attributes[:'score_min_threshold']
  end

  if attributes.key?(:'score_max_threshold')
    self.score_max_threshold = attributes[:'score_max_threshold']
  end

  if attributes.key?(:'error_on_invalid_score')
    self.error_on_invalid_score = attributes[:'error_on_invalid_score']
  end
end

Instance Attribute Details

#api_urlObject

Returns the value of attribute api_url.



23
24
25
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 23

def api_url
  @api_url
end

#error_on_invalid_scoreObject

When enabled and the received captcha score is outside of the given threshold, the stage will show an error message. When not enabled, the flow will continue, but the data from the captcha will be available in the context for policy decisions



32
33
34
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 32

def error_on_invalid_score
  @error_on_invalid_score
end

#interactiveObject

Returns the value of attribute interactive.



25
26
27
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 25

def interactive
  @interactive
end

#js_urlObject

Returns the value of attribute js_url.



21
22
23
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 21

def js_url
  @js_url
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 13

def name
  @name
end

#private_keyObject

Private key, acquired your captcha Provider.



19
20
21
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 19

def private_key
  @private_key
end

#public_keyObject

Public key, acquired your captcha Provider.



16
17
18
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 16

def public_key
  @public_key
end

#score_max_thresholdObject

Returns the value of attribute score_max_threshold.



29
30
31
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 29

def score_max_threshold
  @score_max_threshold
end

#score_min_thresholdObject

Returns the value of attribute score_min_threshold.



27
28
29
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 27

def score_min_threshold
  @score_min_threshold
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 35

def self.attribute_map
  {
    :'name' => :'name',
    :'public_key' => :'public_key',
    :'private_key' => :'private_key',
    :'js_url' => :'js_url',
    :'api_url' => :'api_url',
    :'interactive' => :'interactive',
    :'score_min_threshold' => :'score_min_threshold',
    :'score_max_threshold' => :'score_max_threshold',
    :'error_on_invalid_score' => :'error_on_invalid_score'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 295

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 75

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 60

def self.openapi_types
  {
    :'name' => :'String',
    :'public_key' => :'String',
    :'private_key' => :'String',
    :'js_url' => :'String',
    :'api_url' => :'String',
    :'interactive' => :'Boolean',
    :'score_min_threshold' => :'Float',
    :'score_max_threshold' => :'Float',
    :'error_on_invalid_score' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 266

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      public_key == o.public_key &&
      private_key == o.private_key &&
      js_url == o.js_url &&
      api_url == o.api_url &&
      interactive == o.interactive &&
      score_min_threshold == o.score_min_threshold &&
      score_max_threshold == o.score_max_threshold &&
      error_on_invalid_score == o.error_on_invalid_score
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


282
283
284
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 282

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



288
289
290
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 288

def hash
  [name, public_key, private_key, js_url, api_url, interactive, score_min_threshold, score_max_threshold, error_on_invalid_score].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @public_key.nil?
    invalid_properties.push('invalid value for "public_key", public_key cannot be nil.')
  end

  if @public_key.to_s.length < 1
    invalid_properties.push('invalid value for "public_key", the character length must be greater than or equal to 1.')
  end

  if @private_key.nil?
    invalid_properties.push('invalid value for "private_key", private_key cannot be nil.')
  end

  if @private_key.to_s.length < 1
    invalid_properties.push('invalid value for "private_key", the character length must be greater than or equal to 1.')
  end

  if !@js_url.nil? && @js_url.to_s.length < 1
    invalid_properties.push('invalid value for "js_url", the character length must be greater than or equal to 1.')
  end

  if !@api_url.nil? && @api_url.to_s.length < 1
    invalid_properties.push('invalid value for "api_url", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 317

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/authentik/api/models/captcha_stage_request.rb', line 181

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @public_key.nil?
  return false if @public_key.to_s.length < 1
  return false if @private_key.nil?
  return false if @private_key.to_s.length < 1
  return false if !@js_url.nil? && @js_url.to_s.length < 1
  return false if !@api_url.nil? && @api_url.to_s.length < 1
  true
end