Class: Authentik::Api::CertificateKeyPair
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::CertificateKeyPair
- Defined in:
- lib/authentik/api/models/certificate_key_pair.rb
Overview
CertificateKeyPair Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cert_expiry ⇒ Object
Certificate expiry date.
-
#cert_subject ⇒ Object
Certificate subject as RFC4514 string.
-
#certificate_download_url ⇒ Object
Get URL to download certificate.
-
#fingerprint_sha1 ⇒ Object
SHA1 fingerprint of the certificate.
-
#fingerprint_sha256 ⇒ Object
SHA256 fingerprint of the certificate.
-
#key_type ⇒ Object
Key algorithm type detected from the certificate’s public key.
-
#managed ⇒ Object
Objects that are managed by authentik.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#private_key_available ⇒ Object
Show if this keypair has a private key configured or not.
-
#private_key_download_url ⇒ Object
Get URL to download private key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CertificateKeyPair
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CertificateKeyPair
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 124 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::CertificateKeyPair` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::CertificateKeyPair`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'fingerprint_sha256') self.fingerprint_sha256 = attributes[:'fingerprint_sha256'] else self.fingerprint_sha256 = nil end if attributes.key?(:'fingerprint_sha1') self.fingerprint_sha1 = attributes[:'fingerprint_sha1'] else self.fingerprint_sha1 = nil end if attributes.key?(:'cert_expiry') self.cert_expiry = attributes[:'cert_expiry'] else self.cert_expiry = nil end if attributes.key?(:'cert_subject') self.cert_subject = attributes[:'cert_subject'] else self.cert_subject = nil end if attributes.key?(:'private_key_available') self.private_key_available = attributes[:'private_key_available'] else self.private_key_available = nil end if attributes.key?(:'key_type') self.key_type = attributes[:'key_type'] else self.key_type = nil end if attributes.key?(:'certificate_download_url') self.certificate_download_url = attributes[:'certificate_download_url'] else self.certificate_download_url = nil end if attributes.key?(:'private_key_download_url') self.private_key_download_url = attributes[:'private_key_download_url'] else self.private_key_download_url = nil end if attributes.key?(:'managed') self.managed = attributes[:'managed'] else self.managed = nil end end |
Instance Attribute Details
#cert_expiry ⇒ Object
Certificate expiry date
24 25 26 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 24 def cert_expiry @cert_expiry end |
#cert_subject ⇒ Object
Certificate subject as RFC4514 string
27 28 29 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 27 def cert_subject @cert_subject end |
#certificate_download_url ⇒ Object
Get URL to download certificate
36 37 38 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 36 def certificate_download_url @certificate_download_url end |
#fingerprint_sha1 ⇒ Object
SHA1 fingerprint of the certificate
21 22 23 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 21 def fingerprint_sha1 @fingerprint_sha1 end |
#fingerprint_sha256 ⇒ Object
SHA256 fingerprint of the certificate
18 19 20 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 18 def fingerprint_sha256 @fingerprint_sha256 end |
#key_type ⇒ Object
Key algorithm type detected from the certificate’s public key
33 34 35 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 33 def key_type @key_type end |
#managed ⇒ Object
Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
42 43 44 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 42 def managed @managed end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 13 def pk @pk end |
#private_key_available ⇒ Object
Show if this keypair has a private key configured or not
30 31 32 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 30 def private_key_available @private_key_available end |
#private_key_download_url ⇒ Object
Get URL to download private key
39 40 41 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 39 def private_key_download_url @private_key_download_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
84 85 86 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 84 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 89 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 67 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'fingerprint_sha256' => :'fingerprint_sha256', :'fingerprint_sha1' => :'fingerprint_sha1', :'cert_expiry' => :'cert_expiry', :'cert_subject' => :'cert_subject', :'private_key_available' => :'private_key_available', :'key_type' => :'key_type', :'certificate_download_url' => :'certificate_download_url', :'private_key_download_url' => :'private_key_download_url', :'managed' => :'managed' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 328 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 111 def self.openapi_nullable Set.new([ :'fingerprint_sha256', :'fingerprint_sha1', :'cert_expiry', :'cert_subject', :'key_type', :'managed' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 94 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'fingerprint_sha256' => :'String', :'fingerprint_sha1' => :'String', :'cert_expiry' => :'Time', :'cert_subject' => :'String', :'private_key_available' => :'Boolean', :'key_type' => :'KeyTypeEnum', :'certificate_download_url' => :'String', :'private_key_download_url' => :'String', :'managed' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 297 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && fingerprint_sha256 == o.fingerprint_sha256 && fingerprint_sha1 == o.fingerprint_sha1 && cert_expiry == o.cert_expiry && cert_subject == o.cert_subject && private_key_available == o.private_key_available && key_type == o.key_type && certificate_download_url == o.certificate_download_url && private_key_download_url == o.private_key_download_url && managed == o.managed end |
#eql?(o) ⇒ Boolean
315 316 317 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 315 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
321 322 323 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 321 def hash [pk, name, fingerprint_sha256, fingerprint_sha1, cert_expiry, cert_subject, private_key_available, key_type, certificate_download_url, private_key_download_url, managed].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 207 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @private_key_available.nil? invalid_properties.push('invalid value for "private_key_available", private_key_available cannot be nil.') end if @certificate_download_url.nil? invalid_properties.push('invalid value for "certificate_download_url", certificate_download_url cannot be nil.') end if @private_key_download_url.nil? invalid_properties.push('invalid value for "private_key_download_url", private_key_download_url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 350 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 241 242 243 |
# File 'lib/authentik/api/models/certificate_key_pair.rb', line 235 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @private_key_available.nil? return false if @certificate_download_url.nil? return false if @private_key_download_url.nil? true end |