Class: Authentik::Api::Config
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::Config
- Defined in:
- lib/authentik/api/models/config.rb
Overview
Serialize authentik Config into DRF Object
Instance Attribute Summary collapse
-
#cache_timeout ⇒ Object
Returns the value of attribute cache_timeout.
-
#cache_timeout_flows ⇒ Object
Returns the value of attribute cache_timeout_flows.
-
#cache_timeout_policies ⇒ Object
Returns the value of attribute cache_timeout_policies.
-
#capabilities ⇒ Object
Returns the value of attribute capabilities.
-
#error_reporting ⇒ Object
Returns the value of attribute error_reporting.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Config
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Config
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/authentik/api/models/config.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Config` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Config`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'error_reporting') self.error_reporting = attributes[:'error_reporting'] else self.error_reporting = nil end if attributes.key?(:'capabilities') if (value = attributes[:'capabilities']).is_a?(Array) self.capabilities = value end else self.capabilities = nil end if attributes.key?(:'cache_timeout') self.cache_timeout = attributes[:'cache_timeout'] else self.cache_timeout = nil end if attributes.key?(:'cache_timeout_flows') self.cache_timeout_flows = attributes[:'cache_timeout_flows'] else self.cache_timeout_flows = nil end if attributes.key?(:'cache_timeout_policies') self.cache_timeout_policies = attributes[:'cache_timeout_policies'] else self.cache_timeout_policies = nil end end |
Instance Attribute Details
#cache_timeout ⇒ Object
Returns the value of attribute cache_timeout.
17 18 19 |
# File 'lib/authentik/api/models/config.rb', line 17 def cache_timeout @cache_timeout end |
#cache_timeout_flows ⇒ Object
Returns the value of attribute cache_timeout_flows.
19 20 21 |
# File 'lib/authentik/api/models/config.rb', line 19 def cache_timeout_flows @cache_timeout_flows end |
#cache_timeout_policies ⇒ Object
Returns the value of attribute cache_timeout_policies.
21 22 23 |
# File 'lib/authentik/api/models/config.rb', line 21 def cache_timeout_policies @cache_timeout_policies end |
#capabilities ⇒ Object
Returns the value of attribute capabilities.
15 16 17 |
# File 'lib/authentik/api/models/config.rb', line 15 def capabilities @capabilities end |
#error_reporting ⇒ Object
Returns the value of attribute error_reporting.
13 14 15 |
# File 'lib/authentik/api/models/config.rb', line 13 def error_reporting @error_reporting end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/authentik/api/models/config.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/authentik/api/models/config.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 30 31 32 |
# File 'lib/authentik/api/models/config.rb', line 24 def self.attribute_map { :'error_reporting' => :'error_reporting', :'capabilities' => :'capabilities', :'cache_timeout' => :'cache_timeout', :'cache_timeout_flows' => :'cache_timeout_flows', :'cache_timeout_policies' => :'cache_timeout_policies' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/authentik/api/models/config.rb', line 227 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/authentik/api/models/config.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 |
# File 'lib/authentik/api/models/config.rb', line 45 def self.openapi_types { :'error_reporting' => :'ErrorReportingConfig', :'capabilities' => :'Array<CapabilitiesEnum>', :'cache_timeout' => :'Integer', :'cache_timeout_flows' => :'Integer', :'cache_timeout_policies' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 |
# File 'lib/authentik/api/models/config.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && error_reporting == o.error_reporting && capabilities == o.capabilities && cache_timeout == o.cache_timeout && cache_timeout_flows == o.cache_timeout_flows && cache_timeout_policies == o.cache_timeout_policies end |
#eql?(o) ⇒ Boolean
214 215 216 |
# File 'lib/authentik/api/models/config.rb', line 214 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/authentik/api/models/config.rb', line 220 def hash [error_reporting, capabilities, cache_timeout, cache_timeout_flows, cache_timeout_policies].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/authentik/api/models/config.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @error_reporting.nil? invalid_properties.push('invalid value for "error_reporting", error_reporting cannot be nil.') end if @capabilities.nil? invalid_properties.push('invalid value for "capabilities", capabilities cannot be nil.') end if @cache_timeout.nil? invalid_properties.push('invalid value for "cache_timeout", cache_timeout cannot be nil.') end if @cache_timeout_flows.nil? invalid_properties.push('invalid value for "cache_timeout_flows", cache_timeout_flows cannot be nil.') end if @cache_timeout_policies.nil? invalid_properties.push('invalid value for "cache_timeout_policies", cache_timeout_policies cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/authentik/api/models/config.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 144 145 146 147 148 |
# File 'lib/authentik/api/models/config.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @error_reporting.nil? return false if @capabilities.nil? return false if @cache_timeout.nil? return false if @cache_timeout_flows.nil? return false if @cache_timeout_policies.nil? true end |