Class: Authentik::Api::Connector
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::Connector
- Defined in:
- lib/authentik/api/models/connector.rb
Instance Attribute Summary collapse
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#connector_uuid ⇒ Object
Returns the value of attribute connector_uuid.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Connector
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Connector
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/authentik/api/models/connector.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Connector` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Connector`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'connector_uuid') self.connector_uuid = attributes[:'connector_uuid'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end end |
Instance Attribute Details
#component ⇒ Object
Get object component so that we know how to edit the object
19 20 21 |
# File 'lib/authentik/api/models/connector.rb', line 19 def component @component end |
#connector_uuid ⇒ Object
Returns the value of attribute connector_uuid.
12 13 14 |
# File 'lib/authentik/api/models/connector.rb', line 12 def connector_uuid @connector_uuid end |
#enabled ⇒ Object
Returns the value of attribute enabled.
16 17 18 |
# File 'lib/authentik/api/models/connector.rb', line 16 def enabled @enabled end |
#meta_model_name ⇒ Object
Return internal model name
28 29 30 |
# File 'lib/authentik/api/models/connector.rb', line 28 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
14 15 16 |
# File 'lib/authentik/api/models/connector.rb', line 14 def name @name end |
#verbose_name ⇒ Object
Return object’s verbose_name
22 23 24 |
# File 'lib/authentik/api/models/connector.rb', line 22 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
25 26 27 |
# File 'lib/authentik/api/models/connector.rb', line 25 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/authentik/api/models/connector.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/authentik/api/models/connector.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 |
# File 'lib/authentik/api/models/connector.rb', line 31 def self.attribute_map { :'connector_uuid' => :'connector_uuid', :'name' => :'name', :'enabled' => :'enabled', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/authentik/api/models/connector.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/authentik/api/models/connector.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/authentik/api/models/connector.rb', line 54 def self.openapi_types { :'connector_uuid' => :'String', :'name' => :'String', :'enabled' => :'Boolean', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/authentik/api/models/connector.rb', line 219 def ==(o) return true if self.equal?(o) self.class == o.class && connector_uuid == o.connector_uuid && name == o.name && enabled == o.enabled && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/authentik/api/models/connector.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/authentik/api/models/connector.rb', line 239 def hash [connector_uuid, name, enabled, component, verbose_name, verbose_name_plural, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/authentik/api/models/connector.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/authentik/api/models/connector.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 164 165 |
# File 'lib/authentik/api/models/connector.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? true end |