Class: Authentik::Api::CurrentBrand
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::CurrentBrand
- Defined in:
- lib/authentik/api/models/current_brand.rb
Overview
Partial brand information for styling
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#branding_custom_css ⇒ Object
Returns the value of attribute branding_custom_css.
-
#branding_favicon ⇒ Object
Returns the value of attribute branding_favicon.
-
#branding_favicon_themed_urls ⇒ Object
Returns the value of attribute branding_favicon_themed_urls.
-
#branding_logo ⇒ Object
Returns the value of attribute branding_logo.
-
#branding_logo_themed_urls ⇒ Object
Returns the value of attribute branding_logo_themed_urls.
-
#branding_title ⇒ Object
Returns the value of attribute branding_title.
-
#default_locale ⇒ Object
Returns the value of attribute default_locale.
-
#flags ⇒ Object
Returns the value of attribute flags.
-
#flow_authentication ⇒ Object
Returns the value of attribute flow_authentication.
-
#flow_device_code ⇒ Object
Returns the value of attribute flow_device_code.
-
#flow_invalidation ⇒ Object
Returns the value of attribute flow_invalidation.
-
#flow_recovery ⇒ Object
Returns the value of attribute flow_recovery.
-
#flow_unenrollment ⇒ Object
Returns the value of attribute flow_unenrollment.
-
#flow_user_settings ⇒ Object
Returns the value of attribute flow_user_settings.
-
#matched_domain ⇒ Object
Returns the value of attribute matched_domain.
-
#ui_footer_links ⇒ Object
Returns the value of attribute ui_footer_links.
-
#ui_theme ⇒ Object
Returns the value of attribute ui_theme.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CurrentBrand
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CurrentBrand
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/authentik/api/models/current_brand.rb', line 135 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::CurrentBrand` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::CurrentBrand`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'matched_domain') self.matched_domain = attributes[:'matched_domain'] else self.matched_domain = nil end if attributes.key?(:'branding_title') self.branding_title = attributes[:'branding_title'] else self.branding_title = nil end if attributes.key?(:'branding_logo') self.branding_logo = attributes[:'branding_logo'] else self.branding_logo = nil end if attributes.key?(:'branding_logo_themed_urls') self.branding_logo_themed_urls = attributes[:'branding_logo_themed_urls'] else self.branding_logo_themed_urls = nil end if attributes.key?(:'branding_favicon') self.branding_favicon = attributes[:'branding_favicon'] else self.branding_favicon = nil end if attributes.key?(:'branding_favicon_themed_urls') self.branding_favicon_themed_urls = attributes[:'branding_favicon_themed_urls'] else self.branding_favicon_themed_urls = nil end if attributes.key?(:'branding_custom_css') self.branding_custom_css = attributes[:'branding_custom_css'] else self.branding_custom_css = nil end if attributes.key?(:'ui_footer_links') if (value = attributes[:'ui_footer_links']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'ui_theme') self.ui_theme = attributes[:'ui_theme'] else self.ui_theme = nil end if attributes.key?(:'flow_authentication') self.flow_authentication = attributes[:'flow_authentication'] end if attributes.key?(:'flow_invalidation') self.flow_invalidation = attributes[:'flow_invalidation'] end if attributes.key?(:'flow_recovery') self.flow_recovery = attributes[:'flow_recovery'] end if attributes.key?(:'flow_unenrollment') self.flow_unenrollment = attributes[:'flow_unenrollment'] end if attributes.key?(:'flow_user_settings') self.flow_user_settings = attributes[:'flow_user_settings'] end if attributes.key?(:'flow_device_code') self.flow_device_code = attributes[:'flow_device_code'] end if attributes.key?(:'default_locale') self.default_locale = attributes[:'default_locale'] else self.default_locale = nil end if attributes.key?(:'flags') self.flags = attributes[:'flags'] else self.flags = nil end end |
Instance Attribute Details
#branding_custom_css ⇒ Object
Returns the value of attribute branding_custom_css.
25 26 27 |
# File 'lib/authentik/api/models/current_brand.rb', line 25 def branding_custom_css @branding_custom_css end |
#branding_favicon ⇒ Object
Returns the value of attribute branding_favicon.
21 22 23 |
# File 'lib/authentik/api/models/current_brand.rb', line 21 def branding_favicon @branding_favicon end |
#branding_favicon_themed_urls ⇒ Object
Returns the value of attribute branding_favicon_themed_urls.
23 24 25 |
# File 'lib/authentik/api/models/current_brand.rb', line 23 def branding_favicon_themed_urls @branding_favicon_themed_urls end |
#branding_logo ⇒ Object
Returns the value of attribute branding_logo.
17 18 19 |
# File 'lib/authentik/api/models/current_brand.rb', line 17 def branding_logo @branding_logo end |
#branding_logo_themed_urls ⇒ Object
Returns the value of attribute branding_logo_themed_urls.
19 20 21 |
# File 'lib/authentik/api/models/current_brand.rb', line 19 def branding_logo_themed_urls @branding_logo_themed_urls end |
#branding_title ⇒ Object
Returns the value of attribute branding_title.
15 16 17 |
# File 'lib/authentik/api/models/current_brand.rb', line 15 def branding_title @branding_title end |
#default_locale ⇒ Object
Returns the value of attribute default_locale.
43 44 45 |
# File 'lib/authentik/api/models/current_brand.rb', line 43 def default_locale @default_locale end |
#flags ⇒ Object
Returns the value of attribute flags.
45 46 47 |
# File 'lib/authentik/api/models/current_brand.rb', line 45 def flags @flags end |
#flow_authentication ⇒ Object
Returns the value of attribute flow_authentication.
31 32 33 |
# File 'lib/authentik/api/models/current_brand.rb', line 31 def flow_authentication @flow_authentication end |
#flow_device_code ⇒ Object
Returns the value of attribute flow_device_code.
41 42 43 |
# File 'lib/authentik/api/models/current_brand.rb', line 41 def flow_device_code @flow_device_code end |
#flow_invalidation ⇒ Object
Returns the value of attribute flow_invalidation.
33 34 35 |
# File 'lib/authentik/api/models/current_brand.rb', line 33 def flow_invalidation @flow_invalidation end |
#flow_recovery ⇒ Object
Returns the value of attribute flow_recovery.
35 36 37 |
# File 'lib/authentik/api/models/current_brand.rb', line 35 def flow_recovery @flow_recovery end |
#flow_unenrollment ⇒ Object
Returns the value of attribute flow_unenrollment.
37 38 39 |
# File 'lib/authentik/api/models/current_brand.rb', line 37 def flow_unenrollment @flow_unenrollment end |
#flow_user_settings ⇒ Object
Returns the value of attribute flow_user_settings.
39 40 41 |
# File 'lib/authentik/api/models/current_brand.rb', line 39 def flow_user_settings @flow_user_settings end |
#matched_domain ⇒ Object
Returns the value of attribute matched_domain.
13 14 15 |
# File 'lib/authentik/api/models/current_brand.rb', line 13 def matched_domain @matched_domain end |
#ui_footer_links ⇒ Object
Returns the value of attribute ui_footer_links.
27 28 29 |
# File 'lib/authentik/api/models/current_brand.rb', line 27 def @ui_footer_links end |
#ui_theme ⇒ Object
Returns the value of attribute ui_theme.
29 30 31 |
# File 'lib/authentik/api/models/current_brand.rb', line 29 def ui_theme @ui_theme end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
93 94 95 |
# File 'lib/authentik/api/models/current_brand.rb', line 93 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/authentik/api/models/current_brand.rb', line 98 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/authentik/api/models/current_brand.rb', line 70 def self.attribute_map { :'matched_domain' => :'matched_domain', :'branding_title' => :'branding_title', :'branding_logo' => :'branding_logo', :'branding_logo_themed_urls' => :'branding_logo_themed_urls', :'branding_favicon' => :'branding_favicon', :'branding_favicon_themed_urls' => :'branding_favicon_themed_urls', :'branding_custom_css' => :'branding_custom_css', :'ui_footer_links' => :'ui_footer_links', :'ui_theme' => :'ui_theme', :'flow_authentication' => :'flow_authentication', :'flow_invalidation' => :'flow_invalidation', :'flow_recovery' => :'flow_recovery', :'flow_unenrollment' => :'flow_unenrollment', :'flow_user_settings' => :'flow_user_settings', :'flow_device_code' => :'flow_device_code', :'default_locale' => :'default_locale', :'flags' => :'flags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/authentik/api/models/current_brand.rb', line 431 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
126 127 128 129 130 131 |
# File 'lib/authentik/api/models/current_brand.rb', line 126 def self.openapi_nullable Set.new([ :'branding_logo_themed_urls', :'branding_favicon_themed_urls', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/authentik/api/models/current_brand.rb', line 103 def self.openapi_types { :'matched_domain' => :'String', :'branding_title' => :'String', :'branding_logo' => :'String', :'branding_logo_themed_urls' => :'ThemedUrls', :'branding_favicon' => :'String', :'branding_favicon_themed_urls' => :'ThemedUrls', :'branding_custom_css' => :'String', :'ui_footer_links' => :'Array<FooterLink>', :'ui_theme' => :'UiThemeEnum', :'flow_authentication' => :'String', :'flow_invalidation' => :'String', :'flow_recovery' => :'String', :'flow_unenrollment' => :'String', :'flow_user_settings' => :'String', :'flow_device_code' => :'String', :'default_locale' => :'String', :'flags' => :'CurrentBrandFlags' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/authentik/api/models/current_brand.rb', line 394 def ==(o) return true if self.equal?(o) self.class == o.class && matched_domain == o.matched_domain && branding_title == o.branding_title && branding_logo == o.branding_logo && branding_logo_themed_urls == o.branding_logo_themed_urls && branding_favicon == o.branding_favicon && branding_favicon_themed_urls == o.branding_favicon_themed_urls && branding_custom_css == o.branding_custom_css && == o. && ui_theme == o.ui_theme && flow_authentication == o.flow_authentication && flow_invalidation == o.flow_invalidation && flow_recovery == o.flow_recovery && flow_unenrollment == o.flow_unenrollment && flow_user_settings == o.flow_user_settings && flow_device_code == o.flow_device_code && default_locale == o.default_locale && flags == o.flags end |
#eql?(o) ⇒ Boolean
418 419 420 |
# File 'lib/authentik/api/models/current_brand.rb', line 418 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
424 425 426 |
# File 'lib/authentik/api/models/current_brand.rb', line 424 def hash [matched_domain, branding_title, branding_logo, branding_logo_themed_urls, branding_favicon, branding_favicon_themed_urls, branding_custom_css, , ui_theme, flow_authentication, flow_invalidation, flow_recovery, flow_unenrollment, flow_user_settings, flow_device_code, default_locale, flags].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/authentik/api/models/current_brand.rb', line 244 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @matched_domain.nil? invalid_properties.push('invalid value for "matched_domain", matched_domain cannot be nil.') end if @branding_title.nil? invalid_properties.push('invalid value for "branding_title", branding_title cannot be nil.') end if @branding_logo.nil? invalid_properties.push('invalid value for "branding_logo", branding_logo cannot be nil.') end if @branding_favicon.nil? invalid_properties.push('invalid value for "branding_favicon", branding_favicon cannot be nil.') end if @branding_custom_css.nil? invalid_properties.push('invalid value for "branding_custom_css", branding_custom_css cannot be nil.') end if @ui_footer_links.nil? invalid_properties.push('invalid value for "ui_footer_links", ui_footer_links cannot be nil.') end if @ui_theme.nil? invalid_properties.push('invalid value for "ui_theme", ui_theme cannot be nil.') end if @default_locale.nil? invalid_properties.push('invalid value for "default_locale", default_locale cannot be nil.') end if @flags.nil? invalid_properties.push('invalid value for "flags", flags cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/authentik/api/models/current_brand.rb', line 453 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/authentik/api/models/current_brand.rb', line 288 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @matched_domain.nil? return false if @branding_title.nil? return false if @branding_logo.nil? return false if @branding_favicon.nil? return false if @branding_custom_css.nil? return false if @ui_footer_links.nil? return false if @ui_theme.nil? return false if @default_locale.nil? return false if @flags.nil? true end |