Class: Authentik::Api::DataExport
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::DataExport
- Defined in:
- lib/authentik/api/models/data_export.rb
Overview
Mixin to validate that a valid enterprise license exists before allowing to save the object
Instance Attribute Summary collapse
-
#_query_params ⇒ Object
Returns the value of attribute _query_params.
-
#completed ⇒ Object
Returns the value of attribute completed.
-
#content_type ⇒ Object
Returns the value of attribute content_type.
-
#file_url ⇒ Object
Returns the value of attribute file_url.
-
#id ⇒ Object
Returns the value of attribute id.
-
#requested_by ⇒ Object
Returns the value of attribute requested_by.
-
#requested_on ⇒ Object
Returns the value of attribute requested_on.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataExport
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DataExport
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/authentik/api/models/data_export.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::DataExport` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::DataExport`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'requested_by') self.requested_by = attributes[:'requested_by'] else self.requested_by = nil end if attributes.key?(:'requested_on') self.requested_on = attributes[:'requested_on'] else self.requested_on = nil end if attributes.key?(:'content_type') self.content_type = attributes[:'content_type'] else self.content_type = nil end if attributes.key?(:'_query_params') if (value = attributes[:'_query_params']).is_a?(Hash) self._query_params = value end else self._query_params = nil end if attributes.key?(:'file_url') self.file_url = attributes[:'file_url'] else self.file_url = nil end if attributes.key?(:'completed') self.completed = attributes[:'completed'] else self.completed = nil end end |
Instance Attribute Details
#_query_params ⇒ Object
Returns the value of attribute _query_params.
21 22 23 |
# File 'lib/authentik/api/models/data_export.rb', line 21 def _query_params @_query_params end |
#completed ⇒ Object
Returns the value of attribute completed.
25 26 27 |
# File 'lib/authentik/api/models/data_export.rb', line 25 def completed @completed end |
#content_type ⇒ Object
Returns the value of attribute content_type.
19 20 21 |
# File 'lib/authentik/api/models/data_export.rb', line 19 def content_type @content_type end |
#file_url ⇒ Object
Returns the value of attribute file_url.
23 24 25 |
# File 'lib/authentik/api/models/data_export.rb', line 23 def file_url @file_url end |
#id ⇒ Object
Returns the value of attribute id.
13 14 15 |
# File 'lib/authentik/api/models/data_export.rb', line 13 def id @id end |
#requested_by ⇒ Object
Returns the value of attribute requested_by.
15 16 17 |
# File 'lib/authentik/api/models/data_export.rb', line 15 def requested_by @requested_by end |
#requested_on ⇒ Object
Returns the value of attribute requested_on.
17 18 19 |
# File 'lib/authentik/api/models/data_export.rb', line 17 def requested_on @requested_on end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/authentik/api/models/data_export.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/authentik/api/models/data_export.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/authentik/api/models/data_export.rb', line 28 def self.attribute_map { :'id' => :'id', :'requested_by' => :'requested_by', :'requested_on' => :'requested_on', :'content_type' => :'content_type', :'_query_params' => :'query_params', :'file_url' => :'file_url', :'completed' => :'completed' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/authentik/api/models/data_export.rb', line 279 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/authentik/api/models/data_export.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/authentik/api/models/data_export.rb', line 51 def self.openapi_types { :'id' => :'String', :'requested_by' => :'PartialUser', :'requested_on' => :'Time', :'content_type' => :'ContentType', :'_query_params' => :'Hash<String, Object>', :'file_url' => :'String', :'completed' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/authentik/api/models/data_export.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && requested_by == o.requested_by && requested_on == o.requested_on && content_type == o.content_type && _query_params == o._query_params && file_url == o.file_url && completed == o.completed end |
#eql?(o) ⇒ Boolean
266 267 268 |
# File 'lib/authentik/api/models/data_export.rb', line 266 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
272 273 274 |
# File 'lib/authentik/api/models/data_export.rb', line 272 def hash [id, requested_by, requested_on, content_type, _query_params, file_url, completed].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/authentik/api/models/data_export.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @requested_by.nil? invalid_properties.push('invalid value for "requested_by", requested_by cannot be nil.') end if @requested_on.nil? invalid_properties.push('invalid value for "requested_on", requested_on cannot be nil.') end if @content_type.nil? invalid_properties.push('invalid value for "content_type", content_type cannot be nil.') end if @_query_params.nil? invalid_properties.push('invalid value for "_query_params", _query_params cannot be nil.') end if @file_url.nil? invalid_properties.push('invalid value for "file_url", file_url cannot be nil.') end if @completed.nil? invalid_properties.push('invalid value for "completed", completed cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/authentik/api/models/data_export.rb', line 301 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/authentik/api/models/data_export.rb', line 168 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @requested_by.nil? return false if @requested_on.nil? return false if @content_type.nil? return false if @_query_params.nil? return false if @file_url.nil? return false if @completed.nil? true end |