Class: Authentik::Api::Device

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/device.rb

Overview

Serializer for authenticator devices

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Device

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/authentik/api/models/device.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Device` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Device`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'confirmed')
    self.confirmed = attributes[:'confirmed']
  else
    self.confirmed = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  else
    self.last_updated = nil
  end

  if attributes.key?(:'last_used')
    self.last_used = attributes[:'last_used']
  else
    self.last_used = nil
  end

  if attributes.key?(:'extra_description')
    self.extra_description = attributes[:'extra_description']
  else
    self.extra_description = nil
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  else
    self.external_id = nil
  end
end

Instance Attribute Details

#confirmedObject

Returns the value of attribute confirmed.



29
30
31
# File 'lib/authentik/api/models/device.rb', line 29

def confirmed
  @confirmed
end

#createdObject

Returns the value of attribute created.



31
32
33
# File 'lib/authentik/api/models/device.rb', line 31

def created
  @created
end

#external_idObject

Get external Device ID



41
42
43
# File 'lib/authentik/api/models/device.rb', line 41

def external_id
  @external_id
end

#extra_descriptionObject

Get extra description



38
39
40
# File 'lib/authentik/api/models/device.rb', line 38

def extra_description
  @extra_description
end

#last_updatedObject

Returns the value of attribute last_updated.



33
34
35
# File 'lib/authentik/api/models/device.rb', line 33

def last_updated
  @last_updated
end

#last_usedObject

Returns the value of attribute last_used.



35
36
37
# File 'lib/authentik/api/models/device.rb', line 35

def last_used
  @last_used
end

#meta_model_nameObject

Return internal model name



20
21
22
# File 'lib/authentik/api/models/device.rb', line 20

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/authentik/api/models/device.rb', line 24

def name
  @name
end

#pkObject

Returns the value of attribute pk.



22
23
24
# File 'lib/authentik/api/models/device.rb', line 22

def pk
  @pk
end

#typeObject

Get type of device



27
28
29
# File 'lib/authentik/api/models/device.rb', line 27

def type
  @type
end

#verbose_nameObject

Return object’s verbose_name



14
15
16
# File 'lib/authentik/api/models/device.rb', line 14

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



17
18
19
# File 'lib/authentik/api/models/device.rb', line 17

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/authentik/api/models/device.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/authentik/api/models/device.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/authentik/api/models/device.rb', line 44

def self.attribute_map
  {
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'pk' => :'pk',
    :'name' => :'name',
    :'type' => :'type',
    :'confirmed' => :'confirmed',
    :'created' => :'created',
    :'last_updated' => :'last_updated',
    :'last_used' => :'last_used',
    :'extra_description' => :'extra_description',
    :'external_id' => :'external_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/authentik/api/models/device.rb', line 371

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
94
95
96
# File 'lib/authentik/api/models/device.rb', line 90

def self.openapi_nullable
  Set.new([
    :'last_used',
    :'extra_description',
    :'external_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/authentik/api/models/device.rb', line 72

def self.openapi_types
  {
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'pk' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'confirmed' => :'Boolean',
    :'created' => :'Time',
    :'last_updated' => :'Time',
    :'last_used' => :'Time',
    :'extra_description' => :'String',
    :'external_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/authentik/api/models/device.rb', line 339

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      pk == o.pk &&
      name == o.name &&
      type == o.type &&
      confirmed == o.confirmed &&
      created == o.created &&
      last_updated == o.last_updated &&
      last_used == o.last_used &&
      extra_description == o.extra_description &&
      external_id == o.external_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


358
359
360
# File 'lib/authentik/api/models/device.rb', line 358

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



364
365
366
# File 'lib/authentik/api/models/device.rb', line 364

def hash
  [verbose_name, verbose_name_plural, meta_model_name, pk, name, type, confirmed, created, last_updated, last_used, extra_description, external_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/authentik/api/models/device.rb', line 189

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @confirmed.nil?
    invalid_properties.push('invalid value for "confirmed", confirmed cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @last_updated.nil?
    invalid_properties.push('invalid value for "last_updated", last_updated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/authentik/api/models/device.rb', line 393

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/authentik/api/models/device.rb', line 233

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @pk.nil?
  return false if @name.nil?
  return false if @type.nil?
  return false if @confirmed.nil?
  return false if @created.nil?
  return false if @last_updated.nil?
  true
end