Class: Authentik::Api::EventMatcherPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::EventMatcherPolicy
- Defined in:
- lib/authentik/api/models/event_matcher_policy.rb
Overview
Event Matcher Policy Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Match created events with this action type.
-
#app ⇒ Object
Match events created by selected application.
-
#bound_to ⇒ Object
Return objects policy is bound to.
-
#client_ip ⇒ Object
Matches Event’s Client IP (strict matching, for network matching use an Expression Policy).
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#model ⇒ Object
Match events created by selected model.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#query ⇒ Object
Returns the value of attribute query.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EventMatcherPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EventMatcherPolicy
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::EventMatcherPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::EventMatcherPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'execution_logging') self.execution_logging = attributes[:'execution_logging'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'bound_to') self.bound_to = attributes[:'bound_to'] else self.bound_to = nil end if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'client_ip') self.client_ip = attributes[:'client_ip'] end if attributes.key?(:'app') self.app = attributes[:'app'] end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'query') self.query = attributes[:'query'] end end |
Instance Attribute Details
#action ⇒ Object
Match created events with this action type. When left empty, all action types will be matched.
36 37 38 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 36 def action @action end |
#app ⇒ Object
Match events created by selected application. When left empty, all applications are matched.
42 43 44 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 42 def app @app end |
#bound_to ⇒ Object
Return objects policy is bound to
33 34 35 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 33 def bound_to @bound_to end |
#client_ip ⇒ Object
Matches Event’s Client IP (strict matching, for network matching use an Expression Policy)
39 40 41 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 39 def client_ip @client_ip end |
#component ⇒ Object
Get object component so that we know how to edit the object
21 22 23 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 21 def component @component end |
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.
18 19 20 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 18 def execution_logging @execution_logging end |
#meta_model_name ⇒ Object
Return internal model name
30 31 32 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 30 def @meta_model_name end |
#model ⇒ Object
Match events created by selected model. When left empty, all models are matched. When an app is selected, all the application’s models are matched.
45 46 47 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 45 def model @model end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 13 def pk @pk end |
#query ⇒ Object
Returns the value of attribute query.
47 48 49 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 47 def query @query end |
#verbose_name ⇒ Object
Return object’s verbose_name
24 25 26 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 24 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
27 28 29 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 27 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 72 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'execution_logging' => :'execution_logging', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'bound_to' => :'bound_to', :'action' => :'action', :'client_ip' => :'client_ip', :'app' => :'app', :'model' => :'model', :'query' => :'query' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 368 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
120 121 122 123 124 125 126 127 128 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 120 def self.openapi_nullable Set.new([ :'action', :'client_ip', :'app', :'model', :'query' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 101 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'execution_logging' => :'Boolean', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'bound_to' => :'Integer', :'action' => :'EventActions', :'client_ip' => :'String', :'app' => :'AppEnum', :'model' => :'ModelEnum', :'query' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 335 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && execution_logging == o.execution_logging && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && bound_to == o.bound_to && action == o.action && client_ip == o.client_ip && app == o.app && model == o.model && query == o.query end |
#eql?(o) ⇒ Boolean
355 356 357 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 355 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
361 362 363 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 361 def hash [pk, name, execution_logging, component, verbose_name, verbose_name_plural, , bound_to, action, client_ip, app, model, query].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 215 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @bound_to.nil? invalid_properties.push('invalid value for "bound_to", bound_to cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 390 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/authentik/api/models/event_matcher_policy.rb', line 251 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @bound_to.nil? true end |