Class: Authentik::Api::GeoIPPolicyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::GeoIPPolicyRequest
- Defined in:
- lib/authentik/api/models/geo_ip_policy_request.rb
Overview
GeoIP Policy Serializer
Instance Attribute Summary collapse
-
#asns ⇒ Object
Returns the value of attribute asns.
-
#check_history_distance ⇒ Object
Returns the value of attribute check_history_distance.
-
#check_impossible_travel ⇒ Object
Returns the value of attribute check_impossible_travel.
-
#countries ⇒ Object
Returns the value of attribute countries.
-
#distance_tolerance_km ⇒ Object
Returns the value of attribute distance_tolerance_km.
-
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged.
-
#history_login_count ⇒ Object
Returns the value of attribute history_login_count.
-
#history_max_distance_km ⇒ Object
Returns the value of attribute history_max_distance_km.
-
#impossible_tolerance_km ⇒ Object
Returns the value of attribute impossible_tolerance_km.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GeoIPPolicyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GeoIPPolicyRequest
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::GeoIPPolicyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::GeoIPPolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'execution_logging') self.execution_logging = attributes[:'execution_logging'] end if attributes.key?(:'asns') if (value = attributes[:'asns']).is_a?(Array) self.asns = value end end if attributes.key?(:'countries') if (value = attributes[:'countries']).is_a?(Array) self.countries = value end else self.countries = nil end if attributes.key?(:'check_history_distance') self.check_history_distance = attributes[:'check_history_distance'] end if attributes.key?(:'history_max_distance_km') self.history_max_distance_km = attributes[:'history_max_distance_km'] end if attributes.key?(:'distance_tolerance_km') self.distance_tolerance_km = attributes[:'distance_tolerance_km'] end if attributes.key?(:'history_login_count') self.history_login_count = attributes[:'history_login_count'] end if attributes.key?(:'check_impossible_travel') self.check_impossible_travel = attributes[:'check_impossible_travel'] end if attributes.key?(:'impossible_tolerance_km') self.impossible_tolerance_km = attributes[:'impossible_tolerance_km'] end end |
Instance Attribute Details
#asns ⇒ Object
Returns the value of attribute asns.
18 19 20 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 18 def asns @asns end |
#check_history_distance ⇒ Object
Returns the value of attribute check_history_distance.
22 23 24 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 22 def check_history_distance @check_history_distance end |
#check_impossible_travel ⇒ Object
Returns the value of attribute check_impossible_travel.
30 31 32 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 30 def check_impossible_travel @check_impossible_travel end |
#countries ⇒ Object
Returns the value of attribute countries.
20 21 22 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 20 def countries @countries end |
#distance_tolerance_km ⇒ Object
Returns the value of attribute distance_tolerance_km.
26 27 28 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 26 def distance_tolerance_km @distance_tolerance_km end |
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.
16 17 18 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 16 def execution_logging @execution_logging end |
#history_login_count ⇒ Object
Returns the value of attribute history_login_count.
28 29 30 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 28 def history_login_count @history_login_count end |
#history_max_distance_km ⇒ Object
Returns the value of attribute history_max_distance_km.
24 25 26 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 24 def history_max_distance_km @history_max_distance_km end |
#impossible_tolerance_km ⇒ Object
Returns the value of attribute impossible_tolerance_km.
32 33 34 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 32 def impossible_tolerance_km @impossible_tolerance_km end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 13 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 35 def self.attribute_map { :'name' => :'name', :'execution_logging' => :'execution_logging', :'asns' => :'asns', :'countries' => :'countries', :'check_history_distance' => :'check_history_distance', :'history_max_distance_km' => :'history_max_distance_km', :'distance_tolerance_km' => :'distance_tolerance_km', :'history_login_count' => :'history_login_count', :'check_impossible_travel' => :'check_impossible_travel', :'impossible_tolerance_km' => :'impossible_tolerance_km' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 354 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 61 def self.openapi_types { :'name' => :'String', :'execution_logging' => :'Boolean', :'asns' => :'Array<Integer>', :'countries' => :'Array<CountryCodeEnum>', :'check_history_distance' => :'Boolean', :'history_max_distance_km' => :'Integer', :'distance_tolerance_km' => :'Integer', :'history_login_count' => :'Integer', :'check_impossible_travel' => :'Boolean', :'impossible_tolerance_km' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 324 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && execution_logging == o.execution_logging && asns == o.asns && countries == o.countries && check_history_distance == o.check_history_distance && history_max_distance_km == o.history_max_distance_km && distance_tolerance_km == o.distance_tolerance_km && history_login_count == o.history_login_count && check_impossible_travel == o.check_impossible_travel && impossible_tolerance_km == o.impossible_tolerance_km end |
#eql?(o) ⇒ Boolean
341 342 343 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 341 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
347 348 349 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 347 def hash [name, execution_logging, asns, countries, check_history_distance, history_max_distance_km, distance_tolerance_km, history_login_count, check_impossible_travel, impossible_tolerance_km].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 149 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @countries.nil? invalid_properties.push('invalid value for "countries", countries cannot be nil.') end if @countries.length > 249 invalid_properties.push('invalid value for "countries", number of items must be less than or equal to 249.') end if !@history_max_distance_km.nil? && @history_max_distance_km > 9223372036854775807 invalid_properties.push('invalid value for "history_max_distance_km", must be smaller than or equal to 9223372036854775807.') end if !@history_max_distance_km.nil? && @history_max_distance_km < 0 invalid_properties.push('invalid value for "history_max_distance_km", must be greater than or equal to 0.') end if !@distance_tolerance_km.nil? && @distance_tolerance_km > 2147483647 invalid_properties.push('invalid value for "distance_tolerance_km", must be smaller than or equal to 2147483647.') end if !@distance_tolerance_km.nil? && @distance_tolerance_km < 0 invalid_properties.push('invalid value for "distance_tolerance_km", must be greater than or equal to 0.') end if !@history_login_count.nil? && @history_login_count > 2147483647 invalid_properties.push('invalid value for "history_login_count", must be smaller than or equal to 2147483647.') end if !@history_login_count.nil? && @history_login_count < 0 invalid_properties.push('invalid value for "history_login_count", must be greater than or equal to 0.') end if !@impossible_tolerance_km.nil? && @impossible_tolerance_km > 2147483647 invalid_properties.push('invalid value for "impossible_tolerance_km", must be smaller than or equal to 2147483647.') end if !@impossible_tolerance_km.nil? && @impossible_tolerance_km < 0 invalid_properties.push('invalid value for "impossible_tolerance_km", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 376 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/authentik/api/models/geo_ip_policy_request.rb', line 205 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @countries.nil? return false if @countries.length > 249 return false if !@history_max_distance_km.nil? && @history_max_distance_km > 9223372036854775807 return false if !@history_max_distance_km.nil? && @history_max_distance_km < 0 return false if !@distance_tolerance_km.nil? && @distance_tolerance_km > 2147483647 return false if !@distance_tolerance_km.nil? && @distance_tolerance_km < 0 return false if !@history_login_count.nil? && @history_login_count > 2147483647 return false if !@history_login_count.nil? && @history_login_count < 0 return false if !@impossible_tolerance_km.nil? && @impossible_tolerance_km > 2147483647 return false if !@impossible_tolerance_km.nil? && @impossible_tolerance_km < 0 true end |