Class: Authentik::Api::GlobalTaskStatus
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::GlobalTaskStatus
- Defined in:
- lib/authentik/api/models/global_task_status.rb
Instance Attribute Summary collapse
-
#consumed ⇒ Object
Returns the value of attribute consumed.
-
#done ⇒ Object
Returns the value of attribute done.
-
#error ⇒ Object
Returns the value of attribute error.
-
#info ⇒ Object
Returns the value of attribute info.
-
#postprocess ⇒ Object
Returns the value of attribute postprocess.
-
#preprocess ⇒ Object
Returns the value of attribute preprocess.
-
#queued ⇒ Object
Returns the value of attribute queued.
-
#rejected ⇒ Object
Returns the value of attribute rejected.
-
#running ⇒ Object
Returns the value of attribute running.
-
#warning ⇒ Object
Returns the value of attribute warning.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GlobalTaskStatus
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GlobalTaskStatus
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/authentik/api/models/global_task_status.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::GlobalTaskStatus` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::GlobalTaskStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'queued') self.queued = attributes[:'queued'] else self.queued = nil end if attributes.key?(:'consumed') self.consumed = attributes[:'consumed'] else self.consumed = nil end if attributes.key?(:'preprocess') self.preprocess = attributes[:'preprocess'] else self.preprocess = nil end if attributes.key?(:'running') self.running = attributes[:'running'] else self.running = nil end if attributes.key?(:'postprocess') self.postprocess = attributes[:'postprocess'] else self.postprocess = nil end if attributes.key?(:'rejected') self.rejected = attributes[:'rejected'] else self.rejected = nil end if attributes.key?(:'done') self.done = attributes[:'done'] else self.done = nil end if attributes.key?(:'info') self.info = attributes[:'info'] else self.info = nil end if attributes.key?(:'warning') self.warning = attributes[:'warning'] else self.warning = nil end if attributes.key?(:'error') self.error = attributes[:'error'] else self.error = nil end end |
Instance Attribute Details
#consumed ⇒ Object
Returns the value of attribute consumed.
14 15 16 |
# File 'lib/authentik/api/models/global_task_status.rb', line 14 def consumed @consumed end |
#done ⇒ Object
Returns the value of attribute done.
24 25 26 |
# File 'lib/authentik/api/models/global_task_status.rb', line 24 def done @done end |
#error ⇒ Object
Returns the value of attribute error.
30 31 32 |
# File 'lib/authentik/api/models/global_task_status.rb', line 30 def error @error end |
#info ⇒ Object
Returns the value of attribute info.
26 27 28 |
# File 'lib/authentik/api/models/global_task_status.rb', line 26 def info @info end |
#postprocess ⇒ Object
Returns the value of attribute postprocess.
20 21 22 |
# File 'lib/authentik/api/models/global_task_status.rb', line 20 def postprocess @postprocess end |
#preprocess ⇒ Object
Returns the value of attribute preprocess.
16 17 18 |
# File 'lib/authentik/api/models/global_task_status.rb', line 16 def preprocess @preprocess end |
#queued ⇒ Object
Returns the value of attribute queued.
12 13 14 |
# File 'lib/authentik/api/models/global_task_status.rb', line 12 def queued @queued end |
#rejected ⇒ Object
Returns the value of attribute rejected.
22 23 24 |
# File 'lib/authentik/api/models/global_task_status.rb', line 22 def rejected @rejected end |
#running ⇒ Object
Returns the value of attribute running.
18 19 20 |
# File 'lib/authentik/api/models/global_task_status.rb', line 18 def running @running end |
#warning ⇒ Object
Returns the value of attribute warning.
28 29 30 |
# File 'lib/authentik/api/models/global_task_status.rb', line 28 def warning @warning end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/authentik/api/models/global_task_status.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/authentik/api/models/global_task_status.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/authentik/api/models/global_task_status.rb', line 33 def self.attribute_map { :'queued' => :'queued', :'consumed' => :'consumed', :'preprocess' => :'preprocess', :'running' => :'running', :'postprocess' => :'postprocess', :'rejected' => :'rejected', :'done' => :'done', :'info' => :'info', :'warning' => :'warning', :'error' => :'error' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/authentik/api/models/global_task_status.rb', line 354 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/authentik/api/models/global_task_status.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/authentik/api/models/global_task_status.rb', line 59 def self.openapi_types { :'queued' => :'Integer', :'consumed' => :'Integer', :'preprocess' => :'Integer', :'running' => :'Integer', :'postprocess' => :'Integer', :'rejected' => :'Integer', :'done' => :'Integer', :'info' => :'Integer', :'warning' => :'Integer', :'error' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/authentik/api/models/global_task_status.rb', line 324 def ==(o) return true if self.equal?(o) self.class == o.class && queued == o.queued && consumed == o.consumed && preprocess == o.preprocess && running == o.running && postprocess == o.postprocess && rejected == o.rejected && done == o.done && info == o.info && warning == o.warning && error == o.error end |
#eql?(o) ⇒ Boolean
341 342 343 |
# File 'lib/authentik/api/models/global_task_status.rb', line 341 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
347 348 349 |
# File 'lib/authentik/api/models/global_task_status.rb', line 347 def hash [queued, consumed, preprocess, running, postprocess, rejected, done, info, warning, error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/authentik/api/models/global_task_status.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @queued.nil? invalid_properties.push('invalid value for "queued", queued cannot be nil.') end if @consumed.nil? invalid_properties.push('invalid value for "consumed", consumed cannot be nil.') end if @preprocess.nil? invalid_properties.push('invalid value for "preprocess", preprocess cannot be nil.') end if @running.nil? invalid_properties.push('invalid value for "running", running cannot be nil.') end if @postprocess.nil? invalid_properties.push('invalid value for "postprocess", postprocess cannot be nil.') end if @rejected.nil? invalid_properties.push('invalid value for "rejected", rejected cannot be nil.') end if @done.nil? invalid_properties.push('invalid value for "done", done cannot be nil.') end if @info.nil? invalid_properties.push('invalid value for "info", info cannot be nil.') end if @warning.nil? invalid_properties.push('invalid value for "warning", warning cannot be nil.') end if @error.nil? invalid_properties.push('invalid value for "error", error cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/authentik/api/models/global_task_status.rb', line 376 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/authentik/api/models/global_task_status.rb', line 207 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @queued.nil? return false if @consumed.nil? return false if @preprocess.nil? return false if @running.nil? return false if @postprocess.nil? return false if @rejected.nil? return false if @done.nil? return false if @info.nil? return false if @warning.nil? return false if @error.nil? true end |