Class: Authentik::Api::GoogleWorkspaceProvider

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/google_workspace_provider.rb

Overview

GoogleWorkspaceProvider Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GoogleWorkspaceProvider

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 162

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::GoogleWorkspaceProvider` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::GoogleWorkspaceProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'property_mappings_group')
    if (value = attributes[:'property_mappings_group']).is_a?(Array)
      self.property_mappings_group = value
    end
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'assigned_backchannel_application_slug')
    self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug']
  else
    self.assigned_backchannel_application_slug = nil
  end

  if attributes.key?(:'assigned_backchannel_application_name')
    self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name']
  else
    self.assigned_backchannel_application_name = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'delegated_subject')
    self.delegated_subject = attributes[:'delegated_subject']
  else
    self.delegated_subject = nil
  end

  if attributes.key?(:'credentials')
    if (value = attributes[:'credentials']).is_a?(Hash)
      self.credentials = value
    end
  else
    self.credentials = nil
  end

  if attributes.key?(:'scopes')
    self.scopes = attributes[:'scopes']
  end

  if attributes.key?(:'exclude_users_service_account')
    self. = attributes[:'exclude_users_service_account']
  end

  if attributes.key?(:'filter_group')
    self.filter_group = attributes[:'filter_group']
  end

  if attributes.key?(:'user_delete_action')
    self.user_delete_action = attributes[:'user_delete_action']
  end

  if attributes.key?(:'group_delete_action')
    self.group_delete_action = attributes[:'group_delete_action']
  end

  if attributes.key?(:'default_group_email_domain')
    self.default_group_email_domain = attributes[:'default_group_email_domain']
  else
    self.default_group_email_domain = nil
  end

  if attributes.key?(:'sync_page_size')
    self.sync_page_size = attributes[:'sync_page_size']
  end

  if attributes.key?(:'sync_page_timeout')
    self.sync_page_timeout = attributes[:'sync_page_timeout']
  end

  if attributes.key?(:'dry_run')
    self.dry_run = attributes[:'dry_run']
  end
end

Instance Attribute Details

#assigned_backchannel_application_nameObject

Application’s display Name.



29
30
31
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 29

def assigned_backchannel_application_name
  @assigned_backchannel_application_name
end

#assigned_backchannel_application_slugObject

Internal application name, used in URLs.



26
27
28
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 26

def assigned_backchannel_application_slug
  @assigned_backchannel_application_slug
end

#componentObject

Get object component so that we know how to edit the object



23
24
25
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 23

def component
  @component
end

#credentialsObject

Returns the value of attribute credentials.



42
43
44
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 42

def credentials
  @credentials
end

#default_group_email_domainObject

Returns the value of attribute default_group_email_domain.



54
55
56
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 54

def default_group_email_domain
  @default_group_email_domain
end

#delegated_subjectObject

Returns the value of attribute delegated_subject.



40
41
42
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 40

def delegated_subject
  @delegated_subject
end

#dry_runObject

When enabled, provider will not modify or create objects in the remote system.



63
64
65
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 63

def dry_run
  @dry_run
end

#exclude_users_service_accountObject

Returns the value of attribute exclude_users_service_account.



46
47
48
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 46

def 
  @exclude_users_service_account
end

#filter_groupObject

Returns the value of attribute filter_group.



48
49
50
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 48

def filter_group
  @filter_group
end

#group_delete_actionObject

Returns the value of attribute group_delete_action.



52
53
54
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 52

def group_delete_action
  @group_delete_action
end

#meta_model_nameObject

Return internal model name



38
39
40
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 38

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 15

def name
  @name
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 13

def pk
  @pk
end

#property_mappingsObject

Returns the value of attribute property_mappings.



17
18
19
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 17

def property_mappings
  @property_mappings
end

#property_mappings_groupObject

Property mappings used for group creation/updating.



20
21
22
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 20

def property_mappings_group
  @property_mappings_group
end

#scopesObject

Returns the value of attribute scopes.



44
45
46
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 44

def scopes
  @scopes
end

#sync_page_sizeObject

Controls the number of objects synced in a single task



57
58
59
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 57

def sync_page_size
  @sync_page_size
end

#sync_page_timeoutObject

Timeout for synchronization of a single page



60
61
62
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 60

def sync_page_timeout
  @sync_page_timeout
end

#user_delete_actionObject

Returns the value of attribute user_delete_action.



50
51
52
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 50

def user_delete_action
  @user_delete_action
end

#verbose_nameObject

Return object’s verbose_name



32
33
34
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 32

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



35
36
37
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 35

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



115
116
117
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 115

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



120
121
122
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 120

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 88

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'property_mappings' => :'property_mappings',
    :'property_mappings_group' => :'property_mappings_group',
    :'component' => :'component',
    :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug',
    :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'delegated_subject' => :'delegated_subject',
    :'credentials' => :'credentials',
    :'scopes' => :'scopes',
    :'exclude_users_service_account' => :'exclude_users_service_account',
    :'filter_group' => :'filter_group',
    :'user_delete_action' => :'user_delete_action',
    :'group_delete_action' => :'group_delete_action',
    :'default_group_email_domain' => :'default_group_email_domain',
    :'sync_page_size' => :'sync_page_size',
    :'sync_page_timeout' => :'sync_page_timeout',
    :'dry_run' => :'dry_run'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 519

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



152
153
154
155
156
157
158
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 152

def self.openapi_nullable
  Set.new([
    :'assigned_backchannel_application_slug',
    :'assigned_backchannel_application_name',
    :'filter_group',
  ])
end

.openapi_typesObject

Attribute type mapping.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 125

def self.openapi_types
  {
    :'pk' => :'Integer',
    :'name' => :'String',
    :'property_mappings' => :'Array<String>',
    :'property_mappings_group' => :'Array<String>',
    :'component' => :'String',
    :'assigned_backchannel_application_slug' => :'String',
    :'assigned_backchannel_application_name' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'delegated_subject' => :'String',
    :'credentials' => :'Hash<String, Object>',
    :'scopes' => :'String',
    :'exclude_users_service_account' => :'Boolean',
    :'filter_group' => :'String',
    :'user_delete_action' => :'OutgoingSyncDeleteAction',
    :'group_delete_action' => :'OutgoingSyncDeleteAction',
    :'default_group_email_domain' => :'String',
    :'sync_page_size' => :'Integer',
    :'sync_page_timeout' => :'String',
    :'dry_run' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 478

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      property_mappings == o.property_mappings &&
      property_mappings_group == o.property_mappings_group &&
      component == o.component &&
      assigned_backchannel_application_slug == o.assigned_backchannel_application_slug &&
      assigned_backchannel_application_name == o.assigned_backchannel_application_name &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      delegated_subject == o.delegated_subject &&
      credentials == o.credentials &&
      scopes == o.scopes &&
       == o. &&
      filter_group == o.filter_group &&
      user_delete_action == o.user_delete_action &&
      group_delete_action == o.group_delete_action &&
      default_group_email_domain == o.default_group_email_domain &&
      sync_page_size == o.sync_page_size &&
      sync_page_timeout == o.sync_page_timeout &&
      dry_run == o.dry_run
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


506
507
508
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 506

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



512
513
514
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 512

def hash
  [pk, name, property_mappings, property_mappings_group, component, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, meta_model_name, delegated_subject, credentials, scopes, , filter_group, user_delete_action, group_delete_action, default_group_email_domain, sync_page_size, sync_page_timeout, dry_run].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 291

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @delegated_subject.nil?
    invalid_properties.push('invalid value for "delegated_subject", delegated_subject cannot be nil.')
  end

  if @delegated_subject.to_s.length > 254
    invalid_properties.push('invalid value for "delegated_subject", the character length must be smaller than or equal to 254.')
  end

  if @credentials.nil?
    invalid_properties.push('invalid value for "credentials", credentials cannot be nil.')
  end

  if @default_group_email_domain.nil?
    invalid_properties.push('invalid value for "default_group_email_domain", default_group_email_domain cannot be nil.')
  end

  if !@sync_page_size.nil? && @sync_page_size > 2147483647
    invalid_properties.push('invalid value for "sync_page_size", must be smaller than or equal to 2147483647.')
  end

  if !@sync_page_size.nil? && @sync_page_size < 1
    invalid_properties.push('invalid value for "sync_page_size", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



541
542
543
544
545
546
547
548
549
550
551
552
553
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 541

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/authentik/api/models/google_workspace_provider.rb', line 347

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @delegated_subject.nil?
  return false if @delegated_subject.to_s.length > 254
  return false if @credentials.nil?
  return false if @default_group_email_domain.nil?
  return false if !@sync_page_size.nil? && @sync_page_size > 2147483647
  return false if !@sync_page_size.nil? && @sync_page_size < 1
  true
end