Class: Authentik::Api::GoogleWorkspaceProviderRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/google_workspace_provider_request.rb

Overview

GoogleWorkspaceProvider Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GoogleWorkspaceProviderRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::GoogleWorkspaceProviderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::GoogleWorkspaceProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'property_mappings_group')
    if (value = attributes[:'property_mappings_group']).is_a?(Array)
      self.property_mappings_group = value
    end
  end

  if attributes.key?(:'delegated_subject')
    self.delegated_subject = attributes[:'delegated_subject']
  else
    self.delegated_subject = nil
  end

  if attributes.key?(:'credentials')
    if (value = attributes[:'credentials']).is_a?(Hash)
      self.credentials = value
    end
  else
    self.credentials = nil
  end

  if attributes.key?(:'scopes')
    self.scopes = attributes[:'scopes']
  end

  if attributes.key?(:'exclude_users_service_account')
    self. = attributes[:'exclude_users_service_account']
  end

  if attributes.key?(:'filter_group')
    self.filter_group = attributes[:'filter_group']
  end

  if attributes.key?(:'user_delete_action')
    self.user_delete_action = attributes[:'user_delete_action']
  end

  if attributes.key?(:'group_delete_action')
    self.group_delete_action = attributes[:'group_delete_action']
  end

  if attributes.key?(:'default_group_email_domain')
    self.default_group_email_domain = attributes[:'default_group_email_domain']
  else
    self.default_group_email_domain = nil
  end

  if attributes.key?(:'sync_page_size')
    self.sync_page_size = attributes[:'sync_page_size']
  end

  if attributes.key?(:'sync_page_timeout')
    self.sync_page_timeout = attributes[:'sync_page_timeout']
  end

  if attributes.key?(:'dry_run')
    self.dry_run = attributes[:'dry_run']
  end
end

Instance Attribute Details

#credentialsObject

Returns the value of attribute credentials.



22
23
24
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 22

def credentials
  @credentials
end

#default_group_email_domainObject

Returns the value of attribute default_group_email_domain.



34
35
36
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 34

def default_group_email_domain
  @default_group_email_domain
end

#delegated_subjectObject

Returns the value of attribute delegated_subject.



20
21
22
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 20

def delegated_subject
  @delegated_subject
end

#dry_runObject

When enabled, provider will not modify or create objects in the remote system.



43
44
45
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 43

def dry_run
  @dry_run
end

#exclude_users_service_accountObject

Returns the value of attribute exclude_users_service_account.



26
27
28
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 26

def 
  @exclude_users_service_account
end

#filter_groupObject

Returns the value of attribute filter_group.



28
29
30
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 28

def filter_group
  @filter_group
end

#group_delete_actionObject

Returns the value of attribute group_delete_action.



32
33
34
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 32

def group_delete_action
  @group_delete_action
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 13

def name
  @name
end

#property_mappingsObject

Returns the value of attribute property_mappings.



15
16
17
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 15

def property_mappings
  @property_mappings
end

#property_mappings_groupObject

Property mappings used for group creation/updating.



18
19
20
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 18

def property_mappings_group
  @property_mappings_group
end

#scopesObject

Returns the value of attribute scopes.



24
25
26
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 24

def scopes
  @scopes
end

#sync_page_sizeObject

Controls the number of objects synced in a single task



37
38
39
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 37

def sync_page_size
  @sync_page_size
end

#sync_page_timeoutObject

Timeout for synchronization of a single page



40
41
42
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 40

def sync_page_timeout
  @sync_page_timeout
end

#user_delete_actionObject

Returns the value of attribute user_delete_action.



30
31
32
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 30

def user_delete_action
  @user_delete_action
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



88
89
90
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 88

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 93

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 68

def self.attribute_map
  {
    :'name' => :'name',
    :'property_mappings' => :'property_mappings',
    :'property_mappings_group' => :'property_mappings_group',
    :'delegated_subject' => :'delegated_subject',
    :'credentials' => :'credentials',
    :'scopes' => :'scopes',
    :'exclude_users_service_account' => :'exclude_users_service_account',
    :'filter_group' => :'filter_group',
    :'user_delete_action' => :'user_delete_action',
    :'group_delete_action' => :'group_delete_action',
    :'default_group_email_domain' => :'default_group_email_domain',
    :'sync_page_size' => :'sync_page_size',
    :'sync_page_timeout' => :'sync_page_timeout',
    :'dry_run' => :'dry_run'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 424

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
122
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 118

def self.openapi_nullable
  Set.new([
    :'filter_group',
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 98

def self.openapi_types
  {
    :'name' => :'String',
    :'property_mappings' => :'Array<String>',
    :'property_mappings_group' => :'Array<String>',
    :'delegated_subject' => :'String',
    :'credentials' => :'Hash<String, Object>',
    :'scopes' => :'String',
    :'exclude_users_service_account' => :'Boolean',
    :'filter_group' => :'String',
    :'user_delete_action' => :'OutgoingSyncDeleteAction',
    :'group_delete_action' => :'OutgoingSyncDeleteAction',
    :'default_group_email_domain' => :'String',
    :'sync_page_size' => :'Integer',
    :'sync_page_timeout' => :'String',
    :'dry_run' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 390

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      property_mappings == o.property_mappings &&
      property_mappings_group == o.property_mappings_group &&
      delegated_subject == o.delegated_subject &&
      credentials == o.credentials &&
      scopes == o.scopes &&
       == o. &&
      filter_group == o.filter_group &&
      user_delete_action == o.user_delete_action &&
      group_delete_action == o.group_delete_action &&
      default_group_email_domain == o.default_group_email_domain &&
      sync_page_size == o.sync_page_size &&
      sync_page_timeout == o.sync_page_timeout &&
      dry_run == o.dry_run
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


411
412
413
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 411

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



417
418
419
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 417

def hash
  [name, property_mappings, property_mappings_group, delegated_subject, credentials, scopes, , filter_group, user_delete_action, group_delete_action, default_group_email_domain, sync_page_size, sync_page_timeout, dry_run].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 213

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @delegated_subject.nil?
    invalid_properties.push('invalid value for "delegated_subject", delegated_subject cannot be nil.')
  end

  if @delegated_subject.to_s.length > 254
    invalid_properties.push('invalid value for "delegated_subject", the character length must be smaller than or equal to 254.')
  end

  if @delegated_subject.to_s.length < 1
    invalid_properties.push('invalid value for "delegated_subject", the character length must be greater than or equal to 1.')
  end

  if @credentials.nil?
    invalid_properties.push('invalid value for "credentials", credentials cannot be nil.')
  end

  if !@scopes.nil? && @scopes.to_s.length < 1
    invalid_properties.push('invalid value for "scopes", the character length must be greater than or equal to 1.')
  end

  if @default_group_email_domain.nil?
    invalid_properties.push('invalid value for "default_group_email_domain", default_group_email_domain cannot be nil.')
  end

  if @default_group_email_domain.to_s.length < 1
    invalid_properties.push('invalid value for "default_group_email_domain", the character length must be greater than or equal to 1.')
  end

  if !@sync_page_size.nil? && @sync_page_size > 2147483647
    invalid_properties.push('invalid value for "sync_page_size", must be smaller than or equal to 2147483647.')
  end

  if !@sync_page_size.nil? && @sync_page_size < 1
    invalid_properties.push('invalid value for "sync_page_size", must be greater than or equal to 1.')
  end

  if !@sync_page_timeout.nil? && @sync_page_timeout.to_s.length < 1
    invalid_properties.push('invalid value for "sync_page_timeout", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 446

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/authentik/api/models/google_workspace_provider_request.rb', line 269

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length < 1
  return false if @delegated_subject.nil?
  return false if @delegated_subject.to_s.length > 254
  return false if @delegated_subject.to_s.length < 1
  return false if @credentials.nil?
  return false if !@scopes.nil? && @scopes.to_s.length < 1
  return false if @default_group_email_domain.nil?
  return false if @default_group_email_domain.to_s.length < 1
  return false if !@sync_page_size.nil? && @sync_page_size > 2147483647
  return false if !@sync_page_size.nil? && @sync_page_size < 1
  return false if !@sync_page_timeout.nil? && @sync_page_timeout.to_s.length < 1
  true
end