Class: Authentik::Api::GroupLDAPSourceConnection
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::GroupLDAPSourceConnection
- Defined in:
- lib/authentik/api/models/group_ldap_source_connection.rb
Overview
Group Source Connection
Instance Attribute Summary collapse
-
#created ⇒ Object
Returns the value of attribute created.
-
#group ⇒ Object
Returns the value of attribute group.
-
#identifier ⇒ Object
Returns the value of attribute identifier.
-
#last_updated ⇒ Object
Returns the value of attribute last_updated.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#source ⇒ Object
Returns the value of attribute source.
-
#source_obj ⇒ Object
Returns the value of attribute source_obj.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GroupLDAPSourceConnection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GroupLDAPSourceConnection
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::GroupLDAPSourceConnection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::GroupLDAPSourceConnection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'group') self.group = attributes[:'group'] else self.group = nil end if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'source_obj') self.source_obj = attributes[:'source_obj'] else self.source_obj = nil end if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] else self.identifier = nil end if attributes.key?(:'created') self.created = attributes[:'created'] else self.created = nil end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] else self.last_updated = nil end end |
Instance Attribute Details
#created ⇒ Object
Returns the value of attribute created.
23 24 25 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 23 def created @created end |
#group ⇒ Object
Returns the value of attribute group.
15 16 17 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 15 def group @group end |
#identifier ⇒ Object
Returns the value of attribute identifier.
21 22 23 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 21 def identifier @identifier end |
#last_updated ⇒ Object
Returns the value of attribute last_updated.
25 26 27 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 25 def last_updated @last_updated end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 13 def pk @pk end |
#source ⇒ Object
Returns the value of attribute source.
17 18 19 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 17 def source @source end |
#source_obj ⇒ Object
Returns the value of attribute source_obj.
19 20 21 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 19 def source_obj @source_obj end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 28 def self.attribute_map { :'pk' => :'pk', :'group' => :'group', :'source' => :'source', :'source_obj' => :'source_obj', :'identifier' => :'identifier', :'created' => :'created', :'last_updated' => :'last_updated' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 51 def self.openapi_types { :'pk' => :'Integer', :'group' => :'String', :'source' => :'String', :'source_obj' => :'Source', :'identifier' => :'String', :'created' => :'Time', :'last_updated' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 250 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && group == o.group && source == o.source && source_obj == o.source_obj && identifier == o.identifier && created == o.created && last_updated == o.last_updated end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 270 def hash [pk, group, source, source_obj, identifier, created, last_updated].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @group.nil? invalid_properties.push('invalid value for "group", group cannot be nil.') end if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end if @source_obj.nil? invalid_properties.push('invalid value for "source_obj", source_obj cannot be nil.') end if @identifier.nil? invalid_properties.push('invalid value for "identifier", identifier cannot be nil.') end if @created.nil? invalid_properties.push('invalid value for "created", created cannot be nil.') end if @last_updated.nil? invalid_properties.push('invalid value for "last_updated", last_updated cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/authentik/api/models/group_ldap_source_connection.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @group.nil? return false if @source.nil? return false if @source_obj.nil? return false if @identifier.nil? return false if @created.nil? return false if @last_updated.nil? true end |