Class: Authentik::Api::Invitation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::Invitation
- Defined in:
- lib/authentik/api/models/invitation.rb
Overview
Invitation Serializer
Instance Attribute Summary collapse
-
#created_by ⇒ Object
Returns the value of attribute created_by.
-
#expires ⇒ Object
Returns the value of attribute expires.
-
#fixed_data ⇒ Object
Returns the value of attribute fixed_data.
-
#flow ⇒ Object
When set, only the configured flow can use this invitation.
-
#flow_obj ⇒ Object
Returns the value of attribute flow_obj.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#single_use ⇒ Object
When enabled, the invitation will be deleted after usage.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Invitation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Invitation
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/authentik/api/models/invitation.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::Invitation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::Invitation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'expires') self.expires = attributes[:'expires'] end if attributes.key?(:'fixed_data') if (value = attributes[:'fixed_data']).is_a?(Hash) self.fixed_data = value end end if attributes.key?(:'created_by') self.created_by = attributes[:'created_by'] else self.created_by = nil end if attributes.key?(:'single_use') self.single_use = attributes[:'single_use'] end if attributes.key?(:'flow') self.flow = attributes[:'flow'] end if attributes.key?(:'flow_obj') self.flow_obj = attributes[:'flow_obj'] else self.flow_obj = nil end end |
Instance Attribute Details
#created_by ⇒ Object
Returns the value of attribute created_by.
21 22 23 |
# File 'lib/authentik/api/models/invitation.rb', line 21 def created_by @created_by end |
#expires ⇒ Object
Returns the value of attribute expires.
17 18 19 |
# File 'lib/authentik/api/models/invitation.rb', line 17 def expires @expires end |
#fixed_data ⇒ Object
Returns the value of attribute fixed_data.
19 20 21 |
# File 'lib/authentik/api/models/invitation.rb', line 19 def fixed_data @fixed_data end |
#flow ⇒ Object
When set, only the configured flow can use this invitation.
27 28 29 |
# File 'lib/authentik/api/models/invitation.rb', line 27 def flow @flow end |
#flow_obj ⇒ Object
Returns the value of attribute flow_obj.
29 30 31 |
# File 'lib/authentik/api/models/invitation.rb', line 29 def flow_obj @flow_obj end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/invitation.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/invitation.rb', line 13 def pk @pk end |
#single_use ⇒ Object
When enabled, the invitation will be deleted after usage.
24 25 26 |
# File 'lib/authentik/api/models/invitation.rb', line 24 def single_use @single_use end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/authentik/api/models/invitation.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/authentik/api/models/invitation.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/authentik/api/models/invitation.rb', line 32 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'expires' => :'expires', :'fixed_data' => :'fixed_data', :'created_by' => :'created_by', :'single_use' => :'single_use', :'flow' => :'flow', :'flow_obj' => :'flow_obj' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/authentik/api/models/invitation.rb', line 252 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 74 75 |
# File 'lib/authentik/api/models/invitation.rb', line 70 def self.openapi_nullable Set.new([ :'expires', :'flow', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/authentik/api/models/invitation.rb', line 56 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'expires' => :'Time', :'fixed_data' => :'Hash<String, Object>', :'created_by' => :'PartialUser', :'single_use' => :'Boolean', :'flow' => :'String', :'flow_obj' => :'Flow' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/authentik/api/models/invitation.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && expires == o.expires && fixed_data == o.fixed_data && created_by == o.created_by && single_use == o.single_use && flow == o.flow && flow_obj == o.flow_obj end |
#eql?(o) ⇒ Boolean
239 240 241 |
# File 'lib/authentik/api/models/invitation.rb', line 239 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/authentik/api/models/invitation.rb', line 245 def hash [pk, name, expires, fixed_data, created_by, single_use, flow, flow_obj].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/authentik/api/models/invitation.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @created_by.nil? invalid_properties.push('invalid value for "created_by", created_by cannot be nil.') end if @flow_obj.nil? invalid_properties.push('invalid value for "flow_obj", flow_obj cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/authentik/api/models/invitation.rb', line 274 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 173 174 175 |
# File 'lib/authentik/api/models/invitation.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @name !~ Regexp.new(/^[-a-zA-Z0-9_]+$/) return false if @created_by.nil? return false if @flow_obj.nil? true end |