Class: Authentik::Api::KerberosSource

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/kerberos_source.rb

Overview

Kerberos Source Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KerberosSource

Initializes the object



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/authentik/api/models/kerberos_source.rb', line 226

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::KerberosSource` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::KerberosSource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'slug')
    self.slug = attributes[:'slug']
  else
    self.slug = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'promoted')
    self.promoted = attributes[:'promoted']
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'enrollment_flow')
    self.enrollment_flow = attributes[:'enrollment_flow']
  end

  if attributes.key?(:'user_property_mappings')
    if (value = attributes[:'user_property_mappings']).is_a?(Array)
      self.user_property_mappings = value
    end
  end

  if attributes.key?(:'group_property_mappings')
    if (value = attributes[:'group_property_mappings']).is_a?(Array)
      self.group_property_mappings = value
    end
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'policy_engine_mode')
    self.policy_engine_mode = attributes[:'policy_engine_mode']
  end

  if attributes.key?(:'user_matching_mode')
    self.user_matching_mode = attributes[:'user_matching_mode']
  end

  if attributes.key?(:'managed')
    self.managed = attributes[:'managed']
  else
    self.managed = nil
  end

  if attributes.key?(:'user_path_template')
    self.user_path_template = attributes[:'user_path_template']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'icon_url')
    self.icon_url = attributes[:'icon_url']
  else
    self.icon_url = nil
  end

  if attributes.key?(:'icon_themed_urls')
    self.icon_themed_urls = attributes[:'icon_themed_urls']
  else
    self.icon_themed_urls = nil
  end

  if attributes.key?(:'group_matching_mode')
    self.group_matching_mode = attributes[:'group_matching_mode']
  end

  if attributes.key?(:'realm')
    self.realm = attributes[:'realm']
  else
    self.realm = nil
  end

  if attributes.key?(:'krb5_conf')
    self.krb5_conf = attributes[:'krb5_conf']
  end

  if attributes.key?(:'kadmin_type')
    self.kadmin_type = attributes[:'kadmin_type']
  end

  if attributes.key?(:'sync_users')
    self.sync_users = attributes[:'sync_users']
  end

  if attributes.key?(:'sync_users_password')
    self.sync_users_password = attributes[:'sync_users_password']
  end

  if attributes.key?(:'sync_principal')
    self.sync_principal = attributes[:'sync_principal']
  end

  if attributes.key?(:'sync_ccache')
    self.sync_ccache = attributes[:'sync_ccache']
  end

  if attributes.key?(:'connectivity')
    if (value = attributes[:'connectivity']).is_a?(Hash)
      self.connectivity = value
    end
  else
    self.connectivity = nil
  end

  if attributes.key?(:'spnego_server_name')
    self.spnego_server_name = attributes[:'spnego_server_name']
  end

  if attributes.key?(:'spnego_ccache')
    self.spnego_ccache = attributes[:'spnego_ccache']
  end

  if attributes.key?(:'password_login_update_internal_password')
    self. = attributes[:'password_login_update_internal_password']
  end

  if attributes.key?(:'sync_outgoing_trigger_mode')
    self.sync_outgoing_trigger_mode = attributes[:'sync_outgoing_trigger_mode']
  end
end

Instance Attribute Details

#authentication_flow ⇒ Object

Flow to use when authenticating existing users.



27
28
29
# File 'lib/authentik/api/models/kerberos_source.rb', line 27

def authentication_flow
  @authentication_flow
end

#component ⇒ Object

Get object component so that we know how to edit the object



37
38
39
# File 'lib/authentik/api/models/kerberos_source.rb', line 37

def component
  @component
end

#connectivity ⇒ Object

Get cached source connectivity



89
90
91
# File 'lib/authentik/api/models/kerberos_source.rb', line 89

def connectivity
  @connectivity
end

#enabled ⇒ Object

Returns the value of attribute enabled.



21
22
23
# File 'lib/authentik/api/models/kerberos_source.rb', line 21

def enabled
  @enabled
end

#enrollment_flow ⇒ Object

Flow to use when enrolling new users.



30
31
32
# File 'lib/authentik/api/models/kerberos_source.rb', line 30

def enrollment_flow
  @enrollment_flow
end

#group_matching_mode ⇒ Object

How the source determines if an existing group should be used or a new group created.



65
66
67
# File 'lib/authentik/api/models/kerberos_source.rb', line 65

def group_matching_mode
  @group_matching_mode
end

#group_property_mappings ⇒ Object

Returns the value of attribute group_property_mappings.



34
35
36
# File 'lib/authentik/api/models/kerberos_source.rb', line 34

def group_property_mappings
  @group_property_mappings
end

#icon ⇒ Object

Returns the value of attribute icon.



58
59
60
# File 'lib/authentik/api/models/kerberos_source.rb', line 58

def icon
  @icon
end

#icon_themed_urls ⇒ Object

Returns the value of attribute icon_themed_urls.



62
63
64
# File 'lib/authentik/api/models/kerberos_source.rb', line 62

def icon_themed_urls
  @icon_themed_urls
end

#icon_url ⇒ Object

Returns the value of attribute icon_url.



60
61
62
# File 'lib/authentik/api/models/kerberos_source.rb', line 60

def icon_url
  @icon_url
end

#kadmin_type ⇒ Object

KAdmin server type



74
75
76
# File 'lib/authentik/api/models/kerberos_source.rb', line 74

def kadmin_type
  @kadmin_type
end

#krb5_conf ⇒ Object

Custom krb5.conf to use. Uses the system one by default



71
72
73
# File 'lib/authentik/api/models/kerberos_source.rb', line 71

def krb5_conf
  @krb5_conf
end

#managed ⇒ Object

Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.



54
55
56
# File 'lib/authentik/api/models/kerberos_source.rb', line 54

def managed
  @managed
end

#meta_model_name ⇒ Object

Return internal model name



46
47
48
# File 'lib/authentik/api/models/kerberos_source.rb', line 46

def meta_model_name
  @meta_model_name
end

#name ⇒ Object

Source's display Name.



16
17
18
# File 'lib/authentik/api/models/kerberos_source.rb', line 16

def name
  @name
end

#password_login_update_internal_password ⇒ Object

If enabled, the authentik-stored password will be updated upon login with the Kerberos password backend



98
99
100
# File 'lib/authentik/api/models/kerberos_source.rb', line 98

def 
  
end

#pk ⇒ Object

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/kerberos_source.rb', line 13

def pk
  @pk
end

#policy_engine_mode ⇒ Object

Returns the value of attribute policy_engine_mode.



48
49
50
# File 'lib/authentik/api/models/kerberos_source.rb', line 48

def policy_engine_mode
  @policy_engine_mode
end

When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.



24
25
26
# File 'lib/authentik/api/models/kerberos_source.rb', line 24

def promoted
  @promoted
end

#realm ⇒ Object

Kerberos realm



68
69
70
# File 'lib/authentik/api/models/kerberos_source.rb', line 68

def realm
  @realm
end

#slug ⇒ Object

Internal source name, used in URLs.



19
20
21
# File 'lib/authentik/api/models/kerberos_source.rb', line 19

def slug
  @slug
end

#spnego_ccache ⇒ Object

Credential cache to use for SPNEGO in form type:residual



95
96
97
# File 'lib/authentik/api/models/kerberos_source.rb', line 95

def spnego_ccache
  @spnego_ccache
end

#spnego_server_name ⇒ Object

Force the use of a specific server name for SPNEGO. Must be in the form HTTP@hostname



92
93
94
# File 'lib/authentik/api/models/kerberos_source.rb', line 92

def spnego_server_name
  @spnego_server_name
end

#sync_ccache ⇒ Object

Credentials cache to authenticate to kadmin for sync. Must be in the form TYPE:residual



86
87
88
# File 'lib/authentik/api/models/kerberos_source.rb', line 86

def sync_ccache
  @sync_ccache
end

#sync_outgoing_trigger_mode ⇒ Object

When to trigger sync for outgoing providers



101
102
103
# File 'lib/authentik/api/models/kerberos_source.rb', line 101

def sync_outgoing_trigger_mode
  @sync_outgoing_trigger_mode
end

#sync_principal ⇒ Object

Principal to authenticate to kadmin for sync.



83
84
85
# File 'lib/authentik/api/models/kerberos_source.rb', line 83

def sync_principal
  @sync_principal
end

#sync_users ⇒ Object

Sync users from Kerberos into authentik



77
78
79
# File 'lib/authentik/api/models/kerberos_source.rb', line 77

def sync_users
  @sync_users
end

#sync_users_password ⇒ Object

When a user changes their password, sync it back to Kerberos



80
81
82
# File 'lib/authentik/api/models/kerberos_source.rb', line 80

def sync_users_password
  @sync_users_password
end

#user_matching_mode ⇒ Object

How the source determines if an existing user should be authenticated or a new user enrolled.



51
52
53
# File 'lib/authentik/api/models/kerberos_source.rb', line 51

def user_matching_mode
  @user_matching_mode
end

#user_path_template ⇒ Object

Returns the value of attribute user_path_template.



56
57
58
# File 'lib/authentik/api/models/kerberos_source.rb', line 56

def user_path_template
  @user_path_template
end

#user_property_mappings ⇒ Object

Returns the value of attribute user_property_mappings.



32
33
34
# File 'lib/authentik/api/models/kerberos_source.rb', line 32

def user_property_mappings
  @user_property_mappings
end

#verbose_name ⇒ Object

Return object's verbose_name



40
41
42
# File 'lib/authentik/api/models/kerberos_source.rb', line 40

def verbose_name
  @verbose_name
end

#verbose_name_plural ⇒ Object

Return object's plural verbose_name



43
44
45
# File 'lib/authentik/api/models/kerberos_source.rb', line 43

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



165
166
167
# File 'lib/authentik/api/models/kerberos_source.rb', line 165

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



170
171
172
# File 'lib/authentik/api/models/kerberos_source.rb', line 170

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/authentik/api/models/kerberos_source.rb', line 126

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'slug' => :'slug',
    :'enabled' => :'enabled',
    :'promoted' => :'promoted',
    :'authentication_flow' => :'authentication_flow',
    :'enrollment_flow' => :'enrollment_flow',
    :'user_property_mappings' => :'user_property_mappings',
    :'group_property_mappings' => :'group_property_mappings',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'policy_engine_mode' => :'policy_engine_mode',
    :'user_matching_mode' => :'user_matching_mode',
    :'managed' => :'managed',
    :'user_path_template' => :'user_path_template',
    :'icon' => :'icon',
    :'icon_url' => :'icon_url',
    :'icon_themed_urls' => :'icon_themed_urls',
    :'group_matching_mode' => :'group_matching_mode',
    :'realm' => :'realm',
    :'krb5_conf' => :'krb5_conf',
    :'kadmin_type' => :'kadmin_type',
    :'sync_users' => :'sync_users',
    :'sync_users_password' => :'sync_users_password',
    :'sync_principal' => :'sync_principal',
    :'sync_ccache' => :'sync_ccache',
    :'connectivity' => :'connectivity',
    :'spnego_server_name' => :'spnego_server_name',
    :'spnego_ccache' => :'spnego_ccache',
    :'password_login_update_internal_password' => :'password_login_update_internal_password',
    :'sync_outgoing_trigger_mode' => :'sync_outgoing_trigger_mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
# File 'lib/authentik/api/models/kerberos_source.rb', line 619

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



214
215
216
217
218
219
220
221
222
# File 'lib/authentik/api/models/kerberos_source.rb', line 214

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
    :'enrollment_flow',
    :'managed',
    :'icon_themed_urls',
    :'connectivity',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/authentik/api/models/kerberos_source.rb', line 175

def self.openapi_types
  {
    :'pk' => :'String',
    :'name' => :'String',
    :'slug' => :'String',
    :'enabled' => :'Boolean',
    :'promoted' => :'Boolean',
    :'authentication_flow' => :'String',
    :'enrollment_flow' => :'String',
    :'user_property_mappings' => :'Array<String>',
    :'group_property_mappings' => :'Array<String>',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'policy_engine_mode' => :'PolicyEngineMode',
    :'user_matching_mode' => :'UserMatchingModeEnum',
    :'managed' => :'String',
    :'user_path_template' => :'String',
    :'icon' => :'String',
    :'icon_url' => :'String',
    :'icon_themed_urls' => :'ThemedUrls',
    :'group_matching_mode' => :'GroupMatchingModeEnum',
    :'realm' => :'String',
    :'krb5_conf' => :'String',
    :'kadmin_type' => :'KadminTypeEnum',
    :'sync_users' => :'Boolean',
    :'sync_users_password' => :'Boolean',
    :'sync_principal' => :'String',
    :'sync_ccache' => :'String',
    :'connectivity' => :'Hash<String, String>',
    :'spnego_server_name' => :'String',
    :'spnego_ccache' => :'String',
    :'password_login_update_internal_password' => :'Boolean',
    :'sync_outgoing_trigger_mode' => :'SyncOutgoingTriggerModeEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/authentik/api/models/kerberos_source.rb', line 566

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      slug == o.slug &&
      enabled == o.enabled &&
      promoted == o.promoted &&
      authentication_flow == o.authentication_flow &&
      enrollment_flow == o.enrollment_flow &&
      user_property_mappings == o.user_property_mappings &&
      group_property_mappings == o.group_property_mappings &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      policy_engine_mode == o.policy_engine_mode &&
      user_matching_mode == o.user_matching_mode &&
      managed == o.managed &&
      user_path_template == o.user_path_template &&
      icon == o.icon &&
      icon_url == o.icon_url &&
      icon_themed_urls == o.icon_themed_urls &&
      group_matching_mode == o.group_matching_mode &&
      realm == o.realm &&
      krb5_conf == o.krb5_conf &&
      kadmin_type == o.kadmin_type &&
      sync_users == o.sync_users &&
      sync_users_password == o.sync_users_password &&
      sync_principal == o.sync_principal &&
      sync_ccache == o.sync_ccache &&
      connectivity == o.connectivity &&
      spnego_server_name == o.spnego_server_name &&
      spnego_ccache == o.spnego_ccache &&
       == o. &&
      sync_outgoing_trigger_mode == o.sync_outgoing_trigger_mode
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


606
607
608
# File 'lib/authentik/api/models/kerberos_source.rb', line 606

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



612
613
614
# File 'lib/authentik/api/models/kerberos_source.rb', line 612

def hash
  [pk, name, slug, enabled, promoted, authentication_flow, enrollment_flow, user_property_mappings, group_property_mappings, component, verbose_name, verbose_name_plural, meta_model_name, policy_engine_mode, user_matching_mode, managed, user_path_template, icon, icon_url, icon_themed_urls, group_matching_mode, realm, krb5_conf, kadmin_type, sync_users, sync_users_password, sync_principal, sync_ccache, connectivity, spnego_server_name, spnego_ccache, , sync_outgoing_trigger_mode].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/authentik/api/models/kerberos_source.rb', line 405

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @slug.nil?
    invalid_properties.push('invalid value for "slug", slug cannot be nil.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @slug !~ pattern
    invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.")
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @icon_url.nil?
    invalid_properties.push('invalid value for "icon_url", icon_url cannot be nil.')
  end

  if @realm.nil?
    invalid_properties.push('invalid value for "realm", realm cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash



641
642
643
644
645
646
647
648
649
650
651
652
653
# File 'lib/authentik/api/models/kerberos_source.rb', line 641

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/authentik/api/models/kerberos_source.rb', line 454

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @slug.nil?
  return false if @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @icon_url.nil?
  return false if @realm.nil?
  true
end