Class: Authentik::Api::LDAPOutpostConfig
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::LDAPOutpostConfig
- Defined in:
- lib/authentik/api/models/ldap_outpost_config.rb
Overview
LDAPProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_slug ⇒ Object
Prioritise backchannel slug over direct application slug.
-
#base_dn ⇒ Object
DN under which objects are accessible.
-
#bind_flow_slug ⇒ Object
Returns the value of attribute bind_flow_slug.
-
#bind_mode ⇒ Object
Returns the value of attribute bind_mode.
-
#certificate ⇒ Object
Returns the value of attribute certificate.
-
#gid_start_number ⇒ Object
The start for gidNumbers, this number is added to a number generated from the group.pk to make sure that the numbers aren’t too low for POSIX groups.
-
#mfa_support ⇒ Object
When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#search_mode ⇒ Object
Returns the value of attribute search_mode.
-
#tls_server_name ⇒ Object
Returns the value of attribute tls_server_name.
-
#uid_start_number ⇒ Object
The start for uidNumbers, this number is added to the user.pk to make sure that the numbers aren’t too low for POSIX users.
-
#unbind_flow_slug ⇒ Object
Get slug for unbind flow, defaulting to brand’s default flow.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LDAPOutpostConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LDAPOutpostConfig
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::LDAPOutpostConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::LDAPOutpostConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'base_dn') self.base_dn = attributes[:'base_dn'] end if attributes.key?(:'bind_flow_slug') self.bind_flow_slug = attributes[:'bind_flow_slug'] else self.bind_flow_slug = nil end if attributes.key?(:'unbind_flow_slug') self.unbind_flow_slug = attributes[:'unbind_flow_slug'] else self.unbind_flow_slug = nil end if attributes.key?(:'application_slug') self.application_slug = attributes[:'application_slug'] else self.application_slug = nil end if attributes.key?(:'certificate') self.certificate = attributes[:'certificate'] end if attributes.key?(:'tls_server_name') self.tls_server_name = attributes[:'tls_server_name'] end if attributes.key?(:'uid_start_number') self.uid_start_number = attributes[:'uid_start_number'] end if attributes.key?(:'gid_start_number') self.gid_start_number = attributes[:'gid_start_number'] end if attributes.key?(:'search_mode') self.search_mode = attributes[:'search_mode'] end if attributes.key?(:'bind_mode') self.bind_mode = attributes[:'bind_mode'] end if attributes.key?(:'mfa_support') self.mfa_support = attributes[:'mfa_support'] end end |
Instance Attribute Details
#application_slug ⇒ Object
Prioritise backchannel slug over direct application slug
26 27 28 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 26 def application_slug @application_slug end |
#base_dn ⇒ Object
DN under which objects are accessible.
18 19 20 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 18 def base_dn @base_dn end |
#bind_flow_slug ⇒ Object
Returns the value of attribute bind_flow_slug.
20 21 22 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 20 def bind_flow_slug @bind_flow_slug end |
#bind_mode ⇒ Object
Returns the value of attribute bind_mode.
40 41 42 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 40 def bind_mode @bind_mode end |
#certificate ⇒ Object
Returns the value of attribute certificate.
28 29 30 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 28 def certificate @certificate end |
#gid_start_number ⇒ Object
The start for gidNumbers, this number is added to a number generated from the group.pk to make sure that the numbers aren’t too low for POSIX groups. Default is 4000 to ensure that we don’t collide with local groups or users primary groups gidNumber
36 37 38 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 36 def gid_start_number @gid_start_number end |
#mfa_support ⇒ Object
When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon.
43 44 45 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 43 def mfa_support @mfa_support end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 13 def pk @pk end |
#search_mode ⇒ Object
Returns the value of attribute search_mode.
38 39 40 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 38 def search_mode @search_mode end |
#tls_server_name ⇒ Object
Returns the value of attribute tls_server_name.
30 31 32 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 30 def tls_server_name @tls_server_name end |
#uid_start_number ⇒ Object
The start for uidNumbers, this number is added to the user.pk to make sure that the numbers aren’t too low for POSIX users. Default is 2000 to ensure that we don’t collide with local users uidNumber
33 34 35 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 33 def uid_start_number @uid_start_number end |
#unbind_flow_slug ⇒ Object
Get slug for unbind flow, defaulting to brand’s default flow.
23 24 25 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 23 def unbind_flow_slug @unbind_flow_slug end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 68 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'base_dn' => :'base_dn', :'bind_flow_slug' => :'bind_flow_slug', :'unbind_flow_slug' => :'unbind_flow_slug', :'application_slug' => :'application_slug', :'certificate' => :'certificate', :'tls_server_name' => :'tls_server_name', :'uid_start_number' => :'uid_start_number', :'gid_start_number' => :'gid_start_number', :'search_mode' => :'search_mode', :'bind_mode' => :'bind_mode', :'mfa_support' => :'mfa_support' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 368 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 120 121 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 116 def self.openapi_nullable Set.new([ :'unbind_flow_slug', :'certificate', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 97 def self.openapi_types { :'pk' => :'Integer', :'name' => :'String', :'base_dn' => :'String', :'bind_flow_slug' => :'String', :'unbind_flow_slug' => :'String', :'application_slug' => :'String', :'certificate' => :'String', :'tls_server_name' => :'String', :'uid_start_number' => :'Integer', :'gid_start_number' => :'Integer', :'search_mode' => :'LDAPAPIAccessMode', :'bind_mode' => :'LDAPAPIAccessMode', :'mfa_support' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 335 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && base_dn == o.base_dn && bind_flow_slug == o.bind_flow_slug && unbind_flow_slug == o.unbind_flow_slug && application_slug == o.application_slug && certificate == o.certificate && tls_server_name == o.tls_server_name && uid_start_number == o.uid_start_number && gid_start_number == o.gid_start_number && search_mode == o.search_mode && bind_mode == o.bind_mode && mfa_support == o.mfa_support end |
#eql?(o) ⇒ Boolean
355 356 357 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 355 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
361 362 363 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 361 def hash [pk, name, base_dn, bind_flow_slug, unbind_flow_slug, application_slug, certificate, tls_server_name, uid_start_number, gid_start_number, search_mode, bind_mode, mfa_support].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 204 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @bind_flow_slug.nil? invalid_properties.push('invalid value for "bind_flow_slug", bind_flow_slug cannot be nil.') end if @application_slug.nil? invalid_properties.push('invalid value for "application_slug", application_slug cannot be nil.') end if !@uid_start_number.nil? && @uid_start_number > 2147483647 invalid_properties.push('invalid value for "uid_start_number", must be smaller than or equal to 2147483647.') end if !@uid_start_number.nil? && @uid_start_number < -2147483648 invalid_properties.push('invalid value for "uid_start_number", must be greater than or equal to -2147483648.') end if !@gid_start_number.nil? && @gid_start_number > 2147483647 invalid_properties.push('invalid value for "gid_start_number", must be smaller than or equal to 2147483647.') end if !@gid_start_number.nil? && @gid_start_number < -2147483648 invalid_properties.push('invalid value for "gid_start_number", must be greater than or equal to -2147483648.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 390 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/authentik/api/models/ldap_outpost_config.rb', line 244 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @bind_flow_slug.nil? return false if @application_slug.nil? return false if !@uid_start_number.nil? && @uid_start_number > 2147483647 return false if !@uid_start_number.nil? && @uid_start_number < -2147483648 return false if !@gid_start_number.nil? && @gid_start_number > 2147483647 return false if !@gid_start_number.nil? && @gid_start_number < -2147483648 true end |