Class: Authentik::Api::LifecycleApi
- Inherits:
-
Object
- Object
- Authentik::Api::LifecycleApi
- Defined in:
- lib/authentik/api/api/lifecycle_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LifecycleApi
constructor
A new instance of LifecycleApi.
-
#lifecycle_iterations_create(lifecycle_iteration_request, opts = {}) ⇒ LifecycleIteration
Mixin to validate that a valid enterprise license exists before allowing to save the object.
-
#lifecycle_iterations_create_with_http_info(lifecycle_iteration_request, opts = {}) ⇒ Array<(LifecycleIteration, Integer, Hash)>
Mixin to validate that a valid enterprise license exists before allowing to save the object.
-
#lifecycle_iterations_list_latest(content_type, obj_id, opts = {}) ⇒ Array<LifecycleIteration>
Mixin to validate that a valid enterprise license exists before allowing to save the object.
-
#lifecycle_iterations_list_latest_with_http_info(content_type, obj_id, opts = {}) ⇒ Array<(Array<LifecycleIteration>, Integer, Hash)>
Mixin to validate that a valid enterprise license exists before allowing to save the object.
-
#lifecycle_iterations_list_open(opts = {}) ⇒ PaginatedLifecycleIterationList
Mixin to validate that a valid enterprise license exists before allowing to save the object.
-
#lifecycle_iterations_list_open_with_http_info(opts = {}) ⇒ Array<(PaginatedLifecycleIterationList, Integer, Hash)>
Mixin to validate that a valid enterprise license exists before allowing to save the object.
-
#lifecycle_reviews_create(review_request, opts = {}) ⇒ Review
Mixin to validate that a valid enterprise license exists before allowing to save the object.
-
#lifecycle_reviews_create_with_http_info(review_request, opts = {}) ⇒ Array<(Review, Integer, Hash)>
Mixin to validate that a valid enterprise license exists before allowing to save the object.
- #lifecycle_rules_create(lifecycle_rule_request, opts = {}) ⇒ LifecycleRule
-
#lifecycle_rules_create_with_http_info(lifecycle_rule_request, opts = {}) ⇒ Array<(LifecycleRule, Integer, Hash)>
LifecycleRule data, response status code and response headers.
- #lifecycle_rules_destroy(id, opts = {}) ⇒ nil
-
#lifecycle_rules_destroy_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Nil, response status code and response headers.
- #lifecycle_rules_list(opts = {}) ⇒ PaginatedLifecycleRuleList
-
#lifecycle_rules_list_with_http_info(opts = {}) ⇒ Array<(PaginatedLifecycleRuleList, Integer, Hash)>
PaginatedLifecycleRuleList data, response status code and response headers.
- #lifecycle_rules_partial_update(id, opts = {}) ⇒ LifecycleRule
-
#lifecycle_rules_partial_update_with_http_info(id, opts = {}) ⇒ Array<(LifecycleRule, Integer, Hash)>
LifecycleRule data, response status code and response headers.
- #lifecycle_rules_retrieve(id, opts = {}) ⇒ LifecycleRule
-
#lifecycle_rules_retrieve_with_http_info(id, opts = {}) ⇒ Array<(LifecycleRule, Integer, Hash)>
LifecycleRule data, response status code and response headers.
- #lifecycle_rules_update(id, lifecycle_rule_request, opts = {}) ⇒ LifecycleRule
-
#lifecycle_rules_update_with_http_info(id, lifecycle_rule_request, opts = {}) ⇒ Array<(LifecycleRule, Integer, Hash)>
LifecycleRule data, response status code and response headers.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LifecycleApi
Returns a new instance of LifecycleApi.
13 14 15 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 13 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
11 12 13 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 11 def api_client @api_client end |
Instance Method Details
#lifecycle_iterations_create(lifecycle_iteration_request, opts = {}) ⇒ LifecycleIteration
Mixin to validate that a valid enterprise license exists before allowing to save the object
20 21 22 23 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 20 def lifecycle_iterations_create(lifecycle_iteration_request, opts = {}) data, _status_code, _headers = lifecycle_iterations_create_with_http_info(lifecycle_iteration_request, opts) data end |
#lifecycle_iterations_create_with_http_info(lifecycle_iteration_request, opts = {}) ⇒ Array<(LifecycleIteration, Integer, Hash)>
Mixin to validate that a valid enterprise license exists before allowing to save the object
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 29 def lifecycle_iterations_create_with_http_info(lifecycle_iteration_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_iterations_create ...' end # verify the required parameter 'lifecycle_iteration_request' is set if @api_client.config.client_side_validation && lifecycle_iteration_request.nil? fail ArgumentError, "Missing the required parameter 'lifecycle_iteration_request' when calling LifecycleApi.lifecycle_iterations_create" end # resource path local_var_path = '/lifecycle/iterations/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lifecycle_iteration_request) # return_type return_type = opts[:debug_return_type] || 'LifecycleIteration' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_iterations_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_iterations_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_iterations_list_latest(content_type, obj_id, opts = {}) ⇒ Array<LifecycleIteration>
Mixin to validate that a valid enterprise license exists before allowing to save the object
90 91 92 93 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 90 def lifecycle_iterations_list_latest(content_type, obj_id, opts = {}) data, _status_code, _headers = lifecycle_iterations_list_latest_with_http_info(content_type, obj_id, opts) data end |
#lifecycle_iterations_list_latest_with_http_info(content_type, obj_id, opts = {}) ⇒ Array<(Array<LifecycleIteration>, Integer, Hash)>
Mixin to validate that a valid enterprise license exists before allowing to save the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 103 def lifecycle_iterations_list_latest_with_http_info(content_type, obj_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_iterations_list_latest ...' end # verify the required parameter 'content_type' is set if @api_client.config.client_side_validation && content_type.nil? fail ArgumentError, "Missing the required parameter 'content_type' when calling LifecycleApi.lifecycle_iterations_list_latest" end pattern = Regexp.new(/^[^\/]+$/) if @api_client.config.client_side_validation && content_type !~ pattern fail ArgumentError, "invalid value for 'content_type' when calling LifecycleApi.lifecycle_iterations_list_latest, must conform to the pattern #{pattern}." end # verify the required parameter 'obj_id' is set if @api_client.config.client_side_validation && obj_id.nil? fail ArgumentError, "Missing the required parameter 'obj_id' when calling LifecycleApi.lifecycle_iterations_list_latest" end pattern = Regexp.new(/^[^\/]+$/) if @api_client.config.client_side_validation && obj_id !~ pattern fail ArgumentError, "invalid value for 'obj_id' when calling LifecycleApi.lifecycle_iterations_list_latest, must conform to the pattern #{pattern}." end # resource path local_var_path = '/lifecycle/iterations/latest/{content_type}/{object_id}/'.sub('{content_type}', CGI.escape(content_type.to_s)).sub('{object_id}', CGI.escape(obj_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'user_is_reviewer'] = opts[:'user_is_reviewer'] if !opts[:'user_is_reviewer'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<LifecycleIteration>' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_iterations_list_latest", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_iterations_list_latest\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_iterations_list_open(opts = {}) ⇒ PaginatedLifecycleIterationList
Mixin to validate that a valid enterprise license exists before allowing to save the object
176 177 178 179 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 176 def lifecycle_iterations_list_open(opts = {}) data, _status_code, _headers = lifecycle_iterations_list_open_with_http_info(opts) data end |
#lifecycle_iterations_list_open_with_http_info(opts = {}) ⇒ Array<(PaginatedLifecycleIterationList, Integer, Hash)>
Mixin to validate that a valid enterprise license exists before allowing to save the object
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 189 def lifecycle_iterations_list_open_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_iterations_list_open ...' end # resource path local_var_path = '/lifecycle/iterations/open/' # query parameters query_params = opts[:query_params] || {} query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'user_is_reviewer'] = opts[:'user_is_reviewer'] if !opts[:'user_is_reviewer'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedLifecycleIterationList' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_iterations_list_open", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_iterations_list_open\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_reviews_create(review_request, opts = {}) ⇒ Review
Mixin to validate that a valid enterprise license exists before allowing to save the object
242 243 244 245 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 242 def lifecycle_reviews_create(review_request, opts = {}) data, _status_code, _headers = lifecycle_reviews_create_with_http_info(review_request, opts) data end |
#lifecycle_reviews_create_with_http_info(review_request, opts = {}) ⇒ Array<(Review, Integer, Hash)>
Mixin to validate that a valid enterprise license exists before allowing to save the object
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 251 def lifecycle_reviews_create_with_http_info(review_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_reviews_create ...' end # verify the required parameter 'review_request' is set if @api_client.config.client_side_validation && review_request.nil? fail ArgumentError, "Missing the required parameter 'review_request' when calling LifecycleApi.lifecycle_reviews_create" end # resource path local_var_path = '/lifecycle/reviews/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(review_request) # return_type return_type = opts[:debug_return_type] || 'Review' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_reviews_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_reviews_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_rules_create(lifecycle_rule_request, opts = {}) ⇒ LifecycleRule
307 308 309 310 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 307 def lifecycle_rules_create(lifecycle_rule_request, opts = {}) data, _status_code, _headers = lifecycle_rules_create_with_http_info(lifecycle_rule_request, opts) data end |
#lifecycle_rules_create_with_http_info(lifecycle_rule_request, opts = {}) ⇒ Array<(LifecycleRule, Integer, Hash)>
Returns LifecycleRule data, response status code and response headers.
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 315 def lifecycle_rules_create_with_http_info(lifecycle_rule_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_rules_create ...' end # verify the required parameter 'lifecycle_rule_request' is set if @api_client.config.client_side_validation && lifecycle_rule_request.nil? fail ArgumentError, "Missing the required parameter 'lifecycle_rule_request' when calling LifecycleApi.lifecycle_rules_create" end # resource path local_var_path = '/lifecycle/rules/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lifecycle_rule_request) # return_type return_type = opts[:debug_return_type] || 'LifecycleRule' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_rules_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_rules_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_rules_destroy(id, opts = {}) ⇒ nil
371 372 373 374 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 371 def lifecycle_rules_destroy(id, opts = {}) lifecycle_rules_destroy_with_http_info(id, opts) nil end |
#lifecycle_rules_destroy_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Returns nil, response status code and response headers.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 379 def lifecycle_rules_destroy_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_rules_destroy ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LifecycleApi.lifecycle_rules_destroy" end # resource path local_var_path = '/lifecycle/rules/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_rules_destroy", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_rules_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_rules_list(opts = {}) ⇒ PaginatedLifecycleRuleList
434 435 436 437 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 434 def lifecycle_rules_list(opts = {}) data, _status_code, _headers = lifecycle_rules_list_with_http_info(opts) data end |
#lifecycle_rules_list_with_http_info(opts = {}) ⇒ Array<(PaginatedLifecycleRuleList, Integer, Hash)>
Returns PaginatedLifecycleRuleList data, response status code and response headers.
446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 446 def lifecycle_rules_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_rules_list ...' end # resource path local_var_path = '/lifecycle/rules/' # query parameters query_params = opts[:query_params] || {} query_params[:'content_type__model'] = opts[:'content_type__model'] if !opts[:'content_type__model'].nil? query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedLifecycleRuleList' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_rules_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_rules_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_rules_partial_update(id, opts = {}) ⇒ LifecycleRule
499 500 501 502 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 499 def lifecycle_rules_partial_update(id, opts = {}) data, _status_code, _headers = lifecycle_rules_partial_update_with_http_info(id, opts) data end |
#lifecycle_rules_partial_update_with_http_info(id, opts = {}) ⇒ Array<(LifecycleRule, Integer, Hash)>
Returns LifecycleRule data, response status code and response headers.
508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 508 def lifecycle_rules_partial_update_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_rules_partial_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LifecycleApi.lifecycle_rules_partial_update" end # resource path local_var_path = '/lifecycle/rules/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_lifecycle_rule_request']) # return_type return_type = opts[:debug_return_type] || 'LifecycleRule' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_rules_partial_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_rules_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_rules_retrieve(id, opts = {}) ⇒ LifecycleRule
564 565 566 567 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 564 def lifecycle_rules_retrieve(id, opts = {}) data, _status_code, _headers = lifecycle_rules_retrieve_with_http_info(id, opts) data end |
#lifecycle_rules_retrieve_with_http_info(id, opts = {}) ⇒ Array<(LifecycleRule, Integer, Hash)>
Returns LifecycleRule data, response status code and response headers.
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 572 def lifecycle_rules_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_rules_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LifecycleApi.lifecycle_rules_retrieve" end # resource path local_var_path = '/lifecycle/rules/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LifecycleRule' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_rules_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_rules_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#lifecycle_rules_update(id, lifecycle_rule_request, opts = {}) ⇒ LifecycleRule
624 625 626 627 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 624 def lifecycle_rules_update(id, lifecycle_rule_request, opts = {}) data, _status_code, _headers = lifecycle_rules_update_with_http_info(id, lifecycle_rule_request, opts) data end |
#lifecycle_rules_update_with_http_info(id, lifecycle_rule_request, opts = {}) ⇒ Array<(LifecycleRule, Integer, Hash)>
Returns LifecycleRule data, response status code and response headers.
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 |
# File 'lib/authentik/api/api/lifecycle_api.rb', line 633 def lifecycle_rules_update_with_http_info(id, lifecycle_rule_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LifecycleApi.lifecycle_rules_update ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LifecycleApi.lifecycle_rules_update" end # verify the required parameter 'lifecycle_rule_request' is set if @api_client.config.client_side_validation && lifecycle_rule_request.nil? fail ArgumentError, "Missing the required parameter 'lifecycle_rule_request' when calling LifecycleApi.lifecycle_rules_update" end # resource path local_var_path = '/lifecycle/rules/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lifecycle_rule_request) # return_type return_type = opts[:debug_return_type] || 'LifecycleRule' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"LifecycleApi.lifecycle_rules_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LifecycleApi#lifecycle_rules_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |