Class: Authentik::Api::LifecycleIteration

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/lifecycle_iteration.rb

Overview

Mixin to validate that a valid enterprise license exists before allowing to save the object

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LifecycleIteration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::LifecycleIteration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::LifecycleIteration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'content_type')
    self.content_type = attributes[:'content_type']
  else
    self.content_type = nil
  end

  if attributes.key?(:'obj_id')
    self.obj_id = attributes[:'obj_id']
  else
    self.obj_id = nil
  end

  if attributes.key?(:'object_verbose')
    self.object_verbose = attributes[:'object_verbose']
  else
    self.object_verbose = nil
  end

  if attributes.key?(:'object_admin_url')
    self.object_admin_url = attributes[:'object_admin_url']
  else
    self.object_admin_url = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'opened_on')
    self.opened_on = attributes[:'opened_on']
  else
    self.opened_on = nil
  end

  if attributes.key?(:'grace_period_end')
    self.grace_period_end = attributes[:'grace_period_end']
  else
    self.grace_period_end = nil
  end

  if attributes.key?(:'next_review_date')
    self.next_review_date = attributes[:'next_review_date']
  else
    self.next_review_date = nil
  end

  if attributes.key?(:'reviews')
    if (value = attributes[:'reviews']).is_a?(Array)
      self.reviews = value
    end
  else
    self.reviews = nil
  end

  if attributes.key?(:'user_can_review')
    self.user_can_review = attributes[:'user_can_review']
  else
    self.user_can_review = nil
  end

  if attributes.key?(:'reviewer_groups')
    if (value = attributes[:'reviewer_groups']).is_a?(Array)
      self.reviewer_groups = value
    end
  else
    self.reviewer_groups = nil
  end

  if attributes.key?(:'min_reviewers')
    self.min_reviewers = attributes[:'min_reviewers']
  else
    self.min_reviewers = nil
  end

  if attributes.key?(:'reviewers')
    if (value = attributes[:'reviewers']).is_a?(Array)
      self.reviewers = value
    end
  else
    self.reviewers = nil
  end
end

Instance Attribute Details

#content_typeObject

Returns the value of attribute content_type.



15
16
17
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 15

def content_type
  @content_type
end

#grace_period_endObject

Returns the value of attribute grace_period_end.



27
28
29
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 27

def grace_period_end
  @grace_period_end
end

#idObject

Returns the value of attribute id.



13
14
15
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 13

def id
  @id
end

#min_reviewersObject

Returns the value of attribute min_reviewers.



37
38
39
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 37

def min_reviewers
  @min_reviewers
end

#next_review_dateObject

Returns the value of attribute next_review_date.



29
30
31
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 29

def next_review_date
  @next_review_date
end

#obj_idObject

Returns the value of attribute obj_id.



17
18
19
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 17

def obj_id
  @obj_id
end

#object_admin_urlObject

Returns the value of attribute object_admin_url.



21
22
23
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 21

def object_admin_url
  @object_admin_url
end

#object_verboseObject

Returns the value of attribute object_verbose.



19
20
21
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 19

def object_verbose
  @object_verbose
end

#opened_onObject

Returns the value of attribute opened_on.



25
26
27
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 25

def opened_on
  @opened_on
end

#reviewer_groupsObject

Returns the value of attribute reviewer_groups.



35
36
37
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 35

def reviewer_groups
  @reviewer_groups
end

#reviewersObject

Returns the value of attribute reviewers.



39
40
41
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 39

def reviewers
  @reviewers
end

#reviewsObject

Returns the value of attribute reviews.



31
32
33
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 31

def reviews
  @reviews
end

#stateObject

Returns the value of attribute state.



23
24
25
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 23

def state
  @state
end

#user_can_reviewObject

Returns the value of attribute user_can_review.



33
34
35
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 33

def user_can_review
  @user_can_review
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



84
85
86
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 84

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 89

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 64

def self.attribute_map
  {
    :'id' => :'id',
    :'content_type' => :'content_type',
    :'obj_id' => :'object_id',
    :'object_verbose' => :'object_verbose',
    :'object_admin_url' => :'object_admin_url',
    :'state' => :'state',
    :'opened_on' => :'opened_on',
    :'grace_period_end' => :'grace_period_end',
    :'next_review_date' => :'next_review_date',
    :'reviews' => :'reviews',
    :'user_can_review' => :'user_can_review',
    :'reviewer_groups' => :'reviewer_groups',
    :'min_reviewers' => :'min_reviewers',
    :'reviewers' => :'reviewers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 487

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 94

def self.openapi_types
  {
    :'id' => :'String',
    :'content_type' => :'ContentTypeEnum',
    :'obj_id' => :'String',
    :'object_verbose' => :'String',
    :'object_admin_url' => :'String',
    :'state' => :'LifecycleIterationStateEnum',
    :'opened_on' => :'Time',
    :'grace_period_end' => :'Time',
    :'next_review_date' => :'Time',
    :'reviews' => :'Array<Review>',
    :'user_can_review' => :'Boolean',
    :'reviewer_groups' => :'Array<ReviewerGroup>',
    :'min_reviewers' => :'Integer',
    :'reviewers' => :'Array<ReviewerUser>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 453

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      content_type == o.content_type &&
      obj_id == o.obj_id &&
      object_verbose == o.object_verbose &&
      object_admin_url == o.object_admin_url &&
      state == o.state &&
      opened_on == o.opened_on &&
      grace_period_end == o.grace_period_end &&
      next_review_date == o.next_review_date &&
      reviews == o.reviews &&
      user_can_review == o.user_can_review &&
      reviewer_groups == o.reviewer_groups &&
      min_reviewers == o.min_reviewers &&
      reviewers == o.reviewers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


474
475
476
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 474

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



480
481
482
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 480

def hash
  [id, content_type, obj_id, object_verbose, object_admin_url, state, opened_on, grace_period_end, next_review_date, reviews, user_can_review, reviewer_groups, min_reviewers, reviewers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 228

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @content_type.nil?
    invalid_properties.push('invalid value for "content_type", content_type cannot be nil.')
  end

  if @obj_id.nil?
    invalid_properties.push('invalid value for "obj_id", obj_id cannot be nil.')
  end

  if @object_verbose.nil?
    invalid_properties.push('invalid value for "object_verbose", object_verbose cannot be nil.')
  end

  if @object_admin_url.nil?
    invalid_properties.push('invalid value for "object_admin_url", object_admin_url cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  if @opened_on.nil?
    invalid_properties.push('invalid value for "opened_on", opened_on cannot be nil.')
  end

  if @grace_period_end.nil?
    invalid_properties.push('invalid value for "grace_period_end", grace_period_end cannot be nil.')
  end

  if @next_review_date.nil?
    invalid_properties.push('invalid value for "next_review_date", next_review_date cannot be nil.')
  end

  if @reviews.nil?
    invalid_properties.push('invalid value for "reviews", reviews cannot be nil.')
  end

  if @user_can_review.nil?
    invalid_properties.push('invalid value for "user_can_review", user_can_review cannot be nil.')
  end

  if @reviewer_groups.nil?
    invalid_properties.push('invalid value for "reviewer_groups", reviewer_groups cannot be nil.')
  end

  if @min_reviewers.nil?
    invalid_properties.push('invalid value for "min_reviewers", min_reviewers cannot be nil.')
  end

  if @reviewers.nil?
    invalid_properties.push('invalid value for "reviewers", reviewers cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



509
510
511
512
513
514
515
516
517
518
519
520
521
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 509

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/authentik/api/models/lifecycle_iteration.rb', line 292

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @content_type.nil?
  return false if @obj_id.nil?
  return false if @object_verbose.nil?
  return false if @object_admin_url.nil?
  return false if @state.nil?
  return false if @opened_on.nil?
  return false if @grace_period_end.nil?
  return false if @next_review_date.nil?
  return false if @reviews.nil?
  return false if @user_can_review.nil?
  return false if @reviewer_groups.nil?
  return false if @min_reviewers.nil?
  return false if @reviewers.nil?
  true
end