Class: Authentik::Api::MicrosoftEntraProvider
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::MicrosoftEntraProvider
- Defined in:
- lib/authentik/api/models/microsoft_entra_provider.rb
Overview
MicrosoftEntraProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#assigned_backchannel_application_name ⇒ Object
Application's display Name.
-
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#client_secret ⇒ Object
Returns the value of attribute client_secret.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#discovery_enabled ⇒ Object
When enabled, authentik will attempt to discover existing resources in the remote system.
-
#dry_run ⇒ Object
When enabled, provider will not modify or create objects in the remote system.
-
#exclude_users_service_account ⇒ Object
Returns the value of attribute exclude_users_service_account.
-
#filter_group ⇒ Object
Returns the value of attribute filter_group.
-
#group_delete_action ⇒ Object
Returns the value of attribute group_delete_action.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#property_mappings_group ⇒ Object
Property mappings used for group creation/updating.
-
#sync_page_size ⇒ Object
Controls the number of objects synced in a single task.
-
#sync_page_timeout ⇒ Object
Timeout for synchronization of a single page.
-
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
-
#user_delete_action ⇒ Object
Returns the value of attribute user_delete_action.
-
#verbose_name ⇒ Object
Return object's verbose_name.
-
#verbose_name_plural ⇒ Object
Return object's plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MicrosoftEntraProvider
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MicrosoftEntraProvider
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 163 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::MicrosoftEntraProvider` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::MicrosoftEntraProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'property_mappings_group') if (value = attributes[:'property_mappings_group']).is_a?(Array) self.property_mappings_group = value end end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'assigned_backchannel_application_slug') self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug'] else self.assigned_backchannel_application_slug = nil end if attributes.key?(:'assigned_backchannel_application_name') self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name'] else self.assigned_backchannel_application_name = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] else self.client_id = nil end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] else self.client_secret = nil end if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] else self.tenant_id = nil end if attributes.key?(:'exclude_users_service_account') self.exclude_users_service_account = attributes[:'exclude_users_service_account'] end if attributes.key?(:'filter_group') self.filter_group = attributes[:'filter_group'] end if attributes.key?(:'user_delete_action') self.user_delete_action = attributes[:'user_delete_action'] end if attributes.key?(:'group_delete_action') self.group_delete_action = attributes[:'group_delete_action'] end if attributes.key?(:'sync_page_size') self.sync_page_size = attributes[:'sync_page_size'] end if attributes.key?(:'discovery_enabled') self.discovery_enabled = attributes[:'discovery_enabled'] end if attributes.key?(:'sync_page_timeout') self.sync_page_timeout = attributes[:'sync_page_timeout'] end if attributes.key?(:'dry_run') self.dry_run = attributes[:'dry_run'] end end |
Instance Attribute Details
#assigned_backchannel_application_name ⇒ Object
Application's display Name.
29 30 31 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 29 def assigned_backchannel_application_name @assigned_backchannel_application_name end |
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
26 27 28 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 26 def assigned_backchannel_application_slug @assigned_backchannel_application_slug end |
#client_id ⇒ Object
Returns the value of attribute client_id.
40 41 42 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 40 def client_id @client_id end |
#client_secret ⇒ Object
Returns the value of attribute client_secret.
42 43 44 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 42 def client_secret @client_secret end |
#component ⇒ Object
Get object component so that we know how to edit the object
23 24 25 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 23 def component @component end |
#discovery_enabled ⇒ Object
When enabled, authentik will attempt to discover existing resources in the remote system.
58 59 60 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 58 def discovery_enabled @discovery_enabled end |
#dry_run ⇒ Object
When enabled, provider will not modify or create objects in the remote system.
64 65 66 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 64 def dry_run @dry_run end |
#exclude_users_service_account ⇒ Object
Returns the value of attribute exclude_users_service_account.
46 47 48 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 46 def exclude_users_service_account @exclude_users_service_account end |
#filter_group ⇒ Object
Returns the value of attribute filter_group.
48 49 50 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 48 def filter_group @filter_group end |
#group_delete_action ⇒ Object
Returns the value of attribute group_delete_action.
52 53 54 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 52 def group_delete_action @group_delete_action end |
#meta_model_name ⇒ Object
Return internal model name
38 39 40 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 38 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 13 def pk @pk end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
17 18 19 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 17 def property_mappings @property_mappings end |
#property_mappings_group ⇒ Object
Property mappings used for group creation/updating.
20 21 22 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 20 def property_mappings_group @property_mappings_group end |
#sync_page_size ⇒ Object
Controls the number of objects synced in a single task
55 56 57 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 55 def sync_page_size @sync_page_size end |
#sync_page_timeout ⇒ Object
Timeout for synchronization of a single page
61 62 63 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 61 def sync_page_timeout @sync_page_timeout end |
#tenant_id ⇒ Object
Returns the value of attribute tenant_id.
44 45 46 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 44 def tenant_id @tenant_id end |
#user_delete_action ⇒ Object
Returns the value of attribute user_delete_action.
50 51 52 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 50 def user_delete_action @user_delete_action end |
#verbose_name ⇒ Object
Return object's verbose_name
32 33 34 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 32 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object's plural verbose_name
35 36 37 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 35 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
116 117 118 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 116 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
121 122 123 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 121 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 89 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'property_mappings' => :'property_mappings', :'property_mappings_group' => :'property_mappings_group', :'component' => :'component', :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'client_id' => :'client_id', :'client_secret' => :'client_secret', :'tenant_id' => :'tenant_id', :'exclude_users_service_account' => :'exclude_users_service_account', :'filter_group' => :'filter_group', :'user_delete_action' => :'user_delete_action', :'group_delete_action' => :'group_delete_action', :'sync_page_size' => :'sync_page_size', :'discovery_enabled' => :'discovery_enabled', :'sync_page_timeout' => :'sync_page_timeout', :'dry_run' => :'dry_run' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 509 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
153 154 155 156 157 158 159 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 153 def self.openapi_nullable Set.new([ :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name', :'filter_group', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 126 def self.openapi_types { :'pk' => :'Integer', :'name' => :'String', :'property_mappings' => :'Array<String>', :'property_mappings_group' => :'Array<String>', :'component' => :'String', :'assigned_backchannel_application_slug' => :'String', :'assigned_backchannel_application_name' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'client_id' => :'String', :'client_secret' => :'String', :'tenant_id' => :'String', :'exclude_users_service_account' => :'Boolean', :'filter_group' => :'String', :'user_delete_action' => :'OutgoingSyncDeleteAction', :'group_delete_action' => :'OutgoingSyncDeleteAction', :'sync_page_size' => :'Integer', :'discovery_enabled' => :'Boolean', :'sync_page_timeout' => :'String', :'dry_run' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 468 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && property_mappings == o.property_mappings && property_mappings_group == o.property_mappings_group && component == o.component && assigned_backchannel_application_slug == o.assigned_backchannel_application_slug && assigned_backchannel_application_name == o.assigned_backchannel_application_name && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && client_id == o.client_id && client_secret == o.client_secret && tenant_id == o.tenant_id && exclude_users_service_account == o.exclude_users_service_account && filter_group == o.filter_group && user_delete_action == o.user_delete_action && group_delete_action == o.group_delete_action && sync_page_size == o.sync_page_size && discovery_enabled == o.discovery_enabled && sync_page_timeout == o.sync_page_timeout && dry_run == o.dry_run end |
#eql?(o) ⇒ Boolean
496 497 498 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 496 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
502 503 504 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 502 def hash [pk, name, property_mappings, property_mappings_group, component, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, , client_id, client_secret, tenant_id, exclude_users_service_account, filter_group, user_delete_action, group_delete_action, sync_page_size, discovery_enabled, sync_page_timeout, dry_run].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 290 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @client_id.nil? invalid_properties.push('invalid value for "client_id", client_id cannot be nil.') end if @client_secret.nil? invalid_properties.push('invalid value for "client_secret", client_secret cannot be nil.') end if @tenant_id.nil? invalid_properties.push('invalid value for "tenant_id", tenant_id cannot be nil.') end if !@sync_page_size.nil? && @sync_page_size > 2147483647 invalid_properties.push('invalid value for "sync_page_size", must be smaller than or equal to 2147483647.') end if !@sync_page_size.nil? && @sync_page_size < 1 invalid_properties.push('invalid value for "sync_page_size", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
531 532 533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 531 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/authentik/api/models/microsoft_entra_provider.rb', line 342 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @client_id.nil? return false if @client_secret.nil? return false if @tenant_id.nil? return false if !@sync_page_size.nil? && @sync_page_size > 2147483647 return false if !@sync_page_size.nil? && @sync_page_size < 1 true end |