Class: Authentik::Api::NativeLogoutChallenge
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::NativeLogoutChallenge
- Defined in:
- lib/authentik/api/models/native_logout_challenge.rb
Overview
Challenge for native browser logout
Instance Attribute Summary collapse
-
#binding ⇒ Object
Returns the value of attribute binding.
-
#component ⇒ Object
Returns the value of attribute component.
-
#flow_info ⇒ Object
Returns the value of attribute flow_info.
-
#is_complete ⇒ Object
Returns the value of attribute is_complete.
-
#post_url ⇒ Object
Returns the value of attribute post_url.
-
#provider_name ⇒ Object
Returns the value of attribute provider_name.
-
#redirect_url ⇒ Object
Returns the value of attribute redirect_url.
-
#relay_state ⇒ Object
Returns the value of attribute relay_state.
-
#response_errors ⇒ Object
Returns the value of attribute response_errors.
-
#saml_request ⇒ Object
Returns the value of attribute saml_request.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NativeLogoutChallenge
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NativeLogoutChallenge
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::NativeLogoutChallenge` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::NativeLogoutChallenge`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'flow_info') self.flow_info = attributes[:'flow_info'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = 'ak-provider-saml-native-logout' end if attributes.key?(:'response_errors') if (value = attributes[:'response_errors']).is_a?(Hash) self.response_errors = value end end if attributes.key?(:'post_url') self.post_url = attributes[:'post_url'] end if attributes.key?(:'saml_request') self.saml_request = attributes[:'saml_request'] end if attributes.key?(:'relay_state') self.relay_state = attributes[:'relay_state'] end if attributes.key?(:'provider_name') self.provider_name = attributes[:'provider_name'] end if attributes.key?(:'binding') self.binding = attributes[:'binding'] end if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.key?(:'is_complete') self.is_complete = attributes[:'is_complete'] else self.is_complete = false end end |
Instance Attribute Details
#binding ⇒ Object
Returns the value of attribute binding.
27 28 29 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 27 def binding @binding end |
#component ⇒ Object
Returns the value of attribute component.
15 16 17 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 15 def component @component end |
#flow_info ⇒ Object
Returns the value of attribute flow_info.
13 14 15 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 13 def flow_info @flow_info end |
#is_complete ⇒ Object
Returns the value of attribute is_complete.
31 32 33 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 31 def is_complete @is_complete end |
#post_url ⇒ Object
Returns the value of attribute post_url.
19 20 21 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 19 def post_url @post_url end |
#provider_name ⇒ Object
Returns the value of attribute provider_name.
25 26 27 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 25 def provider_name @provider_name end |
#redirect_url ⇒ Object
Returns the value of attribute redirect_url.
29 30 31 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 29 def redirect_url @redirect_url end |
#relay_state ⇒ Object
Returns the value of attribute relay_state.
23 24 25 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 23 def relay_state @relay_state end |
#response_errors ⇒ Object
Returns the value of attribute response_errors.
17 18 19 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 17 def response_errors @response_errors end |
#saml_request ⇒ Object
Returns the value of attribute saml_request.
21 22 23 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 21 def saml_request @saml_request end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 34 def self.attribute_map { :'flow_info' => :'flow_info', :'component' => :'component', :'response_errors' => :'response_errors', :'post_url' => :'post_url', :'saml_request' => :'saml_request', :'relay_state' => :'relay_state', :'provider_name' => :'provider_name', :'binding' => :'binding', :'redirect_url' => :'redirect_url', :'is_complete' => :'is_complete' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 60 def self.openapi_types { :'flow_info' => :'ContextualFlowInfo', :'component' => :'String', :'response_errors' => :'Hash<String, Array<ErrorDetail>>', :'post_url' => :'String', :'saml_request' => :'String', :'relay_state' => :'String', :'provider_name' => :'String', :'binding' => :'String', :'redirect_url' => :'String', :'is_complete' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && flow_info == o.flow_info && component == o.component && response_errors == o.response_errors && post_url == o.post_url && saml_request == o.saml_request && relay_state == o.relay_state && provider_name == o.provider_name && binding == o.binding && redirect_url == o.redirect_url && is_complete == o.is_complete end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 184 def hash [flow_info, component, response_errors, post_url, saml_request, relay_state, provider_name, binding, redirect_url, is_complete].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/authentik/api/models/native_logout_challenge.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |