Class: Authentik::Api::NotificationRuleRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::NotificationRuleRequest
- Defined in:
- lib/authentik/api/models/notification_rule_request.rb
Overview
NotificationRule Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#destination_event_user ⇒ Object
When enabled, notification will be sent to user the user that triggered the event.When destination_group is configured, notification is sent to both.
-
#destination_group ⇒ Object
Define which group of users this notification should be sent and shown to.
-
#name ⇒ Object
Returns the value of attribute name.
-
#severity ⇒ Object
Controls which severity level the created notifications will have.
-
#transports ⇒ Object
Select which transports should be used to notify the user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NotificationRuleRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NotificationRuleRequest
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::NotificationRuleRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::NotificationRuleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'transports') if (value = attributes[:'transports']).is_a?(Array) self.transports = value end end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'destination_group') self.destination_group = attributes[:'destination_group'] end if attributes.key?(:'destination_event_user') self.destination_event_user = attributes[:'destination_event_user'] end end |
Instance Attribute Details
#destination_event_user ⇒ Object
When enabled, notification will be sent to user the user that triggered the event.When destination_group is configured, notification is sent to both.
25 26 27 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 25 def destination_event_user @destination_event_user end |
#destination_group ⇒ Object
Define which group of users this notification should be sent and shown to. If left empty, Notification won’t ben sent.
22 23 24 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 22 def destination_group @destination_group end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 13 def name @name end |
#severity ⇒ Object
Controls which severity level the created notifications will have.
19 20 21 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 19 def severity @severity end |
#transports ⇒ Object
Select which transports should be used to notify the user. If none are selected, the notification will only be shown in the authentik UI.
16 17 18 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 16 def transports @transports end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 50 def self.attribute_map { :'name' => :'name', :'transports' => :'transports', :'severity' => :'severity', :'destination_group' => :'destination_group', :'destination_event_user' => :'destination_event_user' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 195 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 82 def self.openapi_nullable Set.new([ :'destination_group', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 71 def self.openapi_types { :'name' => :'String', :'transports' => :'Array<String>', :'severity' => :'SeverityEnum', :'destination_group' => :'String', :'destination_event_user' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && transports == o.transports && severity == o.severity && destination_group == o.destination_group && destination_event_user == o.destination_event_user end |
#eql?(o) ⇒ Boolean
182 183 184 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 182 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 188 def hash [name, transports, severity, destination_group, destination_event_user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
147 148 149 150 151 152 |
# File 'lib/authentik/api/models/notification_rule_request.rb', line 147 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 true end |