Class: Authentik::Api::OAuth2Provider
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::OAuth2Provider
- Defined in:
- lib/authentik/api/models/o_auth2_provider.rb
Overview
OAuth2Provider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_code_validity ⇒ Object
Access codes not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#access_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#assigned_application_name ⇒ Object
Application’s display Name.
-
#assigned_application_slug ⇒ Object
Internal application name, used in URLs.
-
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
-
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
-
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
-
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#client_secret ⇒ Object
Returns the value of attribute client_secret.
-
#client_type ⇒ Object
Confidential clients are capable of maintaining the confidentiality of their credentials.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#encryption_key ⇒ Object
Key used to encrypt the tokens.
-
#grant_types ⇒ Object
Returns the value of attribute grant_types.
-
#include_claims_in_id_token ⇒ Object
Include User claims from scopes in the id_token, for applications that don’t access the userinfo endpoint.
-
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
-
#issuer_mode ⇒ Object
Configure how the issuer field of the ID Token should be filled.
-
#jwt_federation_providers ⇒ Object
Returns the value of attribute jwt_federation_providers.
-
#jwt_federation_sources ⇒ Object
Returns the value of attribute jwt_federation_sources.
-
#logout_method ⇒ Object
Backchannel logs out with server to server calls.
-
#logout_uri ⇒ Object
Returns the value of attribute logout_uri.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#redirect_uris ⇒ Object
Returns the value of attribute redirect_uris.
-
#refresh_token_threshold ⇒ Object
When refreshing a token, if the refresh token is valid for less than this duration, it will be renewed.
-
#refresh_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#signing_key ⇒ Object
Key used to sign the tokens.
-
#sub_mode ⇒ Object
Configure what data should be used as unique User Identifier.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OAuth2Provider
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OAuth2Provider
Initializes the object
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 222 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::OAuth2Provider` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::OAuth2Provider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'authorization_flow') self. = attributes[:'authorization_flow'] else self. = nil end if attributes.key?(:'invalidation_flow') self.invalidation_flow = attributes[:'invalidation_flow'] else self.invalidation_flow = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'assigned_application_slug') self.assigned_application_slug = attributes[:'assigned_application_slug'] else self.assigned_application_slug = nil end if attributes.key?(:'assigned_application_name') self.assigned_application_name = attributes[:'assigned_application_name'] else self.assigned_application_name = nil end if attributes.key?(:'assigned_backchannel_application_slug') self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug'] else self.assigned_backchannel_application_slug = nil end if attributes.key?(:'assigned_backchannel_application_name') self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name'] else self.assigned_backchannel_application_name = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'client_type') self.client_type = attributes[:'client_type'] end if attributes.key?(:'grant_types') if (value = attributes[:'grant_types']).is_a?(Array) self.grant_types = value end end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] end if attributes.key?(:'access_code_validity') self.access_code_validity = attributes[:'access_code_validity'] end if attributes.key?(:'access_token_validity') self.access_token_validity = attributes[:'access_token_validity'] end if attributes.key?(:'refresh_token_validity') self.refresh_token_validity = attributes[:'refresh_token_validity'] end if attributes.key?(:'refresh_token_threshold') self.refresh_token_threshold = attributes[:'refresh_token_threshold'] end if attributes.key?(:'include_claims_in_id_token') self.include_claims_in_id_token = attributes[:'include_claims_in_id_token'] end if attributes.key?(:'signing_key') self.signing_key = attributes[:'signing_key'] end if attributes.key?(:'encryption_key') self.encryption_key = attributes[:'encryption_key'] end if attributes.key?(:'redirect_uris') if (value = attributes[:'redirect_uris']).is_a?(Array) self.redirect_uris = value end else self.redirect_uris = nil end if attributes.key?(:'logout_uri') self.logout_uri = attributes[:'logout_uri'] end if attributes.key?(:'logout_method') self.logout_method = attributes[:'logout_method'] end if attributes.key?(:'sub_mode') self.sub_mode = attributes[:'sub_mode'] end if attributes.key?(:'issuer_mode') self.issuer_mode = attributes[:'issuer_mode'] end if attributes.key?(:'jwt_federation_sources') if (value = attributes[:'jwt_federation_sources']).is_a?(Array) self.jwt_federation_sources = value end end if attributes.key?(:'jwt_federation_providers') if (value = attributes[:'jwt_federation_providers']).is_a?(Array) self.jwt_federation_providers = value end end end |
Instance Attribute Details
#access_code_validity ⇒ Object
Access codes not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
62 63 64 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 62 def access_code_validity @access_code_validity end |
#access_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
65 66 67 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 65 def access_token_validity @access_token_validity end |
#assigned_application_name ⇒ Object
Application’s display Name.
35 36 37 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 35 def assigned_application_name @assigned_application_name end |
#assigned_application_slug ⇒ Object
Internal application name, used in URLs.
32 33 34 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 32 def assigned_application_slug @assigned_application_slug end |
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
41 42 43 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 41 def assigned_backchannel_application_name @assigned_backchannel_application_name end |
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
38 39 40 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 38 def assigned_backchannel_application_slug @assigned_backchannel_application_slug end |
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
18 19 20 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 18 def authentication_flow @authentication_flow end |
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
21 22 23 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 21 def @authorization_flow end |
#client_id ⇒ Object
Returns the value of attribute client_id.
57 58 59 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 57 def client_id @client_id end |
#client_secret ⇒ Object
Returns the value of attribute client_secret.
59 60 61 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 59 def client_secret @client_secret end |
#client_type ⇒ Object
Confidential clients are capable of maintaining the confidentiality of their credentials. Public clients are incapable
53 54 55 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 53 def client_type @client_type end |
#component ⇒ Object
Get object component so that we know how to edit the object
29 30 31 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 29 def component @component end |
#encryption_key ⇒ Object
Key used to encrypt the tokens. When set, tokens will be encrypted and returned as JWEs.
80 81 82 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 80 def encryption_key @encryption_key end |
#grant_types ⇒ Object
Returns the value of attribute grant_types.
55 56 57 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 55 def grant_types @grant_types end |
#include_claims_in_id_token ⇒ Object
Include User claims from scopes in the id_token, for applications that don’t access the userinfo endpoint.
74 75 76 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 74 def include_claims_in_id_token @include_claims_in_id_token end |
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
24 25 26 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 24 def invalidation_flow @invalidation_flow end |
#issuer_mode ⇒ Object
Configure how the issuer field of the ID Token should be filled.
93 94 95 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 93 def issuer_mode @issuer_mode end |
#jwt_federation_providers ⇒ Object
Returns the value of attribute jwt_federation_providers.
97 98 99 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 97 def jwt_federation_providers @jwt_federation_providers end |
#jwt_federation_sources ⇒ Object
Returns the value of attribute jwt_federation_sources.
95 96 97 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 95 def jwt_federation_sources @jwt_federation_sources end |
#logout_method ⇒ Object
Backchannel logs out with server to server calls. Frontchannel uses iframes in your browser
87 88 89 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 87 def logout_method @logout_method end |
#logout_uri ⇒ Object
Returns the value of attribute logout_uri.
84 85 86 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 84 def logout_uri @logout_uri end |
#meta_model_name ⇒ Object
Return internal model name
50 51 52 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 50 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 13 def pk @pk end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
26 27 28 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 26 def property_mappings @property_mappings end |
#redirect_uris ⇒ Object
Returns the value of attribute redirect_uris.
82 83 84 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 82 def redirect_uris @redirect_uris end |
#refresh_token_threshold ⇒ Object
When refreshing a token, if the refresh token is valid for less than this duration, it will be renewed. When set to seconds=0, token will always be renewed. (Format: hours=1;minutes=2;seconds=3).
71 72 73 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 71 def refresh_token_threshold @refresh_token_threshold end |
#refresh_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
68 69 70 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 68 def refresh_token_validity @refresh_token_validity end |
#signing_key ⇒ Object
Key used to sign the tokens.
77 78 79 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 77 def signing_key @signing_key end |
#sub_mode ⇒ Object
Configure what data should be used as unique User Identifier. For most cases, the default should be fine.
90 91 92 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 90 def sub_mode @sub_mode end |
#verbose_name ⇒ Object
Return object’s verbose_name
44 45 46 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 44 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
47 48 49 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 47 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
160 161 162 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 160 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
165 166 167 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 165 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 122 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'authentication_flow' => :'authentication_flow', :'authorization_flow' => :'authorization_flow', :'invalidation_flow' => :'invalidation_flow', :'property_mappings' => :'property_mappings', :'component' => :'component', :'assigned_application_slug' => :'assigned_application_slug', :'assigned_application_name' => :'assigned_application_name', :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'client_type' => :'client_type', :'grant_types' => :'grant_types', :'client_id' => :'client_id', :'client_secret' => :'client_secret', :'access_code_validity' => :'access_code_validity', :'access_token_validity' => :'access_token_validity', :'refresh_token_validity' => :'refresh_token_validity', :'refresh_token_threshold' => :'refresh_token_threshold', :'include_claims_in_id_token' => :'include_claims_in_id_token', :'signing_key' => :'signing_key', :'encryption_key' => :'encryption_key', :'redirect_uris' => :'redirect_uris', :'logout_uri' => :'logout_uri', :'logout_method' => :'logout_method', :'sub_mode' => :'sub_mode', :'issuer_mode' => :'issuer_mode', :'jwt_federation_sources' => :'jwt_federation_sources', :'jwt_federation_providers' => :'jwt_federation_providers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 643 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 208 def self.openapi_nullable Set.new([ :'authentication_flow', :'assigned_application_slug', :'assigned_application_name', :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name', :'signing_key', :'encryption_key', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 170 def self.openapi_types { :'pk' => :'Integer', :'name' => :'String', :'authentication_flow' => :'String', :'authorization_flow' => :'String', :'invalidation_flow' => :'String', :'property_mappings' => :'Array<String>', :'component' => :'String', :'assigned_application_slug' => :'String', :'assigned_application_name' => :'String', :'assigned_backchannel_application_slug' => :'String', :'assigned_backchannel_application_name' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'client_type' => :'ClientTypeEnum', :'grant_types' => :'Array<GrantTypesEnum>', :'client_id' => :'String', :'client_secret' => :'String', :'access_code_validity' => :'String', :'access_token_validity' => :'String', :'refresh_token_validity' => :'String', :'refresh_token_threshold' => :'String', :'include_claims_in_id_token' => :'Boolean', :'signing_key' => :'String', :'encryption_key' => :'String', :'redirect_uris' => :'Array<RedirectURI>', :'logout_uri' => :'String', :'logout_method' => :'OAuth2ProviderLogoutMethodEnum', :'sub_mode' => :'SubModeEnum', :'issuer_mode' => :'IssuerModeEnum', :'jwt_federation_sources' => :'Array<String>', :'jwt_federation_providers' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 591 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && authentication_flow == o.authentication_flow && == o. && invalidation_flow == o.invalidation_flow && property_mappings == o.property_mappings && component == o.component && assigned_application_slug == o.assigned_application_slug && assigned_application_name == o.assigned_application_name && assigned_backchannel_application_slug == o.assigned_backchannel_application_slug && assigned_backchannel_application_name == o.assigned_backchannel_application_name && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && client_type == o.client_type && grant_types == o.grant_types && client_id == o.client_id && client_secret == o.client_secret && access_code_validity == o.access_code_validity && access_token_validity == o.access_token_validity && refresh_token_validity == o.refresh_token_validity && refresh_token_threshold == o.refresh_token_threshold && include_claims_in_id_token == o.include_claims_in_id_token && signing_key == o.signing_key && encryption_key == o.encryption_key && redirect_uris == o.redirect_uris && logout_uri == o.logout_uri && logout_method == o.logout_method && sub_mode == o.sub_mode && issuer_mode == o.issuer_mode && jwt_federation_sources == o.jwt_federation_sources && jwt_federation_providers == o.jwt_federation_providers end |
#eql?(o) ⇒ Boolean
630 631 632 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 630 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
636 637 638 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 636 def hash [pk, name, authentication_flow, , invalidation_flow, property_mappings, component, assigned_application_slug, assigned_application_name, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, , client_type, grant_types, client_id, client_secret, access_code_validity, access_token_validity, refresh_token_validity, refresh_token_threshold, include_claims_in_id_token, signing_key, encryption_key, redirect_uris, logout_uri, logout_method, sub_mode, issuer_mode, jwt_federation_sources, jwt_federation_providers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 403 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @authorization_flow.nil? invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.') end if @invalidation_flow.nil? invalid_properties.push('invalid value for "invalidation_flow", invalidation_flow cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if !@client_id.nil? && @client_id.to_s.length > 255 invalid_properties.push('invalid value for "client_id", the character length must be smaller than or equal to 255.') end if !@client_secret.nil? && @client_secret.to_s.length > 255 invalid_properties.push('invalid value for "client_secret", the character length must be smaller than or equal to 255.') end if @redirect_uris.nil? invalid_properties.push('invalid value for "redirect_uris", redirect_uris cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
665 666 667 668 669 670 671 672 673 674 675 676 677 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 665 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/authentik/api/models/o_auth2_provider.rb', line 455 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @authorization_flow.nil? return false if @invalidation_flow.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if !@client_id.nil? && @client_id.to_s.length > 255 return false if !@client_secret.nil? && @client_secret.to_s.length > 255 return false if @redirect_uris.nil? true end |