Class: Authentik::Api::OAuth2ProviderRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::OAuth2ProviderRequest
- Defined in:
- lib/authentik/api/models/o_auth2_provider_request.rb
Overview
OAuth2Provider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_code_validity ⇒ Object
Access codes not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#access_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
-
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#client_secret ⇒ Object
Returns the value of attribute client_secret.
-
#client_type ⇒ Object
Confidential clients are capable of maintaining the confidentiality of their credentials.
-
#encryption_key ⇒ Object
Key used to encrypt the tokens.
-
#grant_types ⇒ Object
Returns the value of attribute grant_types.
-
#include_claims_in_id_token ⇒ Object
Include User claims from scopes in the id_token, for applications that don’t access the userinfo endpoint.
-
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
-
#issuer_mode ⇒ Object
Configure how the issuer field of the ID Token should be filled.
-
#jwt_federation_providers ⇒ Object
Returns the value of attribute jwt_federation_providers.
-
#jwt_federation_sources ⇒ Object
Returns the value of attribute jwt_federation_sources.
-
#logout_method ⇒ Object
Backchannel logs out with server to server calls.
-
#logout_uri ⇒ Object
Returns the value of attribute logout_uri.
-
#name ⇒ Object
Returns the value of attribute name.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#redirect_uris ⇒ Object
Returns the value of attribute redirect_uris.
-
#refresh_token_threshold ⇒ Object
When refreshing a token, if the refresh token is valid for less than this duration, it will be renewed.
-
#refresh_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#signing_key ⇒ Object
Key used to sign the tokens.
-
#sub_mode ⇒ Object
Configure what data should be used as unique User Identifier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OAuth2ProviderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OAuth2ProviderRequest
Initializes the object
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 174 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::OAuth2ProviderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::OAuth2ProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'authorization_flow') self. = attributes[:'authorization_flow'] else self. = nil end if attributes.key?(:'invalidation_flow') self.invalidation_flow = attributes[:'invalidation_flow'] else self.invalidation_flow = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'client_type') self.client_type = attributes[:'client_type'] end if attributes.key?(:'grant_types') if (value = attributes[:'grant_types']).is_a?(Array) self.grant_types = value end end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] end if attributes.key?(:'access_code_validity') self.access_code_validity = attributes[:'access_code_validity'] end if attributes.key?(:'access_token_validity') self.access_token_validity = attributes[:'access_token_validity'] end if attributes.key?(:'refresh_token_validity') self.refresh_token_validity = attributes[:'refresh_token_validity'] end if attributes.key?(:'refresh_token_threshold') self.refresh_token_threshold = attributes[:'refresh_token_threshold'] end if attributes.key?(:'include_claims_in_id_token') self.include_claims_in_id_token = attributes[:'include_claims_in_id_token'] end if attributes.key?(:'signing_key') self.signing_key = attributes[:'signing_key'] end if attributes.key?(:'encryption_key') self.encryption_key = attributes[:'encryption_key'] end if attributes.key?(:'redirect_uris') if (value = attributes[:'redirect_uris']).is_a?(Array) self.redirect_uris = value end else self.redirect_uris = nil end if attributes.key?(:'logout_uri') self.logout_uri = attributes[:'logout_uri'] end if attributes.key?(:'logout_method') self.logout_method = attributes[:'logout_method'] end if attributes.key?(:'sub_mode') self.sub_mode = attributes[:'sub_mode'] end if attributes.key?(:'issuer_mode') self.issuer_mode = attributes[:'issuer_mode'] end if attributes.key?(:'jwt_federation_sources') if (value = attributes[:'jwt_federation_sources']).is_a?(Array) self.jwt_federation_sources = value end end if attributes.key?(:'jwt_federation_providers') if (value = attributes[:'jwt_federation_providers']).is_a?(Array) self.jwt_federation_providers = value end end end |
Instance Attribute Details
#access_code_validity ⇒ Object
Access codes not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
36 37 38 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 36 def access_code_validity @access_code_validity end |
#access_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
39 40 41 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 39 def access_token_validity @access_token_validity end |
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
16 17 18 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 16 def authentication_flow @authentication_flow end |
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
19 20 21 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 19 def @authorization_flow end |
#client_id ⇒ Object
Returns the value of attribute client_id.
31 32 33 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 31 def client_id @client_id end |
#client_secret ⇒ Object
Returns the value of attribute client_secret.
33 34 35 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 33 def client_secret @client_secret end |
#client_type ⇒ Object
Confidential clients are capable of maintaining the confidentiality of their credentials. Public clients are incapable
27 28 29 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 27 def client_type @client_type end |
#encryption_key ⇒ Object
Key used to encrypt the tokens. When set, tokens will be encrypted and returned as JWEs.
54 55 56 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 54 def encryption_key @encryption_key end |
#grant_types ⇒ Object
Returns the value of attribute grant_types.
29 30 31 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 29 def grant_types @grant_types end |
#include_claims_in_id_token ⇒ Object
Include User claims from scopes in the id_token, for applications that don’t access the userinfo endpoint.
48 49 50 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 48 def include_claims_in_id_token @include_claims_in_id_token end |
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
22 23 24 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 22 def invalidation_flow @invalidation_flow end |
#issuer_mode ⇒ Object
Configure how the issuer field of the ID Token should be filled.
67 68 69 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 67 def issuer_mode @issuer_mode end |
#jwt_federation_providers ⇒ Object
Returns the value of attribute jwt_federation_providers.
71 72 73 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 71 def jwt_federation_providers @jwt_federation_providers end |
#jwt_federation_sources ⇒ Object
Returns the value of attribute jwt_federation_sources.
69 70 71 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 69 def jwt_federation_sources @jwt_federation_sources end |
#logout_method ⇒ Object
Backchannel logs out with server to server calls. Frontchannel uses iframes in your browser
61 62 63 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 61 def logout_method @logout_method end |
#logout_uri ⇒ Object
Returns the value of attribute logout_uri.
58 59 60 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 58 def logout_uri @logout_uri end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 13 def name @name end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
24 25 26 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 24 def property_mappings @property_mappings end |
#redirect_uris ⇒ Object
Returns the value of attribute redirect_uris.
56 57 58 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 56 def redirect_uris @redirect_uris end |
#refresh_token_threshold ⇒ Object
When refreshing a token, if the refresh token is valid for less than this duration, it will be renewed. When set to seconds=0, token will always be renewed. (Format: hours=1;minutes=2;seconds=3).
45 46 47 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 45 def refresh_token_threshold @refresh_token_threshold end |
#refresh_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
42 43 44 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 42 def refresh_token_validity @refresh_token_validity end |
#signing_key ⇒ Object
Key used to sign the tokens.
51 52 53 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 51 def signing_key @signing_key end |
#sub_mode ⇒ Object
Configure what data should be used as unique User Identifier. For most cases, the default should be fine.
64 65 66 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 64 def sub_mode @sub_mode end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
125 126 127 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 125 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
130 131 132 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 130 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 96 def self.attribute_map { :'name' => :'name', :'authentication_flow' => :'authentication_flow', :'authorization_flow' => :'authorization_flow', :'invalidation_flow' => :'invalidation_flow', :'property_mappings' => :'property_mappings', :'client_type' => :'client_type', :'grant_types' => :'grant_types', :'client_id' => :'client_id', :'client_secret' => :'client_secret', :'access_code_validity' => :'access_code_validity', :'access_token_validity' => :'access_token_validity', :'refresh_token_validity' => :'refresh_token_validity', :'refresh_token_threshold' => :'refresh_token_threshold', :'include_claims_in_id_token' => :'include_claims_in_id_token', :'signing_key' => :'signing_key', :'encryption_key' => :'encryption_key', :'redirect_uris' => :'redirect_uris', :'logout_uri' => :'logout_uri', :'logout_method' => :'logout_method', :'sub_mode' => :'sub_mode', :'issuer_mode' => :'issuer_mode', :'jwt_federation_sources' => :'jwt_federation_sources', :'jwt_federation_providers' => :'jwt_federation_providers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 551 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
164 165 166 167 168 169 170 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 164 def self.openapi_nullable Set.new([ :'authentication_flow', :'signing_key', :'encryption_key', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 135 def self.openapi_types { :'name' => :'String', :'authentication_flow' => :'String', :'authorization_flow' => :'String', :'invalidation_flow' => :'String', :'property_mappings' => :'Array<String>', :'client_type' => :'ClientTypeEnum', :'grant_types' => :'Array<GrantTypesEnum>', :'client_id' => :'String', :'client_secret' => :'String', :'access_code_validity' => :'String', :'access_token_validity' => :'String', :'refresh_token_validity' => :'String', :'refresh_token_threshold' => :'String', :'include_claims_in_id_token' => :'Boolean', :'signing_key' => :'String', :'encryption_key' => :'String', :'redirect_uris' => :'Array<RedirectURIRequest>', :'logout_uri' => :'String', :'logout_method' => :'OAuth2ProviderLogoutMethodEnum', :'sub_mode' => :'SubModeEnum', :'issuer_mode' => :'IssuerModeEnum', :'jwt_federation_sources' => :'Array<String>', :'jwt_federation_providers' => :'Array<Integer>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 508 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && authentication_flow == o.authentication_flow && == o. && invalidation_flow == o.invalidation_flow && property_mappings == o.property_mappings && client_type == o.client_type && grant_types == o.grant_types && client_id == o.client_id && client_secret == o.client_secret && access_code_validity == o.access_code_validity && access_token_validity == o.access_token_validity && refresh_token_validity == o.refresh_token_validity && refresh_token_threshold == o.refresh_token_threshold && include_claims_in_id_token == o.include_claims_in_id_token && signing_key == o.signing_key && encryption_key == o.encryption_key && redirect_uris == o.redirect_uris && logout_uri == o.logout_uri && logout_method == o.logout_method && sub_mode == o.sub_mode && issuer_mode == o.issuer_mode && jwt_federation_sources == o.jwt_federation_sources && jwt_federation_providers == o.jwt_federation_providers end |
#eql?(o) ⇒ Boolean
538 539 540 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 538 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
544 545 546 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 544 def hash [name, authentication_flow, , invalidation_flow, property_mappings, client_type, grant_types, client_id, client_secret, access_code_validity, access_token_validity, refresh_token_validity, refresh_token_threshold, include_claims_in_id_token, signing_key, encryption_key, redirect_uris, logout_uri, logout_method, sub_mode, issuer_mode, jwt_federation_sources, jwt_federation_providers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 301 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @authorization_flow.nil? invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.') end if @invalidation_flow.nil? invalid_properties.push('invalid value for "invalidation_flow", invalidation_flow cannot be nil.') end if !@client_id.nil? && @client_id.to_s.length > 255 invalid_properties.push('invalid value for "client_id", the character length must be smaller than or equal to 255.') end if !@client_id.nil? && @client_id.to_s.length < 1 invalid_properties.push('invalid value for "client_id", the character length must be greater than or equal to 1.') end if !@client_secret.nil? && @client_secret.to_s.length > 255 invalid_properties.push('invalid value for "client_secret", the character length must be smaller than or equal to 255.') end if !@access_code_validity.nil? && @access_code_validity.to_s.length < 1 invalid_properties.push('invalid value for "access_code_validity", the character length must be greater than or equal to 1.') end if !@access_token_validity.nil? && @access_token_validity.to_s.length < 1 invalid_properties.push('invalid value for "access_token_validity", the character length must be greater than or equal to 1.') end if !@refresh_token_validity.nil? && @refresh_token_validity.to_s.length < 1 invalid_properties.push('invalid value for "refresh_token_validity", the character length must be greater than or equal to 1.') end if !@refresh_token_threshold.nil? && @refresh_token_threshold.to_s.length < 1 invalid_properties.push('invalid value for "refresh_token_threshold", the character length must be greater than or equal to 1.') end if @redirect_uris.nil? invalid_properties.push('invalid value for "redirect_uris", redirect_uris cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 573 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/authentik/api/models/o_auth2_provider_request.rb', line 357 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @authorization_flow.nil? return false if @invalidation_flow.nil? return false if !@client_id.nil? && @client_id.to_s.length > 255 return false if !@client_id.nil? && @client_id.to_s.length < 1 return false if !@client_secret.nil? && @client_secret.to_s.length > 255 return false if !@access_code_validity.nil? && @access_code_validity.to_s.length < 1 return false if !@access_token_validity.nil? && @access_token_validity.to_s.length < 1 return false if !@refresh_token_validity.nil? && @refresh_token_validity.to_s.length < 1 return false if !@refresh_token_threshold.nil? && @refresh_token_threshold.to_s.length < 1 return false if @redirect_uris.nil? true end |