Class: Authentik::Api::PartialUser
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PartialUser
- Defined in:
- lib/authentik/api/models/partial_user.rb
Overview
Partial User Serializer, does not include child relations.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#email ⇒ Object
Returns the value of attribute email.
-
#is_active ⇒ Object
Designates whether this user should be treated as active.
-
#last_login ⇒ Object
Returns the value of attribute last_login.
-
#name ⇒ Object
User’s display name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#uid ⇒ Object
Returns the value of attribute uid.
-
#username ⇒ Object
Required.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PartialUser
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PartialUser
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/authentik/api/models/partial_user.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PartialUser` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PartialUser`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'last_login') self.last_login = attributes[:'last_login'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end if attributes.key?(:'uid') self.uid = attributes[:'uid'] else self.uid = nil end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
28 29 30 |
# File 'lib/authentik/api/models/partial_user.rb', line 28 def attributes @attributes end |
#email ⇒ Object
Returns the value of attribute email.
26 27 28 |
# File 'lib/authentik/api/models/partial_user.rb', line 26 def email @email end |
#is_active ⇒ Object
Designates whether this user should be treated as active. Unselect this instead of deleting accounts.
22 23 24 |
# File 'lib/authentik/api/models/partial_user.rb', line 22 def is_active @is_active end |
#last_login ⇒ Object
Returns the value of attribute last_login.
24 25 26 |
# File 'lib/authentik/api/models/partial_user.rb', line 24 def last_login @last_login end |
#name ⇒ Object
User’s display name.
19 20 21 |
# File 'lib/authentik/api/models/partial_user.rb', line 19 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/partial_user.rb', line 13 def pk @pk end |
#uid ⇒ Object
Returns the value of attribute uid.
30 31 32 |
# File 'lib/authentik/api/models/partial_user.rb', line 30 def uid @uid end |
#username ⇒ Object
Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.
16 17 18 |
# File 'lib/authentik/api/models/partial_user.rb', line 16 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/authentik/api/models/partial_user.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/authentik/api/models/partial_user.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/authentik/api/models/partial_user.rb', line 33 def self.attribute_map { :'pk' => :'pk', :'username' => :'username', :'name' => :'name', :'is_active' => :'is_active', :'last_login' => :'last_login', :'email' => :'email', :'attributes' => :'attributes', :'uid' => :'uid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/authentik/api/models/partial_user.rb', line 280 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 75 |
# File 'lib/authentik/api/models/partial_user.rb', line 71 def self.openapi_nullable Set.new([ :'last_login', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/authentik/api/models/partial_user.rb', line 57 def self.openapi_types { :'pk' => :'Integer', :'username' => :'String', :'name' => :'String', :'is_active' => :'Boolean', :'last_login' => :'Time', :'email' => :'String', :'attributes' => :'Hash<String, Object>', :'uid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/authentik/api/models/partial_user.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && username == o.username && name == o.name && is_active == o.is_active && last_login == o.last_login && email == o.email && attributes == o.attributes && uid == o.uid end |
#eql?(o) ⇒ Boolean
267 268 269 |
# File 'lib/authentik/api/models/partial_user.rb', line 267 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
273 274 275 |
# File 'lib/authentik/api/models/partial_user.rb', line 273 def hash [pk, username, name, is_active, last_login, email, attributes, uid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/authentik/api/models/partial_user.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end if @username.to_s.length > 150 invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 150.') end pattern = Regexp.new(/^[\w.@+-]+$/) if @username !~ pattern invalid_properties.push("invalid value for \"username\", must conform to the pattern #{pattern}.") end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if !@email.nil? && @email.to_s.length > 254 invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 254.') end if @uid.nil? invalid_properties.push('invalid value for "uid", uid cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/authentik/api/models/partial_user.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/authentik/api/models/partial_user.rb', line 175 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @username.nil? return false if @username.to_s.length > 150 return false if @username !~ Regexp.new(/^[\w.@+-]+$/) return false if @name.nil? return false if !@email.nil? && @email.to_s.length > 254 return false if @uid.nil? true end |