Class: Authentik::Api::PasswordPolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PasswordPolicy
- Defined in:
- lib/authentik/api/models/password_policy.rb
Overview
Password Policy Serializer
Instance Attribute Summary collapse
-
#amount_digits ⇒ Object
Returns the value of attribute amount_digits.
-
#amount_lowercase ⇒ Object
Returns the value of attribute amount_lowercase.
-
#amount_symbols ⇒ Object
Returns the value of attribute amount_symbols.
-
#amount_uppercase ⇒ Object
Returns the value of attribute amount_uppercase.
-
#bound_to ⇒ Object
Return objects policy is bound to.
-
#check_have_i_been_pwned ⇒ Object
Returns the value of attribute check_have_i_been_pwned.
-
#check_static_rules ⇒ Object
Returns the value of attribute check_static_rules.
-
#check_zxcvbn ⇒ Object
Returns the value of attribute check_zxcvbn.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged.
-
#hibp_allowed_count ⇒ Object
How many times the password hash is allowed to be on haveibeenpwned.
-
#length_min ⇒ Object
Returns the value of attribute length_min.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#password_field ⇒ Object
Field key to check, field keys defined in Prompt stages are available.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#symbol_charset ⇒ Object
Returns the value of attribute symbol_charset.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
-
#zxcvbn_score_threshold ⇒ Object
If the zxcvbn score is equal or less than this value, the policy will fail.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PasswordPolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PasswordPolicy
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/authentik/api/models/password_policy.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PasswordPolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PasswordPolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'execution_logging') self.execution_logging = attributes[:'execution_logging'] end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'bound_to') self.bound_to = attributes[:'bound_to'] else self.bound_to = nil end if attributes.key?(:'password_field') self.password_field = attributes[:'password_field'] end if attributes.key?(:'amount_digits') self.amount_digits = attributes[:'amount_digits'] end if attributes.key?(:'amount_uppercase') self.amount_uppercase = attributes[:'amount_uppercase'] end if attributes.key?(:'amount_lowercase') self.amount_lowercase = attributes[:'amount_lowercase'] end if attributes.key?(:'amount_symbols') self.amount_symbols = attributes[:'amount_symbols'] end if attributes.key?(:'length_min') self.length_min = attributes[:'length_min'] end if attributes.key?(:'symbol_charset') self.symbol_charset = attributes[:'symbol_charset'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'check_static_rules') self.check_static_rules = attributes[:'check_static_rules'] end if attributes.key?(:'check_have_i_been_pwned') self.check_have_i_been_pwned = attributes[:'check_have_i_been_pwned'] end if attributes.key?(:'check_zxcvbn') self.check_zxcvbn = attributes[:'check_zxcvbn'] end if attributes.key?(:'hibp_allowed_count') self.hibp_allowed_count = attributes[:'hibp_allowed_count'] end if attributes.key?(:'zxcvbn_score_threshold') self.zxcvbn_score_threshold = attributes[:'zxcvbn_score_threshold'] end end |
Instance Attribute Details
#amount_digits ⇒ Object
Returns the value of attribute amount_digits.
38 39 40 |
# File 'lib/authentik/api/models/password_policy.rb', line 38 def amount_digits @amount_digits end |
#amount_lowercase ⇒ Object
Returns the value of attribute amount_lowercase.
42 43 44 |
# File 'lib/authentik/api/models/password_policy.rb', line 42 def amount_lowercase @amount_lowercase end |
#amount_symbols ⇒ Object
Returns the value of attribute amount_symbols.
44 45 46 |
# File 'lib/authentik/api/models/password_policy.rb', line 44 def amount_symbols @amount_symbols end |
#amount_uppercase ⇒ Object
Returns the value of attribute amount_uppercase.
40 41 42 |
# File 'lib/authentik/api/models/password_policy.rb', line 40 def amount_uppercase @amount_uppercase end |
#bound_to ⇒ Object
Return objects policy is bound to
33 34 35 |
# File 'lib/authentik/api/models/password_policy.rb', line 33 def bound_to @bound_to end |
#check_have_i_been_pwned ⇒ Object
Returns the value of attribute check_have_i_been_pwned.
54 55 56 |
# File 'lib/authentik/api/models/password_policy.rb', line 54 def check_have_i_been_pwned @check_have_i_been_pwned end |
#check_static_rules ⇒ Object
Returns the value of attribute check_static_rules.
52 53 54 |
# File 'lib/authentik/api/models/password_policy.rb', line 52 def check_static_rules @check_static_rules end |
#check_zxcvbn ⇒ Object
Returns the value of attribute check_zxcvbn.
56 57 58 |
# File 'lib/authentik/api/models/password_policy.rb', line 56 def check_zxcvbn @check_zxcvbn end |
#component ⇒ Object
Get object component so that we know how to edit the object
21 22 23 |
# File 'lib/authentik/api/models/password_policy.rb', line 21 def component @component end |
#error_message ⇒ Object
Returns the value of attribute error_message.
50 51 52 |
# File 'lib/authentik/api/models/password_policy.rb', line 50 def @error_message end |
#execution_logging ⇒ Object
When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.
18 19 20 |
# File 'lib/authentik/api/models/password_policy.rb', line 18 def execution_logging @execution_logging end |
#hibp_allowed_count ⇒ Object
How many times the password hash is allowed to be on haveibeenpwned
59 60 61 |
# File 'lib/authentik/api/models/password_policy.rb', line 59 def hibp_allowed_count @hibp_allowed_count end |
#length_min ⇒ Object
Returns the value of attribute length_min.
46 47 48 |
# File 'lib/authentik/api/models/password_policy.rb', line 46 def length_min @length_min end |
#meta_model_name ⇒ Object
Return internal model name
30 31 32 |
# File 'lib/authentik/api/models/password_policy.rb', line 30 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/password_policy.rb', line 15 def name @name end |
#password_field ⇒ Object
Field key to check, field keys defined in Prompt stages are available.
36 37 38 |
# File 'lib/authentik/api/models/password_policy.rb', line 36 def password_field @password_field end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/password_policy.rb', line 13 def pk @pk end |
#symbol_charset ⇒ Object
Returns the value of attribute symbol_charset.
48 49 50 |
# File 'lib/authentik/api/models/password_policy.rb', line 48 def symbol_charset @symbol_charset end |
#verbose_name ⇒ Object
Return object’s verbose_name
24 25 26 |
# File 'lib/authentik/api/models/password_policy.rb', line 24 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
27 28 29 |
# File 'lib/authentik/api/models/password_policy.rb', line 27 def verbose_name_plural @verbose_name_plural end |
#zxcvbn_score_threshold ⇒ Object
If the zxcvbn score is equal or less than this value, the policy will fail.
62 63 64 |
# File 'lib/authentik/api/models/password_policy.rb', line 62 def zxcvbn_score_threshold @zxcvbn_score_threshold end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
92 93 94 |
# File 'lib/authentik/api/models/password_policy.rb', line 92 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/authentik/api/models/password_policy.rb', line 97 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/authentik/api/models/password_policy.rb', line 65 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'execution_logging' => :'execution_logging', :'component' => :'component', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'bound_to' => :'bound_to', :'password_field' => :'password_field', :'amount_digits' => :'amount_digits', :'amount_uppercase' => :'amount_uppercase', :'amount_lowercase' => :'amount_lowercase', :'amount_symbols' => :'amount_symbols', :'length_min' => :'length_min', :'symbol_charset' => :'symbol_charset', :'error_message' => :'error_message', :'check_static_rules' => :'check_static_rules', :'check_have_i_been_pwned' => :'check_have_i_been_pwned', :'check_zxcvbn' => :'check_zxcvbn', :'hibp_allowed_count' => :'hibp_allowed_count', :'zxcvbn_score_threshold' => :'zxcvbn_score_threshold' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/authentik/api/models/password_policy.rb', line 608 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
129 130 131 132 |
# File 'lib/authentik/api/models/password_policy.rb', line 129 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/authentik/api/models/password_policy.rb', line 102 def self.openapi_types { :'pk' => :'String', :'name' => :'String', :'execution_logging' => :'Boolean', :'component' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'bound_to' => :'Integer', :'password_field' => :'String', :'amount_digits' => :'Integer', :'amount_uppercase' => :'Integer', :'amount_lowercase' => :'Integer', :'amount_symbols' => :'Integer', :'length_min' => :'Integer', :'symbol_charset' => :'String', :'error_message' => :'String', :'check_static_rules' => :'Boolean', :'check_have_i_been_pwned' => :'Boolean', :'check_zxcvbn' => :'Boolean', :'hibp_allowed_count' => :'Integer', :'zxcvbn_score_threshold' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/authentik/api/models/password_policy.rb', line 567 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && execution_logging == o.execution_logging && component == o.component && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && bound_to == o.bound_to && password_field == o.password_field && amount_digits == o.amount_digits && amount_uppercase == o.amount_uppercase && amount_lowercase == o.amount_lowercase && amount_symbols == o.amount_symbols && length_min == o.length_min && symbol_charset == o.symbol_charset && == o. && check_static_rules == o.check_static_rules && check_have_i_been_pwned == o.check_have_i_been_pwned && check_zxcvbn == o.check_zxcvbn && hibp_allowed_count == o.hibp_allowed_count && zxcvbn_score_threshold == o.zxcvbn_score_threshold end |
#eql?(o) ⇒ Boolean
595 596 597 |
# File 'lib/authentik/api/models/password_policy.rb', line 595 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
601 602 603 |
# File 'lib/authentik/api/models/password_policy.rb', line 601 def hash [pk, name, execution_logging, component, verbose_name, verbose_name_plural, , bound_to, password_field, amount_digits, amount_uppercase, amount_lowercase, amount_symbols, length_min, symbol_charset, , check_static_rules, check_have_i_been_pwned, check_zxcvbn, hibp_allowed_count, zxcvbn_score_threshold].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/authentik/api/models/password_policy.rb', line 251 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @bound_to.nil? invalid_properties.push('invalid value for "bound_to", bound_to cannot be nil.') end if !@amount_digits.nil? && @amount_digits > 2147483647 invalid_properties.push('invalid value for "amount_digits", must be smaller than or equal to 2147483647.') end if !@amount_digits.nil? && @amount_digits < 0 invalid_properties.push('invalid value for "amount_digits", must be greater than or equal to 0.') end if !@amount_uppercase.nil? && @amount_uppercase > 2147483647 invalid_properties.push('invalid value for "amount_uppercase", must be smaller than or equal to 2147483647.') end if !@amount_uppercase.nil? && @amount_uppercase < 0 invalid_properties.push('invalid value for "amount_uppercase", must be greater than or equal to 0.') end if !@amount_lowercase.nil? && @amount_lowercase > 2147483647 invalid_properties.push('invalid value for "amount_lowercase", must be smaller than or equal to 2147483647.') end if !@amount_lowercase.nil? && @amount_lowercase < 0 invalid_properties.push('invalid value for "amount_lowercase", must be greater than or equal to 0.') end if !@amount_symbols.nil? && @amount_symbols > 2147483647 invalid_properties.push('invalid value for "amount_symbols", must be smaller than or equal to 2147483647.') end if !@amount_symbols.nil? && @amount_symbols < 0 invalid_properties.push('invalid value for "amount_symbols", must be greater than or equal to 0.') end if !@length_min.nil? && @length_min > 2147483647 invalid_properties.push('invalid value for "length_min", must be smaller than or equal to 2147483647.') end if !@length_min.nil? && @length_min < 0 invalid_properties.push('invalid value for "length_min", must be greater than or equal to 0.') end if !@hibp_allowed_count.nil? && @hibp_allowed_count > 2147483647 invalid_properties.push('invalid value for "hibp_allowed_count", must be smaller than or equal to 2147483647.') end if !@hibp_allowed_count.nil? && @hibp_allowed_count < 0 invalid_properties.push('invalid value for "hibp_allowed_count", must be greater than or equal to 0.') end if !@zxcvbn_score_threshold.nil? && @zxcvbn_score_threshold > 2147483647 invalid_properties.push('invalid value for "zxcvbn_score_threshold", must be smaller than or equal to 2147483647.') end if !@zxcvbn_score_threshold.nil? && @zxcvbn_score_threshold < 0 invalid_properties.push('invalid value for "zxcvbn_score_threshold", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/authentik/api/models/password_policy.rb', line 630 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/authentik/api/models/password_policy.rb', line 343 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @bound_to.nil? return false if !@amount_digits.nil? && @amount_digits > 2147483647 return false if !@amount_digits.nil? && @amount_digits < 0 return false if !@amount_uppercase.nil? && @amount_uppercase > 2147483647 return false if !@amount_uppercase.nil? && @amount_uppercase < 0 return false if !@amount_lowercase.nil? && @amount_lowercase > 2147483647 return false if !@amount_lowercase.nil? && @amount_lowercase < 0 return false if !@amount_symbols.nil? && @amount_symbols > 2147483647 return false if !@amount_symbols.nil? && @amount_symbols < 0 return false if !@length_min.nil? && @length_min > 2147483647 return false if !@length_min.nil? && @length_min < 0 return false if !@hibp_allowed_count.nil? && @hibp_allowed_count > 2147483647 return false if !@hibp_allowed_count.nil? && @hibp_allowed_count < 0 return false if !@zxcvbn_score_threshold.nil? && @zxcvbn_score_threshold > 2147483647 return false if !@zxcvbn_score_threshold.nil? && @zxcvbn_score_threshold < 0 true end |