Class: Authentik::Api::PatchedAuthenticatorDuoStageRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedAuthenticatorDuoStageRequest
- Defined in:
- lib/authentik/api/models/patched_authenticator_duo_stage_request.rb
Overview
AuthenticatorDuoStage Serializer
Instance Attribute Summary collapse
-
#admin_integration_key ⇒ Object
Returns the value of attribute admin_integration_key.
-
#admin_secret_key ⇒ Object
Returns the value of attribute admin_secret_key.
-
#api_hostname ⇒ Object
Returns the value of attribute api_hostname.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#client_secret ⇒ Object
Returns the value of attribute client_secret.
-
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage.
-
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedAuthenticatorDuoStageRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedAuthenticatorDuoStageRequest
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 77 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedAuthenticatorDuoStageRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedAuthenticatorDuoStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'configure_flow') self.configure_flow = attributes[:'configure_flow'] end if attributes.key?(:'friendly_name') self.friendly_name = attributes[:'friendly_name'] end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] end if attributes.key?(:'api_hostname') self.api_hostname = attributes[:'api_hostname'] end if attributes.key?(:'admin_integration_key') self.admin_integration_key = attributes[:'admin_integration_key'] end if attributes.key?(:'admin_secret_key') self.admin_secret_key = attributes[:'admin_secret_key'] end end |
Instance Attribute Details
#admin_integration_key ⇒ Object
Returns the value of attribute admin_integration_key.
26 27 28 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 26 def admin_integration_key @admin_integration_key end |
#admin_secret_key ⇒ Object
Returns the value of attribute admin_secret_key.
28 29 30 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 28 def admin_secret_key @admin_secret_key end |
#api_hostname ⇒ Object
Returns the value of attribute api_hostname.
24 25 26 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 24 def api_hostname @api_hostname end |
#client_id ⇒ Object
Returns the value of attribute client_id.
20 21 22 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 20 def client_id @client_id end |
#client_secret ⇒ Object
Returns the value of attribute client_secret.
22 23 24 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 22 def client_secret @client_secret end |
#configure_flow ⇒ Object
Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.
16 17 18 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 16 def configure_flow @configure_flow end |
#friendly_name ⇒ Object
Returns the value of attribute friendly_name.
18 19 20 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 18 def friendly_name @friendly_name end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 13 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 31 def self.attribute_map { :'name' => :'name', :'configure_flow' => :'configure_flow', :'friendly_name' => :'friendly_name', :'client_id' => :'client_id', :'client_secret' => :'client_secret', :'api_hostname' => :'api_hostname', :'admin_integration_key' => :'admin_integration_key', :'admin_secret_key' => :'admin_secret_key' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 245 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 73 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 69 def self.openapi_nullable Set.new([ :'configure_flow', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 55 def self.openapi_types { :'name' => :'String', :'configure_flow' => :'String', :'friendly_name' => :'String', :'client_id' => :'String', :'client_secret' => :'String', :'api_hostname' => :'String', :'admin_integration_key' => :'String', :'admin_secret_key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 217 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && configure_flow == o.configure_flow && friendly_name == o.friendly_name && client_id == o.client_id && client_secret == o.client_secret && api_hostname == o.api_hostname && admin_integration_key == o.admin_integration_key && admin_secret_key == o.admin_secret_key end |
#eql?(o) ⇒ Boolean
232 233 234 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 232 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 238 def hash [name, configure_flow, friendly_name, client_id, client_secret, api_hostname, admin_integration_key, admin_secret_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@client_id.nil? && @client_id.to_s.length < 1 invalid_properties.push('invalid value for "client_id", the character length must be greater than or equal to 1.') end if !@client_secret.nil? && @client_secret.to_s.length < 1 invalid_properties.push('invalid value for "client_secret", the character length must be greater than or equal to 1.') end if !@api_hostname.nil? && @api_hostname.to_s.length < 1 invalid_properties.push('invalid value for "api_hostname", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/patched_authenticator_duo_stage_request.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@client_id.nil? && @client_id.to_s.length < 1 return false if !@client_secret.nil? && @client_secret.to_s.length < 1 return false if !@api_hostname.nil? && @api_hostname.to_s.length < 1 true end |