Class: Authentik::Api::PatchedAuthenticatorWebAuthnStageRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb

Overview

AuthenticatorWebAuthnStage Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedAuthenticatorWebAuthnStageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedAuthenticatorWebAuthnStageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedAuthenticatorWebAuthnStageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'configure_flow')
    self.configure_flow = attributes[:'configure_flow']
  end

  if attributes.key?(:'friendly_name')
    self.friendly_name = attributes[:'friendly_name']
  end

  if attributes.key?(:'user_verification')
    self.user_verification = attributes[:'user_verification']
  end

  if attributes.key?(:'authenticator_attachment')
    self.authenticator_attachment = attributes[:'authenticator_attachment']
  end

  if attributes.key?(:'resident_key_requirement')
    self.resident_key_requirement = attributes[:'resident_key_requirement']
  end

  if attributes.key?(:'device_type_restrictions')
    if (value = attributes[:'device_type_restrictions']).is_a?(Array)
      self.device_type_restrictions = value
    end
  end

  if attributes.key?(:'max_attempts')
    self.max_attempts = attributes[:'max_attempts']
  end
end

Instance Attribute Details

#authenticator_attachmentObject

Returns the value of attribute authenticator_attachment.



22
23
24
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 22

def authenticator_attachment
  @authenticator_attachment
end

#configure_flowObject

Flow used by an authenticated user to configure this Stage. If empty, user will not be able to configure this stage.



16
17
18
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 16

def configure_flow
  @configure_flow
end

#device_type_restrictionsObject

Returns the value of attribute device_type_restrictions.



26
27
28
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 26

def device_type_restrictions
  @device_type_restrictions
end

#friendly_nameObject

Returns the value of attribute friendly_name.



18
19
20
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 18

def friendly_name
  @friendly_name
end

#max_attemptsObject

Returns the value of attribute max_attempts.



28
29
30
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 28

def max_attempts
  @max_attempts
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 13

def name
  @name
end

#resident_key_requirementObject

Returns the value of attribute resident_key_requirement.



24
25
26
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 24

def resident_key_requirement
  @resident_key_requirement
end

#user_verificationObject

Returns the value of attribute user_verification.



20
21
22
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 20

def user_verification
  @user_verification
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 53

def self.attribute_map
  {
    :'name' => :'name',
    :'configure_flow' => :'configure_flow',
    :'friendly_name' => :'friendly_name',
    :'user_verification' => :'user_verification',
    :'authenticator_attachment' => :'authenticator_attachment',
    :'resident_key_requirement' => :'resident_key_requirement',
    :'device_type_restrictions' => :'device_type_restrictions',
    :'max_attempts' => :'max_attempts'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 241

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
96
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 91

def self.openapi_nullable
  Set.new([
    :'configure_flow',
    :'authenticator_attachment',
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 77

def self.openapi_types
  {
    :'name' => :'String',
    :'configure_flow' => :'String',
    :'friendly_name' => :'String',
    :'user_verification' => :'UserVerificationEnum',
    :'authenticator_attachment' => :'AuthenticatorAttachmentEnum',
    :'resident_key_requirement' => :'ResidentKeyRequirementEnum',
    :'device_type_restrictions' => :'Array<String>',
    :'max_attempts' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      configure_flow == o.configure_flow &&
      friendly_name == o.friendly_name &&
      user_verification == o.user_verification &&
      authenticator_attachment == o.authenticator_attachment &&
      resident_key_requirement == o.resident_key_requirement &&
      device_type_restrictions == o.device_type_restrictions &&
      max_attempts == o.max_attempts
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


228
229
230
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 228

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



234
235
236
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 234

def hash
  [name, configure_flow, friendly_name, user_verification, authenticator_attachment, resident_key_requirement, device_type_restrictions, max_attempts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@max_attempts.nil? && @max_attempts > 2147483647
    invalid_properties.push('invalid value for "max_attempts", must be smaller than or equal to 2147483647.')
  end

  if !@max_attempts.nil? && @max_attempts < 0
    invalid_properties.push('invalid value for "max_attempts", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 263

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
176
177
# File 'lib/authentik/api/models/patched_authenticator_web_authn_stage_request.rb', line 171

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@max_attempts.nil? && @max_attempts > 2147483647
  return false if !@max_attempts.nil? && @max_attempts < 0
  true
end