Class: Authentik::Api::PatchedDeviceUserBindingRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedDeviceUserBindingRequest
- Defined in:
- lib/authentik/api/models/patched_device_user_binding_request.rb
Overview
PolicyBinding Serializer
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#failure_result ⇒ Object
Result if the Policy execution fails.
-
#group ⇒ Object
Returns the value of attribute group.
-
#is_primary ⇒ Object
Returns the value of attribute is_primary.
-
#negate ⇒ Object
Negates the outcome of the policy.
-
#order ⇒ Object
Returns the value of attribute order.
-
#policy ⇒ Object
Returns the value of attribute policy.
-
#target ⇒ Object
Returns the value of attribute target.
-
#timeout ⇒ Object
Timeout after which Policy execution is terminated.
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedDeviceUserBindingRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedDeviceUserBindingRequest
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedDeviceUserBindingRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedDeviceUserBindingRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'policy') self.policy = attributes[:'policy'] end if attributes.key?(:'group') self.group = attributes[:'group'] end if attributes.key?(:'user') self.user = attributes[:'user'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'negate') self.negate = attributes[:'negate'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'order') self.order = attributes[:'order'] end if attributes.key?(:'timeout') self.timeout = attributes[:'timeout'] end if attributes.key?(:'failure_result') self.failure_result = attributes[:'failure_result'] end if attributes.key?(:'is_primary') self.is_primary = attributes[:'is_primary'] end end |
Instance Attribute Details
#enabled ⇒ Object
Returns the value of attribute enabled.
24 25 26 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 24 def enabled @enabled end |
#failure_result ⇒ Object
Result if the Policy execution fails.
32 33 34 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 32 def failure_result @failure_result end |
#group ⇒ Object
Returns the value of attribute group.
15 16 17 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 15 def group @group end |
#is_primary ⇒ Object
Returns the value of attribute is_primary.
34 35 36 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 34 def is_primary @is_primary end |
#negate ⇒ Object
Negates the outcome of the policy. Messages are unaffected.
22 23 24 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 22 def negate @negate end |
#order ⇒ Object
Returns the value of attribute order.
26 27 28 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 26 def order @order end |
#policy ⇒ Object
Returns the value of attribute policy.
13 14 15 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 13 def policy @policy end |
#target ⇒ Object
Returns the value of attribute target.
19 20 21 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 19 def target @target end |
#timeout ⇒ Object
Timeout after which Policy execution is terminated.
29 30 31 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 29 def timeout @timeout end |
#user ⇒ Object
Returns the value of attribute user.
17 18 19 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 17 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 37 def self.attribute_map { :'policy' => :'policy', :'group' => :'group', :'user' => :'user', :'target' => :'target', :'negate' => :'negate', :'enabled' => :'enabled', :'order' => :'order', :'timeout' => :'timeout', :'failure_result' => :'failure_result', :'is_primary' => :'is_primary' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 247 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 83 84 85 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 79 def self.openapi_nullable Set.new([ :'policy', :'group', :'user', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 63 def self.openapi_types { :'policy' => :'String', :'group' => :'String', :'user' => :'Integer', :'target' => :'String', :'negate' => :'Boolean', :'enabled' => :'Boolean', :'order' => :'Integer', :'timeout' => :'Integer', :'failure_result' => :'Boolean', :'is_primary' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 217 def ==(o) return true if self.equal?(o) self.class == o.class && policy == o.policy && group == o.group && user == o.user && target == o.target && negate == o.negate && enabled == o.enabled && order == o.order && timeout == o.timeout && failure_result == o.failure_result && is_primary == o.is_primary end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 240 def hash [policy, group, user, target, negate, enabled, order, timeout, failure_result, is_primary].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@order.nil? && @order > 2147483647 invalid_properties.push('invalid value for "order", must be smaller than or equal to 2147483647.') end if !@order.nil? && @order < -2147483648 invalid_properties.push('invalid value for "order", must be greater than or equal to -2147483648.') end if !@timeout.nil? && @timeout > 2147483647 invalid_properties.push('invalid value for "timeout", must be smaller than or equal to 2147483647.') end if !@timeout.nil? && @timeout < 0 invalid_properties.push('invalid value for "timeout", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 |
# File 'lib/authentik/api/models/patched_device_user_binding_request.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@order.nil? && @order > 2147483647 return false if !@order.nil? && @order < -2147483648 return false if !@timeout.nil? && @timeout > 2147483647 return false if !@timeout.nil? && @timeout < 0 true end |