Class: Authentik::Api::PatchedEventRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedEventRequest
- Defined in:
- lib/authentik/api/models/patched_event_request.rb
Overview
Event Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Returns the value of attribute action.
-
#app ⇒ Object
Returns the value of attribute app.
-
#brand ⇒ Object
Returns the value of attribute brand.
-
#client_ip ⇒ Object
Returns the value of attribute client_ip.
-
#context ⇒ Object
Returns the value of attribute context.
-
#expires ⇒ Object
Returns the value of attribute expires.
-
#user ⇒ Object
Returns the value of attribute user.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedEventRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedEventRequest
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedEventRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedEventRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user') if (value = attributes[:'user']).is_a?(Hash) self.user = value end end if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'app') self.app = attributes[:'app'] end if attributes.key?(:'context') if (value = attributes[:'context']).is_a?(Hash) self.context = value end end if attributes.key?(:'client_ip') self.client_ip = attributes[:'client_ip'] end if attributes.key?(:'expires') self.expires = attributes[:'expires'] end if attributes.key?(:'brand') if (value = attributes[:'brand']).is_a?(Hash) self.brand = value end end end |
Instance Attribute Details
#action ⇒ Object
Returns the value of attribute action.
15 16 17 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 15 def action @action end |
#app ⇒ Object
Returns the value of attribute app.
17 18 19 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 17 def app @app end |
#brand ⇒ Object
Returns the value of attribute brand.
25 26 27 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 25 def brand @brand end |
#client_ip ⇒ Object
Returns the value of attribute client_ip.
21 22 23 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 21 def client_ip @client_ip end |
#context ⇒ Object
Returns the value of attribute context.
19 20 21 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 19 def context @context end |
#expires ⇒ Object
Returns the value of attribute expires.
23 24 25 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 23 def expires @expires end |
#user ⇒ Object
Returns the value of attribute user.
13 14 15 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 13 def user @user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 50 def self.attribute_map { :'user' => :'user', :'action' => :'action', :'app' => :'app', :'context' => :'context', :'client_ip' => :'client_ip', :'expires' => :'expires', :'brand' => :'brand' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 221 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 90 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 86 def self.openapi_nullable Set.new([ :'client_ip', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 73 def self.openapi_types { :'user' => :'Hash<String, Object>', :'action' => :'EventActions', :'app' => :'String', :'context' => :'Hash<String, Object>', :'client_ip' => :'String', :'expires' => :'Time', :'brand' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && user == o.user && action == o.action && app == o.app && context == o.context && client_ip == o.client_ip && expires == o.expires && brand == o.brand end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 214 def hash [user, action, app, context, client_ip, expires, brand].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@app.nil? && @app.to_s.length < 1 invalid_properties.push('invalid value for "app", the character length must be greater than or equal to 1.') end if !@client_ip.nil? && @client_ip.to_s.length < 1 invalid_properties.push('invalid value for "client_ip", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 243 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 |
# File 'lib/authentik/api/models/patched_event_request.rb', line 161 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@app.nil? && @app.to_s.length < 1 return false if !@client_ip.nil? && @client_ip.to_s.length < 1 true end |