Class: Authentik::Api::PatchedFlowRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedFlowRequest
- Defined in:
- lib/authentik/api/models/patched_flow_request.rb
Overview
Flow Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#authentication ⇒ Object
Required level of authentication and authorization to access a flow.
-
#background ⇒ Object
Background shown during execution.
-
#compatibility_mode ⇒ Object
Enable compatibility mode, increases compatibility with password managers on mobile devices.
-
#denied_action ⇒ Object
Configure what should happen when a flow denies access to a user.
-
#designation ⇒ Object
Decides what this Flow is used for.
-
#layout ⇒ Object
Returns the value of attribute layout.
-
#name ⇒ Object
Returns the value of attribute name.
-
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
-
#slug ⇒ Object
Visible in the URL.
-
#title ⇒ Object
Shown as the Title in Flow pages.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedFlowRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedFlowRequest
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedFlowRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedFlowRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'designation') self.designation = attributes[:'designation'] end if attributes.key?(:'background') self.background = attributes[:'background'] end if attributes.key?(:'policy_engine_mode') self.policy_engine_mode = attributes[:'policy_engine_mode'] end if attributes.key?(:'compatibility_mode') self.compatibility_mode = attributes[:'compatibility_mode'] end if attributes.key?(:'layout') self.layout = attributes[:'layout'] end if attributes.key?(:'denied_action') self.denied_action = attributes[:'denied_action'] end if attributes.key?(:'authentication') self.authentication = attributes[:'authentication'] end end |
Instance Attribute Details
#authentication ⇒ Object
Required level of authentication and authorization to access a flow.
38 39 40 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 38 def authentication @authentication end |
#background ⇒ Object
Background shown during execution
25 26 27 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 25 def background @background end |
#compatibility_mode ⇒ Object
Enable compatibility mode, increases compatibility with password managers on mobile devices.
30 31 32 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 30 def compatibility_mode @compatibility_mode end |
#denied_action ⇒ Object
Configure what should happen when a flow denies access to a user.
35 36 37 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 35 def denied_action @denied_action end |
#designation ⇒ Object
Decides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik.
22 23 24 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 22 def designation @designation end |
#layout ⇒ Object
Returns the value of attribute layout.
32 33 34 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 32 def layout @layout end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 13 def name @name end |
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
27 28 29 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 27 def policy_engine_mode @policy_engine_mode end |
#slug ⇒ Object
Visible in the URL.
16 17 18 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 16 def slug @slug end |
#title ⇒ Object
Shown as the Title in Flow pages.
19 20 21 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 19 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 63 def self.attribute_map { :'name' => :'name', :'slug' => :'slug', :'title' => :'title', :'designation' => :'designation', :'background' => :'background', :'policy_engine_mode' => :'policy_engine_mode', :'compatibility_mode' => :'compatibility_mode', :'layout' => :'layout', :'denied_action' => :'denied_action', :'authentication' => :'authentication' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 282 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 89 def self.openapi_types { :'name' => :'String', :'slug' => :'String', :'title' => :'String', :'designation' => :'FlowDesignationEnum', :'background' => :'String', :'policy_engine_mode' => :'PolicyEngineMode', :'compatibility_mode' => :'Boolean', :'layout' => :'FlowLayoutEnum', :'denied_action' => :'DeniedActionEnum', :'authentication' => :'AuthenticationEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && slug == o.slug && title == o.title && designation == o.designation && background == o.background && policy_engine_mode == o.policy_engine_mode && compatibility_mode == o.compatibility_mode && layout == o.layout && denied_action == o.denied_action && authentication == o.authentication end |
#eql?(o) ⇒ Boolean
269 270 271 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 269 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 275 def hash [name, slug, title, designation, background, policy_engine_mode, compatibility_mode, layout, denied_action, authentication].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@slug.nil? && @slug.to_s.length < 1 invalid_properties.push('invalid value for "slug", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/) if !@slug.nil? && @slug !~ pattern invalid_properties.push("invalid value for \"slug\", must conform to the pattern #{pattern}.") end if !@title.nil? && @title.to_s.length < 1 invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
194 195 196 197 198 199 200 201 |
# File 'lib/authentik/api/models/patched_flow_request.rb', line 194 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@slug.nil? && @slug.to_s.length < 1 return false if !@slug.nil? && @slug !~ Regexp.new(/^[-a-zA-Z0-9_]+$/) return false if !@title.nil? && @title.to_s.length < 1 true end |