Class: Authentik::Api::PatchedSAMLProviderRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedSAMLProviderRequest
- Defined in:
- lib/authentik/api/models/patched_saml_provider_request.rb
Overview
SAMLProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#acs_url ⇒ Object
Returns the value of attribute acs_url.
-
#assertion_valid_not_before ⇒ Object
Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).
-
#assertion_valid_not_on_or_after ⇒ Object
Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#audience ⇒ Object
Value of the audience restriction field of the assertion.
-
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
-
#authn_context_class_ref_mapping ⇒ Object
Configure how the AuthnContextClassRef value will be created.
-
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
-
#default_name_id_policy ⇒ Object
Returns the value of attribute default_name_id_policy.
-
#default_relay_state ⇒ Object
Default relay_state value for IDP-initiated logins.
-
#digest_algorithm ⇒ Object
Returns the value of attribute digest_algorithm.
-
#encryption_kp ⇒ Object
When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair.
-
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
-
#issuer ⇒ Object
Also known as EntityID.
-
#logout_method ⇒ Object
Method to use for logout.
-
#name ⇒ Object
Returns the value of attribute name.
-
#name_id_mapping ⇒ Object
Configure how the NameID value will be created.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#session_valid_not_on_or_after ⇒ Object
Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#sign_assertion ⇒ Object
Returns the value of attribute sign_assertion.
-
#sign_logout_request ⇒ Object
Returns the value of attribute sign_logout_request.
-
#sign_response ⇒ Object
Returns the value of attribute sign_response.
-
#signature_algorithm ⇒ Object
Returns the value of attribute signature_algorithm.
-
#signing_kp ⇒ Object
Keypair used to sign outgoing Responses going to the Service Provider.
-
#sls_binding ⇒ Object
This determines how authentik sends the logout response back to the Service Provider.
-
#sls_url ⇒ Object
Single Logout Service URL where the logout response should be sent.
-
#sp_binding ⇒ Object
This determines how authentik sends the response back to the Service Provider.
-
#verification_kp ⇒ Object
When selected, incoming assertion’s Signatures will be validated against this certificate.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedSAMLProviderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedSAMLProviderRequest
Initializes the object
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 197 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedSAMLProviderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedSAMLProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'authorization_flow') self. = attributes[:'authorization_flow'] end if attributes.key?(:'invalidation_flow') self.invalidation_flow = attributes[:'invalidation_flow'] end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'acs_url') self.acs_url = attributes[:'acs_url'] end if attributes.key?(:'sls_url') self.sls_url = attributes[:'sls_url'] end if attributes.key?(:'audience') self.audience = attributes[:'audience'] end if attributes.key?(:'issuer') self.issuer = attributes[:'issuer'] end if attributes.key?(:'assertion_valid_not_before') self.assertion_valid_not_before = attributes[:'assertion_valid_not_before'] end if attributes.key?(:'assertion_valid_not_on_or_after') self.assertion_valid_not_on_or_after = attributes[:'assertion_valid_not_on_or_after'] end if attributes.key?(:'session_valid_not_on_or_after') self.session_valid_not_on_or_after = attributes[:'session_valid_not_on_or_after'] end if attributes.key?(:'name_id_mapping') self.name_id_mapping = attributes[:'name_id_mapping'] end if attributes.key?(:'authn_context_class_ref_mapping') self.authn_context_class_ref_mapping = attributes[:'authn_context_class_ref_mapping'] end if attributes.key?(:'digest_algorithm') self.digest_algorithm = attributes[:'digest_algorithm'] end if attributes.key?(:'signature_algorithm') self.signature_algorithm = attributes[:'signature_algorithm'] end if attributes.key?(:'signing_kp') self.signing_kp = attributes[:'signing_kp'] end if attributes.key?(:'verification_kp') self.verification_kp = attributes[:'verification_kp'] end if attributes.key?(:'encryption_kp') self.encryption_kp = attributes[:'encryption_kp'] end if attributes.key?(:'sign_assertion') self.sign_assertion = attributes[:'sign_assertion'] end if attributes.key?(:'sign_response') self.sign_response = attributes[:'sign_response'] end if attributes.key?(:'sign_logout_request') self.sign_logout_request = attributes[:'sign_logout_request'] end if attributes.key?(:'sp_binding') self.sp_binding = attributes[:'sp_binding'] end if attributes.key?(:'sls_binding') self.sls_binding = attributes[:'sls_binding'] end if attributes.key?(:'logout_method') self.logout_method = attributes[:'logout_method'] end if attributes.key?(:'default_relay_state') self.default_relay_state = attributes[:'default_relay_state'] end if attributes.key?(:'default_name_id_policy') self.default_name_id_policy = attributes[:'default_name_id_policy'] end end |
Instance Attribute Details
#acs_url ⇒ Object
Returns the value of attribute acs_url.
26 27 28 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 26 def acs_url @acs_url end |
#assertion_valid_not_before ⇒ Object
Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).
38 39 40 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 38 def assertion_valid_not_before @assertion_valid_not_before end |
#assertion_valid_not_on_or_after ⇒ Object
Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
41 42 43 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 41 def assertion_valid_not_on_or_after @assertion_valid_not_on_or_after end |
#audience ⇒ Object
Value of the audience restriction field of the assertion. When left empty, no audience restriction will be added.
32 33 34 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 32 def audience @audience end |
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
16 17 18 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 16 def authentication_flow @authentication_flow end |
#authn_context_class_ref_mapping ⇒ Object
Configure how the AuthnContextClassRef value will be created. When left empty, the AuthnContextClassRef will be set based on which authentication methods the user used to authenticate.
50 51 52 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 50 def authn_context_class_ref_mapping @authn_context_class_ref_mapping end |
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
19 20 21 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 19 def @authorization_flow end |
#default_name_id_policy ⇒ Object
Returns the value of attribute default_name_id_policy.
83 84 85 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 83 def default_name_id_policy @default_name_id_policy end |
#default_relay_state ⇒ Object
Default relay_state value for IDP-initiated logins
81 82 83 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 81 def default_relay_state @default_relay_state end |
#digest_algorithm ⇒ Object
Returns the value of attribute digest_algorithm.
52 53 54 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 52 def digest_algorithm @digest_algorithm end |
#encryption_kp ⇒ Object
When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.
63 64 65 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 63 def encryption_kp @encryption_kp end |
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
22 23 24 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 22 def invalidation_flow @invalidation_flow end |
#issuer ⇒ Object
Also known as EntityID
35 36 37 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 35 def issuer @issuer end |
#logout_method ⇒ Object
Method to use for logout. Front-channel iframe loads all logout URLs simultaneously in hidden iframes. Front-channel native uses your active browser tab to send post requests and redirect to providers. Back-channel sends logout requests directly from the server without user interaction (requires POST SLS binding).
78 79 80 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 78 def logout_method @logout_method end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 13 def name @name end |
#name_id_mapping ⇒ Object
Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be considered
47 48 49 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 47 def name_id_mapping @name_id_mapping end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
24 25 26 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 24 def property_mappings @property_mappings end |
#session_valid_not_on_or_after ⇒ Object
Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
44 45 46 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 44 def session_valid_not_on_or_after @session_valid_not_on_or_after end |
#sign_assertion ⇒ Object
Returns the value of attribute sign_assertion.
65 66 67 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 65 def sign_assertion @sign_assertion end |
#sign_logout_request ⇒ Object
Returns the value of attribute sign_logout_request.
69 70 71 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 69 def sign_logout_request @sign_logout_request end |
#sign_response ⇒ Object
Returns the value of attribute sign_response.
67 68 69 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 67 def sign_response @sign_response end |
#signature_algorithm ⇒ Object
Returns the value of attribute signature_algorithm.
54 55 56 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 54 def signature_algorithm @signature_algorithm end |
#signing_kp ⇒ Object
Keypair used to sign outgoing Responses going to the Service Provider.
57 58 59 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 57 def signing_kp @signing_kp end |
#sls_binding ⇒ Object
This determines how authentik sends the logout response back to the Service Provider.
75 76 77 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 75 def sls_binding @sls_binding end |
#sls_url ⇒ Object
Single Logout Service URL where the logout response should be sent.
29 30 31 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 29 def sls_url @sls_url end |
#sp_binding ⇒ Object
This determines how authentik sends the response back to the Service Provider.
72 73 74 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 72 def sp_binding @sp_binding end |
#verification_kp ⇒ Object
When selected, incoming assertion’s Signatures will be validated against this certificate. To allow unsigned Requests, leave on default.
60 61 62 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 60 def verification_kp @verification_kp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
141 142 143 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 141 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
146 147 148 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 146 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 108 def self.attribute_map { :'name' => :'name', :'authentication_flow' => :'authentication_flow', :'authorization_flow' => :'authorization_flow', :'invalidation_flow' => :'invalidation_flow', :'property_mappings' => :'property_mappings', :'acs_url' => :'acs_url', :'sls_url' => :'sls_url', :'audience' => :'audience', :'issuer' => :'issuer', :'assertion_valid_not_before' => :'assertion_valid_not_before', :'assertion_valid_not_on_or_after' => :'assertion_valid_not_on_or_after', :'session_valid_not_on_or_after' => :'session_valid_not_on_or_after', :'name_id_mapping' => :'name_id_mapping', :'authn_context_class_ref_mapping' => :'authn_context_class_ref_mapping', :'digest_algorithm' => :'digest_algorithm', :'signature_algorithm' => :'signature_algorithm', :'signing_kp' => :'signing_kp', :'verification_kp' => :'verification_kp', :'encryption_kp' => :'encryption_kp', :'sign_assertion' => :'sign_assertion', :'sign_response' => :'sign_response', :'sign_logout_request' => :'sign_logout_request', :'sp_binding' => :'sp_binding', :'sls_binding' => :'sls_binding', :'logout_method' => :'logout_method', :'default_relay_state' => :'default_relay_state', :'default_name_id_policy' => :'default_name_id_policy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 500 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
184 185 186 187 188 189 190 191 192 193 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 184 def self.openapi_nullable Set.new([ :'authentication_flow', :'name_id_mapping', :'authn_context_class_ref_mapping', :'signing_kp', :'verification_kp', :'encryption_kp', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 151 def self.openapi_types { :'name' => :'String', :'authentication_flow' => :'String', :'authorization_flow' => :'String', :'invalidation_flow' => :'String', :'property_mappings' => :'Array<String>', :'acs_url' => :'String', :'sls_url' => :'String', :'audience' => :'String', :'issuer' => :'String', :'assertion_valid_not_before' => :'String', :'assertion_valid_not_on_or_after' => :'String', :'session_valid_not_on_or_after' => :'String', :'name_id_mapping' => :'String', :'authn_context_class_ref_mapping' => :'String', :'digest_algorithm' => :'DigestAlgorithmEnum', :'signature_algorithm' => :'SignatureAlgorithmEnum', :'signing_kp' => :'String', :'verification_kp' => :'String', :'encryption_kp' => :'String', :'sign_assertion' => :'Boolean', :'sign_response' => :'Boolean', :'sign_logout_request' => :'Boolean', :'sp_binding' => :'SAMLBindingsEnum', :'sls_binding' => :'SAMLBindingsEnum', :'logout_method' => :'SAMLLogoutMethods', :'default_relay_state' => :'String', :'default_name_id_policy' => :'SAMLNameIDPolicyEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 453 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && authentication_flow == o.authentication_flow && == o. && invalidation_flow == o.invalidation_flow && property_mappings == o.property_mappings && acs_url == o.acs_url && sls_url == o.sls_url && audience == o.audience && issuer == o.issuer && assertion_valid_not_before == o.assertion_valid_not_before && assertion_valid_not_on_or_after == o.assertion_valid_not_on_or_after && session_valid_not_on_or_after == o.session_valid_not_on_or_after && name_id_mapping == o.name_id_mapping && authn_context_class_ref_mapping == o.authn_context_class_ref_mapping && digest_algorithm == o.digest_algorithm && signature_algorithm == o.signature_algorithm && signing_kp == o.signing_kp && verification_kp == o.verification_kp && encryption_kp == o.encryption_kp && sign_assertion == o.sign_assertion && sign_response == o.sign_response && sign_logout_request == o.sign_logout_request && sp_binding == o.sp_binding && sls_binding == o.sls_binding && logout_method == o.logout_method && default_relay_state == o.default_relay_state && default_name_id_policy == o.default_name_id_policy end |
#eql?(o) ⇒ Boolean
487 488 489 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 487 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
493 494 495 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 493 def hash [name, authentication_flow, , invalidation_flow, property_mappings, acs_url, sls_url, audience, issuer, assertion_valid_not_before, assertion_valid_not_on_or_after, session_valid_not_on_or_after, name_id_mapping, authn_context_class_ref_mapping, digest_algorithm, signature_algorithm, signing_kp, verification_kp, encryption_kp, sign_assertion, sign_response, sign_logout_request, sp_binding, sls_binding, logout_method, default_relay_state, default_name_id_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 324 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@acs_url.nil? && @acs_url.to_s.length < 1 invalid_properties.push('invalid value for "acs_url", the character length must be greater than or equal to 1.') end if !@issuer.nil? && @issuer.to_s.length < 1 invalid_properties.push('invalid value for "issuer", the character length must be greater than or equal to 1.') end if !@assertion_valid_not_before.nil? && @assertion_valid_not_before.to_s.length < 1 invalid_properties.push('invalid value for "assertion_valid_not_before", the character length must be greater than or equal to 1.') end if !@assertion_valid_not_on_or_after.nil? && @assertion_valid_not_on_or_after.to_s.length < 1 invalid_properties.push('invalid value for "assertion_valid_not_on_or_after", the character length must be greater than or equal to 1.') end if !@session_valid_not_on_or_after.nil? && @session_valid_not_on_or_after.to_s.length < 1 invalid_properties.push('invalid value for "session_valid_not_on_or_after", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 522 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
356 357 358 359 360 361 362 363 364 365 |
# File 'lib/authentik/api/models/patched_saml_provider_request.rb', line 356 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@acs_url.nil? && @acs_url.to_s.length < 1 return false if !@issuer.nil? && @issuer.to_s.length < 1 return false if !@assertion_valid_not_before.nil? && @assertion_valid_not_before.to_s.length < 1 return false if !@assertion_valid_not_on_or_after.nil? && @assertion_valid_not_on_or_after.to_s.length < 1 return false if !@session_valid_not_on_or_after.nil? && @session_valid_not_on_or_after.to_s.length < 1 true end |