Class: Authentik::Api::PatchedUserRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::PatchedUserRequest
- Defined in:
- lib/authentik/api/models/patched_user_request.rb
Overview
User Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#email ⇒ Object
Returns the value of attribute email.
-
#groups ⇒ Object
Returns the value of attribute groups.
-
#is_active ⇒ Object
Designates whether this user should be treated as active.
-
#last_login ⇒ Object
Returns the value of attribute last_login.
-
#name ⇒ Object
User’s display name.
-
#path ⇒ Object
Returns the value of attribute path.
-
#roles ⇒ Object
Returns the value of attribute roles.
-
#type ⇒ Object
Returns the value of attribute type.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchedUserRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchedUserRequest
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedUserRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedUserRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'last_login') self.last_login = attributes[:'last_login'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'roles') if (value = attributes[:'roles']).is_a?(Array) self.roles = value end end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end if attributes.key?(:'path') self.path = attributes[:'path'] end if attributes.key?(:'type') self.type = attributes[:'type'] end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
29 30 31 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 29 def attributes @attributes end |
#email ⇒ Object
Returns the value of attribute email.
27 28 29 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 27 def email @email end |
#groups ⇒ Object
Returns the value of attribute groups.
23 24 25 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 23 def groups @groups end |
#is_active ⇒ Object
Designates whether this user should be treated as active. Unselect this instead of deleting accounts.
19 20 21 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 19 def is_active @is_active end |
#last_login ⇒ Object
Returns the value of attribute last_login.
21 22 23 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 21 def last_login @last_login end |
#name ⇒ Object
User’s display name.
16 17 18 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 16 def name @name end |
#path ⇒ Object
Returns the value of attribute path.
31 32 33 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 31 def path @path end |
#roles ⇒ Object
Returns the value of attribute roles.
25 26 27 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 25 def roles @roles end |
#type ⇒ Object
Returns the value of attribute type.
33 34 35 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 33 def type @type end |
#username ⇒ Object
Returns the value of attribute username.
13 14 15 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 13 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 58 def self.attribute_map { :'username' => :'username', :'name' => :'name', :'is_active' => :'is_active', :'last_login' => :'last_login', :'groups' => :'groups', :'roles' => :'roles', :'email' => :'email', :'attributes' => :'attributes', :'path' => :'path', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 282 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 104 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 100 def self.openapi_nullable Set.new([ :'last_login', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 84 def self.openapi_types { :'username' => :'String', :'name' => :'String', :'is_active' => :'Boolean', :'last_login' => :'Time', :'groups' => :'Array<String>', :'roles' => :'Array<String>', :'email' => :'String', :'attributes' => :'Hash<String, Object>', :'path' => :'String', :'type' => :'UserTypeEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && username == o.username && name == o.name && is_active == o.is_active && last_login == o.last_login && groups == o.groups && roles == o.roles && email == o.email && attributes == o.attributes && path == o.path && type == o.type end |
#eql?(o) ⇒ Boolean
269 270 271 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 269 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 275 def hash [username, name, is_active, last_login, groups, roles, email, attributes, path, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@username.nil? && @username.to_s.length > 150 invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 150.') end if !@username.nil? && @username.to_s.length < 1 invalid_properties.push('invalid value for "username", the character length must be greater than or equal to 1.') end if !@email.nil? && @email.to_s.length > 254 invalid_properties.push('invalid value for "email", the character length must be smaller than or equal to 254.') end if !@path.nil? && @path.to_s.length < 1 invalid_properties.push('invalid value for "path", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 |
# File 'lib/authentik/api/models/patched_user_request.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@username.nil? && @username.to_s.length > 150 return false if !@username.nil? && @username.to_s.length < 1 return false if !@email.nil? && @email.to_s.length > 254 return false if !@path.nil? && @path.to_s.length < 1 true end |