Class: Authentik::Api::PatchedWSFederationProviderRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/patched_ws_federation_provider_request.rb

Overview

WSFederationProvider Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchedWSFederationProviderRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 156

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PatchedWSFederationProviderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PatchedWSFederationProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'authorization_flow')
    self.authorization_flow = attributes[:'authorization_flow']
  end

  if attributes.key?(:'invalidation_flow')
    self.invalidation_flow = attributes[:'invalidation_flow']
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'reply_url')
    self.reply_url = attributes[:'reply_url']
  end

  if attributes.key?(:'wtrealm')
    self.wtrealm = attributes[:'wtrealm']
  end

  if attributes.key?(:'assertion_valid_not_before')
    self.assertion_valid_not_before = attributes[:'assertion_valid_not_before']
  end

  if attributes.key?(:'assertion_valid_not_on_or_after')
    self.assertion_valid_not_on_or_after = attributes[:'assertion_valid_not_on_or_after']
  end

  if attributes.key?(:'session_valid_not_on_or_after')
    self.session_valid_not_on_or_after = attributes[:'session_valid_not_on_or_after']
  end

  if attributes.key?(:'name_id_mapping')
    self.name_id_mapping = attributes[:'name_id_mapping']
  end

  if attributes.key?(:'authn_context_class_ref_mapping')
    self.authn_context_class_ref_mapping = attributes[:'authn_context_class_ref_mapping']
  end

  if attributes.key?(:'digest_algorithm')
    self.digest_algorithm = attributes[:'digest_algorithm']
  end

  if attributes.key?(:'signature_algorithm')
    self.signature_algorithm = attributes[:'signature_algorithm']
  end

  if attributes.key?(:'signing_kp')
    self.signing_kp = attributes[:'signing_kp']
  end

  if attributes.key?(:'encryption_kp')
    self.encryption_kp = attributes[:'encryption_kp']
  end

  if attributes.key?(:'sign_assertion')
    self.sign_assertion = attributes[:'sign_assertion']
  end

  if attributes.key?(:'sign_logout_request')
    self.sign_logout_request = attributes[:'sign_logout_request']
  end

  if attributes.key?(:'default_name_id_policy')
    self.default_name_id_policy = attributes[:'default_name_id_policy']
  end
end

Instance Attribute Details

#assertion_valid_not_beforeObject

Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).



31
32
33
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 31

def assertion_valid_not_before
  @assertion_valid_not_before
end

#assertion_valid_not_on_or_afterObject

Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).



34
35
36
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 34

def assertion_valid_not_on_or_after
  @assertion_valid_not_on_or_after
end

#authentication_flowObject

Flow used for authentication when the associated application is accessed by an un-authenticated user.



16
17
18
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 16

def authentication_flow
  @authentication_flow
end

#authn_context_class_ref_mappingObject

Configure how the AuthnContextClassRef value will be created. When left empty, the AuthnContextClassRef will be set based on which authentication methods the user used to authenticate.



43
44
45
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 43

def authn_context_class_ref_mapping
  @authn_context_class_ref_mapping
end

#authorization_flowObject

Flow used when authorizing this provider.



19
20
21
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 19

def authorization_flow
  @authorization_flow
end

#default_name_id_policyObject

Returns the value of attribute default_name_id_policy.



59
60
61
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 59

def default_name_id_policy
  @default_name_id_policy
end

#digest_algorithmObject

Returns the value of attribute digest_algorithm.



45
46
47
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 45

def digest_algorithm
  @digest_algorithm
end

#encryption_kpObject

When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.



53
54
55
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 53

def encryption_kp
  @encryption_kp
end

#invalidation_flowObject

Flow used ending the session from a provider.



22
23
24
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 22

def invalidation_flow
  @invalidation_flow
end

#nameObject

Returns the value of attribute name.



13
14
15
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 13

def name
  @name
end

#name_id_mappingObject

Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be considered



40
41
42
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 40

def name_id_mapping
  @name_id_mapping
end

#property_mappingsObject

Returns the value of attribute property_mappings.



24
25
26
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 24

def property_mappings
  @property_mappings
end

#reply_urlObject

Returns the value of attribute reply_url.



26
27
28
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 26

def reply_url
  @reply_url
end

#session_valid_not_on_or_afterObject

Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).



37
38
39
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 37

def session_valid_not_on_or_after
  @session_valid_not_on_or_after
end

#sign_assertionObject

Returns the value of attribute sign_assertion.



55
56
57
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 55

def sign_assertion
  @sign_assertion
end

#sign_logout_requestObject

Returns the value of attribute sign_logout_request.



57
58
59
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 57

def sign_logout_request
  @sign_logout_request
end

#signature_algorithmObject

Returns the value of attribute signature_algorithm.



47
48
49
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 47

def signature_algorithm
  @signature_algorithm
end

#signing_kpObject

Keypair used to sign outgoing Responses going to the Service Provider.



50
51
52
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 50

def signing_kp
  @signing_kp
end

#wtrealmObject

Returns the value of attribute wtrealm.



28
29
30
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 28

def wtrealm
  @wtrealm
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



109
110
111
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 109

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 114

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 84

def self.attribute_map
  {
    :'name' => :'name',
    :'authentication_flow' => :'authentication_flow',
    :'authorization_flow' => :'authorization_flow',
    :'invalidation_flow' => :'invalidation_flow',
    :'property_mappings' => :'property_mappings',
    :'reply_url' => :'reply_url',
    :'wtrealm' => :'wtrealm',
    :'assertion_valid_not_before' => :'assertion_valid_not_before',
    :'assertion_valid_not_on_or_after' => :'assertion_valid_not_on_or_after',
    :'session_valid_not_on_or_after' => :'session_valid_not_on_or_after',
    :'name_id_mapping' => :'name_id_mapping',
    :'authn_context_class_ref_mapping' => :'authn_context_class_ref_mapping',
    :'digest_algorithm' => :'digest_algorithm',
    :'signature_algorithm' => :'signature_algorithm',
    :'signing_kp' => :'signing_kp',
    :'encryption_kp' => :'encryption_kp',
    :'sign_assertion' => :'sign_assertion',
    :'sign_logout_request' => :'sign_logout_request',
    :'default_name_id_policy' => :'default_name_id_policy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 419

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



144
145
146
147
148
149
150
151
152
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 144

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
    :'name_id_mapping',
    :'authn_context_class_ref_mapping',
    :'signing_kp',
    :'encryption_kp',
  ])
end

.openapi_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 119

def self.openapi_types
  {
    :'name' => :'String',
    :'authentication_flow' => :'String',
    :'authorization_flow' => :'String',
    :'invalidation_flow' => :'String',
    :'property_mappings' => :'Array<String>',
    :'reply_url' => :'String',
    :'wtrealm' => :'String',
    :'assertion_valid_not_before' => :'String',
    :'assertion_valid_not_on_or_after' => :'String',
    :'session_valid_not_on_or_after' => :'String',
    :'name_id_mapping' => :'String',
    :'authn_context_class_ref_mapping' => :'String',
    :'digest_algorithm' => :'DigestAlgorithmEnum',
    :'signature_algorithm' => :'SignatureAlgorithmEnum',
    :'signing_kp' => :'String',
    :'encryption_kp' => :'String',
    :'sign_assertion' => :'Boolean',
    :'sign_logout_request' => :'Boolean',
    :'default_name_id_policy' => :'SAMLNameIDPolicyEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 380

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      authentication_flow == o.authentication_flow &&
      authorization_flow == o.authorization_flow &&
      invalidation_flow == o.invalidation_flow &&
      property_mappings == o.property_mappings &&
      reply_url == o.reply_url &&
      wtrealm == o.wtrealm &&
      assertion_valid_not_before == o.assertion_valid_not_before &&
      assertion_valid_not_on_or_after == o.assertion_valid_not_on_or_after &&
      session_valid_not_on_or_after == o.session_valid_not_on_or_after &&
      name_id_mapping == o.name_id_mapping &&
      authn_context_class_ref_mapping == o.authn_context_class_ref_mapping &&
      digest_algorithm == o.digest_algorithm &&
      signature_algorithm == o.signature_algorithm &&
      signing_kp == o.signing_kp &&
      encryption_kp == o.encryption_kp &&
      sign_assertion == o.sign_assertion &&
      sign_logout_request == o.sign_logout_request &&
      default_name_id_policy == o.default_name_id_policy
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


406
407
408
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 406

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



412
413
414
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 412

def hash
  [name, authentication_flow, authorization_flow, invalidation_flow, property_mappings, reply_url, wtrealm, assertion_valid_not_before, assertion_valid_not_on_or_after, session_valid_not_on_or_after, name_id_mapping, authn_context_class_ref_mapping, digest_algorithm, signature_algorithm, signing_kp, encryption_kp, sign_assertion, sign_logout_request, default_name_id_policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 251

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@reply_url.nil? && @reply_url.to_s.length < 1
    invalid_properties.push('invalid value for "reply_url", the character length must be greater than or equal to 1.')
  end

  if !@wtrealm.nil? && @wtrealm.to_s.length < 1
    invalid_properties.push('invalid value for "wtrealm", the character length must be greater than or equal to 1.')
  end

  if !@assertion_valid_not_before.nil? && @assertion_valid_not_before.to_s.length < 1
    invalid_properties.push('invalid value for "assertion_valid_not_before", the character length must be greater than or equal to 1.')
  end

  if !@assertion_valid_not_on_or_after.nil? && @assertion_valid_not_on_or_after.to_s.length < 1
    invalid_properties.push('invalid value for "assertion_valid_not_on_or_after", the character length must be greater than or equal to 1.')
  end

  if !@session_valid_not_on_or_after.nil? && @session_valid_not_on_or_after.to_s.length < 1
    invalid_properties.push('invalid value for "session_valid_not_on_or_after", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 441

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



283
284
285
286
287
288
289
290
291
292
# File 'lib/authentik/api/models/patched_ws_federation_provider_request.rb', line 283

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@reply_url.nil? && @reply_url.to_s.length < 1
  return false if !@wtrealm.nil? && @wtrealm.to_s.length < 1
  return false if !@assertion_valid_not_before.nil? && @assertion_valid_not_before.to_s.length < 1
  return false if !@assertion_valid_not_on_or_after.nil? && @assertion_valid_not_on_or_after.to_s.length < 1
  return false if !@session_valid_not_on_or_after.nil? && @session_valid_not_on_or_after.to_s.length < 1
  true
end