Class: Authentik::Api::PolicyTestResult

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/policy_test_result.rb

Overview

result of a policy test

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PolicyTestResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/authentik/api/models/policy_test_result.rb', line 55

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::PolicyTestResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::PolicyTestResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'passing')
    self.passing = attributes[:'passing']
  else
    self.passing = nil
  end

  if attributes.key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  else
    self.messages = nil
  end

  if attributes.key?(:'log_messages')
    if (value = attributes[:'log_messages']).is_a?(Array)
      self.log_messages = value
    end
  else
    self.log_messages = nil
  end
end

Instance Attribute Details

#log_messagesObject

Returns the value of attribute log_messages.



17
18
19
# File 'lib/authentik/api/models/policy_test_result.rb', line 17

def log_messages
  @log_messages
end

#messagesObject

Returns the value of attribute messages.



15
16
17
# File 'lib/authentik/api/models/policy_test_result.rb', line 15

def messages
  @messages
end

#passingObject

Returns the value of attribute passing.



13
14
15
# File 'lib/authentik/api/models/policy_test_result.rb', line 13

def passing
  @passing
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



29
30
31
# File 'lib/authentik/api/models/policy_test_result.rb', line 29

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



34
35
36
# File 'lib/authentik/api/models/policy_test_result.rb', line 34

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



20
21
22
23
24
25
26
# File 'lib/authentik/api/models/policy_test_result.rb', line 20

def self.attribute_map
  {
    :'passing' => :'passing',
    :'messages' => :'messages',
    :'log_messages' => :'log_messages'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/authentik/api/models/policy_test_result.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



48
49
50
51
# File 'lib/authentik/api/models/policy_test_result.rb', line 48

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



39
40
41
42
43
44
45
# File 'lib/authentik/api/models/policy_test_result.rb', line 39

def self.openapi_types
  {
    :'passing' => :'Boolean',
    :'messages' => :'Array<String>',
    :'log_messages' => :'Array<LogEvent>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



154
155
156
157
158
159
160
# File 'lib/authentik/api/models/policy_test_result.rb', line 154

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      passing == o.passing &&
      messages == o.messages &&
      log_messages == o.log_messages
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/authentik/api/models/policy_test_result.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/authentik/api/models/policy_test_result.rb', line 170

def hash
  [passing, messages, log_messages].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/authentik/api/models/policy_test_result.rb', line 94

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @passing.nil?
    invalid_properties.push('invalid value for "passing", passing cannot be nil.')
  end

  if @messages.nil?
    invalid_properties.push('invalid value for "messages", messages cannot be nil.')
  end

  if @log_messages.nil?
    invalid_properties.push('invalid value for "log_messages", log_messages cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/authentik/api/models/policy_test_result.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



114
115
116
117
118
119
120
# File 'lib/authentik/api/models/policy_test_result.rb', line 114

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @passing.nil?
  return false if @messages.nil?
  return false if @log_messages.nil?
  true
end