Class: Authentik::Api::ProxyProvider
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ProxyProvider
- Defined in:
- lib/authentik/api/models/proxy_provider.rb
Overview
ProxyProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#assigned_application_name ⇒ Object
Application’s display Name.
-
#assigned_application_slug ⇒ Object
Internal application name, used in URLs.
-
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
-
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
-
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
-
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
-
#basic_auth_enabled ⇒ Object
Set a custom HTTP-Basic Authentication header based on values from authentik.
-
#basic_auth_password_attribute ⇒ Object
User/Group Attribute used for the password part of the HTTP-Basic Header.
-
#basic_auth_user_attribute ⇒ Object
User/Group Attribute used for the user part of the HTTP-Basic Header.
-
#certificate ⇒ Object
Returns the value of attribute certificate.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#cookie_domain ⇒ Object
Returns the value of attribute cookie_domain.
-
#external_host ⇒ Object
Returns the value of attribute external_host.
-
#intercept_header_auth ⇒ Object
When enabled, this provider will intercept the authorization header and authenticate requests based on its value.
-
#internal_host ⇒ Object
Returns the value of attribute internal_host.
-
#internal_host_ssl_validation ⇒ Object
Validate SSL Certificates of upstream servers.
-
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
-
#jwt_federation_providers ⇒ Object
Returns the value of attribute jwt_federation_providers.
-
#jwt_federation_sources ⇒ Object
Returns the value of attribute jwt_federation_sources.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#mode ⇒ Object
Enable support for forwardAuth in traefik and nginx auth_request.
-
#name ⇒ Object
Returns the value of attribute name.
-
#outpost_set ⇒ Object
Returns the value of attribute outpost_set.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#redirect_uris ⇒ Object
Returns the value of attribute redirect_uris.
-
#refresh_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#skip_path_regex ⇒ Object
Regular expressions for which authentication is not required.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProxyProvider
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProxyProvider
Initializes the object
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 219 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ProxyProvider` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ProxyProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'authorization_flow') self. = attributes[:'authorization_flow'] else self. = nil end if attributes.key?(:'invalidation_flow') self.invalidation_flow = attributes[:'invalidation_flow'] else self.invalidation_flow = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'assigned_application_slug') self.assigned_application_slug = attributes[:'assigned_application_slug'] else self.assigned_application_slug = nil end if attributes.key?(:'assigned_application_name') self.assigned_application_name = attributes[:'assigned_application_name'] else self.assigned_application_name = nil end if attributes.key?(:'assigned_backchannel_application_slug') self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug'] else self.assigned_backchannel_application_slug = nil end if attributes.key?(:'assigned_backchannel_application_name') self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name'] else self.assigned_backchannel_application_name = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] else self.client_id = nil end if attributes.key?(:'internal_host') self.internal_host = attributes[:'internal_host'] end if attributes.key?(:'external_host') self.external_host = attributes[:'external_host'] else self.external_host = nil end if attributes.key?(:'internal_host_ssl_validation') self.internal_host_ssl_validation = attributes[:'internal_host_ssl_validation'] end if attributes.key?(:'certificate') self.certificate = attributes[:'certificate'] end if attributes.key?(:'skip_path_regex') self.skip_path_regex = attributes[:'skip_path_regex'] end if attributes.key?(:'basic_auth_enabled') self.basic_auth_enabled = attributes[:'basic_auth_enabled'] end if attributes.key?(:'basic_auth_password_attribute') self.basic_auth_password_attribute = attributes[:'basic_auth_password_attribute'] end if attributes.key?(:'basic_auth_user_attribute') self.basic_auth_user_attribute = attributes[:'basic_auth_user_attribute'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'intercept_header_auth') self.intercept_header_auth = attributes[:'intercept_header_auth'] end if attributes.key?(:'redirect_uris') if (value = attributes[:'redirect_uris']).is_a?(Array) self.redirect_uris = value end else self.redirect_uris = nil end if attributes.key?(:'cookie_domain') self. = attributes[:'cookie_domain'] end if attributes.key?(:'jwt_federation_sources') if (value = attributes[:'jwt_federation_sources']).is_a?(Array) self.jwt_federation_sources = value end end if attributes.key?(:'jwt_federation_providers') if (value = attributes[:'jwt_federation_providers']).is_a?(Array) self.jwt_federation_providers = value end end if attributes.key?(:'access_token_validity') self.access_token_validity = attributes[:'access_token_validity'] end if attributes.key?(:'refresh_token_validity') self.refresh_token_validity = attributes[:'refresh_token_validity'] end if attributes.key?(:'outpost_set') if (value = attributes[:'outpost_set']).is_a?(Array) self.outpost_set = value end else self.outpost_set = nil end end |
Instance Attribute Details
#access_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
90 91 92 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 90 def access_token_validity @access_token_validity end |
#assigned_application_name ⇒ Object
Application’s display Name.
35 36 37 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 35 def assigned_application_name @assigned_application_name end |
#assigned_application_slug ⇒ Object
Internal application name, used in URLs.
32 33 34 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 32 def assigned_application_slug @assigned_application_slug end |
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
41 42 43 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 41 def assigned_backchannel_application_name @assigned_backchannel_application_name end |
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
38 39 40 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 38 def assigned_backchannel_application_slug @assigned_backchannel_application_slug end |
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
18 19 20 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 18 def authentication_flow @authentication_flow end |
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
21 22 23 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 21 def @authorization_flow end |
#basic_auth_enabled ⇒ Object
Set a custom HTTP-Basic Authentication header based on values from authentik.
67 68 69 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 67 def basic_auth_enabled @basic_auth_enabled end |
#basic_auth_password_attribute ⇒ Object
User/Group Attribute used for the password part of the HTTP-Basic Header.
70 71 72 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 70 def basic_auth_password_attribute @basic_auth_password_attribute end |
#basic_auth_user_attribute ⇒ Object
User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user’s Email address is used.
73 74 75 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 73 def basic_auth_user_attribute @basic_auth_user_attribute end |
#certificate ⇒ Object
Returns the value of attribute certificate.
61 62 63 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 61 def certificate @certificate end |
#client_id ⇒ Object
Returns the value of attribute client_id.
52 53 54 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 52 def client_id @client_id end |
#component ⇒ Object
Get object component so that we know how to edit the object
29 30 31 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 29 def component @component end |
#cookie_domain ⇒ Object
Returns the value of attribute cookie_domain.
83 84 85 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 83 def @cookie_domain end |
#external_host ⇒ Object
Returns the value of attribute external_host.
56 57 58 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 56 def external_host @external_host end |
#intercept_header_auth ⇒ Object
When enabled, this provider will intercept the authorization header and authenticate requests based on its value.
79 80 81 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 79 def intercept_header_auth @intercept_header_auth end |
#internal_host ⇒ Object
Returns the value of attribute internal_host.
54 55 56 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 54 def internal_host @internal_host end |
#internal_host_ssl_validation ⇒ Object
Validate SSL Certificates of upstream servers
59 60 61 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 59 def internal_host_ssl_validation @internal_host_ssl_validation end |
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
24 25 26 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 24 def invalidation_flow @invalidation_flow end |
#jwt_federation_providers ⇒ Object
Returns the value of attribute jwt_federation_providers.
87 88 89 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 87 def jwt_federation_providers @jwt_federation_providers end |
#jwt_federation_sources ⇒ Object
Returns the value of attribute jwt_federation_sources.
85 86 87 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 85 def jwt_federation_sources @jwt_federation_sources end |
#meta_model_name ⇒ Object
Return internal model name
50 51 52 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 50 def @meta_model_name end |
#mode ⇒ Object
Enable support for forwardAuth in traefik and nginx auth_request. Exclusive with internal_host.
76 77 78 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 76 def mode @mode end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 15 def name @name end |
#outpost_set ⇒ Object
Returns the value of attribute outpost_set.
95 96 97 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 95 def outpost_set @outpost_set end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 13 def pk @pk end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
26 27 28 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 26 def property_mappings @property_mappings end |
#redirect_uris ⇒ Object
Returns the value of attribute redirect_uris.
81 82 83 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 81 def redirect_uris @redirect_uris end |
#refresh_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
93 94 95 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 93 def refresh_token_validity @refresh_token_validity end |
#skip_path_regex ⇒ Object
Regular expressions for which authentication is not required. Each new line is interpreted as a new Regular Expression.
64 65 66 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 64 def skip_path_regex @skip_path_regex end |
#verbose_name ⇒ Object
Return object’s verbose_name
44 45 46 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 44 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
47 48 49 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 47 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
158 159 160 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 158 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
163 164 165 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 163 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 120 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'authentication_flow' => :'authentication_flow', :'authorization_flow' => :'authorization_flow', :'invalidation_flow' => :'invalidation_flow', :'property_mappings' => :'property_mappings', :'component' => :'component', :'assigned_application_slug' => :'assigned_application_slug', :'assigned_application_name' => :'assigned_application_name', :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'client_id' => :'client_id', :'internal_host' => :'internal_host', :'external_host' => :'external_host', :'internal_host_ssl_validation' => :'internal_host_ssl_validation', :'certificate' => :'certificate', :'skip_path_regex' => :'skip_path_regex', :'basic_auth_enabled' => :'basic_auth_enabled', :'basic_auth_password_attribute' => :'basic_auth_password_attribute', :'basic_auth_user_attribute' => :'basic_auth_user_attribute', :'mode' => :'mode', :'intercept_header_auth' => :'intercept_header_auth', :'redirect_uris' => :'redirect_uris', :'cookie_domain' => :'cookie_domain', :'jwt_federation_sources' => :'jwt_federation_sources', :'jwt_federation_providers' => :'jwt_federation_providers', :'access_token_validity' => :'access_token_validity', :'refresh_token_validity' => :'refresh_token_validity', :'outpost_set' => :'outpost_set' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 653 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
206 207 208 209 210 211 212 213 214 215 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 206 def self.openapi_nullable Set.new([ :'authentication_flow', :'assigned_application_slug', :'assigned_application_name', :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name', :'certificate', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 168 def self.openapi_types { :'pk' => :'Integer', :'name' => :'String', :'authentication_flow' => :'String', :'authorization_flow' => :'String', :'invalidation_flow' => :'String', :'property_mappings' => :'Array<String>', :'component' => :'String', :'assigned_application_slug' => :'String', :'assigned_application_name' => :'String', :'assigned_backchannel_application_slug' => :'String', :'assigned_backchannel_application_name' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'client_id' => :'String', :'internal_host' => :'String', :'external_host' => :'String', :'internal_host_ssl_validation' => :'Boolean', :'certificate' => :'String', :'skip_path_regex' => :'String', :'basic_auth_enabled' => :'Boolean', :'basic_auth_password_attribute' => :'String', :'basic_auth_user_attribute' => :'String', :'mode' => :'ProxyMode', :'intercept_header_auth' => :'Boolean', :'redirect_uris' => :'Array<RedirectURI>', :'cookie_domain' => :'String', :'jwt_federation_sources' => :'Array<String>', :'jwt_federation_providers' => :'Array<Integer>', :'access_token_validity' => :'String', :'refresh_token_validity' => :'String', :'outpost_set' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 601 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && authentication_flow == o.authentication_flow && == o. && invalidation_flow == o.invalidation_flow && property_mappings == o.property_mappings && component == o.component && assigned_application_slug == o.assigned_application_slug && assigned_application_name == o.assigned_application_name && assigned_backchannel_application_slug == o.assigned_backchannel_application_slug && assigned_backchannel_application_name == o.assigned_backchannel_application_name && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && client_id == o.client_id && internal_host == o.internal_host && external_host == o.external_host && internal_host_ssl_validation == o.internal_host_ssl_validation && certificate == o.certificate && skip_path_regex == o.skip_path_regex && basic_auth_enabled == o.basic_auth_enabled && basic_auth_password_attribute == o.basic_auth_password_attribute && basic_auth_user_attribute == o.basic_auth_user_attribute && mode == o.mode && intercept_header_auth == o.intercept_header_auth && redirect_uris == o.redirect_uris && == o. && jwt_federation_sources == o.jwt_federation_sources && jwt_federation_providers == o.jwt_federation_providers && access_token_validity == o.access_token_validity && refresh_token_validity == o.refresh_token_validity && outpost_set == o.outpost_set end |
#eql?(o) ⇒ Boolean
640 641 642 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 640 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
646 647 648 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 646 def hash [pk, name, authentication_flow, , invalidation_flow, property_mappings, component, assigned_application_slug, assigned_application_name, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, , client_id, internal_host, external_host, internal_host_ssl_validation, certificate, skip_path_regex, basic_auth_enabled, basic_auth_password_attribute, basic_auth_user_attribute, mode, intercept_header_auth, redirect_uris, , jwt_federation_sources, jwt_federation_providers, access_token_validity, refresh_token_validity, outpost_set].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 406 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @authorization_flow.nil? invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.') end if @invalidation_flow.nil? invalid_properties.push('invalid value for "invalidation_flow", invalidation_flow cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @client_id.nil? invalid_properties.push('invalid value for "client_id", client_id cannot be nil.') end if @external_host.nil? invalid_properties.push('invalid value for "external_host", external_host cannot be nil.') end if @redirect_uris.nil? invalid_properties.push('invalid value for "redirect_uris", redirect_uris cannot be nil.') end if @outpost_set.nil? invalid_properties.push('invalid value for "outpost_set", outpost_set cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
675 676 677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 675 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/authentik/api/models/proxy_provider.rb', line 462 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @authorization_flow.nil? return false if @invalidation_flow.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @client_id.nil? return false if @external_host.nil? return false if @redirect_uris.nil? return false if @outpost_set.nil? true end |