Class: Authentik::Api::ProxyProviderRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::ProxyProviderRequest
- Defined in:
- lib/authentik/api/models/proxy_provider_request.rb
Overview
ProxyProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
-
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
-
#basic_auth_enabled ⇒ Object
Set a custom HTTP-Basic Authentication header based on values from authentik.
-
#basic_auth_password_attribute ⇒ Object
User/Group Attribute used for the password part of the HTTP-Basic Header.
-
#basic_auth_user_attribute ⇒ Object
User/Group Attribute used for the user part of the HTTP-Basic Header.
-
#certificate ⇒ Object
Returns the value of attribute certificate.
-
#cookie_domain ⇒ Object
Returns the value of attribute cookie_domain.
-
#external_host ⇒ Object
Returns the value of attribute external_host.
-
#intercept_header_auth ⇒ Object
When enabled, this provider will intercept the authorization header and authenticate requests based on its value.
-
#internal_host ⇒ Object
Returns the value of attribute internal_host.
-
#internal_host_ssl_validation ⇒ Object
Validate SSL Certificates of upstream servers.
-
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
-
#jwt_federation_providers ⇒ Object
Returns the value of attribute jwt_federation_providers.
-
#jwt_federation_sources ⇒ Object
Returns the value of attribute jwt_federation_sources.
-
#mode ⇒ Object
Enable support for forwardAuth in traefik and nginx auth_request.
-
#name ⇒ Object
Returns the value of attribute name.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#refresh_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
-
#skip_path_regex ⇒ Object
Regular expressions for which authentication is not required.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProxyProviderRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProxyProviderRequest
Initializes the object
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 159 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::ProxyProviderRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::ProxyProviderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'authentication_flow') self.authentication_flow = attributes[:'authentication_flow'] end if attributes.key?(:'authorization_flow') self. = attributes[:'authorization_flow'] else self. = nil end if attributes.key?(:'invalidation_flow') self.invalidation_flow = attributes[:'invalidation_flow'] else self.invalidation_flow = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'internal_host') self.internal_host = attributes[:'internal_host'] end if attributes.key?(:'external_host') self.external_host = attributes[:'external_host'] else self.external_host = nil end if attributes.key?(:'internal_host_ssl_validation') self.internal_host_ssl_validation = attributes[:'internal_host_ssl_validation'] end if attributes.key?(:'certificate') self.certificate = attributes[:'certificate'] end if attributes.key?(:'skip_path_regex') self.skip_path_regex = attributes[:'skip_path_regex'] end if attributes.key?(:'basic_auth_enabled') self.basic_auth_enabled = attributes[:'basic_auth_enabled'] end if attributes.key?(:'basic_auth_password_attribute') self.basic_auth_password_attribute = attributes[:'basic_auth_password_attribute'] end if attributes.key?(:'basic_auth_user_attribute') self.basic_auth_user_attribute = attributes[:'basic_auth_user_attribute'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] end if attributes.key?(:'intercept_header_auth') self.intercept_header_auth = attributes[:'intercept_header_auth'] end if attributes.key?(:'cookie_domain') self. = attributes[:'cookie_domain'] end if attributes.key?(:'jwt_federation_sources') if (value = attributes[:'jwt_federation_sources']).is_a?(Array) self.jwt_federation_sources = value end end if attributes.key?(:'jwt_federation_providers') if (value = attributes[:'jwt_federation_providers']).is_a?(Array) self.jwt_federation_providers = value end end if attributes.key?(:'access_token_validity') self.access_token_validity = attributes[:'access_token_validity'] end if attributes.key?(:'refresh_token_validity') self.refresh_token_validity = attributes[:'refresh_token_validity'] end end |
Instance Attribute Details
#access_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
60 61 62 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 60 def access_token_validity @access_token_validity end |
#authentication_flow ⇒ Object
Flow used for authentication when the associated application is accessed by an un-authenticated user.
16 17 18 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 16 def authentication_flow @authentication_flow end |
#authorization_flow ⇒ Object
Flow used when authorizing this provider.
19 20 21 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 19 def @authorization_flow end |
#basic_auth_enabled ⇒ Object
Set a custom HTTP-Basic Authentication header based on values from authentik.
39 40 41 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 39 def basic_auth_enabled @basic_auth_enabled end |
#basic_auth_password_attribute ⇒ Object
User/Group Attribute used for the password part of the HTTP-Basic Header.
42 43 44 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 42 def basic_auth_password_attribute @basic_auth_password_attribute end |
#basic_auth_user_attribute ⇒ Object
User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user’s Email address is used.
45 46 47 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 45 def basic_auth_user_attribute @basic_auth_user_attribute end |
#certificate ⇒ Object
Returns the value of attribute certificate.
33 34 35 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 33 def certificate @certificate end |
#cookie_domain ⇒ Object
Returns the value of attribute cookie_domain.
53 54 55 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 53 def @cookie_domain end |
#external_host ⇒ Object
Returns the value of attribute external_host.
28 29 30 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 28 def external_host @external_host end |
#intercept_header_auth ⇒ Object
When enabled, this provider will intercept the authorization header and authenticate requests based on its value.
51 52 53 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 51 def intercept_header_auth @intercept_header_auth end |
#internal_host ⇒ Object
Returns the value of attribute internal_host.
26 27 28 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 26 def internal_host @internal_host end |
#internal_host_ssl_validation ⇒ Object
Validate SSL Certificates of upstream servers
31 32 33 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 31 def internal_host_ssl_validation @internal_host_ssl_validation end |
#invalidation_flow ⇒ Object
Flow used ending the session from a provider.
22 23 24 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 22 def invalidation_flow @invalidation_flow end |
#jwt_federation_providers ⇒ Object
Returns the value of attribute jwt_federation_providers.
57 58 59 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 57 def jwt_federation_providers @jwt_federation_providers end |
#jwt_federation_sources ⇒ Object
Returns the value of attribute jwt_federation_sources.
55 56 57 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 55 def jwt_federation_sources @jwt_federation_sources end |
#mode ⇒ Object
Enable support for forwardAuth in traefik and nginx auth_request. Exclusive with internal_host.
48 49 50 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 48 def mode @mode end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 13 def name @name end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
24 25 26 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 24 def property_mappings @property_mappings end |
#refresh_token_validity ⇒ Object
Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
63 64 65 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 63 def refresh_token_validity @refresh_token_validity end |
#skip_path_regex ⇒ Object
Regular expressions for which authentication is not required. Each new line is interpreted as a new Regular Expression.
36 37 38 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 36 def skip_path_regex @skip_path_regex end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
114 115 116 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 114 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
119 120 121 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 119 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 88 def self.attribute_map { :'name' => :'name', :'authentication_flow' => :'authentication_flow', :'authorization_flow' => :'authorization_flow', :'invalidation_flow' => :'invalidation_flow', :'property_mappings' => :'property_mappings', :'internal_host' => :'internal_host', :'external_host' => :'external_host', :'internal_host_ssl_validation' => :'internal_host_ssl_validation', :'certificate' => :'certificate', :'skip_path_regex' => :'skip_path_regex', :'basic_auth_enabled' => :'basic_auth_enabled', :'basic_auth_password_attribute' => :'basic_auth_password_attribute', :'basic_auth_user_attribute' => :'basic_auth_user_attribute', :'mode' => :'mode', :'intercept_header_auth' => :'intercept_header_auth', :'cookie_domain' => :'cookie_domain', :'jwt_federation_sources' => :'jwt_federation_sources', :'jwt_federation_providers' => :'jwt_federation_providers', :'access_token_validity' => :'access_token_validity', :'refresh_token_validity' => :'refresh_token_validity' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 441 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
150 151 152 153 154 155 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 150 def self.openapi_nullable Set.new([ :'authentication_flow', :'certificate', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 124 def self.openapi_types { :'name' => :'String', :'authentication_flow' => :'String', :'authorization_flow' => :'String', :'invalidation_flow' => :'String', :'property_mappings' => :'Array<String>', :'internal_host' => :'String', :'external_host' => :'String', :'internal_host_ssl_validation' => :'Boolean', :'certificate' => :'String', :'skip_path_regex' => :'String', :'basic_auth_enabled' => :'Boolean', :'basic_auth_password_attribute' => :'String', :'basic_auth_user_attribute' => :'String', :'mode' => :'ProxyMode', :'intercept_header_auth' => :'Boolean', :'cookie_domain' => :'String', :'jwt_federation_sources' => :'Array<String>', :'jwt_federation_providers' => :'Array<Integer>', :'access_token_validity' => :'String', :'refresh_token_validity' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 401 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && authentication_flow == o.authentication_flow && == o. && invalidation_flow == o.invalidation_flow && property_mappings == o.property_mappings && internal_host == o.internal_host && external_host == o.external_host && internal_host_ssl_validation == o.internal_host_ssl_validation && certificate == o.certificate && skip_path_regex == o.skip_path_regex && basic_auth_enabled == o.basic_auth_enabled && basic_auth_password_attribute == o.basic_auth_password_attribute && basic_auth_user_attribute == o.basic_auth_user_attribute && mode == o.mode && intercept_header_auth == o.intercept_header_auth && == o. && jwt_federation_sources == o.jwt_federation_sources && jwt_federation_providers == o.jwt_federation_providers && access_token_validity == o.access_token_validity && refresh_token_validity == o.refresh_token_validity end |
#eql?(o) ⇒ Boolean
428 429 430 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 428 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
434 435 436 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 434 def hash [name, authentication_flow, , invalidation_flow, property_mappings, internal_host, external_host, internal_host_ssl_validation, certificate, skip_path_regex, basic_auth_enabled, basic_auth_password_attribute, basic_auth_user_attribute, mode, intercept_header_auth, , jwt_federation_sources, jwt_federation_providers, access_token_validity, refresh_token_validity].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 270 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @authorization_flow.nil? invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.') end if @invalidation_flow.nil? invalid_properties.push('invalid value for "invalidation_flow", invalidation_flow cannot be nil.') end if @external_host.nil? invalid_properties.push('invalid value for "external_host", external_host cannot be nil.') end if @external_host.to_s.length < 1 invalid_properties.push('invalid value for "external_host", the character length must be greater than or equal to 1.') end if !@access_token_validity.nil? && @access_token_validity.to_s.length < 1 invalid_properties.push('invalid value for "access_token_validity", the character length must be greater than or equal to 1.') end if !@refresh_token_validity.nil? && @refresh_token_validity.to_s.length < 1 invalid_properties.push('invalid value for "refresh_token_validity", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 463 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/authentik/api/models/proxy_provider_request.rb', line 310 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if @authorization_flow.nil? return false if @invalidation_flow.nil? return false if @external_host.nil? return false if @external_host.to_s.length < 1 return false if !@access_token_validity.nil? && @access_token_validity.to_s.length < 1 return false if !@refresh_token_validity.nil? && @refresh_token_validity.to_s.length < 1 true end |