Class: Authentik::Api::RacApi
- Inherits:
-
Object
- Object
- Authentik::Api::RacApi
- Defined in:
- lib/authentik/api/api/rac_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ RacApi
constructor
A new instance of RacApi.
-
#rac_connection_tokens_destroy(connection_token_uuid, opts = {}) ⇒ nil
ConnectionToken Viewset.
-
#rac_connection_tokens_destroy_with_http_info(connection_token_uuid, opts = {}) ⇒ Array<(nil, Integer, Hash)>
ConnectionToken Viewset.
-
#rac_connection_tokens_list(opts = {}) ⇒ PaginatedConnectionTokenList
ConnectionToken Viewset.
-
#rac_connection_tokens_list_with_http_info(opts = {}) ⇒ Array<(PaginatedConnectionTokenList, Integer, Hash)>
ConnectionToken Viewset.
-
#rac_connection_tokens_partial_update(connection_token_uuid, opts = {}) ⇒ ConnectionToken
ConnectionToken Viewset.
-
#rac_connection_tokens_partial_update_with_http_info(connection_token_uuid, opts = {}) ⇒ Array<(ConnectionToken, Integer, Hash)>
ConnectionToken Viewset.
-
#rac_connection_tokens_retrieve(connection_token_uuid, opts = {}) ⇒ ConnectionToken
ConnectionToken Viewset.
-
#rac_connection_tokens_retrieve_with_http_info(connection_token_uuid, opts = {}) ⇒ Array<(ConnectionToken, Integer, Hash)>
ConnectionToken Viewset.
-
#rac_connection_tokens_update(connection_token_uuid, connection_token_request, opts = {}) ⇒ ConnectionToken
ConnectionToken Viewset.
-
#rac_connection_tokens_update_with_http_info(connection_token_uuid, connection_token_request, opts = {}) ⇒ Array<(ConnectionToken, Integer, Hash)>
ConnectionToken Viewset.
-
#rac_connection_tokens_used_by_list(connection_token_uuid, opts = {}) ⇒ Array<UsedBy>
Get a list of all objects that use this object.
-
#rac_connection_tokens_used_by_list_with_http_info(connection_token_uuid, opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>
Get a list of all objects that use this object.
-
#rac_endpoints_create(endpoint_request, opts = {}) ⇒ Endpoint
Endpoint Viewset.
-
#rac_endpoints_create_with_http_info(endpoint_request, opts = {}) ⇒ Array<(Endpoint, Integer, Hash)>
Endpoint Viewset.
-
#rac_endpoints_destroy(pbm_uuid, opts = {}) ⇒ nil
Endpoint Viewset.
-
#rac_endpoints_destroy_with_http_info(pbm_uuid, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Endpoint Viewset.
-
#rac_endpoints_list(opts = {}) ⇒ PaginatedEndpointList
List accessible endpoints.
-
#rac_endpoints_list_with_http_info(opts = {}) ⇒ Array<(PaginatedEndpointList, Integer, Hash)>
List accessible endpoints.
-
#rac_endpoints_partial_update(pbm_uuid, opts = {}) ⇒ Endpoint
Endpoint Viewset.
-
#rac_endpoints_partial_update_with_http_info(pbm_uuid, opts = {}) ⇒ Array<(Endpoint, Integer, Hash)>
Endpoint Viewset.
-
#rac_endpoints_retrieve(pbm_uuid, opts = {}) ⇒ Endpoint
Endpoint Viewset.
-
#rac_endpoints_retrieve_with_http_info(pbm_uuid, opts = {}) ⇒ Array<(Endpoint, Integer, Hash)>
Endpoint Viewset.
-
#rac_endpoints_update(pbm_uuid, endpoint_request, opts = {}) ⇒ Endpoint
Endpoint Viewset.
-
#rac_endpoints_update_with_http_info(pbm_uuid, endpoint_request, opts = {}) ⇒ Array<(Endpoint, Integer, Hash)>
Endpoint Viewset.
-
#rac_endpoints_used_by_list(pbm_uuid, opts = {}) ⇒ Array<UsedBy>
Get a list of all objects that use this object.
-
#rac_endpoints_used_by_list_with_http_info(pbm_uuid, opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>
Get a list of all objects that use this object.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
11 12 13 |
# File 'lib/authentik/api/api/rac_api.rb', line 11 def api_client @api_client end |
Instance Method Details
#rac_connection_tokens_destroy(connection_token_uuid, opts = {}) ⇒ nil
ConnectionToken Viewset
20 21 22 23 |
# File 'lib/authentik/api/api/rac_api.rb', line 20 def rac_connection_tokens_destroy(connection_token_uuid, opts = {}) rac_connection_tokens_destroy_with_http_info(connection_token_uuid, opts) nil end |
#rac_connection_tokens_destroy_with_http_info(connection_token_uuid, opts = {}) ⇒ Array<(nil, Integer, Hash)>
ConnectionToken Viewset
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/authentik/api/api/rac_api.rb', line 29 def rac_connection_tokens_destroy_with_http_info(connection_token_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_connection_tokens_destroy ...' end # verify the required parameter 'connection_token_uuid' is set if @api_client.config.client_side_validation && connection_token_uuid.nil? fail ArgumentError, "Missing the required parameter 'connection_token_uuid' when calling RacApi.rac_connection_tokens_destroy" end # resource path local_var_path = '/rac/connection_tokens/{connection_token_uuid}/'.sub('{connection_token_uuid}', CGI.escape(connection_token_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_connection_tokens_destroy", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_connection_tokens_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_connection_tokens_list(opts = {}) ⇒ PaginatedConnectionTokenList
ConnectionToken Viewset
87 88 89 90 |
# File 'lib/authentik/api/api/rac_api.rb', line 87 def rac_connection_tokens_list(opts = {}) data, _status_code, _headers = rac_connection_tokens_list_with_http_info(opts) data end |
#rac_connection_tokens_list_with_http_info(opts = {}) ⇒ Array<(PaginatedConnectionTokenList, Integer, Hash)>
ConnectionToken Viewset
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/authentik/api/api/rac_api.rb', line 102 def rac_connection_tokens_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_connection_tokens_list ...' end # resource path local_var_path = '/rac/connection_tokens/' # query parameters query_params = opts[:query_params] || {} query_params[:'endpoint'] = opts[:'endpoint'] if !opts[:'endpoint'].nil? query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'provider'] = opts[:'provider'] if !opts[:'provider'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'session__user'] = opts[:'session__user'] if !opts[:'session__user'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedConnectionTokenList' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_connection_tokens_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_connection_tokens_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_connection_tokens_partial_update(connection_token_uuid, opts = {}) ⇒ ConnectionToken
ConnectionToken Viewset
158 159 160 161 |
# File 'lib/authentik/api/api/rac_api.rb', line 158 def rac_connection_tokens_partial_update(connection_token_uuid, opts = {}) data, _status_code, _headers = rac_connection_tokens_partial_update_with_http_info(connection_token_uuid, opts) data end |
#rac_connection_tokens_partial_update_with_http_info(connection_token_uuid, opts = {}) ⇒ Array<(ConnectionToken, Integer, Hash)>
ConnectionToken Viewset
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/authentik/api/api/rac_api.rb', line 168 def rac_connection_tokens_partial_update_with_http_info(connection_token_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_connection_tokens_partial_update ...' end # verify the required parameter 'connection_token_uuid' is set if @api_client.config.client_side_validation && connection_token_uuid.nil? fail ArgumentError, "Missing the required parameter 'connection_token_uuid' when calling RacApi.rac_connection_tokens_partial_update" end # resource path local_var_path = '/rac/connection_tokens/{connection_token_uuid}/'.sub('{connection_token_uuid}', CGI.escape(connection_token_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_connection_token_request']) # return_type return_type = opts[:debug_return_type] || 'ConnectionToken' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_connection_tokens_partial_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_connection_tokens_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_connection_tokens_retrieve(connection_token_uuid, opts = {}) ⇒ ConnectionToken
ConnectionToken Viewset
225 226 227 228 |
# File 'lib/authentik/api/api/rac_api.rb', line 225 def rac_connection_tokens_retrieve(connection_token_uuid, opts = {}) data, _status_code, _headers = rac_connection_tokens_retrieve_with_http_info(connection_token_uuid, opts) data end |
#rac_connection_tokens_retrieve_with_http_info(connection_token_uuid, opts = {}) ⇒ Array<(ConnectionToken, Integer, Hash)>
ConnectionToken Viewset
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/authentik/api/api/rac_api.rb', line 234 def rac_connection_tokens_retrieve_with_http_info(connection_token_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_connection_tokens_retrieve ...' end # verify the required parameter 'connection_token_uuid' is set if @api_client.config.client_side_validation && connection_token_uuid.nil? fail ArgumentError, "Missing the required parameter 'connection_token_uuid' when calling RacApi.rac_connection_tokens_retrieve" end # resource path local_var_path = '/rac/connection_tokens/{connection_token_uuid}/'.sub('{connection_token_uuid}', CGI.escape(connection_token_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConnectionToken' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_connection_tokens_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_connection_tokens_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_connection_tokens_update(connection_token_uuid, connection_token_request, opts = {}) ⇒ ConnectionToken
ConnectionToken Viewset
287 288 289 290 |
# File 'lib/authentik/api/api/rac_api.rb', line 287 def rac_connection_tokens_update(connection_token_uuid, connection_token_request, opts = {}) data, _status_code, _headers = rac_connection_tokens_update_with_http_info(connection_token_uuid, connection_token_request, opts) data end |
#rac_connection_tokens_update_with_http_info(connection_token_uuid, connection_token_request, opts = {}) ⇒ Array<(ConnectionToken, Integer, Hash)>
ConnectionToken Viewset
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/authentik/api/api/rac_api.rb', line 297 def rac_connection_tokens_update_with_http_info(connection_token_uuid, connection_token_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_connection_tokens_update ...' end # verify the required parameter 'connection_token_uuid' is set if @api_client.config.client_side_validation && connection_token_uuid.nil? fail ArgumentError, "Missing the required parameter 'connection_token_uuid' when calling RacApi.rac_connection_tokens_update" end # verify the required parameter 'connection_token_request' is set if @api_client.config.client_side_validation && connection_token_request.nil? fail ArgumentError, "Missing the required parameter 'connection_token_request' when calling RacApi.rac_connection_tokens_update" end # resource path local_var_path = '/rac/connection_tokens/{connection_token_uuid}/'.sub('{connection_token_uuid}', CGI.escape(connection_token_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(connection_token_request) # return_type return_type = opts[:debug_return_type] || 'ConnectionToken' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_connection_tokens_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_connection_tokens_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_connection_tokens_used_by_list(connection_token_uuid, opts = {}) ⇒ Array<UsedBy>
Get a list of all objects that use this object
358 359 360 361 |
# File 'lib/authentik/api/api/rac_api.rb', line 358 def rac_connection_tokens_used_by_list(connection_token_uuid, opts = {}) data, _status_code, _headers = rac_connection_tokens_used_by_list_with_http_info(connection_token_uuid, opts) data end |
#rac_connection_tokens_used_by_list_with_http_info(connection_token_uuid, opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>
Get a list of all objects that use this object
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 |
# File 'lib/authentik/api/api/rac_api.rb', line 367 def rac_connection_tokens_used_by_list_with_http_info(connection_token_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_connection_tokens_used_by_list ...' end # verify the required parameter 'connection_token_uuid' is set if @api_client.config.client_side_validation && connection_token_uuid.nil? fail ArgumentError, "Missing the required parameter 'connection_token_uuid' when calling RacApi.rac_connection_tokens_used_by_list" end # resource path local_var_path = '/rac/connection_tokens/{connection_token_uuid}/used_by/'.sub('{connection_token_uuid}', CGI.escape(connection_token_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<UsedBy>' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_connection_tokens_used_by_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_connection_tokens_used_by_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_endpoints_create(endpoint_request, opts = {}) ⇒ Endpoint
Endpoint Viewset
419 420 421 422 |
# File 'lib/authentik/api/api/rac_api.rb', line 419 def rac_endpoints_create(endpoint_request, opts = {}) data, _status_code, _headers = rac_endpoints_create_with_http_info(endpoint_request, opts) data end |
#rac_endpoints_create_with_http_info(endpoint_request, opts = {}) ⇒ Array<(Endpoint, Integer, Hash)>
Endpoint Viewset
428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/authentik/api/api/rac_api.rb', line 428 def rac_endpoints_create_with_http_info(endpoint_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_endpoints_create ...' end # verify the required parameter 'endpoint_request' is set if @api_client.config.client_side_validation && endpoint_request.nil? fail ArgumentError, "Missing the required parameter 'endpoint_request' when calling RacApi.rac_endpoints_create" end # resource path local_var_path = '/rac/endpoints/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(endpoint_request) # return_type return_type = opts[:debug_return_type] || 'Endpoint' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_endpoints_create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_endpoints_create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_endpoints_destroy(pbm_uuid, opts = {}) ⇒ nil
Endpoint Viewset
485 486 487 488 |
# File 'lib/authentik/api/api/rac_api.rb', line 485 def rac_endpoints_destroy(pbm_uuid, opts = {}) rac_endpoints_destroy_with_http_info(pbm_uuid, opts) nil end |
#rac_endpoints_destroy_with_http_info(pbm_uuid, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Endpoint Viewset
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/authentik/api/api/rac_api.rb', line 494 def rac_endpoints_destroy_with_http_info(pbm_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_endpoints_destroy ...' end # verify the required parameter 'pbm_uuid' is set if @api_client.config.client_side_validation && pbm_uuid.nil? fail ArgumentError, "Missing the required parameter 'pbm_uuid' when calling RacApi.rac_endpoints_destroy" end # resource path local_var_path = '/rac/endpoints/{pbm_uuid}/'.sub('{pbm_uuid}', CGI.escape(pbm_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_endpoints_destroy", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_endpoints_destroy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_endpoints_list(opts = {}) ⇒ PaginatedEndpointList
List accessible endpoints
552 553 554 555 |
# File 'lib/authentik/api/api/rac_api.rb', line 552 def rac_endpoints_list(opts = {}) data, _status_code, _headers = rac_endpoints_list_with_http_info(opts) data end |
#rac_endpoints_list_with_http_info(opts = {}) ⇒ Array<(PaginatedEndpointList, Integer, Hash)>
List accessible endpoints
567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'lib/authentik/api/api/rac_api.rb', line 567 def rac_endpoints_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_endpoints_list ...' end # resource path local_var_path = '/rac/endpoints/' # query parameters query_params = opts[:query_params] || {} query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'ordering'] = opts[:'ordering'] if !opts[:'ordering'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'page_size'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'provider'] = opts[:'provider'] if !opts[:'provider'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? query_params[:'superuser_full_list'] = opts[:'superuser_full_list'] if !opts[:'superuser_full_list'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedEndpointList' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_endpoints_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_endpoints_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_endpoints_partial_update(pbm_uuid, opts = {}) ⇒ Endpoint
Endpoint Viewset
623 624 625 626 |
# File 'lib/authentik/api/api/rac_api.rb', line 623 def rac_endpoints_partial_update(pbm_uuid, opts = {}) data, _status_code, _headers = rac_endpoints_partial_update_with_http_info(pbm_uuid, opts) data end |
#rac_endpoints_partial_update_with_http_info(pbm_uuid, opts = {}) ⇒ Array<(Endpoint, Integer, Hash)>
Endpoint Viewset
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 |
# File 'lib/authentik/api/api/rac_api.rb', line 633 def rac_endpoints_partial_update_with_http_info(pbm_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_endpoints_partial_update ...' end # verify the required parameter 'pbm_uuid' is set if @api_client.config.client_side_validation && pbm_uuid.nil? fail ArgumentError, "Missing the required parameter 'pbm_uuid' when calling RacApi.rac_endpoints_partial_update" end # resource path local_var_path = '/rac/endpoints/{pbm_uuid}/'.sub('{pbm_uuid}', CGI.escape(pbm_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'patched_endpoint_request']) # return_type return_type = opts[:debug_return_type] || 'Endpoint' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_endpoints_partial_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_endpoints_partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_endpoints_retrieve(pbm_uuid, opts = {}) ⇒ Endpoint
Endpoint Viewset
690 691 692 693 |
# File 'lib/authentik/api/api/rac_api.rb', line 690 def rac_endpoints_retrieve(pbm_uuid, opts = {}) data, _status_code, _headers = rac_endpoints_retrieve_with_http_info(pbm_uuid, opts) data end |
#rac_endpoints_retrieve_with_http_info(pbm_uuid, opts = {}) ⇒ Array<(Endpoint, Integer, Hash)>
Endpoint Viewset
699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 |
# File 'lib/authentik/api/api/rac_api.rb', line 699 def rac_endpoints_retrieve_with_http_info(pbm_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_endpoints_retrieve ...' end # verify the required parameter 'pbm_uuid' is set if @api_client.config.client_side_validation && pbm_uuid.nil? fail ArgumentError, "Missing the required parameter 'pbm_uuid' when calling RacApi.rac_endpoints_retrieve" end # resource path local_var_path = '/rac/endpoints/{pbm_uuid}/'.sub('{pbm_uuid}', CGI.escape(pbm_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Endpoint' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_endpoints_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_endpoints_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_endpoints_update(pbm_uuid, endpoint_request, opts = {}) ⇒ Endpoint
Endpoint Viewset
752 753 754 755 |
# File 'lib/authentik/api/api/rac_api.rb', line 752 def rac_endpoints_update(pbm_uuid, endpoint_request, opts = {}) data, _status_code, _headers = rac_endpoints_update_with_http_info(pbm_uuid, endpoint_request, opts) data end |
#rac_endpoints_update_with_http_info(pbm_uuid, endpoint_request, opts = {}) ⇒ Array<(Endpoint, Integer, Hash)>
Endpoint Viewset
762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 |
# File 'lib/authentik/api/api/rac_api.rb', line 762 def rac_endpoints_update_with_http_info(pbm_uuid, endpoint_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_endpoints_update ...' end # verify the required parameter 'pbm_uuid' is set if @api_client.config.client_side_validation && pbm_uuid.nil? fail ArgumentError, "Missing the required parameter 'pbm_uuid' when calling RacApi.rac_endpoints_update" end # verify the required parameter 'endpoint_request' is set if @api_client.config.client_side_validation && endpoint_request.nil? fail ArgumentError, "Missing the required parameter 'endpoint_request' when calling RacApi.rac_endpoints_update" end # resource path local_var_path = '/rac/endpoints/{pbm_uuid}/'.sub('{pbm_uuid}', CGI.escape(pbm_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(endpoint_request) # return_type return_type = opts[:debug_return_type] || 'Endpoint' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_endpoints_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_endpoints_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rac_endpoints_used_by_list(pbm_uuid, opts = {}) ⇒ Array<UsedBy>
Get a list of all objects that use this object
823 824 825 826 |
# File 'lib/authentik/api/api/rac_api.rb', line 823 def rac_endpoints_used_by_list(pbm_uuid, opts = {}) data, _status_code, _headers = rac_endpoints_used_by_list_with_http_info(pbm_uuid, opts) data end |
#rac_endpoints_used_by_list_with_http_info(pbm_uuid, opts = {}) ⇒ Array<(Array<UsedBy>, Integer, Hash)>
Get a list of all objects that use this object
832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 |
# File 'lib/authentik/api/api/rac_api.rb', line 832 def rac_endpoints_used_by_list_with_http_info(pbm_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RacApi.rac_endpoints_used_by_list ...' end # verify the required parameter 'pbm_uuid' is set if @api_client.config.client_side_validation && pbm_uuid.nil? fail ArgumentError, "Missing the required parameter 'pbm_uuid' when calling RacApi.rac_endpoints_used_by_list" end # resource path local_var_path = '/rac/endpoints/{pbm_uuid}/used_by/'.sub('{pbm_uuid}', CGI.escape(pbm_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<UsedBy>' # auth_names auth_names = opts[:debug_auth_names] || ['authentik'] = opts.merge( :operation => :"RacApi.rac_endpoints_used_by_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RacApi#rac_endpoints_used_by_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |