Class: Authentik::Api::RequestRuleRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::RequestRuleRequest
- Defined in:
- lib/authentik/api/models/request_rule_request.rb
Overview
Mixin to validate that a valid enterprise license exists before allowing to save the object
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#min_reviewers ⇒ Object
Returns the value of attribute min_reviewers.
-
#min_reviewers_is_per_group ⇒ Object
Returns the value of attribute min_reviewers_is_per_group.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notification_mode ⇒ Object
Returns the value of attribute notification_mode.
-
#notification_transports ⇒ Object
Returns the value of attribute notification_transports.
-
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
-
#request_flow ⇒ Object
Returns the value of attribute request_flow.
-
#uuid ⇒ Object
Returns the value of attribute uuid.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RequestRuleRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RequestRuleRequest
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::RequestRuleRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::RequestRuleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'policy_engine_mode') self.policy_engine_mode = attributes[:'policy_engine_mode'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'notification_transports') if (value = attributes[:'notification_transports']).is_a?(Array) self.notification_transports = value end end if attributes.key?(:'notification_mode') self.notification_mode = attributes[:'notification_mode'] end if attributes.key?(:'min_reviewers') self.min_reviewers = attributes[:'min_reviewers'] end if attributes.key?(:'min_reviewers_is_per_group') self.min_reviewers_is_per_group = attributes[:'min_reviewers_is_per_group'] end if attributes.key?(:'request_flow') self.request_flow = attributes[:'request_flow'] end end |
Instance Attribute Details
#min_reviewers ⇒ Object
Returns the value of attribute min_reviewers.
23 24 25 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 23 def min_reviewers @min_reviewers end |
#min_reviewers_is_per_group ⇒ Object
Returns the value of attribute min_reviewers_is_per_group.
25 26 27 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 25 def min_reviewers_is_per_group @min_reviewers_is_per_group end |
#name ⇒ Object
Returns the value of attribute name.
17 18 19 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 17 def name @name end |
#notification_mode ⇒ Object
Returns the value of attribute notification_mode.
21 22 23 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 21 def notification_mode @notification_mode end |
#notification_transports ⇒ Object
Returns the value of attribute notification_transports.
19 20 21 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 19 def notification_transports @notification_transports end |
#policy_engine_mode ⇒ Object
Returns the value of attribute policy_engine_mode.
15 16 17 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 15 def policy_engine_mode @policy_engine_mode end |
#request_flow ⇒ Object
Returns the value of attribute request_flow.
27 28 29 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 27 def request_flow @request_flow end |
#uuid ⇒ Object
Returns the value of attribute uuid.
13 14 15 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 13 def uuid @uuid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 52 def self.attribute_map { :'uuid' => :'uuid', :'policy_engine_mode' => :'policy_engine_mode', :'name' => :'name', :'notification_transports' => :'notification_transports', :'notification_mode' => :'notification_mode', :'min_reviewers' => :'min_reviewers', :'min_reviewers_is_per_group' => :'min_reviewers_is_per_group', :'request_flow' => :'request_flow' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 94 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 90 def self.openapi_nullable Set.new([ :'request_flow' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 76 def self.openapi_types { :'uuid' => :'String', :'policy_engine_mode' => :'PolicyEngineMode', :'name' => :'String', :'notification_transports' => :'Array<String>', :'notification_mode' => :'NotificationModeEnum', :'min_reviewers' => :'Integer', :'min_reviewers_is_per_group' => :'Boolean', :'request_flow' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 218 def ==(o) return true if self.equal?(o) self.class == o.class && uuid == o.uuid && policy_engine_mode == o.policy_engine_mode && name == o.name && notification_transports == o.notification_transports && notification_mode == o.notification_mode && min_reviewers == o.min_reviewers && min_reviewers_is_per_group == o.min_reviewers_is_per_group && request_flow == o.request_flow end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 239 def hash [uuid, policy_engine_mode, name, notification_transports, notification_mode, min_reviewers, min_reviewers_is_per_group, request_flow].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@min_reviewers.nil? && @min_reviewers > 32767 invalid_properties.push('invalid value for "min_reviewers", must be smaller than or equal to 32767.') end if !@min_reviewers.nil? && @min_reviewers < 0 invalid_properties.push('invalid value for "min_reviewers", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 180 181 182 |
# File 'lib/authentik/api/models/request_rule_request.rb', line 175 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length < 1 return false if !@min_reviewers.nil? && @min_reviewers > 32767 return false if !@min_reviewers.nil? && @min_reviewers < 0 true end |