Class: Authentik::Api::RequestableTarget
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::RequestableTarget
- Defined in:
- lib/authentik/api/models/requestable_target.rb
Overview
Generic representation of a single request target: whatever was actually requested (an Application, an Application Entitlement, ...), always paired with the parent it belongs to, so the UI/audit trail has that context even when the request itself was scoped narrower than the whole app.
Instance Attribute Summary collapse
-
#label ⇒ Object
Returns the value of attribute label.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#parent ⇒ Object
Returns the value of attribute parent.
-
#pbm_uuid ⇒ Object
Returns the value of attribute pbm_uuid.
-
#verbose_name ⇒ Object
Return object's verbose_name.
-
#verbose_name_plural ⇒ Object
Return object's plural verbose_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RequestableTarget
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RequestableTarget
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/authentik/api/models/requestable_target.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::RequestableTarget` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::RequestableTarget`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'pbm_uuid') self.pbm_uuid = attributes[:'pbm_uuid'] else self.pbm_uuid = nil end if attributes.key?(:'label') self.label = attributes[:'label'] else self.label = nil end if attributes.key?(:'parent') self.parent = attributes[:'parent'] else self.parent = nil end end |
Instance Attribute Details
#label ⇒ Object
Returns the value of attribute label.
24 25 26 |
# File 'lib/authentik/api/models/requestable_target.rb', line 24 def label @label end |
#meta_model_name ⇒ Object
Return internal model name
20 21 22 |
# File 'lib/authentik/api/models/requestable_target.rb', line 20 def @meta_model_name end |
#parent ⇒ Object
Returns the value of attribute parent.
26 27 28 |
# File 'lib/authentik/api/models/requestable_target.rb', line 26 def parent @parent end |
#pbm_uuid ⇒ Object
Returns the value of attribute pbm_uuid.
22 23 24 |
# File 'lib/authentik/api/models/requestable_target.rb', line 22 def pbm_uuid @pbm_uuid end |
#verbose_name ⇒ Object
Return object's verbose_name
14 15 16 |
# File 'lib/authentik/api/models/requestable_target.rb', line 14 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object's plural verbose_name
17 18 19 |
# File 'lib/authentik/api/models/requestable_target.rb', line 17 def verbose_name_plural @verbose_name_plural end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/authentik/api/models/requestable_target.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/authentik/api/models/requestable_target.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/authentik/api/models/requestable_target.rb', line 29 def self.attribute_map { :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'pbm_uuid' => :'pbm_uuid', :'label' => :'label', :'parent' => :'parent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/authentik/api/models/requestable_target.rb', line 240 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
63 64 65 66 67 |
# File 'lib/authentik/api/models/requestable_target.rb', line 63 def self.openapi_nullable Set.new([ :'parent' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/authentik/api/models/requestable_target.rb', line 51 def self.openapi_types { :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'pbm_uuid' => :'String', :'label' => :'String', :'parent' => :'Application' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 |
# File 'lib/authentik/api/models/requestable_target.rb', line 214 def ==(o) return true if self.equal?(o) self.class == o.class && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && pbm_uuid == o.pbm_uuid && label == o.label && parent == o.parent end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/authentik/api/models/requestable_target.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/authentik/api/models/requestable_target.rb', line 233 def hash [verbose_name, verbose_name_plural, , pbm_uuid, label, parent].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/authentik/api/models/requestable_target.rb', line 124 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @pbm_uuid.nil? invalid_properties.push('invalid value for "pbm_uuid", pbm_uuid cannot be nil.') end if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/authentik/api/models/requestable_target.rb', line 262 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 160 |
# File 'lib/authentik/api/models/requestable_target.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @pbm_uuid.nil? return false if @label.nil? true end |