Class: Authentik::Api::RoleObjectPermission

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/role_object_permission.rb

Overview

Role-bound object level permission

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RoleObjectPermission

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/authentik/api/models/role_object_permission.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::RoleObjectPermission` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::RoleObjectPermission`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'codename')
    self.codename = attributes[:'codename']
  else
    self.codename = nil
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  else
    self.model = nil
  end

  if attributes.key?(:'app_label')
    self.app_label = attributes[:'app_label']
  else
    self.app_label = nil
  end

  if attributes.key?(:'object_pk')
    self.object_pk = attributes[:'object_pk']
  else
    self.object_pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end
end

Instance Attribute Details

#app_labelObject

Returns the value of attribute app_label.



19
20
21
# File 'lib/authentik/api/models/role_object_permission.rb', line 19

def app_label
  @app_label
end

#codenameObject

Returns the value of attribute codename.



15
16
17
# File 'lib/authentik/api/models/role_object_permission.rb', line 15

def codename
  @codename
end

#idObject

Returns the value of attribute id.



13
14
15
# File 'lib/authentik/api/models/role_object_permission.rb', line 13

def id
  @id
end

#modelObject

Returns the value of attribute model.



17
18
19
# File 'lib/authentik/api/models/role_object_permission.rb', line 17

def model
  @model
end

#nameObject

Returns the value of attribute name.



23
24
25
# File 'lib/authentik/api/models/role_object_permission.rb', line 23

def name
  @name
end

#object_pkObject

Returns the value of attribute object_pk.



21
22
23
# File 'lib/authentik/api/models/role_object_permission.rb', line 21

def object_pk
  @object_pk
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/authentik/api/models/role_object_permission.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/authentik/api/models/role_object_permission.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
33
34
35
# File 'lib/authentik/api/models/role_object_permission.rb', line 26

def self.attribute_map
  {
    :'id' => :'id',
    :'codename' => :'codename',
    :'model' => :'model',
    :'app_label' => :'app_label',
    :'object_pk' => :'object_pk',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/authentik/api/models/role_object_permission.rb', line 251

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/authentik/api/models/role_object_permission.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
56
57
# File 'lib/authentik/api/models/role_object_permission.rb', line 48

def self.openapi_types
  {
    :'id' => :'Integer',
    :'codename' => :'String',
    :'model' => :'String',
    :'app_label' => :'String',
    :'object_pk' => :'String',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



225
226
227
228
229
230
231
232
233
234
# File 'lib/authentik/api/models/role_object_permission.rb', line 225

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      codename == o.codename &&
      model == o.model &&
      app_label == o.app_label &&
      object_pk == o.object_pk &&
      name == o.name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


238
239
240
# File 'lib/authentik/api/models/role_object_permission.rb', line 238

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



244
245
246
# File 'lib/authentik/api/models/role_object_permission.rb', line 244

def hash
  [id, codename, model, app_label, object_pk, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/authentik/api/models/role_object_permission.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @codename.nil?
    invalid_properties.push('invalid value for "codename", codename cannot be nil.')
  end

  if @model.nil?
    invalid_properties.push('invalid value for "model", model cannot be nil.')
  end

  if @app_label.nil?
    invalid_properties.push('invalid value for "app_label", app_label cannot be nil.')
  end

  if @object_pk.nil?
    invalid_properties.push('invalid value for "object_pk", object_pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/authentik/api/models/role_object_permission.rb', line 273

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
158
159
160
161
# File 'lib/authentik/api/models/role_object_permission.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @codename.nil?
  return false if @model.nil?
  return false if @app_label.nil?
  return false if @object_pk.nil?
  return false if @name.nil?
  true
end