Class: Authentik::Api::SCIMProvider
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::SCIMProvider
- Defined in:
- lib/authentik/api/models/scim_provider.rb
Overview
SCIMProvider Serializer
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
-
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
-
#auth_mode ⇒ Object
Returns the value of attribute auth_mode.
-
#auth_oauth ⇒ Object
OAuth Source used for authentication.
-
#auth_oauth_params ⇒ Object
Additional OAuth parameters, such as grant_type.
-
#compatibility_mode ⇒ Object
Alter authentik behavior for vendor-specific SCIM implementations.
-
#component ⇒ Object
Get object component so that we know how to edit the object.
-
#dry_run ⇒ Object
When enabled, provider will not modify or create objects in the remote system.
-
#exclude_users_service_account ⇒ Object
Returns the value of attribute exclude_users_service_account.
-
#group_filters ⇒ Object
Group filters used to define sync-scope for groups.
-
#meta_model_name ⇒ Object
Return internal model name.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pk ⇒ Object
Returns the value of attribute pk.
-
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
-
#property_mappings_group ⇒ Object
Property mappings used for group creation/updating.
-
#service_provider_config_cache_timeout ⇒ Object
Cache duration for ServiceProviderConfig responses.
-
#sync_page_size ⇒ Object
Controls the number of objects synced in a single task.
-
#sync_page_timeout ⇒ Object
Timeout for synchronization of a single page.
-
#token ⇒ Object
Authentication token.
-
#url ⇒ Object
Base URL to SCIM requests, usually ends in /v2.
-
#verbose_name ⇒ Object
Return object’s verbose_name.
-
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name.
-
#verify_certificates ⇒ Object
Returns the value of attribute verify_certificates.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SCIMProvider
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SCIMProvider
Initializes the object
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/authentik/api/models/scim_provider.rb', line 177 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SCIMProvider` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SCIMProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pk') self.pk = attributes[:'pk'] else self.pk = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'property_mappings') if (value = attributes[:'property_mappings']).is_a?(Array) self.property_mappings = value end end if attributes.key?(:'property_mappings_group') if (value = attributes[:'property_mappings_group']).is_a?(Array) self.property_mappings_group = value end end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'assigned_backchannel_application_slug') self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug'] else self.assigned_backchannel_application_slug = nil end if attributes.key?(:'assigned_backchannel_application_name') self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name'] else self.assigned_backchannel_application_name = nil end if attributes.key?(:'verbose_name') self.verbose_name = attributes[:'verbose_name'] else self.verbose_name = nil end if attributes.key?(:'verbose_name_plural') self.verbose_name_plural = attributes[:'verbose_name_plural'] else self.verbose_name_plural = nil end if attributes.key?(:'meta_model_name') self. = attributes[:'meta_model_name'] else self. = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'verify_certificates') self.verify_certificates = attributes[:'verify_certificates'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'auth_mode') self.auth_mode = attributes[:'auth_mode'] end if attributes.key?(:'auth_oauth') self.auth_oauth = attributes[:'auth_oauth'] end if attributes.key?(:'auth_oauth_params') if (value = attributes[:'auth_oauth_params']).is_a?(Hash) self.auth_oauth_params = value end end if attributes.key?(:'compatibility_mode') self.compatibility_mode = attributes[:'compatibility_mode'] end if attributes.key?(:'service_provider_config_cache_timeout') self.service_provider_config_cache_timeout = attributes[:'service_provider_config_cache_timeout'] end if attributes.key?(:'exclude_users_service_account') self.exclude_users_service_account = attributes[:'exclude_users_service_account'] end if attributes.key?(:'sync_page_size') self.sync_page_size = attributes[:'sync_page_size'] end if attributes.key?(:'sync_page_timeout') self.sync_page_timeout = attributes[:'sync_page_timeout'] end if attributes.key?(:'group_filters') if (value = attributes[:'group_filters']).is_a?(Array) self.group_filters = value end end if attributes.key?(:'dry_run') self.dry_run = attributes[:'dry_run'] end end |
Instance Attribute Details
#assigned_backchannel_application_name ⇒ Object
Application’s display Name.
29 30 31 |
# File 'lib/authentik/api/models/scim_provider.rb', line 29 def assigned_backchannel_application_name @assigned_backchannel_application_name end |
#assigned_backchannel_application_slug ⇒ Object
Internal application name, used in URLs.
26 27 28 |
# File 'lib/authentik/api/models/scim_provider.rb', line 26 def assigned_backchannel_application_slug @assigned_backchannel_application_slug end |
#auth_mode ⇒ Object
Returns the value of attribute auth_mode.
48 49 50 |
# File 'lib/authentik/api/models/scim_provider.rb', line 48 def auth_mode @auth_mode end |
#auth_oauth ⇒ Object
OAuth Source used for authentication
51 52 53 |
# File 'lib/authentik/api/models/scim_provider.rb', line 51 def auth_oauth @auth_oauth end |
#auth_oauth_params ⇒ Object
Additional OAuth parameters, such as grant_type
54 55 56 |
# File 'lib/authentik/api/models/scim_provider.rb', line 54 def auth_oauth_params @auth_oauth_params end |
#compatibility_mode ⇒ Object
Alter authentik behavior for vendor-specific SCIM implementations.
57 58 59 |
# File 'lib/authentik/api/models/scim_provider.rb', line 57 def compatibility_mode @compatibility_mode end |
#component ⇒ Object
Get object component so that we know how to edit the object
23 24 25 |
# File 'lib/authentik/api/models/scim_provider.rb', line 23 def component @component end |
#dry_run ⇒ Object
When enabled, provider will not modify or create objects in the remote system.
74 75 76 |
# File 'lib/authentik/api/models/scim_provider.rb', line 74 def dry_run @dry_run end |
#exclude_users_service_account ⇒ Object
Returns the value of attribute exclude_users_service_account.
62 63 64 |
# File 'lib/authentik/api/models/scim_provider.rb', line 62 def exclude_users_service_account @exclude_users_service_account end |
#group_filters ⇒ Object
Group filters used to define sync-scope for groups.
71 72 73 |
# File 'lib/authentik/api/models/scim_provider.rb', line 71 def group_filters @group_filters end |
#meta_model_name ⇒ Object
Return internal model name
38 39 40 |
# File 'lib/authentik/api/models/scim_provider.rb', line 38 def @meta_model_name end |
#name ⇒ Object
Returns the value of attribute name.
15 16 17 |
# File 'lib/authentik/api/models/scim_provider.rb', line 15 def name @name end |
#pk ⇒ Object
Returns the value of attribute pk.
13 14 15 |
# File 'lib/authentik/api/models/scim_provider.rb', line 13 def pk @pk end |
#property_mappings ⇒ Object
Returns the value of attribute property_mappings.
17 18 19 |
# File 'lib/authentik/api/models/scim_provider.rb', line 17 def property_mappings @property_mappings end |
#property_mappings_group ⇒ Object
Property mappings used for group creation/updating.
20 21 22 |
# File 'lib/authentik/api/models/scim_provider.rb', line 20 def property_mappings_group @property_mappings_group end |
#service_provider_config_cache_timeout ⇒ Object
Cache duration for ServiceProviderConfig responses. Set minutes=0 to disable.
60 61 62 |
# File 'lib/authentik/api/models/scim_provider.rb', line 60 def service_provider_config_cache_timeout @service_provider_config_cache_timeout end |
#sync_page_size ⇒ Object
Controls the number of objects synced in a single task
65 66 67 |
# File 'lib/authentik/api/models/scim_provider.rb', line 65 def sync_page_size @sync_page_size end |
#sync_page_timeout ⇒ Object
Timeout for synchronization of a single page
68 69 70 |
# File 'lib/authentik/api/models/scim_provider.rb', line 68 def sync_page_timeout @sync_page_timeout end |
#token ⇒ Object
Authentication token
46 47 48 |
# File 'lib/authentik/api/models/scim_provider.rb', line 46 def token @token end |
#url ⇒ Object
Base URL to SCIM requests, usually ends in /v2
41 42 43 |
# File 'lib/authentik/api/models/scim_provider.rb', line 41 def url @url end |
#verbose_name ⇒ Object
Return object’s verbose_name
32 33 34 |
# File 'lib/authentik/api/models/scim_provider.rb', line 32 def verbose_name @verbose_name end |
#verbose_name_plural ⇒ Object
Return object’s plural verbose_name
35 36 37 |
# File 'lib/authentik/api/models/scim_provider.rb', line 35 def verbose_name_plural @verbose_name_plural end |
#verify_certificates ⇒ Object
Returns the value of attribute verify_certificates.
43 44 45 |
# File 'lib/authentik/api/models/scim_provider.rb', line 43 def verify_certificates @verify_certificates end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
128 129 130 |
# File 'lib/authentik/api/models/scim_provider.rb', line 128 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
133 134 135 |
# File 'lib/authentik/api/models/scim_provider.rb', line 133 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/authentik/api/models/scim_provider.rb', line 99 def self.attribute_map { :'pk' => :'pk', :'name' => :'name', :'property_mappings' => :'property_mappings', :'property_mappings_group' => :'property_mappings_group', :'component' => :'component', :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name', :'verbose_name' => :'verbose_name', :'verbose_name_plural' => :'verbose_name_plural', :'meta_model_name' => :'meta_model_name', :'url' => :'url', :'verify_certificates' => :'verify_certificates', :'token' => :'token', :'auth_mode' => :'auth_mode', :'auth_oauth' => :'auth_oauth', :'auth_oauth_params' => :'auth_oauth_params', :'compatibility_mode' => :'compatibility_mode', :'service_provider_config_cache_timeout' => :'service_provider_config_cache_timeout', :'exclude_users_service_account' => :'exclude_users_service_account', :'sync_page_size' => :'sync_page_size', :'sync_page_timeout' => :'sync_page_timeout', :'group_filters' => :'group_filters', :'dry_run' => :'dry_run' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/authentik/api/models/scim_provider.rb', line 503 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
167 168 169 170 171 172 173 |
# File 'lib/authentik/api/models/scim_provider.rb', line 167 def self.openapi_nullable Set.new([ :'assigned_backchannel_application_slug', :'assigned_backchannel_application_name', :'auth_oauth', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/authentik/api/models/scim_provider.rb', line 138 def self.openapi_types { :'pk' => :'Integer', :'name' => :'String', :'property_mappings' => :'Array<String>', :'property_mappings_group' => :'Array<String>', :'component' => :'String', :'assigned_backchannel_application_slug' => :'String', :'assigned_backchannel_application_name' => :'String', :'verbose_name' => :'String', :'verbose_name_plural' => :'String', :'meta_model_name' => :'String', :'url' => :'String', :'verify_certificates' => :'Boolean', :'token' => :'String', :'auth_mode' => :'SCIMAuthenticationModeEnum', :'auth_oauth' => :'String', :'auth_oauth_params' => :'Hash<String, Object>', :'compatibility_mode' => :'CompatibilityModeEnum', :'service_provider_config_cache_timeout' => :'String', :'exclude_users_service_account' => :'Boolean', :'sync_page_size' => :'Integer', :'sync_page_timeout' => :'String', :'group_filters' => :'Array<String>', :'dry_run' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/authentik/api/models/scim_provider.rb', line 460 def ==(o) return true if self.equal?(o) self.class == o.class && pk == o.pk && name == o.name && property_mappings == o.property_mappings && property_mappings_group == o.property_mappings_group && component == o.component && assigned_backchannel_application_slug == o.assigned_backchannel_application_slug && assigned_backchannel_application_name == o.assigned_backchannel_application_name && verbose_name == o.verbose_name && verbose_name_plural == o.verbose_name_plural && == o. && url == o.url && verify_certificates == o.verify_certificates && token == o.token && auth_mode == o.auth_mode && auth_oauth == o.auth_oauth && auth_oauth_params == o.auth_oauth_params && compatibility_mode == o.compatibility_mode && service_provider_config_cache_timeout == o.service_provider_config_cache_timeout && exclude_users_service_account == o.exclude_users_service_account && sync_page_size == o.sync_page_size && sync_page_timeout == o.sync_page_timeout && group_filters == o.group_filters && dry_run == o.dry_run end |
#eql?(o) ⇒ Boolean
490 491 492 |
# File 'lib/authentik/api/models/scim_provider.rb', line 490 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
496 497 498 |
# File 'lib/authentik/api/models/scim_provider.rb', line 496 def hash [pk, name, property_mappings, property_mappings_group, component, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, , url, verify_certificates, token, auth_mode, auth_oauth, auth_oauth_params, compatibility_mode, service_provider_config_cache_timeout, exclude_users_service_account, sync_page_size, sync_page_timeout, group_filters, dry_run].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/authentik/api/models/scim_provider.rb', line 312 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @pk.nil? invalid_properties.push('invalid value for "pk", pk cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @verbose_name.nil? invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.') end if @verbose_name_plural.nil? invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.') end if @meta_model_name.nil? invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if !@sync_page_size.nil? && @sync_page_size > 2147483647 invalid_properties.push('invalid value for "sync_page_size", must be smaller than or equal to 2147483647.') end if !@sync_page_size.nil? && @sync_page_size < 1 invalid_properties.push('invalid value for "sync_page_size", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
525 526 527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/authentik/api/models/scim_provider.rb', line 525 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/authentik/api/models/scim_provider.rb', line 356 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @pk.nil? return false if @name.nil? return false if @component.nil? return false if @verbose_name.nil? return false if @verbose_name_plural.nil? return false if @meta_model_name.nil? return false if @url.nil? return false if !@sync_page_size.nil? && @sync_page_size > 2147483647 return false if !@sync_page_size.nil? && @sync_page_size < 1 true end |