Class: Authentik::Api::SSFProvider

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/ssf_provider.rb

Overview

SSFProvider Serializer

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SSFProvider

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/authentik/api/models/ssf_provider.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SSFProvider` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SSFProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'signing_key')
    self.signing_key = attributes[:'signing_key']
  else
    self.signing_key = nil
  end

  if attributes.key?(:'token_obj')
    self.token_obj = attributes[:'token_obj']
  else
    self.token_obj = nil
  end

  if attributes.key?(:'oidc_auth_providers')
    if (value = attributes[:'oidc_auth_providers']).is_a?(Array)
      self.oidc_auth_providers = value
    end
  end

  if attributes.key?(:'ssf_url')
    self.ssf_url = attributes[:'ssf_url']
  else
    self.ssf_url = nil
  end

  if attributes.key?(:'event_retention')
    self.event_retention = attributes[:'event_retention']
  end
end

Instance Attribute Details

#componentObject

Get object component so that we know how to edit the object



18
19
20
# File 'lib/authentik/api/models/ssf_provider.rb', line 18

def component
  @component
end

#event_retentionObject

Returns the value of attribute event_retention.



38
39
40
# File 'lib/authentik/api/models/ssf_provider.rb', line 38

def event_retention
  @event_retention
end

#meta_model_nameObject

Return internal model name



27
28
29
# File 'lib/authentik/api/models/ssf_provider.rb', line 27

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/ssf_provider.rb', line 15

def name
  @name
end

#oidc_auth_providersObject

Returns the value of attribute oidc_auth_providers.



34
35
36
# File 'lib/authentik/api/models/ssf_provider.rb', line 34

def oidc_auth_providers
  @oidc_auth_providers
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/ssf_provider.rb', line 13

def pk
  @pk
end

#signing_keyObject

Key used to sign the SSF Events.



30
31
32
# File 'lib/authentik/api/models/ssf_provider.rb', line 30

def signing_key
  @signing_key
end

#ssf_urlObject

Returns the value of attribute ssf_url.



36
37
38
# File 'lib/authentik/api/models/ssf_provider.rb', line 36

def ssf_url
  @ssf_url
end

#token_objObject

Returns the value of attribute token_obj.



32
33
34
# File 'lib/authentik/api/models/ssf_provider.rb', line 32

def token_obj
  @token_obj
end

#verbose_nameObject

Return object’s verbose_name



21
22
23
# File 'lib/authentik/api/models/ssf_provider.rb', line 21

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



24
25
26
# File 'lib/authentik/api/models/ssf_provider.rb', line 24

def verbose_name_plural
  @verbose_name_plural
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/authentik/api/models/ssf_provider.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/authentik/api/models/ssf_provider.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/authentik/api/models/ssf_provider.rb', line 41

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'component' => :'component',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'signing_key' => :'signing_key',
    :'token_obj' => :'token_obj',
    :'oidc_auth_providers' => :'oidc_auth_providers',
    :'ssf_url' => :'ssf_url',
    :'event_retention' => :'event_retention'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/authentik/api/models/ssf_provider.rb', line 340

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
89
# File 'lib/authentik/api/models/ssf_provider.rb', line 85

def self.openapi_nullable
  Set.new([
    :'ssf_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/authentik/api/models/ssf_provider.rb', line 68

def self.openapi_types
  {
    :'pk' => :'Integer',
    :'name' => :'String',
    :'component' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'signing_key' => :'String',
    :'token_obj' => :'Token',
    :'oidc_auth_providers' => :'Array<Integer>',
    :'ssf_url' => :'String',
    :'event_retention' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/authentik/api/models/ssf_provider.rb', line 309

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      component == o.component &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      signing_key == o.signing_key &&
      token_obj == o.token_obj &&
      oidc_auth_providers == o.oidc_auth_providers &&
      ssf_url == o.ssf_url &&
      event_retention == o.event_retention
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


327
328
329
# File 'lib/authentik/api/models/ssf_provider.rb', line 327

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



333
334
335
# File 'lib/authentik/api/models/ssf_provider.rb', line 333

def hash
  [pk, name, component, verbose_name, verbose_name_plural, meta_model_name, signing_key, token_obj, oidc_auth_providers, ssf_url, event_retention].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/authentik/api/models/ssf_provider.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @signing_key.nil?
    invalid_properties.push('invalid value for "signing_key", signing_key cannot be nil.')
  end

  if @token_obj.nil?
    invalid_properties.push('invalid value for "token_obj", token_obj cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/authentik/api/models/ssf_provider.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/authentik/api/models/ssf_provider.rb', line 214

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @signing_key.nil?
  return false if @token_obj.nil?
  true
end