Class: Authentik::Api::SSFStream

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/ssf_stream.rb

Overview

SSFStream Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SSFStream

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/authentik/api/models/ssf_stream.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::SSFStream` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::SSFStream`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'provider_obj')
    self.provider_obj = attributes[:'provider_obj']
  else
    self.provider_obj = nil
  end

  if attributes.key?(:'delivery_method')
    self.delivery_method = attributes[:'delivery_method']
  else
    self.delivery_method = nil
  end

  if attributes.key?(:'endpoint_url')
    self.endpoint_url = attributes[:'endpoint_url']
  end

  if attributes.key?(:'events_requested')
    if (value = attributes[:'events_requested']).is_a?(Array)
      self.events_requested = value
    end
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  else
    self.format = nil
  end

  if attributes.key?(:'aud')
    if (value = attributes[:'aud']).is_a?(Array)
      self.aud = value
    end
  end

  if attributes.key?(:'iss')
    self.iss = attributes[:'iss']
  else
    self.iss = nil
  end
end

Instance Attribute Details

#audObject

Returns the value of attribute aud.



27
28
29
# File 'lib/authentik/api/models/ssf_stream.rb', line 27

def aud
  @aud
end

#delivery_methodObject

Returns the value of attribute delivery_method.



19
20
21
# File 'lib/authentik/api/models/ssf_stream.rb', line 19

def delivery_method
  @delivery_method
end

#endpoint_urlObject

Returns the value of attribute endpoint_url.



21
22
23
# File 'lib/authentik/api/models/ssf_stream.rb', line 21

def endpoint_url
  @endpoint_url
end

#events_requestedObject

Returns the value of attribute events_requested.



23
24
25
# File 'lib/authentik/api/models/ssf_stream.rb', line 23

def events_requested
  @events_requested
end

#formatObject

Returns the value of attribute format.



25
26
27
# File 'lib/authentik/api/models/ssf_stream.rb', line 25

def format
  @format
end

#issObject

Returns the value of attribute iss.



29
30
31
# File 'lib/authentik/api/models/ssf_stream.rb', line 29

def iss
  @iss
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/ssf_stream.rb', line 13

def pk
  @pk
end

#providerObject

Returns the value of attribute provider.



15
16
17
# File 'lib/authentik/api/models/ssf_stream.rb', line 15

def provider
  @provider
end

#provider_objObject

Returns the value of attribute provider_obj.



17
18
19
# File 'lib/authentik/api/models/ssf_stream.rb', line 17

def provider_obj
  @provider_obj
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/authentik/api/models/ssf_stream.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/authentik/api/models/ssf_stream.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/authentik/api/models/ssf_stream.rb', line 54

def self.attribute_map
  {
    :'pk' => :'pk',
    :'provider' => :'provider',
    :'provider_obj' => :'provider_obj',
    :'delivery_method' => :'delivery_method',
    :'endpoint_url' => :'endpoint_url',
    :'events_requested' => :'events_requested',
    :'format' => :'format',
    :'aud' => :'aud',
    :'iss' => :'iss'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/authentik/api/models/ssf_stream.rb', line 305

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
# File 'lib/authentik/api/models/ssf_stream.rb', line 94

def self.openapi_nullable
  Set.new([
    :'endpoint_url',
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/authentik/api/models/ssf_stream.rb', line 79

def self.openapi_types
  {
    :'pk' => :'String',
    :'provider' => :'Integer',
    :'provider_obj' => :'SSFProvider',
    :'delivery_method' => :'DeliveryMethodEnum',
    :'endpoint_url' => :'String',
    :'events_requested' => :'Array<EventsRequestedEnum>',
    :'format' => :'String',
    :'aud' => :'Array<String>',
    :'iss' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/authentik/api/models/ssf_stream.rb', line 276

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      provider == o.provider &&
      provider_obj == o.provider_obj &&
      delivery_method == o.delivery_method &&
      endpoint_url == o.endpoint_url &&
      events_requested == o.events_requested &&
      format == o.format &&
      aud == o.aud &&
      iss == o.iss
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


292
293
294
# File 'lib/authentik/api/models/ssf_stream.rb', line 292

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



298
299
300
# File 'lib/authentik/api/models/ssf_stream.rb', line 298

def hash
  [pk, provider, provider_obj, delivery_method, endpoint_url, events_requested, format, aud, iss].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/authentik/api/models/ssf_stream.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if @provider_obj.nil?
    invalid_properties.push('invalid value for "provider_obj", provider_obj cannot be nil.')
  end

  if @delivery_method.nil?
    invalid_properties.push('invalid value for "delivery_method", delivery_method cannot be nil.')
  end

  if @format.nil?
    invalid_properties.push('invalid value for "format", format cannot be nil.')
  end

  if @iss.nil?
    invalid_properties.push('invalid value for "iss", iss cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/authentik/api/models/ssf_stream.rb', line 327

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
# File 'lib/authentik/api/models/ssf_stream.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @provider.nil?
  return false if @provider_obj.nil?
  return false if @delivery_method.nil?
  return false if @format.nil?
  return false if @iss.nil?
  true
end