Class: Authentik::Api::TokenRequest

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/token_request.rb

Overview

Token Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TokenRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/authentik/api/models/token_request.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::TokenRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::TokenRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'managed')
    self.managed = attributes[:'managed']
  end

  if attributes.key?(:'identifier')
    self.identifier = attributes[:'identifier']
  else
    self.identifier = nil
  end

  if attributes.key?(:'intent')
    self.intent = attributes[:'intent']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'expires')
    self.expires = attributes[:'expires']
  end

  if attributes.key?(:'expiring')
    self.expiring = attributes[:'expiring']
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/authentik/api/models/token_request.rb', line 22

def description
  @description
end

#expiresObject

Returns the value of attribute expires.



24
25
26
# File 'lib/authentik/api/models/token_request.rb', line 24

def expires
  @expires
end

#expiringObject

Returns the value of attribute expiring.



26
27
28
# File 'lib/authentik/api/models/token_request.rb', line 26

def expiring
  @expiring
end

#identifierObject

Returns the value of attribute identifier.



16
17
18
# File 'lib/authentik/api/models/token_request.rb', line 16

def identifier
  @identifier
end

#intentObject

Returns the value of attribute intent.



18
19
20
# File 'lib/authentik/api/models/token_request.rb', line 18

def intent
  @intent
end

#managedObject

Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.



14
15
16
# File 'lib/authentik/api/models/token_request.rb', line 14

def managed
  @managed
end

#userObject

Returns the value of attribute user.



20
21
22
# File 'lib/authentik/api/models/token_request.rb', line 20

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/authentik/api/models/token_request.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/authentik/api/models/token_request.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/authentik/api/models/token_request.rb', line 51

def self.attribute_map
  {
    :'managed' => :'managed',
    :'identifier' => :'identifier',
    :'intent' => :'intent',
    :'user' => :'user',
    :'description' => :'description',
    :'expires' => :'expires',
    :'expiring' => :'expiring'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/authentik/api/models/token_request.rb', line 244

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
91
92
# File 'lib/authentik/api/models/token_request.rb', line 87

def self.openapi_nullable
  Set.new([
    :'managed',
    :'expires',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
# File 'lib/authentik/api/models/token_request.rb', line 74

def self.openapi_types
  {
    :'managed' => :'String',
    :'identifier' => :'String',
    :'intent' => :'IntentEnum',
    :'user' => :'Integer',
    :'description' => :'String',
    :'expires' => :'Time',
    :'expiring' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
# File 'lib/authentik/api/models/token_request.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      managed == o.managed &&
      identifier == o.identifier &&
      intent == o.intent &&
      user == o.user &&
      description == o.description &&
      expires == o.expires &&
      expiring == o.expiring
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/authentik/api/models/token_request.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/authentik/api/models/token_request.rb', line 237

def hash
  [managed, identifier, intent, user, description, expires, expiring].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/authentik/api/models/token_request.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@managed.nil? && @managed.to_s.length < 1
    invalid_properties.push('invalid value for "managed", the character length must be greater than or equal to 1.')
  end

  if @identifier.nil?
    invalid_properties.push('invalid value for "identifier", identifier cannot be nil.')
  end

  if @identifier.to_s.length > 255
    invalid_properties.push('invalid value for "identifier", the character length must be smaller than or equal to 255.')
  end

  if @identifier.to_s.length < 1
    invalid_properties.push('invalid value for "identifier", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^[-a-zA-Z0-9_]+$/)
  if @identifier !~ pattern
    invalid_properties.push("invalid value for \"identifier\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/authentik/api/models/token_request.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



172
173
174
175
176
177
178
179
180
# File 'lib/authentik/api/models/token_request.rb', line 172

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@managed.nil? && @managed.to_s.length < 1
  return false if @identifier.nil?
  return false if @identifier.to_s.length > 255
  return false if @identifier.to_s.length < 1
  return false if @identifier !~ Regexp.new(/^[-a-zA-Z0-9_]+$/)
  true
end