Class: Authentik::Api::UserOffboarding
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Authentik::Api::UserOffboarding
- Defined in:
- lib/authentik/api/models/user_offboarding.rb
Overview
Mixin to validate that a valid enterprise license exists before allowing to save the object
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action ⇒ Object
Returns the value of attribute action.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#created_by_obj ⇒ Object
Returns the value of attribute created_by_obj.
-
#executed_at ⇒ Object
Returns the value of attribute executed_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#revoke_sessions ⇒ Object
Revoke all of the user's sessions when offboarding.
-
#revoke_tokens ⇒ Object
Revoke all of the user's tokens when offboarding.
-
#scheduled_at ⇒ Object
Absolute time at which the offboarding action is executed.
-
#status ⇒ Object
Returns the value of attribute status.
-
#user ⇒ Object
Returns the value of attribute user.
-
#user_obj ⇒ Object
Returns the value of attribute user_obj.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserOffboarding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserOffboarding
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UserOffboarding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UserOffboarding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'user') self.user = attributes[:'user'] else self.user = nil end if attributes.key?(:'user_obj') self.user_obj = attributes[:'user_obj'] else self.user_obj = nil end if attributes.key?(:'scheduled_at') self.scheduled_at = attributes[:'scheduled_at'] else self.scheduled_at = nil end if attributes.key?(:'action') self.action = attributes[:'action'] end if attributes.key?(:'revoke_sessions') self.revoke_sessions = attributes[:'revoke_sessions'] end if attributes.key?(:'revoke_tokens') self.revoke_tokens = attributes[:'revoke_tokens'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'created_by_obj') self.created_by_obj = attributes[:'created_by_obj'] else self.created_by_obj = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'executed_at') self.executed_at = attributes[:'executed_at'] else self.executed_at = nil end end |
Instance Attribute Details
#action ⇒ Object
Returns the value of attribute action.
22 23 24 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 22 def action @action end |
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 34 def created_at @created_at end |
#created_by_obj ⇒ Object
Returns the value of attribute created_by_obj.
32 33 34 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 32 def created_by_obj @created_by_obj end |
#executed_at ⇒ Object
Returns the value of attribute executed_at.
36 37 38 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 36 def executed_at @executed_at end |
#id ⇒ Object
Returns the value of attribute id.
13 14 15 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 13 def id @id end |
#revoke_sessions ⇒ Object
Revoke all of the user's sessions when offboarding.
25 26 27 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 25 def revoke_sessions @revoke_sessions end |
#revoke_tokens ⇒ Object
Revoke all of the user's tokens when offboarding.
28 29 30 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 28 def revoke_tokens @revoke_tokens end |
#scheduled_at ⇒ Object
Absolute time at which the offboarding action is executed.
20 21 22 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 20 def scheduled_at @scheduled_at end |
#status ⇒ Object
Returns the value of attribute status.
30 31 32 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 30 def status @status end |
#user ⇒ Object
Returns the value of attribute user.
15 16 17 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 15 def user @user end |
#user_obj ⇒ Object
Returns the value of attribute user_obj.
17 18 19 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 17 def user_obj @user_obj end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 61 def self.attribute_map { :'id' => :'id', :'user' => :'user', :'user_obj' => :'user_obj', :'scheduled_at' => :'scheduled_at', :'action' => :'action', :'revoke_sessions' => :'revoke_sessions', :'revoke_tokens' => :'revoke_tokens', :'status' => :'status', :'created_by_obj' => :'created_by_obj', :'created_at' => :'created_at', :'executed_at' => :'executed_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 341 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 109 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 105 def self.openapi_nullable Set.new([ :'executed_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 88 def self.openapi_types { :'id' => :'String', :'user' => :'Integer', :'user_obj' => :'PartialUser', :'scheduled_at' => :'Time', :'action' => :'OffboardingActionEnum', :'revoke_sessions' => :'Boolean', :'revoke_tokens' => :'Boolean', :'status' => :'OffboardingStatusEnum', :'created_by_obj' => :'PartialUser', :'created_at' => :'Time', :'executed_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 310 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && user == o.user && user_obj == o.user_obj && scheduled_at == o.scheduled_at && action == o.action && revoke_sessions == o.revoke_sessions && revoke_tokens == o.revoke_tokens && status == o.status && created_by_obj == o.created_by_obj && created_at == o.created_at && executed_at == o.executed_at end |
#eql?(o) ⇒ Boolean
328 329 330 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 328 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
334 335 336 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 334 def hash [id, user, user_obj, scheduled_at, action, revoke_sessions, revoke_tokens, status, created_by_obj, created_at, executed_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 190 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @user.nil? invalid_properties.push('invalid value for "user", user cannot be nil.') end if @user_obj.nil? invalid_properties.push('invalid value for "user_obj", user_obj cannot be nil.') end if @scheduled_at.nil? invalid_properties.push('invalid value for "scheduled_at", scheduled_at cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @created_by_obj.nil? invalid_properties.push('invalid value for "created_by_obj", created_by_obj cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 363 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/authentik/api/models/user_offboarding.rb', line 226 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @user.nil? return false if @user_obj.nil? return false if @scheduled_at.nil? return false if @status.nil? return false if @created_by_obj.nil? return false if @created_at.nil? true end |