Class: Authentik::Api::UserServiceAccountResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/authentik/api/models/user_service_account_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserServiceAccountResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/authentik/api/models/user_service_account_response.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::UserServiceAccountResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::UserServiceAccountResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  else
    self.username = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  else
    self.token = nil
  end

  if attributes.key?(:'user_uid')
    self.user_uid = attributes[:'user_uid']
  else
    self.user_uid = nil
  end

  if attributes.key?(:'user_pk')
    self.user_pk = attributes[:'user_pk']
  else
    self.user_pk = nil
  end

  if attributes.key?(:'group_pk')
    self.group_pk = attributes[:'group_pk']
  end
end

Instance Attribute Details

#group_pkObject

Returns the value of attribute group_pk.



20
21
22
# File 'lib/authentik/api/models/user_service_account_response.rb', line 20

def group_pk
  @group_pk
end

#tokenObject

Returns the value of attribute token.



14
15
16
# File 'lib/authentik/api/models/user_service_account_response.rb', line 14

def token
  @token
end

#user_pkObject

Returns the value of attribute user_pk.



18
19
20
# File 'lib/authentik/api/models/user_service_account_response.rb', line 18

def user_pk
  @user_pk
end

#user_uidObject

Returns the value of attribute user_uid.



16
17
18
# File 'lib/authentik/api/models/user_service_account_response.rb', line 16

def user_uid
  @user_uid
end

#usernameObject

Returns the value of attribute username.



12
13
14
# File 'lib/authentik/api/models/user_service_account_response.rb', line 12

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/authentik/api/models/user_service_account_response.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/authentik/api/models/user_service_account_response.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
28
29
30
31
# File 'lib/authentik/api/models/user_service_account_response.rb', line 23

def self.attribute_map
  {
    :'username' => :'username',
    :'token' => :'token',
    :'user_uid' => :'user_uid',
    :'user_pk' => :'user_pk',
    :'group_pk' => :'group_pk'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/authentik/api/models/user_service_account_response.rb', line 207

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



55
56
57
58
# File 'lib/authentik/api/models/user_service_account_response.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
# File 'lib/authentik/api/models/user_service_account_response.rb', line 44

def self.openapi_types
  {
    :'username' => :'String',
    :'token' => :'String',
    :'user_uid' => :'String',
    :'user_pk' => :'Integer',
    :'group_pk' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
190
# File 'lib/authentik/api/models/user_service_account_response.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      username == o.username &&
      token == o.token &&
      user_uid == o.user_uid &&
      user_pk == o.user_pk &&
      group_pk == o.group_pk
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/authentik/api/models/user_service_account_response.rb', line 194

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



200
201
202
# File 'lib/authentik/api/models/user_service_account_response.rb', line 200

def hash
  [username, token, user_uid, user_pk, group_pk].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/authentik/api/models/user_service_account_response.rb', line 107

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  if @token.nil?
    invalid_properties.push('invalid value for "token", token cannot be nil.')
  end

  if @user_uid.nil?
    invalid_properties.push('invalid value for "user_uid", user_uid cannot be nil.')
  end

  if @user_pk.nil?
    invalid_properties.push('invalid value for "user_pk", user_pk cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/authentik/api/models/user_service_account_response.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
137
138
# File 'lib/authentik/api/models/user_service_account_response.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @username.nil?
  return false if @token.nil?
  return false if @user_uid.nil?
  return false if @user_pk.nil?
  true
end