Class: Authentik::Api::WSFederationProvider

Inherits:
ApiModelBase show all
Defined in:
lib/authentik/api/models/ws_federation_provider.rb

Overview

WSFederationProvider Serializer

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WSFederationProvider

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 214

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Authentik::Api::WSFederationProvider` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Authentik::Api::WSFederationProvider`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pk')
    self.pk = attributes[:'pk']
  else
    self.pk = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'authentication_flow')
    self.authentication_flow = attributes[:'authentication_flow']
  end

  if attributes.key?(:'authorization_flow')
    self.authorization_flow = attributes[:'authorization_flow']
  else
    self.authorization_flow = nil
  end

  if attributes.key?(:'invalidation_flow')
    self.invalidation_flow = attributes[:'invalidation_flow']
  else
    self.invalidation_flow = nil
  end

  if attributes.key?(:'property_mappings')
    if (value = attributes[:'property_mappings']).is_a?(Array)
      self.property_mappings = value
    end
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  else
    self.component = nil
  end

  if attributes.key?(:'assigned_application_slug')
    self.assigned_application_slug = attributes[:'assigned_application_slug']
  else
    self.assigned_application_slug = nil
  end

  if attributes.key?(:'assigned_application_name')
    self.assigned_application_name = attributes[:'assigned_application_name']
  else
    self.assigned_application_name = nil
  end

  if attributes.key?(:'assigned_backchannel_application_slug')
    self.assigned_backchannel_application_slug = attributes[:'assigned_backchannel_application_slug']
  else
    self.assigned_backchannel_application_slug = nil
  end

  if attributes.key?(:'assigned_backchannel_application_name')
    self.assigned_backchannel_application_name = attributes[:'assigned_backchannel_application_name']
  else
    self.assigned_backchannel_application_name = nil
  end

  if attributes.key?(:'verbose_name')
    self.verbose_name = attributes[:'verbose_name']
  else
    self.verbose_name = nil
  end

  if attributes.key?(:'verbose_name_plural')
    self.verbose_name_plural = attributes[:'verbose_name_plural']
  else
    self.verbose_name_plural = nil
  end

  if attributes.key?(:'meta_model_name')
    self.meta_model_name = attributes[:'meta_model_name']
  else
    self.meta_model_name = nil
  end

  if attributes.key?(:'reply_url')
    self.reply_url = attributes[:'reply_url']
  else
    self.reply_url = nil
  end

  if attributes.key?(:'wtrealm')
    self.wtrealm = attributes[:'wtrealm']
  else
    self.wtrealm = nil
  end

  if attributes.key?(:'assertion_valid_not_before')
    self.assertion_valid_not_before = attributes[:'assertion_valid_not_before']
  end

  if attributes.key?(:'assertion_valid_not_on_or_after')
    self.assertion_valid_not_on_or_after = attributes[:'assertion_valid_not_on_or_after']
  end

  if attributes.key?(:'session_valid_not_on_or_after')
    self.session_valid_not_on_or_after = attributes[:'session_valid_not_on_or_after']
  end

  if attributes.key?(:'name_id_mapping')
    self.name_id_mapping = attributes[:'name_id_mapping']
  end

  if attributes.key?(:'authn_context_class_ref_mapping')
    self.authn_context_class_ref_mapping = attributes[:'authn_context_class_ref_mapping']
  end

  if attributes.key?(:'digest_algorithm')
    self.digest_algorithm = attributes[:'digest_algorithm']
  end

  if attributes.key?(:'signature_algorithm')
    self.signature_algorithm = attributes[:'signature_algorithm']
  end

  if attributes.key?(:'signing_kp')
    self.signing_kp = attributes[:'signing_kp']
  end

  if attributes.key?(:'encryption_kp')
    self.encryption_kp = attributes[:'encryption_kp']
  end

  if attributes.key?(:'sign_assertion')
    self.sign_assertion = attributes[:'sign_assertion']
  end

  if attributes.key?(:'sign_logout_request')
    self.sign_logout_request = attributes[:'sign_logout_request']
  end

  if attributes.key?(:'default_name_id_policy')
    self.default_name_id_policy = attributes[:'default_name_id_policy']
  end

  if attributes.key?(:'url_download_metadata')
    self. = attributes[:'url_download_metadata']
  else
    self. = nil
  end

  if attributes.key?(:'url_wsfed')
    self.url_wsfed = attributes[:'url_wsfed']
  else
    self.url_wsfed = nil
  end
end

Instance Attribute Details

#assertion_valid_not_beforeObject

Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).



57
58
59
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 57

def assertion_valid_not_before
  @assertion_valid_not_before
end

#assertion_valid_not_on_or_afterObject

Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).



60
61
62
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 60

def assertion_valid_not_on_or_after
  @assertion_valid_not_on_or_after
end

#assigned_application_nameObject

Application’s display Name.



35
36
37
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 35

def assigned_application_name
  @assigned_application_name
end

#assigned_application_slugObject

Internal application name, used in URLs.



32
33
34
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 32

def assigned_application_slug
  @assigned_application_slug
end

#assigned_backchannel_application_nameObject

Application’s display Name.



41
42
43
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 41

def assigned_backchannel_application_name
  @assigned_backchannel_application_name
end

#assigned_backchannel_application_slugObject

Internal application name, used in URLs.



38
39
40
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 38

def assigned_backchannel_application_slug
  @assigned_backchannel_application_slug
end

#authentication_flowObject

Flow used for authentication when the associated application is accessed by an un-authenticated user.



18
19
20
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 18

def authentication_flow
  @authentication_flow
end

#authn_context_class_ref_mappingObject

Configure how the AuthnContextClassRef value will be created. When left empty, the AuthnContextClassRef will be set based on which authentication methods the user used to authenticate.



69
70
71
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 69

def authn_context_class_ref_mapping
  @authn_context_class_ref_mapping
end

#authorization_flowObject

Flow used when authorizing this provider.



21
22
23
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 21

def authorization_flow
  @authorization_flow
end

#componentObject

Get object component so that we know how to edit the object



29
30
31
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 29

def component
  @component
end

#default_name_id_policyObject

Returns the value of attribute default_name_id_policy.



85
86
87
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 85

def default_name_id_policy
  @default_name_id_policy
end

#digest_algorithmObject

Returns the value of attribute digest_algorithm.



71
72
73
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 71

def digest_algorithm
  @digest_algorithm
end

#encryption_kpObject

When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.



79
80
81
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 79

def encryption_kp
  @encryption_kp
end

#invalidation_flowObject

Flow used ending the session from a provider.



24
25
26
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 24

def invalidation_flow
  @invalidation_flow
end

#meta_model_nameObject

Return internal model name



50
51
52
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 50

def meta_model_name
  @meta_model_name
end

#nameObject

Returns the value of attribute name.



15
16
17
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 15

def name
  @name
end

#name_id_mappingObject

Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be considered



66
67
68
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 66

def name_id_mapping
  @name_id_mapping
end

#pkObject

Returns the value of attribute pk.



13
14
15
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 13

def pk
  @pk
end

#property_mappingsObject

Returns the value of attribute property_mappings.



26
27
28
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 26

def property_mappings
  @property_mappings
end

#reply_urlObject

Returns the value of attribute reply_url.



52
53
54
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 52

def reply_url
  @reply_url
end

#session_valid_not_on_or_afterObject

Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).



63
64
65
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 63

def session_valid_not_on_or_after
  @session_valid_not_on_or_after
end

#sign_assertionObject

Returns the value of attribute sign_assertion.



81
82
83
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 81

def sign_assertion
  @sign_assertion
end

#sign_logout_requestObject

Returns the value of attribute sign_logout_request.



83
84
85
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 83

def sign_logout_request
  @sign_logout_request
end

#signature_algorithmObject

Returns the value of attribute signature_algorithm.



73
74
75
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 73

def signature_algorithm
  @signature_algorithm
end

#signing_kpObject

Keypair used to sign outgoing Responses going to the Service Provider.



76
77
78
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 76

def signing_kp
  @signing_kp
end

#url_download_metadataObject

Get metadata download URL



88
89
90
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 88

def 
  @url_download_metadata
end

#url_wsfedObject

Get WS-Fed url



91
92
93
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 91

def url_wsfed
  @url_wsfed
end

#verbose_nameObject

Return object’s verbose_name



44
45
46
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 44

def verbose_name
  @verbose_name
end

#verbose_name_pluralObject

Return object’s plural verbose_name



47
48
49
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 47

def verbose_name_plural
  @verbose_name_plural
end

#wtrealmObject

Returns the value of attribute wtrealm.



54
55
56
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 54

def wtrealm
  @wtrealm
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



152
153
154
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 152

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



157
158
159
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 157

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 116

def self.attribute_map
  {
    :'pk' => :'pk',
    :'name' => :'name',
    :'authentication_flow' => :'authentication_flow',
    :'authorization_flow' => :'authorization_flow',
    :'invalidation_flow' => :'invalidation_flow',
    :'property_mappings' => :'property_mappings',
    :'component' => :'component',
    :'assigned_application_slug' => :'assigned_application_slug',
    :'assigned_application_name' => :'assigned_application_name',
    :'assigned_backchannel_application_slug' => :'assigned_backchannel_application_slug',
    :'assigned_backchannel_application_name' => :'assigned_backchannel_application_name',
    :'verbose_name' => :'verbose_name',
    :'verbose_name_plural' => :'verbose_name_plural',
    :'meta_model_name' => :'meta_model_name',
    :'reply_url' => :'reply_url',
    :'wtrealm' => :'wtrealm',
    :'assertion_valid_not_before' => :'assertion_valid_not_before',
    :'assertion_valid_not_on_or_after' => :'assertion_valid_not_on_or_after',
    :'session_valid_not_on_or_after' => :'session_valid_not_on_or_after',
    :'name_id_mapping' => :'name_id_mapping',
    :'authn_context_class_ref_mapping' => :'authn_context_class_ref_mapping',
    :'digest_algorithm' => :'digest_algorithm',
    :'signature_algorithm' => :'signature_algorithm',
    :'signing_kp' => :'signing_kp',
    :'encryption_kp' => :'encryption_kp',
    :'sign_assertion' => :'sign_assertion',
    :'sign_logout_request' => :'sign_logout_request',
    :'default_name_id_policy' => :'default_name_id_policy',
    :'url_download_metadata' => :'url_download_metadata',
    :'url_wsfed' => :'url_wsfed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 630

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 198

def self.openapi_nullable
  Set.new([
    :'authentication_flow',
    :'assigned_application_slug',
    :'assigned_application_name',
    :'assigned_backchannel_application_slug',
    :'assigned_backchannel_application_name',
    :'name_id_mapping',
    :'authn_context_class_ref_mapping',
    :'signing_kp',
    :'encryption_kp',
  ])
end

.openapi_typesObject

Attribute type mapping.



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 162

def self.openapi_types
  {
    :'pk' => :'Integer',
    :'name' => :'String',
    :'authentication_flow' => :'String',
    :'authorization_flow' => :'String',
    :'invalidation_flow' => :'String',
    :'property_mappings' => :'Array<String>',
    :'component' => :'String',
    :'assigned_application_slug' => :'String',
    :'assigned_application_name' => :'String',
    :'assigned_backchannel_application_slug' => :'String',
    :'assigned_backchannel_application_name' => :'String',
    :'verbose_name' => :'String',
    :'verbose_name_plural' => :'String',
    :'meta_model_name' => :'String',
    :'reply_url' => :'String',
    :'wtrealm' => :'String',
    :'assertion_valid_not_before' => :'String',
    :'assertion_valid_not_on_or_after' => :'String',
    :'session_valid_not_on_or_after' => :'String',
    :'name_id_mapping' => :'String',
    :'authn_context_class_ref_mapping' => :'String',
    :'digest_algorithm' => :'DigestAlgorithmEnum',
    :'signature_algorithm' => :'SignatureAlgorithmEnum',
    :'signing_kp' => :'String',
    :'encryption_kp' => :'String',
    :'sign_assertion' => :'Boolean',
    :'sign_logout_request' => :'Boolean',
    :'default_name_id_policy' => :'SAMLNameIDPolicyEnum',
    :'url_download_metadata' => :'String',
    :'url_wsfed' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 580

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pk == o.pk &&
      name == o.name &&
      authentication_flow == o.authentication_flow &&
      authorization_flow == o.authorization_flow &&
      invalidation_flow == o.invalidation_flow &&
      property_mappings == o.property_mappings &&
      component == o.component &&
      assigned_application_slug == o.assigned_application_slug &&
      assigned_application_name == o.assigned_application_name &&
      assigned_backchannel_application_slug == o.assigned_backchannel_application_slug &&
      assigned_backchannel_application_name == o.assigned_backchannel_application_name &&
      verbose_name == o.verbose_name &&
      verbose_name_plural == o.verbose_name_plural &&
      meta_model_name == o.meta_model_name &&
      reply_url == o.reply_url &&
      wtrealm == o.wtrealm &&
      assertion_valid_not_before == o.assertion_valid_not_before &&
      assertion_valid_not_on_or_after == o.assertion_valid_not_on_or_after &&
      session_valid_not_on_or_after == o.session_valid_not_on_or_after &&
      name_id_mapping == o.name_id_mapping &&
      authn_context_class_ref_mapping == o.authn_context_class_ref_mapping &&
      digest_algorithm == o.digest_algorithm &&
      signature_algorithm == o.signature_algorithm &&
      signing_kp == o.signing_kp &&
      encryption_kp == o.encryption_kp &&
      sign_assertion == o.sign_assertion &&
      sign_logout_request == o.sign_logout_request &&
      default_name_id_policy == o.default_name_id_policy &&
       == o. &&
      url_wsfed == o.url_wsfed
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


617
618
619
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 617

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



623
624
625
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 623

def hash
  [pk, name, authentication_flow, authorization_flow, invalidation_flow, property_mappings, component, assigned_application_slug, assigned_application_name, assigned_backchannel_application_slug, assigned_backchannel_application_name, verbose_name, verbose_name_plural, meta_model_name, reply_url, wtrealm, assertion_valid_not_before, assertion_valid_not_on_or_after, session_valid_not_on_or_after, name_id_mapping, authn_context_class_ref_mapping, digest_algorithm, signature_algorithm, signing_kp, encryption_kp, sign_assertion, sign_logout_request, default_name_id_policy, , url_wsfed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 385

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pk.nil?
    invalid_properties.push('invalid value for "pk", pk cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @authorization_flow.nil?
    invalid_properties.push('invalid value for "authorization_flow", authorization_flow cannot be nil.')
  end

  if @invalidation_flow.nil?
    invalid_properties.push('invalid value for "invalidation_flow", invalidation_flow cannot be nil.')
  end

  if @component.nil?
    invalid_properties.push('invalid value for "component", component cannot be nil.')
  end

  if @verbose_name.nil?
    invalid_properties.push('invalid value for "verbose_name", verbose_name cannot be nil.')
  end

  if @verbose_name_plural.nil?
    invalid_properties.push('invalid value for "verbose_name_plural", verbose_name_plural cannot be nil.')
  end

  if @meta_model_name.nil?
    invalid_properties.push('invalid value for "meta_model_name", meta_model_name cannot be nil.')
  end

  if @reply_url.nil?
    invalid_properties.push('invalid value for "reply_url", reply_url cannot be nil.')
  end

  if @wtrealm.nil?
    invalid_properties.push('invalid value for "wtrealm", wtrealm cannot be nil.')
  end

  if @url_download_metadata.nil?
    invalid_properties.push('invalid value for "url_download_metadata", url_download_metadata cannot be nil.')
  end

  if @url_wsfed.nil?
    invalid_properties.push('invalid value for "url_wsfed", url_wsfed cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



652
653
654
655
656
657
658
659
660
661
662
663
664
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 652

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/authentik/api/models/ws_federation_provider.rb', line 441

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pk.nil?
  return false if @name.nil?
  return false if @authorization_flow.nil?
  return false if @invalidation_flow.nil?
  return false if @component.nil?
  return false if @verbose_name.nil?
  return false if @verbose_name_plural.nil?
  return false if @meta_model_name.nil?
  return false if @reply_url.nil?
  return false if @wtrealm.nil?
  return false if @url_download_metadata.nil?
  return false if @url_wsfed.nil?
  true
end